# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_reservation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!gcp/gcp_compute_reservation.proto\x12#oak9.tython.gcp.compute_reservation\x1a\x13shared/shared.proto\"M\n+ComputeReservationXShareSettingsXProjectMap\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x9d\x01\n ComputeReservationXShareSettings\x12\x12\n\nshare_type\x18\x01 \x01(\t\x12\x65\n\x0bproject_map\x18\x02 \x03(\x0b\x32P.oak9.tython.gcp.compute_reservation.ComputeReservationXShareSettingsXProjectMap\"\x82\x01\nKComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators\x12\x19\n\x11\x61\x63\x63\x65lerator_count\x18\x01 \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x02 \x01(\t\"n\nCComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds\x12\x14\n\x0c\x64isk_size_gb\x18\x01 \x01(\x01\x12\x11\n\tinterface\x18\x02 \x01(\t\"\xf8\x02\n9ComputeReservationXSpecificReservationXInstanceProperties\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x02 \x01(\t\x12\x8c\x01\n\x12guest_accelerators\x18\x03 \x03(\x0b\x32p.oak9.tython.gcp.compute_reservation.ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators\x12|\n\nlocal_ssds\x18\x04 \x03(\x0b\x32h.oak9.tython.gcp.compute_reservation.ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds\"\xca\x01\n&ComputeReservationXSpecificReservation\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x14\n\x0cin_use_count\x18\x02 \x01(\x01\x12{\n\x13instance_properties\x18\x03 \x01(\x0b\x32^.oak9.tython.gcp.compute_reservation.ComputeReservationXSpecificReservationXInstanceProperties\"M\n\x1b\x43omputeReservationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb3\x04\n\x12\x43omputeReservation\x12\x12\n\ncommitment\x18\x01 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12%\n\x1dspecific_reservation_required\x18\x08 \x01(\x08\x12\x0e\n\x06status\x18\t \x01(\t\x12\x0c\n\x04zone\x18\n \x01(\t\x12]\n\x0eshare_settings\x18\x0b \x01(\x0b\x32\x45.oak9.tython.gcp.compute_reservation.ComputeReservationXShareSettings\x12i\n\x14specific_reservation\x18\x0c \x01(\x0b\x32K.oak9.tython.gcp.compute_reservation.ComputeReservationXSpecificReservation\x12R\n\x08timeouts\x18\r \x01(\x0b\x32@.oak9.tython.gcp.compute_reservation.ComputeReservationXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_reservation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTERESERVATIONXSHARESETTINGSXPROJECTMAP._serialized_start=95
  _COMPUTERESERVATIONXSHARESETTINGSXPROJECTMAP._serialized_end=172
  _COMPUTERESERVATIONXSHARESETTINGS._serialized_start=175
  _COMPUTERESERVATIONXSHARESETTINGS._serialized_end=332
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIESXGUESTACCELERATORS._serialized_start=335
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIESXGUESTACCELERATORS._serialized_end=465
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIESXLOCALSSDS._serialized_start=467
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIESXLOCALSSDS._serialized_end=577
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIES._serialized_start=580
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIES._serialized_end=956
  _COMPUTERESERVATIONXSPECIFICRESERVATION._serialized_start=959
  _COMPUTERESERVATIONXSPECIFICRESERVATION._serialized_end=1161
  _COMPUTERESERVATIONXTIMEOUTS._serialized_start=1163
  _COMPUTERESERVATIONXTIMEOUTS._serialized_end=1240
  _COMPUTERESERVATION._serialized_start=1243
  _COMPUTERESERVATION._serialized_end=1806
# @@protoc_insertion_point(module_scope)
