# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_amazonmq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_amazonmq.proto\x12\x18oak9.tython.aws.amazonmq\x1a\x13shared/shared.proto\"n\n\x15\x42rokerConfigurationId\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08revision\x18\x02 \x01(\x05\x12\n\n\x02id\x18\x03 \x01(\t\"\x8f\x01\n\x17\x42rokerMaintenanceWindow\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x61y_of_week\x18\x02 \x01(\t\x12\x13\n\x0btime_of_day\x18\x03 \x01(\t\x12\x11\n\ttime_zone\x18\x04 \x01(\t\"t\n\x15\x42rokerInterBrokerCred\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\xe9\x02\n\x14\x42rokerServerMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x16\n\x0euser_role_name\x18\x03 \x01(\t\x12\x1c\n\x14user_search_matching\x18\x04 \x01(\t\x12\x11\n\trole_name\x18\x05 \x01(\t\x12\x11\n\tuser_base\x18\x06 \x01(\t\x12\x1b\n\x13user_search_subtree\x18\x07 \x01(\x08\x12\x1c\n\x14role_search_matching\x18\x08 \x01(\t\x12 \n\x18service_account_username\x18\t \x01(\t\x12\x11\n\trole_base\x18\n \x01(\t\x12 \n\x18service_account_password\x18\x0b \x01(\t\x12\x1b\n\x13role_search_subtree\x18\x0c \x01(\x08\"\xe3\x01\n\x12\x42rokerLdapMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x12inter_broker_creds\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.amazonmq.BrokerInterBrokerCred\x12G\n\x0fserver_metadata\x18\x03 \x01(\x0b\x32..oak9.tython.aws.amazonmq.BrokerServerMetadata\"\x91\x01\n\nBrokerUser\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06groups\x18\x03 \x03(\t\x12\x16\n\x0e\x63onsole_access\x18\x04 \x01(\x08\x12\x10\n\x08password\x18\x05 \x01(\t\"h\n\rBrokerLogList\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x61udit\x18\x02 \x01(\x08\x12\x0f\n\x07general\x18\x03 \x01(\x08\"\xed\x02\n\x18\x42rokerLdapServerMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x16\n\x0euser_role_name\x18\x03 \x01(\t\x12\x1c\n\x14user_search_matching\x18\x04 \x01(\t\x12\x11\n\trole_name\x18\x05 \x01(\t\x12\x11\n\tuser_base\x18\x06 \x01(\t\x12\x1b\n\x13user_search_subtree\x18\x07 \x01(\x08\x12\x1c\n\x14role_search_matching\x18\x08 \x01(\t\x12 \n\x18service_account_username\x18\t \x01(\t\x12\x11\n\trole_base\x18\n \x01(\t\x12 \n\x18service_account_password\x18\x0b \x01(\t\x12\x1b\n\x13role_search_subtree\x18\x0c \x01(\x08\"\x81\x01\n\x17\x42rokerEncryptionOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nkms_key_id\x18\x02 \x01(\t\x12\x19\n\x11use_aws_owned_key\x18\x03 \x01(\x08\"f\n\x0f\x42rokerTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x8a\x07\n\x06\x42roker\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fsecurity_groups\x18\x02 \x03(\t\x12\x14\n\x0cstorage_type\x18\x03 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x04 \x01(\t\x12\x46\n\rconfiguration\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.amazonmq.BrokerConfigurationId\x12\x1f\n\x17\x61uthentication_strategy\x18\x06 \x01(\t\x12X\n\x1dmaintenance_window_start_time\x18\x07 \x01(\x0b\x32\x31.oak9.tython.aws.amazonmq.BrokerMaintenanceWindow\x12\x43\n\rldap_metadata\x18\x08 \x01(\x0b\x32,.oak9.tython.aws.amazonmq.BrokerLdapMetadata\x12\x1a\n\x12host_instance_type\x18\t \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\n \x01(\x08\x12\x33\n\x05users\x18\x0b \x03(\x0b\x32$.oak9.tython.aws.amazonmq.BrokerUser\x12\x35\n\x04logs\x18\x0c \x01(\x0b\x32\'.oak9.tython.aws.amazonmq.BrokerLogList\x12\x12\n\nsubnet_ids\x18\r \x03(\t\x12\x13\n\x0b\x62roker_name\x18\x0e \x01(\t\x12P\n\x14ldap_server_metadata\x18\x0f \x01(\x0b\x32\x32.oak9.tython.aws.amazonmq.BrokerLdapServerMetadata\x12\x17\n\x0f\x64\x65ployment_mode\x18\x10 \x01(\t\x12\x13\n\x0b\x65ngine_type\x18\x11 \x01(\t\x12\x1b\n\x13publicly_accessible\x18\x12 \x01(\x08\x12M\n\x12\x65ncryption_options\x18\x13 \x01(\x0b\x32\x31.oak9.tython.aws.amazonmq.BrokerEncryptionOptions\x12\x37\n\x04tags\x18\x14 \x03(\x0b\x32).oak9.tython.aws.amazonmq.BrokerTagsEntry\"\xd3\x01\n\x08\x41mazonMQ\x12\x30\n\x06\x62roker\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.amazonmq.Broker\x12>\n\rconfiguration\x18\x02 \x03(\x0b\x32\'.oak9.tython.aws.amazonmq.Configuration\x12U\n\x19\x63onfiguration_association\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.amazonmq.ConfigurationAssociation\"m\n\x16\x43onfigurationTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xe6\x01\n\rConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65ngine_version\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x65ngine_type\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\x12>\n\x04tags\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.amazonmq.ConfigurationTagsEntry\x12\x0c\n\x04name\x18\x07 \x01(\t\"\x80\x01\n\'ConfigurationAssociationConfigurationId\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08revision\x18\x02 \x01(\x05\x12\n\n\x02id\x18\x03 \x01(\t\"\xbd\x01\n\x18\x43onfigurationAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62roker\x18\x02 \x01(\t\x12X\n\rconfiguration\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.amazonmq.ConfigurationAssociationConfigurationIdb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_amazonmq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BROKERCONFIGURATIONID._serialized_start=73
  _BROKERCONFIGURATIONID._serialized_end=183
  _BROKERMAINTENANCEWINDOW._serialized_start=186
  _BROKERMAINTENANCEWINDOW._serialized_end=329
  _BROKERINTERBROKERCRED._serialized_start=331
  _BROKERINTERBROKERCRED._serialized_end=447
  _BROKERSERVERMETADATA._serialized_start=450
  _BROKERSERVERMETADATA._serialized_end=811
  _BROKERLDAPMETADATA._serialized_start=814
  _BROKERLDAPMETADATA._serialized_end=1041
  _BROKERUSER._serialized_start=1044
  _BROKERUSER._serialized_end=1189
  _BROKERLOGLIST._serialized_start=1191
  _BROKERLOGLIST._serialized_end=1295
  _BROKERLDAPSERVERMETADATA._serialized_start=1298
  _BROKERLDAPSERVERMETADATA._serialized_end=1663
  _BROKERENCRYPTIONOPTIONS._serialized_start=1666
  _BROKERENCRYPTIONOPTIONS._serialized_end=1795
  _BROKERTAGSENTRY._serialized_start=1797
  _BROKERTAGSENTRY._serialized_end=1899
  _BROKER._serialized_start=1902
  _BROKER._serialized_end=2808
  _AMAZONMQ._serialized_start=2811
  _AMAZONMQ._serialized_end=3022
  _CONFIGURATIONTAGSENTRY._serialized_start=3024
  _CONFIGURATIONTAGSENTRY._serialized_end=3133
  _CONFIGURATION._serialized_start=3136
  _CONFIGURATION._serialized_end=3366
  _CONFIGURATIONASSOCIATIONCONFIGURATIONID._serialized_start=3369
  _CONFIGURATIONASSOCIATIONCONFIGURATIONID._serialized_end=3497
  _CONFIGURATIONASSOCIATION._serialized_start=3500
  _CONFIGURATIONASSOCIATION._serialized_end=3689
# @@protoc_insertion_point(module_scope)
