# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_redis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gcp/gcp_redis.proto\x12\x15oak9.tython.gcp.redis\x1a\x13shared/shared.proto\"\x83\x01\nARedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime\x12\r\n\x05hours\x18\x01 \x01(\x01\x12\x0f\n\x07minutes\x18\x02 \x01(\x01\x12\r\n\x05nanos\x18\x03 \x01(\x01\x12\x0f\n\x07seconds\x18\x04 \x01(\x01\"\xc6\x01\n7RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\x12l\n\nstart_time\x18\x03 \x01(\x0b\x32X.oak9.tython.gcp.redis.RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime\"\xd3\x01\n\x1fRedisInstanceXMaintenancePolicy\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0bupdate_time\x18\x03 \x01(\t\x12q\n\x19weekly_maintenance_window\x18\x04 \x03(\x0b\x32N.oak9.tython.gcp.redis.RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow\"i\n!RedisInstanceXMaintenanceSchedule\x12\x10\n\x08\x65nd_time\x18\x01 \x01(\t\x12\x1e\n\x16schedule_deadline_time\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\"H\n\x16RedisInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8d\x0b\n\rRedisInstance\x12\x1f\n\x17\x61lternative_location_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61uth_enabled\x18\x02 \x01(\x08\x12\x13\n\x0b\x61uth_string\x18\x03 \x01(\t\x12\x1a\n\x12\x61uthorized_network\x18\x04 \x01(\t\x12\x14\n\x0c\x63onnect_mode\x18\x05 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x06 \x01(\t\x12\x1b\n\x13\x63urrent_location_id\x18\x07 \x01(\t\x12\x1c\n\x14\x63ustomer_managed_key\x18\x08 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\t \x01(\t\x12\x0c\n\x04host\x18\n \x01(\t\x12\n\n\x02id\x18\x0b \x01(\t\x12@\n\x06labels\x18\x0c \x03(\x0b\x32\x30.oak9.tython.gcp.redis.RedisInstance.LabelsEntry\x12\x13\n\x0blocation_id\x18\r \x01(\t\x12\x16\n\x0ememory_size_gb\x18\x0e \x01(\x01\x12\x0c\n\x04name\x18\x0f \x01(\t\x12>\n\x05nodes\x18\x10 \x03(\x0b\x32/.oak9.tython.gcp.redis.RedisInstance.NodesEntry\x12 \n\x18persistence_iam_identity\x18\x11 \x01(\t\x12\x0c\n\x04port\x18\x12 \x01(\x01\x12\x0f\n\x07project\x18\x13 \x01(\t\x12\x15\n\rread_endpoint\x18\x14 \x01(\t\x12\x1a\n\x12read_endpoint_port\x18\x15 \x01(\x01\x12\x1a\n\x12read_replicas_mode\x18\x16 \x01(\t\x12M\n\rredis_configs\x18\x17 \x03(\x0b\x32\x36.oak9.tython.gcp.redis.RedisInstance.RedisConfigsEntry\x12\x15\n\rredis_version\x18\x18 \x01(\t\x12\x0e\n\x06region\x18\x19 \x01(\t\x12\x15\n\rreplica_count\x18\x1a \x01(\x01\x12\x19\n\x11reserved_ip_range\x18\x1b \x01(\t\x12\x1a\n\x12secondary_ip_range\x18\x1c \x01(\t\x12P\n\x0fserver_ca_certs\x18\x1d \x03(\x0b\x32\x37.oak9.tython.gcp.redis.RedisInstance.ServerCaCertsEntry\x12\x0c\n\x04tier\x18\x1e \x01(\t\x12\x1f\n\x17transit_encryption_mode\x18\x1f \x01(\t\x12R\n\x12maintenance_policy\x18  \x01(\x0b\x32\x36.oak9.tython.gcp.redis.RedisInstanceXMaintenancePolicy\x12V\n\x14maintenance_schedule\x18! \x01(\x0b\x32\x38.oak9.tython.gcp.redis.RedisInstanceXMaintenanceSchedule\x12?\n\x08timeouts\x18\" \x01(\x0b\x32-.oak9.tython.gcp.redis.RedisInstanceXTimeouts\x12\x37\n\rresource_info\x18# \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nNodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11RedisConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12ServerCaCertsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_redis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REDISINSTANCE_LABELSENTRY._options = None
  _REDISINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _REDISINSTANCE_NODESENTRY._options = None
  _REDISINSTANCE_NODESENTRY._serialized_options = b'8\001'
  _REDISINSTANCE_REDISCONFIGSENTRY._options = None
  _REDISINSTANCE_REDISCONFIGSENTRY._serialized_options = b'8\001'
  _REDISINSTANCE_SERVERCACERTSENTRY._options = None
  _REDISINSTANCE_SERVERCACERTSENTRY._serialized_options = b'8\001'
  _REDISINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOWXSTARTTIME._serialized_start=68
  _REDISINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOWXSTARTTIME._serialized_end=199
  _REDISINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOW._serialized_start=202
  _REDISINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOW._serialized_end=400
  _REDISINSTANCEXMAINTENANCEPOLICY._serialized_start=403
  _REDISINSTANCEXMAINTENANCEPOLICY._serialized_end=614
  _REDISINSTANCEXMAINTENANCESCHEDULE._serialized_start=616
  _REDISINSTANCEXMAINTENANCESCHEDULE._serialized_end=721
  _REDISINSTANCEXTIMEOUTS._serialized_start=723
  _REDISINSTANCEXTIMEOUTS._serialized_end=795
  _REDISINSTANCE._serialized_start=798
  _REDISINSTANCE._serialized_end=2219
  _REDISINSTANCE_LABELSENTRY._serialized_start=2021
  _REDISINSTANCE_LABELSENTRY._serialized_end=2066
  _REDISINSTANCE_NODESENTRY._serialized_start=2068
  _REDISINSTANCE_NODESENTRY._serialized_end=2112
  _REDISINSTANCE_REDISCONFIGSENTRY._serialized_start=2114
  _REDISINSTANCE_REDISCONFIGSENTRY._serialized_end=2165
  _REDISINSTANCE_SERVERCACERTSENTRY._serialized_start=2167
  _REDISINSTANCE_SERVERCACERTSENTRY._serialized_end=2219
# @@protoc_insertion_point(module_scope)
