# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_opsworkscm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_opsworkscm.proto\x12\x1aoak9.tython.aws.opsworkscm\x1a\x13shared/shared.proto\"m\n\x15ServerEngineAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xec\x05\n\x06Server\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08key_pair\x18\x02 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x03 \x01(\t\x12\x18\n\x10service_role_arn\x18\x04 \x01(\t\x12 \n\x18\x64isable_automated_backup\x18\x05 \x01(\x08\x12\x11\n\tbackup_id\x18\x06 \x01(\t\x12\x14\n\x0c\x65ngine_model\x18\x07 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x08 \x01(\t\x12#\n\x1b\x61ssociate_public_ip_address\x18\t \x01(\x08\x12\x1c\n\x14instance_profile_arn\x18\n \x01(\t\x12\x1a\n\x12\x63ustom_certificate\x18\x0b \x01(\t\x12\x1f\n\x17preferred_backup_window\x18\x0c \x01(\t\x12\x1a\n\x12security_group_ids\x18\r \x03(\t\x12\x12\n\nsubnet_ids\x18\x0e \x03(\t\x12\x15\n\rcustom_domain\x18\x0f \x01(\t\x12\x1a\n\x12\x63ustom_private_key\x18\x10 \x01(\t\x12\x13\n\x0bserver_name\x18\x11 \x01(\t\x12L\n\x11\x65ngine_attributes\x18\x12 \x03(\x0b\x32\x31.oak9.tython.aws.opsworkscm.ServerEngineAttribute\x12\x1e\n\x16\x62\x61\x63kup_retention_count\x18\x13 \x01(\x05\x12\x15\n\rinstance_type\x18\x14 \x01(\t\x12:\n\x04tags\x18\x15 \x03(\x0b\x32,.oak9.tython.aws.opsworkscm.Server.TagsEntry\x12\x0e\n\x06\x65ngine\x18\x16 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\nOpsWorksCM\x12\x32\n\x06server\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.opsworkscm.Serverb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_opsworkscm_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVER_TAGSENTRY._options = None
  _SERVER_TAGSENTRY._serialized_options = b'8\001'
  _SERVERENGINEATTRIBUTE._serialized_start=77
  _SERVERENGINEATTRIBUTE._serialized_end=186
  _SERVER._serialized_start=189
  _SERVER._serialized_end=937
  _SERVER_TAGSENTRY._serialized_start=894
  _SERVER_TAGSENTRY._serialized_end=937
  _OPSWORKSCM._serialized_start=939
  _OPSWORKSCM._serialized_end=1003
# @@protoc_insertion_point(module_scope)
