# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_service.proto\x12\x17oak9.tython.gcp.service\x1a\x13shared/shared.proto\")\n\x17ServiceAccountXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\"\xab\x02\n\x0eServiceAccount\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x11\n\tunique_id\x18\t \x01(\t\x12\x42\n\x08timeouts\x18\n \x01(\x0b\x32\x30.oak9.tython.gcp.service.ServiceAccountXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"ServiceAccountIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf8\x01\n\x18ServiceAccountIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12N\n\tcondition\x18\x06 \x01(\x0b\x32;.oak9.tython.gcp.service.ServiceAccountIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n!ServiceAccountIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf5\x01\n\x17ServiceAccountIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12M\n\tcondition\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.service.ServiceAccountIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\x17ServiceAccountIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x03\n\x11ServiceAccountKey\x12\n\n\x02id\x18\x01 \x01(\t\x12H\n\x07keepers\x18\x02 \x03(\x0b\x32\x37.oak9.tython.gcp.service.ServiceAccountKey.KeepersEntry\x12\x15\n\rkey_algorithm\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0bprivate_key\x18\x05 \x01(\t\x12\x18\n\x10private_key_type\x18\x06 \x01(\t\x12\x12\n\npublic_key\x18\x07 \x01(\t\x12\x17\n\x0fpublic_key_data\x18\x08 \x01(\t\x12\x17\n\x0fpublic_key_type\x18\t \x01(\t\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x12\x13\n\x0bvalid_after\x18\x0b \x01(\t\x12\x14\n\x0cvalid_before\x18\x0c \x01(\t\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a.\n\x0cKeepersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n$ServiceNetworkingConnectionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x87\x02\n\x1bServiceNetworkingConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07peering\x18\x03 \x01(\t\x12\x1f\n\x17reserved_peering_ranges\x18\x04 \x03(\t\x12\x0f\n\x07service\x18\x05 \x01(\t\x12O\n\x08timeouts\x18\x06 \x01(\x0b\x32=.oak9.tython.gcp.service.ServiceNetworkingConnectionXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n)ServiceNetworkingPeeredDnsDomainXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\"\xa2\x02\n ServiceNetworkingPeeredDnsDomain\x12\x12\n\ndns_suffix\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\x12T\n\x08timeouts\x18\x08 \x01(\x0b\x32\x42.oak9.tython.gcp.service.ServiceNetworkingPeeredDnsDomainXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVICEACCOUNTKEY_KEEPERSENTRY._options = None
  _SERVICEACCOUNTKEY_KEEPERSENTRY._serialized_options = b'8\001'
  _SERVICEACCOUNTXTIMEOUTS._serialized_start=71
  _SERVICEACCOUNTXTIMEOUTS._serialized_end=112
  _SERVICEACCOUNT._serialized_start=115
  _SERVICEACCOUNT._serialized_end=414
  _SERVICEACCOUNTIAMBINDINGXCONDITION._serialized_start=416
  _SERVICEACCOUNTIAMBINDINGXCONDITION._serialized_end=508
  _SERVICEACCOUNTIAMBINDING._serialized_start=511
  _SERVICEACCOUNTIAMBINDING._serialized_end=759
  _SERVICEACCOUNTIAMMEMBERXCONDITION._serialized_start=761
  _SERVICEACCOUNTIAMMEMBERXCONDITION._serialized_end=852
  _SERVICEACCOUNTIAMMEMBER._serialized_start=855
  _SERVICEACCOUNTIAMMEMBER._serialized_end=1100
  _SERVICEACCOUNTIAMPOLICY._serialized_start=1103
  _SERVICEACCOUNTIAMPOLICY._serialized_end=1260
  _SERVICEACCOUNTKEY._serialized_start=1263
  _SERVICEACCOUNTKEY._serialized_end=1698
  _SERVICEACCOUNTKEY_KEEPERSENTRY._serialized_start=1652
  _SERVICEACCOUNTKEY_KEEPERSENTRY._serialized_end=1698
  _SERVICENETWORKINGCONNECTIONXTIMEOUTS._serialized_start=1700
  _SERVICENETWORKINGCONNECTIONXTIMEOUTS._serialized_end=1786
  _SERVICENETWORKINGCONNECTION._serialized_start=1789
  _SERVICENETWORKINGCONNECTION._serialized_end=2052
  _SERVICENETWORKINGPEEREDDNSDOMAINXTIMEOUTS._serialized_start=2054
  _SERVICENETWORKINGPEEREDDNSDOMAINXTIMEOUTS._serialized_end=2143
  _SERVICENETWORKINGPEEREDDNSDOMAIN._serialized_start=2146
  _SERVICENETWORKINGPEEREDDNSDOMAIN._serialized_end=2436
# @@protoc_insertion_point(module_scope)
