# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_applicationinsights.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!aws/aws_applicationinsights.proto\x12#oak9.tython.aws.applicationinsights\x1a\x13shared/shared.proto\"\x84\x01\n\x1a\x41pplicationCustomComponent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63omponent_name\x18\x02 \x01(\t\x12\x15\n\rresource_list\x18\x03 \x03(\t\"\x85\x01\n\x15\x41pplicationLogPattern\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cpattern_name\x18\x02 \x01(\t\x12\x0f\n\x07pattern\x18\x03 \x01(\t\x12\x0c\n\x04rank\x18\x04 \x01(\x05\"\xbf\x01\n\x18\x41pplicationLogPatternSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10pattern_set_name\x18\x02 \x01(\t\x12P\n\x0clog_patterns\x18\x03 \x03(\x0b\x32:.oak9.tython.aws.applicationinsights.ApplicationLogPattern\"l\n\x16\x41pplicationAlarmMetric\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61larm_metric_name\x18\x02 \x01(\t\"\xac\x01\n\x0e\x41pplicationLog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_group_name\x18\x02 \x01(\t\x12\x10\n\x08log_path\x18\x03 \x01(\t\x12\x10\n\x08log_type\x18\x04 \x01(\t\x12\x10\n\x08\x65ncoding\x18\x05 \x01(\t\x12\x13\n\x0bpattern_set\x18\x06 \x01(\t\"\xa9\x01\n\x17\x41pplicationWindowsEvent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_group_name\x18\x02 \x01(\t\x12\x12\n\nevent_name\x18\x03 \x01(\t\x12\x14\n\x0c\x65vent_levels\x18\x04 \x03(\t\x12\x13\n\x0bpattern_set\x18\x05 \x01(\t\"q\n\x10\x41pplicationAlarm\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nalarm_name\x18\x02 \x01(\t\x12\x10\n\x08severity\x18\x03 \x01(\t\"\x8e\x03\n\x1f\x41pplicationConfigurationDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\ralarm_metrics\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.applicationinsights.ApplicationAlarmMetric\x12\x41\n\x04logs\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.applicationinsights.ApplicationLog\x12T\n\x0ewindows_events\x18\x04 \x03(\x0b\x32<.oak9.tython.aws.applicationinsights.ApplicationWindowsEvent\x12\x45\n\x06\x61larms\x18\x05 \x03(\x0b\x32\x35.oak9.tython.aws.applicationinsights.ApplicationAlarm\"\xd3\x02\n+ApplicationSubComponentConfigurationDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\ralarm_metrics\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.applicationinsights.ApplicationAlarmMetric\x12\x41\n\x04logs\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.applicationinsights.ApplicationLog\x12T\n\x0ewindows_events\x18\x04 \x03(\x0b\x32<.oak9.tython.aws.applicationinsights.ApplicationWindowsEvent\"\xfe\x01\n(ApplicationSubComponentTypeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12sub_component_type\x18\x02 \x01(\t\x12}\n#sub_component_configuration_details\x18\x03 \x01(\x0b\x32P.oak9.tython.aws.applicationinsights.ApplicationSubComponentConfigurationDetails\"\xbb\x02\n!ApplicationComponentConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x15\x63onfiguration_details\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.applicationinsights.ApplicationConfigurationDetails\x12x\n!sub_component_type_configurations\x18\x03 \x03(\x0b\x32M.oak9.tython.aws.applicationinsights.ApplicationSubComponentTypeConfiguration\"\xae\x03\n%ApplicationComponentMonitoringSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63omponent_name\x18\x02 \x01(\t\x12\x15\n\rcomponent_arn\x18\x03 \x01(\t\x12\x0c\n\x04tier\x18\x04 \x01(\t\x12$\n\x1c\x63omponent_configuration_mode\x18\x05 \x01(\t\x12y\n)default_overwrite_component_configuration\x18\x06 \x01(\x0b\x32\x46.oak9.tython.aws.applicationinsights.ApplicationComponentConfiguration\x12n\n\x1e\x63ustom_component_configuration\x18\x07 \x01(\x0b\x32\x46.oak9.tython.aws.applicationinsights.ApplicationComponentConfiguration\"\xff\x04\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13resource_group_name\x18\x02 \x01(\t\x12\x1b\n\x13\x63we_monitor_enabled\x18\x03 \x01(\x08\x12\x1a\n\x12ops_center_enabled\x18\x04 \x01(\x08\x12\x1e\n\x16ops_item_sns_topic_arn\x18\x05 \x01(\t\x12H\n\x04tags\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.applicationinsights.Application.TagsEntry\x12Z\n\x11\x63ustom_components\x18\x07 \x03(\x0b\x32?.oak9.tython.aws.applicationinsights.ApplicationCustomComponent\x12W\n\x10log_pattern_sets\x18\x08 \x03(\x0b\x32=.oak9.tython.aws.applicationinsights.ApplicationLogPatternSet\x12\"\n\x1a\x61uto_configuration_enabled\x18\t \x01(\x08\x12q\n\x1d\x63omponent_monitoring_settings\x18\n \x03(\x0b\x32J.oak9.tython.aws.applicationinsights.ApplicationComponentMonitoringSetting\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x13\x41pplicationInsights\x12\x45\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32\x30.oak9.tython.aws.applicationinsights.Applicationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_applicationinsights_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATION_TAGSENTRY._options = None
  _APPLICATION_TAGSENTRY._serialized_options = b'8\001'
  _APPLICATIONCUSTOMCOMPONENT._serialized_start=96
  _APPLICATIONCUSTOMCOMPONENT._serialized_end=228
  _APPLICATIONLOGPATTERN._serialized_start=231
  _APPLICATIONLOGPATTERN._serialized_end=364
  _APPLICATIONLOGPATTERNSET._serialized_start=367
  _APPLICATIONLOGPATTERNSET._serialized_end=558
  _APPLICATIONALARMMETRIC._serialized_start=560
  _APPLICATIONALARMMETRIC._serialized_end=668
  _APPLICATIONLOG._serialized_start=671
  _APPLICATIONLOG._serialized_end=843
  _APPLICATIONWINDOWSEVENT._serialized_start=846
  _APPLICATIONWINDOWSEVENT._serialized_end=1015
  _APPLICATIONALARM._serialized_start=1017
  _APPLICATIONALARM._serialized_end=1130
  _APPLICATIONCONFIGURATIONDETAILS._serialized_start=1133
  _APPLICATIONCONFIGURATIONDETAILS._serialized_end=1531
  _APPLICATIONSUBCOMPONENTCONFIGURATIONDETAILS._serialized_start=1534
  _APPLICATIONSUBCOMPONENTCONFIGURATIONDETAILS._serialized_end=1873
  _APPLICATIONSUBCOMPONENTTYPECONFIGURATION._serialized_start=1876
  _APPLICATIONSUBCOMPONENTTYPECONFIGURATION._serialized_end=2130
  _APPLICATIONCOMPONENTCONFIGURATION._serialized_start=2133
  _APPLICATIONCOMPONENTCONFIGURATION._serialized_end=2448
  _APPLICATIONCOMPONENTMONITORINGSETTING._serialized_start=2451
  _APPLICATIONCOMPONENTMONITORINGSETTING._serialized_end=2881
  _APPLICATION._serialized_start=2884
  _APPLICATION._serialized_end=3523
  _APPLICATION_TAGSENTRY._serialized_start=3480
  _APPLICATION_TAGSENTRY._serialized_end=3523
  _APPLICATIONINSIGHTS._serialized_start=3525
  _APPLICATIONINSIGHTS._serialized_end=3617
# @@protoc_insertion_point(module_scope)
