"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_ContainerRegistry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRIES_FIELD_NUMBER: builtins.int
    @property
    def registries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Registries]: ...
    def __init__(
        self,
        *,
        registries: collections.abc.Iterable[global___Registries] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["registries", b"registries"]) -> None: ...

global___Microsoft_ContainerRegistry = Microsoft_ContainerRegistry

@typing_extensions.final
class RegistriesWebhooks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CustomHeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    CUSTOM_HEADERS_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SERVICE_URI_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def custom_headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    scope: builtins.str
    service_uri: builtins.str
    status: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        actions: collections.abc.Iterable[builtins.str] | None = ...,
        custom_headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        scope: builtins.str = ...,
        service_uri: builtins.str = ...,
        status: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "custom_headers", b"custom_headers", "location", b"location", "name", b"name", "resource_info", b"resource_info", "scope", b"scope", "service_uri", b"service_uri", "status", b"status", "tags", b"tags"]) -> None: ...

global___RegistriesWebhooks = RegistriesWebhooks

@typing_extensions.final
class RegistriesTokens(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    SCOPE_MAP_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def credentials(self) -> global___TokenCredentialsProperties: ...
    scope_map_id: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        credentials: global___TokenCredentialsProperties | None = ...,
        scope_map_id: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "name", b"name", "resource_info", b"resource_info", "scope_map_id", b"scope_map_id", "status", b"status"]) -> None: ...

global___RegistriesTokens = RegistriesTokens

@typing_extensions.final
class TokenCredentialsProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATES_FIELD_NUMBER: builtins.int
    PASSWORDS_FIELD_NUMBER: builtins.int
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TokenCertificate]: ...
    @property
    def passwords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TokenPassword]: ...
    def __init__(
        self,
        *,
        certificates: collections.abc.Iterable[global___TokenCertificate] | None = ...,
        passwords: collections.abc.Iterable[global___TokenPassword] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificates", b"certificates", "passwords", b"passwords"]) -> None: ...

global___TokenCredentialsProperties = TokenCredentialsProperties

@typing_extensions.final
class TokenPassword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIME_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    creation_time: builtins.str
    expiry: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        creation_time: builtins.str = ...,
        expiry: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "expiry", b"expiry", "name", b"name"]) -> None: ...

global___TokenPassword = TokenPassword

@typing_extensions.final
class TokenCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCODED_PEM_CERTIFICATE_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    THUMBPRINT_FIELD_NUMBER: builtins.int
    encoded_pem_certificate: builtins.str
    expiry: builtins.str
    name: builtins.str
    thumbprint: builtins.str
    def __init__(
        self,
        *,
        encoded_pem_certificate: builtins.str = ...,
        expiry: builtins.str = ...,
        name: builtins.str = ...,
        thumbprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encoded_pem_certificate", b"encoded_pem_certificate", "expiry", b"expiry", "name", b"name", "thumbprint", b"thumbprint"]) -> None: ...

global___TokenCertificate = TokenCertificate

@typing_extensions.final
class RegistriesScopeMaps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        actions: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "description", b"description", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___RegistriesScopeMaps = RegistriesScopeMaps

@typing_extensions.final
class RegistriesReplications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REGION_ENDPOINT_ENABLED_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANCY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    region_endpoint_enabled: builtins.bool
    zone_redundancy: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        region_endpoint_enabled: builtins.bool = ...,
        zone_redundancy: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "region_endpoint_enabled", b"region_endpoint_enabled", "resource_info", b"resource_info", "tags", b"tags", "zone_redundancy", b"zone_redundancy"]) -> None: ...

global___RegistriesReplications = RegistriesReplications

@typing_extensions.final
class RegistriesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___RegistriesPrivateEndpointConnections = RegistriesPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class RegistriesPipelineRuns(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FORCE_UPDATE_TAG_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    force_update_tag: builtins.str
    @property
    def request(self) -> global___PipelineRunRequest: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        force_update_tag: builtins.str = ...,
        request: global___PipelineRunRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["request", b"request", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["force_update_tag", b"force_update_tag", "name", b"name", "request", b"request", "resource_info", b"resource_info"]) -> None: ...

global___RegistriesPipelineRuns = RegistriesPipelineRuns

@typing_extensions.final
class PipelineRunRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACTS_FIELD_NUMBER: builtins.int
    CATALOG_DIGEST_FIELD_NUMBER: builtins.int
    PIPELINE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    @property
    def artifacts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    catalog_digest: builtins.str
    pipeline_resource_id: builtins.str
    @property
    def source(self) -> global___PipelineRunSourceProperties: ...
    @property
    def target(self) -> global___PipelineRunTargetProperties: ...
    def __init__(
        self,
        *,
        artifacts: collections.abc.Iterable[builtins.str] | None = ...,
        catalog_digest: builtins.str = ...,
        pipeline_resource_id: builtins.str = ...,
        source: global___PipelineRunSourceProperties | None = ...,
        target: global___PipelineRunTargetProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source", b"source", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts", "catalog_digest", b"catalog_digest", "pipeline_resource_id", b"pipeline_resource_id", "source", b"source", "target", b"target"]) -> None: ...

global___PipelineRunRequest = PipelineRunRequest

@typing_extensions.final
class PipelineRunTargetProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___PipelineRunTargetProperties = PipelineRunTargetProperties

@typing_extensions.final
class PipelineRunSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___PipelineRunSourceProperties = PipelineRunSourceProperties

@typing_extensions.final
class RegistriesImportPipelines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityProperties: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source(self) -> global___ImportPipelineSourceProperties: ...
    @property
    def trigger(self) -> global___PipelineTriggerProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityProperties | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: collections.abc.Iterable[builtins.str] | None = ...,
        source: global___ImportPipelineSourceProperties | None = ...,
        trigger: global___PipelineTriggerProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info", "source", b"source", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource_info", b"resource_info", "source", b"source", "trigger", b"trigger"]) -> None: ...

global___RegistriesImportPipelines = RegistriesImportPipelines

@typing_extensions.final
class PipelineTriggerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def source_trigger(self) -> global___PipelineSourceTriggerProperties: ...
    def __init__(
        self,
        *,
        source_trigger: global___PipelineSourceTriggerProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_trigger", b"source_trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_trigger", b"source_trigger"]) -> None: ...

global___PipelineTriggerProperties = PipelineTriggerProperties

@typing_extensions.final
class PipelineSourceTriggerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___PipelineSourceTriggerProperties = PipelineSourceTriggerProperties

@typing_extensions.final
class ImportPipelineSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    key_vault_uri: builtins.str
    type: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        key_vault_uri: builtins.str = ...,
        type: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_uri", b"key_vault_uri", "type", b"type", "uri", b"uri"]) -> None: ...

global___ImportPipelineSourceProperties = ImportPipelineSourceProperties

@typing_extensions.final
class RegistriesExportPipelines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityProperties: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def target(self) -> global___ExportPipelineTargetProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityProperties | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: collections.abc.Iterable[builtins.str] | None = ...,
        target: global___ExportPipelineTargetProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource_info", b"resource_info", "target", b"target"]) -> None: ...

global___RegistriesExportPipelines = RegistriesExportPipelines

@typing_extensions.final
class ExportPipelineTargetProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    key_vault_uri: builtins.str
    type: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        key_vault_uri: builtins.str = ...,
        type: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_uri", b"key_vault_uri", "type", b"type", "uri", b"uri"]) -> None: ...

global___ExportPipelineTargetProperties = ExportPipelineTargetProperties

@typing_extensions.final
class RegistriesConnectedRegistries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CLIENT_TOKEN_IDS_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    LOGIN_SERVER_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_LIST_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def client_token_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def logging(self) -> global___LoggingProperties: ...
    @property
    def login_server(self) -> global___LoginServerProperties: ...
    mode: builtins.str
    @property
    def notifications_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def parent(self) -> global___ParentProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        client_token_ids: collections.abc.Iterable[builtins.str] | None = ...,
        logging: global___LoggingProperties | None = ...,
        login_server: global___LoginServerProperties | None = ...,
        mode: builtins.str = ...,
        notifications_list: collections.abc.Iterable[builtins.str] | None = ...,
        parent: global___ParentProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging", b"logging", "login_server", b"login_server", "parent", b"parent", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_token_ids", b"client_token_ids", "logging", b"logging", "login_server", b"login_server", "mode", b"mode", "name", b"name", "notifications_list", b"notifications_list", "parent", b"parent", "resource_info", b"resource_info"]) -> None: ...

global___RegistriesConnectedRegistries = RegistriesConnectedRegistries

@typing_extensions.final
class ParentProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SYNC_PROPERTIES_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def sync_properties(self) -> global___SyncProperties: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        sync_properties: global___SyncProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_properties", b"sync_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "sync_properties", b"sync_properties"]) -> None: ...

global___ParentProperties = ParentProperties

@typing_extensions.final
class SyncProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_TTL_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    SYNC_WINDOW_FIELD_NUMBER: builtins.int
    TOKEN_ID_FIELD_NUMBER: builtins.int
    message_ttl: builtins.str
    schedule: builtins.str
    sync_window: builtins.str
    token_id: builtins.str
    def __init__(
        self,
        *,
        message_ttl: builtins.str = ...,
        schedule: builtins.str = ...,
        sync_window: builtins.str = ...,
        token_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_ttl", b"message_ttl", "schedule", b"schedule", "sync_window", b"sync_window", "token_id", b"token_id"]) -> None: ...

global___SyncProperties = SyncProperties

@typing_extensions.final
class LoginServerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___LoginServerProperties = LoginServerProperties

@typing_extensions.final
class LoggingProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIT_LOG_STATUS_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    audit_log_status: builtins.str
    log_level: builtins.str
    def __init__(
        self,
        *,
        audit_log_status: builtins.str = ...,
        log_level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_log_status", b"audit_log_status", "log_level", b"log_level"]) -> None: ...

global___LoggingProperties = LoggingProperties

@typing_extensions.final
class Registries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMIN_USER_ENABLED_FIELD_NUMBER: builtins.int
    ANONYMOUS_PULL_ENABLED_FIELD_NUMBER: builtins.int
    DATA_ENDPOINT_ENABLED_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    NETWORK_RULE_BYPASS_OPTIONS_FIELD_NUMBER: builtins.int
    NETWORK_RULE_SET_FIELD_NUMBER: builtins.int
    POLICIES_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANCY_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    REGISTRIES_CONNECTED_REGISTRIES_FIELD_NUMBER: builtins.int
    REGISTRIES_EXPORT_PIPELINES_FIELD_NUMBER: builtins.int
    REGISTRIES_IMPORT_PIPELINES_FIELD_NUMBER: builtins.int
    REGISTRIES_PIPELINE_RUNS_FIELD_NUMBER: builtins.int
    REGISTRIES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    REGISTRIES_REPLICATIONS_FIELD_NUMBER: builtins.int
    REGISTRIES_SCOPE_MAPS_FIELD_NUMBER: builtins.int
    REGISTRIES_TOKENS_FIELD_NUMBER: builtins.int
    REGISTRIES_WEBHOOKS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityProperties: ...
    location: builtins.str
    name: builtins.str
    admin_user_enabled: builtins.bool
    anonymous_pull_enabled: builtins.bool
    data_endpoint_enabled: builtins.bool
    @property
    def encryption(self) -> global___EncryptionProperty: ...
    network_rule_bypass_options: builtins.str
    @property
    def network_rule_set(self) -> global___NetworkRuleSet: ...
    @property
    def policies(self) -> global___Policies: ...
    public_network_access: builtins.str
    zone_redundancy: builtins.str
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def registries_connected_registries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesConnectedRegistries]: ...
    @property
    def registries_export_pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesExportPipelines]: ...
    @property
    def registries_import_pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesImportPipelines]: ...
    @property
    def registries_pipeline_runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesPipelineRuns]: ...
    @property
    def registries_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesPrivateEndpointConnections]: ...
    @property
    def registries_replications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesReplications]: ...
    @property
    def registries_scope_maps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesScopeMaps]: ...
    @property
    def registries_tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesTokens]: ...
    @property
    def registries_webhooks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesWebhooks]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityProperties | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        admin_user_enabled: builtins.bool = ...,
        anonymous_pull_enabled: builtins.bool = ...,
        data_endpoint_enabled: builtins.bool = ...,
        encryption: global___EncryptionProperty | None = ...,
        network_rule_bypass_options: builtins.str = ...,
        network_rule_set: global___NetworkRuleSet | None = ...,
        policies: global___Policies | None = ...,
        public_network_access: builtins.str = ...,
        zone_redundancy: builtins.str = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        registries_connected_registries: collections.abc.Iterable[global___RegistriesConnectedRegistries] | None = ...,
        registries_export_pipelines: collections.abc.Iterable[global___RegistriesExportPipelines] | None = ...,
        registries_import_pipelines: collections.abc.Iterable[global___RegistriesImportPipelines] | None = ...,
        registries_pipeline_runs: collections.abc.Iterable[global___RegistriesPipelineRuns] | None = ...,
        registries_private_endpoint_connections: collections.abc.Iterable[global___RegistriesPrivateEndpointConnections] | None = ...,
        registries_replications: collections.abc.Iterable[global___RegistriesReplications] | None = ...,
        registries_scope_maps: collections.abc.Iterable[global___RegistriesScopeMaps] | None = ...,
        registries_tokens: collections.abc.Iterable[global___RegistriesTokens] | None = ...,
        registries_webhooks: collections.abc.Iterable[global___RegistriesWebhooks] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption", b"encryption", "identity", b"identity", "network_rule_set", b"network_rule_set", "policies", b"policies", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_user_enabled", b"admin_user_enabled", "anonymous_pull_enabled", b"anonymous_pull_enabled", "data_endpoint_enabled", b"data_endpoint_enabled", "encryption", b"encryption", "identity", b"identity", "location", b"location", "name", b"name", "network_rule_bypass_options", b"network_rule_bypass_options", "network_rule_set", b"network_rule_set", "policies", b"policies", "public_network_access", b"public_network_access", "registries_connected_registries", b"registries_connected_registries", "registries_export_pipelines", b"registries_export_pipelines", "registries_import_pipelines", b"registries_import_pipelines", "registries_pipeline_runs", b"registries_pipeline_runs", "registries_private_endpoint_connections", b"registries_private_endpoint_connections", "registries_replications", b"registries_replications", "registries_scope_maps", b"registries_scope_maps", "registries_tokens", b"registries_tokens", "registries_webhooks", b"registries_webhooks", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "zone_redundancy", b"zone_redundancy"]) -> None: ...

global___Registries = Registries

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class Policies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_POLICY_FIELD_NUMBER: builtins.int
    QUARANTINE_POLICY_FIELD_NUMBER: builtins.int
    RETENTION_POLICY_FIELD_NUMBER: builtins.int
    TRUST_POLICY_FIELD_NUMBER: builtins.int
    @property
    def export_policy(self) -> global___ExportPolicy: ...
    @property
    def quarantine_policy(self) -> global___QuarantinePolicy: ...
    @property
    def retention_policy(self) -> global___RetentionPolicy: ...
    @property
    def trust_policy(self) -> global___TrustPolicy: ...
    def __init__(
        self,
        *,
        export_policy: global___ExportPolicy | None = ...,
        quarantine_policy: global___QuarantinePolicy | None = ...,
        retention_policy: global___RetentionPolicy | None = ...,
        trust_policy: global___TrustPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["export_policy", b"export_policy", "quarantine_policy", b"quarantine_policy", "retention_policy", b"retention_policy", "trust_policy", b"trust_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["export_policy", b"export_policy", "quarantine_policy", b"quarantine_policy", "retention_policy", b"retention_policy", "trust_policy", b"trust_policy"]) -> None: ...

global___Policies = Policies

@typing_extensions.final
class TrustPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    status: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status", "type", b"type"]) -> None: ...

global___TrustPolicy = TrustPolicy

@typing_extensions.final
class RetentionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    days: builtins.int
    status: builtins.str
    def __init__(
        self,
        *,
        days: builtins.int = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days", b"days", "status", b"status"]) -> None: ...

global___RetentionPolicy = RetentionPolicy

@typing_extensions.final
class QuarantinePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___QuarantinePolicy = QuarantinePolicy

@typing_extensions.final
class ExportPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___ExportPolicy = ExportPolicy

@typing_extensions.final
class NetworkRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IPRule]: ...
    @property
    def virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualNetworkRule]: ...
    def __init__(
        self,
        *,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___IPRule] | None = ...,
        virtual_network_rules: collections.abc.Iterable[global___VirtualNetworkRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_action", b"default_action", "ip_rules", b"ip_rules", "virtual_network_rules", b"virtual_network_rules"]) -> None: ...

global___NetworkRuleSet = NetworkRuleSet

@typing_extensions.final
class VirtualNetworkRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    action: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "id", b"id"]) -> None: ...

global___VirtualNetworkRule = VirtualNetworkRule

@typing_extensions.final
class IPRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    action: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "value", b"value"]) -> None: ...

global___IPRule = IPRule

@typing_extensions.final
class EncryptionProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_PROPERTIES_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def key_vault_properties(self) -> global___KeyVaultProperties: ...
    status: builtins.str
    def __init__(
        self,
        *,
        key_vault_properties: global___KeyVaultProperties | None = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_vault_properties", b"key_vault_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_properties", b"key_vault_properties", "status", b"status"]) -> None: ...

global___EncryptionProperty = EncryptionProperty

@typing_extensions.final
class KeyVaultProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_FIELD_NUMBER: builtins.int
    KEY_IDENTIFIER_FIELD_NUMBER: builtins.int
    identity: builtins.str
    key_identifier: builtins.str
    def __init__(
        self,
        *,
        identity: builtins.str = ...,
        key_identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "key_identifier", b"key_identifier"]) -> None: ...

global___KeyVaultProperties = KeyVaultProperties

@typing_extensions.final
class IdentityProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRINCIPAL_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    principal_id: builtins.str
    tenant_id: builtins.str
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        principal_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["principal_id", b"principal_id", "tenant_id", b"tenant_id", "type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___IdentityProperties = IdentityProperties
