# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cassandra.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_cassandra.proto\x12\x19oak9.tython.aws.cassandra\x1a\x13shared/shared.proto\"Z\n\x08Keyspace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rkeyspace_name\x18\x02 \x01(\t\"s\n\tCassandra\x12\x35\n\x08keyspace\x18\x01 \x03(\x0b\x32#.oak9.tython.aws.cassandra.Keyspace\x12/\n\x05table\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.cassandra.Table\"p\n\x0bTableColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63olumn_name\x18\x02 \x01(\t\x12\x13\n\x0b\x63olumn_type\x18\x03 \x01(\t\"\x9d\x01\n\x18TableClusteringKeyColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x36\n\x06\x63olumn\x18\x02 \x01(\x0b\x32&.oak9.tython.aws.cassandra.TableColumn\x12\x10\n\x08order_by\x18\x03 \x01(\t\"\x90\x01\n\x1aTableProvisionedThroughput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13read_capacity_units\x18\x02 \x01(\x05\x12\x1c\n\x14write_capacity_units\x18\x03 \x01(\x05\"\xb0\x01\n\x10TableBillingMode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12U\n\x16provisioned_throughput\x18\x03 \x01(\x0b\x32\x35.oak9.tython.aws.cassandra.TableProvisionedThroughput\"\x8b\x03\n\x05Table\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rkeyspace_name\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12?\n\x0fregular_columns\x18\x04 \x03(\x0b\x32&.oak9.tython.aws.cassandra.TableColumn\x12\x45\n\x15partition_key_columns\x18\x05 \x03(\x0b\x32&.oak9.tython.aws.cassandra.TableColumn\x12S\n\x16\x63lustering_key_columns\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.cassandra.TableClusteringKeyColumn\x12\x41\n\x0c\x62illing_mode\x18\x07 \x01(\x0b\x32+.oak9.tython.aws.cassandra.TableBillingModeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cassandra_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KEYSPACE._serialized_start=75
  _KEYSPACE._serialized_end=165
  _CASSANDRA._serialized_start=167
  _CASSANDRA._serialized_end=282
  _TABLECOLUMN._serialized_start=284
  _TABLECOLUMN._serialized_end=396
  _TABLECLUSTERINGKEYCOLUMN._serialized_start=399
  _TABLECLUSTERINGKEYCOLUMN._serialized_end=556
  _TABLEPROVISIONEDTHROUGHPUT._serialized_start=559
  _TABLEPROVISIONEDTHROUGHPUT._serialized_end=703
  _TABLEBILLINGMODE._serialized_start=706
  _TABLEBILLINGMODE._serialized_end=882
  _TABLE._serialized_start=885
  _TABLE._serialized_end=1280
# @@protoc_insertion_point(module_scope)
