# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_shared.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_shared.proto\x12\x1eoak9.tython.gcp.compute_shared\x1a\x13shared/shared.proto\"F\n$ComputeSharedVpcHostProjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xcb\x01\n\x1b\x43omputeSharedVpcHostProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12V\n\x08timeouts\x18\x03 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_shared.ComputeSharedVpcHostProjectXTimeouts\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"I\n\'ComputeSharedVpcServiceProjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xef\x01\n\x1e\x43omputeSharedVpcServiceProject\x12\x14\n\x0chost_project\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x17\n\x0fservice_project\x18\x03 \x01(\t\x12Y\n\x08timeouts\x18\x04 \x01(\x0b\x32G.oak9.tython.gcp.compute_shared.ComputeSharedVpcServiceProjectXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_shared_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESHAREDVPCHOSTPROJECTXTIMEOUTS._serialized_start=85
  _COMPUTESHAREDVPCHOSTPROJECTXTIMEOUTS._serialized_end=155
  _COMPUTESHAREDVPCHOSTPROJECT._serialized_start=158
  _COMPUTESHAREDVPCHOSTPROJECT._serialized_end=361
  _COMPUTESHAREDVPCSERVICEPROJECTXTIMEOUTS._serialized_start=363
  _COMPUTESHAREDVPCSERVICEPROJECTXTIMEOUTS._serialized_end=436
  _COMPUTESHAREDVPCSERVICEPROJECT._serialized_start=439
  _COMPUTESHAREDVPCSERVICEPROJECT._serialized_end=678
# @@protoc_insertion_point(module_scope)
