# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_qldb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61ws/aws_qldb.proto\x12\x14oak9.tython.aws.qldb\x1a\x13shared/shared.proto\"\xe9\x01\n\x06Ledger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10permissions_mode\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x03 \x01(\x08\x12\x34\n\x04tags\x18\x04 \x03(\x0b\x32&.oak9.tython.aws.qldb.Ledger.TagsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x04QLDB\x12,\n\x06ledger\x18\x01 \x01(\x0b\x32\x1c.oak9.tython.aws.qldb.Ledger\x12,\n\x06stream\x18\x02 \x03(\x0b\x32\x1c.oak9.tython.aws.qldb.Stream\"\x86\x01\n\x1aStreamKinesisConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nstream_arn\x18\x02 \x01(\t\x12\x1b\n\x13\x61ggregation_enabled\x18\x03 \x01(\x08\"\xeb\x02\n\x06Stream\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bledger_name\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x12\x1c\n\x14inclusive_start_time\x18\x05 \x01(\t\x12\x1a\n\x12\x65xclusive_end_time\x18\x06 \x01(\t\x12O\n\x15kinesis_configuration\x18\x07 \x01(\x0b\x32\x30.oak9.tython.aws.qldb.StreamKinesisConfiguration\x12\x34\n\x04tags\x18\x08 \x03(\x0b\x32&.oak9.tython.aws.qldb.Stream.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_qldb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LEDGER_TAGSENTRY._options = None
  _LEDGER_TAGSENTRY._serialized_options = b'8\001'
  _STREAM_TAGSENTRY._options = None
  _STREAM_TAGSENTRY._serialized_options = b'8\001'
  _LEDGER._serialized_start=66
  _LEDGER._serialized_end=299
  _LEDGER_TAGSENTRY._serialized_start=256
  _LEDGER_TAGSENTRY._serialized_end=299
  _QLDB._serialized_start=301
  _QLDB._serialized_end=399
  _STREAMKINESISCONFIGURATION._serialized_start=402
  _STREAMKINESISCONFIGURATION._serialized_end=536
  _STREAM._serialized_start=539
  _STREAM._serialized_end=902
  _STREAM_TAGSENTRY._serialized_start=256
  _STREAM_TAGSENTRY._serialized_end=299
# @@protoc_insertion_point(module_scope)
