# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_workflows.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_workflows.proto\x12\x19oak9.tython.gcp.workflows\x1a\x13shared/shared.proto\"L\n\x1aWorkflowsWorkflowXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf3\x03\n\x11WorkflowsWorkflow\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12H\n\x06labels\x18\x04 \x03(\x0b\x32\x38.oak9.tython.gcp.workflows.WorkflowsWorkflow.LabelsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0bname_prefix\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x13\n\x0brevision_id\x18\t \x01(\t\x12\x17\n\x0fservice_account\x18\n \x01(\t\x12\x17\n\x0fsource_contents\x18\x0b \x01(\t\x12\r\n\x05state\x18\x0c \x01(\t\x12\x13\n\x0bupdate_time\x18\r \x01(\t\x12G\n\x08timeouts\x18\x0e \x01(\x0b\x32\x35.oak9.tython.gcp.workflows.WorkflowsWorkflowXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_workflows_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKFLOWSWORKFLOW_LABELSENTRY._options = None
  _WORKFLOWSWORKFLOW_LABELSENTRY._serialized_options = b'8\001'
  _WORKFLOWSWORKFLOWXTIMEOUTS._serialized_start=75
  _WORKFLOWSWORKFLOWXTIMEOUTS._serialized_end=151
  _WORKFLOWSWORKFLOW._serialized_start=154
  _WORKFLOWSWORKFLOW._serialized_end=653
  _WORKFLOWSWORKFLOW_LABELSENTRY._serialized_start=608
  _WORKFLOWSWORKFLOW_LABELSENTRY._serialized_end=653
# @@protoc_insertion_point(module_scope)
