# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.rbac.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.kubernetes/kubernetes_io.k8s.api.rbac.v1.proto\x12\x1boak9.tython.k8s.api.rbac.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xa8\x01\n\x0f\x41ggregationRule\x12\\\n\x16\x63luster_role_selectors\x18\x01 \x03(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb6\x02\n\x0b\x43lusterRole\x12\x46\n\x10\x61ggregation_rule\x18\x01 \x01(\x0b\x32,.oak9.tython.k8s.api.rbac.v1.AggregationRule\x12\x13\n\x0b\x61pi_version\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x05rules\x18\x05 \x03(\x0b\x32\'.oak9.tython.k8s.api.rbac.v1.PolicyRule\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x02\n\x12\x43lusterRoleBinding\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x08role_ref\x18\x04 \x01(\x0b\x32$.oak9.tython.k8s.api.rbac.v1.RoleRef\x12\x36\n\x08subjects\x18\x05 \x03(\x0b\x32$.oak9.tython.k8s.api.rbac.v1.Subject\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x16\x43lusterRoleBindingList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12>\n\x05items\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.rbac.v1.ClusterRoleBinding\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x01\n\x0f\x43lusterRoleList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x37\n\x05items\x18\x02 \x03(\x0b\x32(.oak9.tython.k8s.api.rbac.v1.ClusterRole\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x01\n\nPolicyRule\x12\x12\n\napi_groups\x18\x01 \x03(\t\x12\x1b\n\x13non_resource_u_r_ls\x18\x02 \x03(\t\x12\x16\n\x0eresource_names\x18\x03 \x03(\t\x12\x11\n\tresources\x18\x04 \x03(\t\x12\r\n\x05verbs\x18\x05 \x03(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe7\x01\n\x04Role\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x05rules\x18\x04 \x03(\x0b\x32\'.oak9.tython.k8s.api.rbac.v1.PolicyRule\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x02\n\x0bRoleBinding\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x08role_ref\x18\x04 \x01(\x0b\x32$.oak9.tython.k8s.api.rbac.v1.RoleRef\x12\x36\n\x08subjects\x18\x05 \x03(\x0b\x32$.oak9.tython.k8s.api.rbac.v1.Subject\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x01\n\x0fRoleBindingList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x37\n\x05items\x18\x02 \x03(\x0b\x32(.oak9.tython.k8s.api.rbac.v1.RoleBinding\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe3\x01\n\x08RoleList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.oak9.tython.k8s.api.rbac.v1.Role\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"q\n\x07RoleRef\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x84\x01\n\x07Subject\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AGGREGATIONRULE._serialized_start=167
  _AGGREGATIONRULE._serialized_end=335
  _CLUSTERROLE._serialized_start=338
  _CLUSTERROLE._serialized_end=648
  _CLUSTERROLEBINDING._serialized_start=651
  _CLUSTERROLEBINDING._serialized_end=952
  _CLUSTERROLEBINDINGLIST._serialized_start=955
  _CLUSTERROLEBINDINGLIST._serialized_end=1210
  _CLUSTERROLELIST._serialized_start=1213
  _CLUSTERROLELIST._serialized_end=1454
  _POLICYRULE._serialized_start=1457
  _POLICYRULE._serialized_end=1633
  _ROLE._serialized_start=1636
  _ROLE._serialized_end=1867
  _ROLEBINDING._serialized_start=1870
  _ROLEBINDING._serialized_end=2164
  _ROLEBINDINGLIST._serialized_start=2167
  _ROLEBINDINGLIST._serialized_end=2408
  _ROLELIST._serialized_start=2411
  _ROLELIST._serialized_end=2638
  _ROLEREF._serialized_start=2640
  _ROLEREF._serialized_end=2753
  _SUBJECT._serialized_start=2756
  _SUBJECT._serialized_end=2888
# @@protoc_insertion_point(module_scope)
