# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticache_replicationgroup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*aws/aws_elasticache_replicationgroup.proto\x12,oak9.tython.aws.elasticache_replicationgroup\x1a\x13shared/shared.proto\"\xe5\x01\n&ReplicationGroupNodeGroupConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rnode_group_id\x18\x02 \x01(\t\x12!\n\x19primary_availability_zone\x18\x03 \x01(\t\x12\"\n\x1areplica_availability_zones\x18\x04 \x03(\t\x12\x15\n\rreplica_count\x18\x05 \x01(\x05\x12\r\n\x05slots\x18\x06 \x01(\t\"\x9a\t\n\x10ReplicationGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1a\x61t_rest_encryption_enabled\x18\x02 \x01(\x08\x12\x12\n\nauth_token\x18\x03 \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x04 \x01(\x08\x12\"\n\x1a\x61utomatic_failover_enabled\x18\x05 \x01(\x08\x12\x17\n\x0f\x63\x61\x63he_node_type\x18\x06 \x01(\t\x12\"\n\x1a\x63\x61\x63he_parameter_group_name\x18\x07 \x01(\t\x12\"\n\x1a\x63\x61\x63he_security_group_names\x18\x08 \x03(\t\x12\x1f\n\x17\x63\x61\x63he_subnet_group_name\x18\t \x01(\t\x12\x0e\n\x06\x65ngine\x18\n \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x0b \x01(\t\x12\x12\n\nkms_key_id\x18\x0c \x01(\t\x12\x18\n\x10multi_az_enabled\x18\r \x01(\x08\x12v\n\x18node_group_configuration\x18\x0e \x03(\x0b\x32T.oak9.tython.aws.elasticache_replicationgroup.ReplicationGroupNodeGroupConfiguration\x12\x1e\n\x16notification_topic_arn\x18\x0f \x01(\t\x12\x1a\n\x12num_cache_clusters\x18\x10 \x01(\x05\x12\x17\n\x0fnum_node_groups\x18\x11 \x01(\x05\x12\x0c\n\x04port\x18\x12 \x01(\x05\x12#\n\x1bpreferred_cache_cluster_azs\x18\x13 \x03(\t\x12$\n\x1cpreferred_maintenance_window\x18\x14 \x01(\t\x12\x1a\n\x12primary_cluster_id\x18\x15 \x01(\t\x12\x1f\n\x17replicas_per_node_group\x18\x16 \x01(\x05\x12%\n\x1dreplication_group_description\x18\x17 \x01(\t\x12\x1c\n\x14replication_group_id\x18\x18 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x19 \x03(\t\x12\x15\n\rsnapshot_arns\x18\x1a \x03(\t\x12\x15\n\rsnapshot_name\x18\x1b \x01(\t\x12 \n\x18snapshot_retention_limit\x18\x1c \x01(\x05\x12\x17\n\x0fsnapshot_window\x18\x1d \x01(\t\x12\x1f\n\x17snapshotting_cluster_id\x18\x1e \x01(\t\x12V\n\x04tags\x18\x1f \x03(\x0b\x32H.oak9.tython.aws.elasticache_replicationgroup.ReplicationGroup.TagsEntry\x12\"\n\x1atransit_encryption_enabled\x18  \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x03\n\x1c\x45lastiCache_ReplicationGroup\x12Y\n\x11replication_group\x18\x01 \x01(\x0b\x32>.oak9.tython.aws.elasticache_replicationgroup.ReplicationGroup\x12S\n\x0esecurity_group\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.elasticache_replicationgroup.SecurityGroup\x12\x62\n\x16security_group_ingress\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.elasticache_replicationgroup.SecurityGroupIngress\x12O\n\x0csubnet_group\x18\x04 \x01(\x0b\x32\x39.oak9.tython.aws.elasticache_replicationgroup.SubnetGroup\"]\n\rSecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xba\x01\n\x14SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x61\x63he_security_group_name\x18\x02 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x03 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x04 \x01(\t\"\x90\x01\n\x0bSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x63\x61\x63he_subnet_group_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticache_replicationgroup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPLICATIONGROUP_TAGSENTRY._options = None
  _REPLICATIONGROUP_TAGSENTRY._serialized_options = b'8\001'
  _REPLICATIONGROUPNODEGROUPCONFIGURATION._serialized_start=114
  _REPLICATIONGROUPNODEGROUPCONFIGURATION._serialized_end=343
  _REPLICATIONGROUP._serialized_start=346
  _REPLICATIONGROUP._serialized_end=1524
  _REPLICATIONGROUP_TAGSENTRY._serialized_start=1481
  _REPLICATIONGROUP_TAGSENTRY._serialized_end=1524
  _ELASTICACHE_REPLICATIONGROUP._serialized_start=1527
  _ELASTICACHE_REPLICATIONGROUP._serialized_end=1914
  _SECURITYGROUP._serialized_start=1916
  _SECURITYGROUP._serialized_end=2009
  _SECURITYGROUPINGRESS._serialized_start=2012
  _SECURITYGROUPINGRESS._serialized_end=2198
  _SUBNETGROUP._serialized_start=2201
  _SUBNETGROUP._serialized_end=2345
# @@protoc_insertion_point(module_scope)
