"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BrokerConfigurationId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    revision: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        revision: builtins.int = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___BrokerConfigurationId = BrokerConfigurationId

@typing_extensions.final
class BrokerMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    TIME_OF_DAY_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    day_of_week: builtins.str
    time_of_day: builtins.str
    time_zone: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        day_of_week: builtins.str = ...,
        time_of_day: builtins.str = ...,
        time_zone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week", "resource_info", b"resource_info", "time_of_day", b"time_of_day", "time_zone", b"time_zone"]) -> None: ...

global___BrokerMaintenanceWindow = BrokerMaintenanceWindow

@typing_extensions.final
class BrokerInterBrokerCred(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___BrokerInterBrokerCred = BrokerInterBrokerCred

@typing_extensions.final
class BrokerServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    USER_ROLE_NAME_FIELD_NUMBER: builtins.int
    USER_SEARCH_MATCHING_FIELD_NUMBER: builtins.int
    ROLE_NAME_FIELD_NUMBER: builtins.int
    USER_BASE_FIELD_NUMBER: builtins.int
    USER_SEARCH_SUBTREE_FIELD_NUMBER: builtins.int
    ROLE_SEARCH_MATCHING_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_USERNAME_FIELD_NUMBER: builtins.int
    ROLE_BASE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_PASSWORD_FIELD_NUMBER: builtins.int
    ROLE_SEARCH_SUBTREE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    user_role_name: builtins.str
    user_search_matching: builtins.str
    role_name: builtins.str
    user_base: builtins.str
    user_search_subtree: builtins.bool
    role_search_matching: builtins.str
    service_account_username: builtins.str
    role_base: builtins.str
    service_account_password: builtins.str
    role_search_subtree: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        user_role_name: builtins.str = ...,
        user_search_matching: builtins.str = ...,
        role_name: builtins.str = ...,
        user_base: builtins.str = ...,
        user_search_subtree: builtins.bool = ...,
        role_search_matching: builtins.str = ...,
        service_account_username: builtins.str = ...,
        role_base: builtins.str = ...,
        service_account_password: builtins.str = ...,
        role_search_subtree: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosts", b"hosts", "resource_info", b"resource_info", "role_base", b"role_base", "role_name", b"role_name", "role_search_matching", b"role_search_matching", "role_search_subtree", b"role_search_subtree", "service_account_password", b"service_account_password", "service_account_username", b"service_account_username", "user_base", b"user_base", "user_role_name", b"user_role_name", "user_search_matching", b"user_search_matching", "user_search_subtree", b"user_search_subtree"]) -> None: ...

global___BrokerServerMetadata = BrokerServerMetadata

@typing_extensions.final
class BrokerLdapMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTER_BROKER_CREDS_FIELD_NUMBER: builtins.int
    SERVER_METADATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def inter_broker_creds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BrokerInterBrokerCred]: ...
    @property
    def server_metadata(self) -> global___BrokerServerMetadata: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        inter_broker_creds: collections.abc.Iterable[global___BrokerInterBrokerCred] | None = ...,
        server_metadata: global___BrokerServerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "server_metadata", b"server_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inter_broker_creds", b"inter_broker_creds", "resource_info", b"resource_info", "server_metadata", b"server_metadata"]) -> None: ...

global___BrokerLdapMetadata = BrokerLdapMetadata

@typing_extensions.final
class BrokerUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    CONSOLE_ACCESS_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    console_access: builtins.bool
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        console_access: builtins.bool = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["console_access", b"console_access", "groups", b"groups", "password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___BrokerUser = BrokerUser

@typing_extensions.final
class BrokerLogList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUDIT_FIELD_NUMBER: builtins.int
    GENERAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    audit: builtins.bool
    general: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        audit: builtins.bool = ...,
        general: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit", b"audit", "general", b"general", "resource_info", b"resource_info"]) -> None: ...

global___BrokerLogList = BrokerLogList

@typing_extensions.final
class BrokerLdapServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    USER_ROLE_NAME_FIELD_NUMBER: builtins.int
    USER_SEARCH_MATCHING_FIELD_NUMBER: builtins.int
    ROLE_NAME_FIELD_NUMBER: builtins.int
    USER_BASE_FIELD_NUMBER: builtins.int
    USER_SEARCH_SUBTREE_FIELD_NUMBER: builtins.int
    ROLE_SEARCH_MATCHING_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_USERNAME_FIELD_NUMBER: builtins.int
    ROLE_BASE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_PASSWORD_FIELD_NUMBER: builtins.int
    ROLE_SEARCH_SUBTREE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    user_role_name: builtins.str
    user_search_matching: builtins.str
    role_name: builtins.str
    user_base: builtins.str
    user_search_subtree: builtins.bool
    role_search_matching: builtins.str
    service_account_username: builtins.str
    role_base: builtins.str
    service_account_password: builtins.str
    role_search_subtree: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        user_role_name: builtins.str = ...,
        user_search_matching: builtins.str = ...,
        role_name: builtins.str = ...,
        user_base: builtins.str = ...,
        user_search_subtree: builtins.bool = ...,
        role_search_matching: builtins.str = ...,
        service_account_username: builtins.str = ...,
        role_base: builtins.str = ...,
        service_account_password: builtins.str = ...,
        role_search_subtree: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosts", b"hosts", "resource_info", b"resource_info", "role_base", b"role_base", "role_name", b"role_name", "role_search_matching", b"role_search_matching", "role_search_subtree", b"role_search_subtree", "service_account_password", b"service_account_password", "service_account_username", b"service_account_username", "user_base", b"user_base", "user_role_name", b"user_role_name", "user_search_matching", b"user_search_matching", "user_search_subtree", b"user_search_subtree"]) -> None: ...

global___BrokerLdapServerMetadata = BrokerLdapServerMetadata

@typing_extensions.final
class BrokerEncryptionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    USE_AWS_OWNED_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_id: builtins.str
    use_aws_owned_key: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_id: builtins.str = ...,
        use_aws_owned_key: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_id", b"kms_key_id", "resource_info", b"resource_info", "use_aws_owned_key", b"use_aws_owned_key"]) -> None: ...

global___BrokerEncryptionOptions = BrokerEncryptionOptions

@typing_extensions.final
class BrokerTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___BrokerTagsEntry = BrokerTagsEntry

@typing_extensions.final
class Broker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTHENTICATION_STRATEGY_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_START_TIME_FIELD_NUMBER: builtins.int
    LDAP_METADATA_FIELD_NUMBER: builtins.int
    HOST_INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    AUTO_MINOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    BROKER_NAME_FIELD_NUMBER: builtins.int
    LDAP_SERVER_METADATA_FIELD_NUMBER: builtins.int
    DEPLOYMENT_MODE_FIELD_NUMBER: builtins.int
    ENGINE_TYPE_FIELD_NUMBER: builtins.int
    PUBLICLY_ACCESSIBLE_FIELD_NUMBER: builtins.int
    ENCRYPTION_OPTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    storage_type: builtins.str
    engine_version: builtins.str
    @property
    def configuration(self) -> global___BrokerConfigurationId: ...
    authentication_strategy: builtins.str
    @property
    def maintenance_window_start_time(self) -> global___BrokerMaintenanceWindow: ...
    @property
    def ldap_metadata(self) -> global___BrokerLdapMetadata: ...
    host_instance_type: builtins.str
    auto_minor_version_upgrade: builtins.bool
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BrokerUser]: ...
    @property
    def logs(self) -> global___BrokerLogList: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    broker_name: builtins.str
    @property
    def ldap_server_metadata(self) -> global___BrokerLdapServerMetadata: ...
    deployment_mode: builtins.str
    engine_type: builtins.str
    publicly_accessible: builtins.bool
    @property
    def encryption_options(self) -> global___BrokerEncryptionOptions: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BrokerTagsEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        storage_type: builtins.str = ...,
        engine_version: builtins.str = ...,
        configuration: global___BrokerConfigurationId | None = ...,
        authentication_strategy: builtins.str = ...,
        maintenance_window_start_time: global___BrokerMaintenanceWindow | None = ...,
        ldap_metadata: global___BrokerLdapMetadata | None = ...,
        host_instance_type: builtins.str = ...,
        auto_minor_version_upgrade: builtins.bool = ...,
        users: collections.abc.Iterable[global___BrokerUser] | None = ...,
        logs: global___BrokerLogList | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        broker_name: builtins.str = ...,
        ldap_server_metadata: global___BrokerLdapServerMetadata | None = ...,
        deployment_mode: builtins.str = ...,
        engine_type: builtins.str = ...,
        publicly_accessible: builtins.bool = ...,
        encryption_options: global___BrokerEncryptionOptions | None = ...,
        tags: collections.abc.Iterable[global___BrokerTagsEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "encryption_options", b"encryption_options", "ldap_metadata", b"ldap_metadata", "ldap_server_metadata", b"ldap_server_metadata", "logs", b"logs", "maintenance_window_start_time", b"maintenance_window_start_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_strategy", b"authentication_strategy", "auto_minor_version_upgrade", b"auto_minor_version_upgrade", "broker_name", b"broker_name", "configuration", b"configuration", "deployment_mode", b"deployment_mode", "encryption_options", b"encryption_options", "engine_type", b"engine_type", "engine_version", b"engine_version", "host_instance_type", b"host_instance_type", "ldap_metadata", b"ldap_metadata", "ldap_server_metadata", b"ldap_server_metadata", "logs", b"logs", "maintenance_window_start_time", b"maintenance_window_start_time", "publicly_accessible", b"publicly_accessible", "resource_info", b"resource_info", "security_groups", b"security_groups", "storage_type", b"storage_type", "subnet_ids", b"subnet_ids", "tags", b"tags", "users", b"users"]) -> None: ...

global___Broker = Broker

@typing_extensions.final
class AmazonMQ(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    CONFIGURATION_ASSOCIATION_FIELD_NUMBER: builtins.int
    @property
    def broker(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Broker]: ...
    @property
    def configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Configuration]: ...
    @property
    def configuration_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationAssociation]: ...
    def __init__(
        self,
        *,
        broker: collections.abc.Iterable[global___Broker] | None = ...,
        configuration: collections.abc.Iterable[global___Configuration] | None = ...,
        configuration_association: collections.abc.Iterable[global___ConfigurationAssociation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["broker", b"broker", "configuration", b"configuration", "configuration_association", b"configuration_association"]) -> None: ...

global___AmazonMQ = AmazonMQ

@typing_extensions.final
class ConfigurationTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ConfigurationTagsEntry = ConfigurationTagsEntry

@typing_extensions.final
class Configuration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENGINE_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    engine_version: builtins.str
    description: builtins.str
    engine_type: builtins.str
    data: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationTagsEntry]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        engine_version: builtins.str = ...,
        description: builtins.str = ...,
        engine_type: builtins.str = ...,
        data: builtins.str = ...,
        tags: collections.abc.Iterable[global___ConfigurationTagsEntry] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "description", b"description", "engine_type", b"engine_type", "engine_version", b"engine_version", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Configuration = Configuration

@typing_extensions.final
class ConfigurationAssociationConfigurationId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    revision: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        revision: builtins.int = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___ConfigurationAssociationConfigurationId = ConfigurationAssociationConfigurationId

@typing_extensions.final
class ConfigurationAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BROKER_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    broker: builtins.str
    @property
    def configuration(self) -> global___ConfigurationAssociationConfigurationId: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        broker: builtins.str = ...,
        configuration: global___ConfigurationAssociationConfigurationId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["broker", b"broker", "configuration", b"configuration", "resource_info", b"resource_info"]) -> None: ...

global___ConfigurationAssociation = ConfigurationAssociation
