# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticache_cachecluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&aws/aws_elasticache_cachecluster.proto\x12(oak9.tython.aws.elasticache_cachecluster\x1a\x13shared/shared.proto\"\xfa\x05\n\x0c\x43\x61\x63heCluster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61z_mode\x18\x02 \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x03 \x01(\x08\x12\x17\n\x0f\x63\x61\x63he_node_type\x18\x04 \x01(\t\x12\"\n\x1a\x63\x61\x63he_parameter_group_name\x18\x05 \x01(\t\x12\"\n\x1a\x63\x61\x63he_security_group_names\x18\x06 \x03(\t\x12\x1f\n\x17\x63\x61\x63he_subnet_group_name\x18\x07 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x08 \x01(\t\x12\x0e\n\x06\x65ngine\x18\t \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\n \x01(\t\x12\x1e\n\x16notification_topic_arn\x18\x0b \x01(\t\x12\x17\n\x0fnum_cache_nodes\x18\x0c \x01(\x05\x12\x0c\n\x04port\x18\r \x01(\x05\x12#\n\x1bpreferred_availability_zone\x18\x0e \x01(\t\x12$\n\x1cpreferred_availability_zones\x18\x0f \x03(\t\x12$\n\x1cpreferred_maintenance_window\x18\x10 \x01(\t\x12\x15\n\rsnapshot_arns\x18\x11 \x03(\t\x12\x15\n\rsnapshot_name\x18\x12 \x01(\t\x12 \n\x18snapshot_retention_limit\x18\x13 \x01(\x05\x12\x17\n\x0fsnapshot_window\x18\x14 \x01(\t\x12N\n\x04tags\x18\x15 \x03(\x0b\x32@.oak9.tython.aws.elasticache_cachecluster.CacheCluster.TagsEntry\x12\x1e\n\x16vpc_security_group_ids\x18\x16 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe7\x02\n\x18\x45lastiCache_CacheCluster\x12M\n\rcache_cluster\x18\x01 \x01(\x0b\x32\x36.oak9.tython.aws.elasticache_cachecluster.CacheCluster\x12O\n\x0esecurity_group\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.elasticache_cachecluster.SecurityGroup\x12^\n\x16security_group_ingress\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.elasticache_cachecluster.SecurityGroupIngress\x12K\n\x0csubnet_group\x18\x04 \x01(\x0b\x32\x35.oak9.tython.aws.elasticache_cachecluster.SubnetGroup\"]\n\rSecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xba\x01\n\x14SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x61\x63he_security_group_name\x18\x02 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x03 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x04 \x01(\t\"\x90\x01\n\x0bSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x63\x61\x63he_subnet_group_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticache_cachecluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CACHECLUSTER_TAGSENTRY._options = None
  _CACHECLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _CACHECLUSTER._serialized_start=106
  _CACHECLUSTER._serialized_end=868
  _CACHECLUSTER_TAGSENTRY._serialized_start=825
  _CACHECLUSTER_TAGSENTRY._serialized_end=868
  _ELASTICACHE_CACHECLUSTER._serialized_start=871
  _ELASTICACHE_CACHECLUSTER._serialized_end=1230
  _SECURITYGROUP._serialized_start=1232
  _SECURITYGROUP._serialized_end=1325
  _SECURITYGROUPINGRESS._serialized_start=1328
  _SECURITYGROUPINGRESS._serialized_end=1514
  _SUBNETGROUP._serialized_start=1517
  _SUBNETGROUP._serialized_end=1661
# @@protoc_insertion_point(module_scope)
