"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_container_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleContainer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_CLUSTER_FIELD_NUMBER: builtins.int
    CONTAINER_NODE_POOL_FIELD_NUMBER: builtins.int
    @property
    def container_cluster(self) -> gcp.gcp_container_pb2.ContainerCluster: ...
    @property
    def container_node_pool(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_container_pb2.ContainerNodePool]: ...
    def __init__(
        self,
        *,
        container_cluster: gcp.gcp_container_pb2.ContainerCluster | None = ...,
        container_node_pool: collections.abc.Iterable[gcp.gcp_container_pb2.ContainerNodePool] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_cluster", b"container_cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_cluster", b"container_cluster", "container_node_pool", b"container_node_pool"]) -> None: ...

global___GoogleContainer = GoogleContainer
