"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NotebooksEnvironmentXContainerImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    repository: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository", "tag", b"tag"]) -> None: ...

global___NotebooksEnvironmentXContainerImage = NotebooksEnvironmentXContainerImage

@typing_extensions.final
class NotebooksEnvironmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NotebooksEnvironmentXTimeouts = NotebooksEnvironmentXTimeouts

@typing_extensions.final
class NotebooksEnvironmentXVmImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FAMILY_FIELD_NUMBER: builtins.int
    IMAGE_NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    image_family: builtins.str
    image_name: builtins.str
    project: builtins.str
    def __init__(
        self,
        *,
        image_family: builtins.str = ...,
        image_name: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_family", b"image_family", "image_name", b"image_name", "project", b"project"]) -> None: ...

global___NotebooksEnvironmentXVmImage = NotebooksEnvironmentXVmImage

@typing_extensions.final
class NotebooksEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POST_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    CONTAINER_IMAGE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VM_IMAGE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    post_startup_script: builtins.str
    project: builtins.str
    @property
    def container_image(self) -> global___NotebooksEnvironmentXContainerImage: ...
    @property
    def timeouts(self) -> global___NotebooksEnvironmentXTimeouts: ...
    @property
    def vm_image(self) -> global___NotebooksEnvironmentXVmImage: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        post_startup_script: builtins.str = ...,
        project: builtins.str = ...,
        container_image: global___NotebooksEnvironmentXContainerImage | None = ...,
        timeouts: global___NotebooksEnvironmentXTimeouts | None = ...,
        vm_image: global___NotebooksEnvironmentXVmImage | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_image", b"container_image", "resource_info", b"resource_info", "timeouts", b"timeouts", "vm_image", b"vm_image"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_image", b"container_image", "create_time", b"create_time", "description", b"description", "display_name", b"display_name", "id", b"id", "location", b"location", "name", b"name", "post_startup_script", b"post_startup_script", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "vm_image", b"vm_image"]) -> None: ...

global___NotebooksEnvironment = NotebooksEnvironment

@typing_extensions.final
class NotebooksInstanceXAcceleratorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORE_COUNT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    core_count: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        core_count: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["core_count", b"core_count", "type", b"type"]) -> None: ...

global___NotebooksInstanceXAcceleratorConfig = NotebooksInstanceXAcceleratorConfig

@typing_extensions.final
class NotebooksInstanceXContainerImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    repository: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository", "tag", b"tag"]) -> None: ...

global___NotebooksInstanceXContainerImage = NotebooksInstanceXContainerImage

@typing_extensions.final
class NotebooksInstanceXReservationAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUME_RESERVATION_TYPE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    consume_reservation_type: builtins.str
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        consume_reservation_type: builtins.str = ...,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["consume_reservation_type", b"consume_reservation_type", "key", b"key", "values", b"values"]) -> None: ...

global___NotebooksInstanceXReservationAffinity = NotebooksInstanceXReservationAffinity

@typing_extensions.final
class NotebooksInstanceXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    ENABLE_VTPM_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    enable_vtpm: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
        enable_vtpm: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot", "enable_vtpm", b"enable_vtpm"]) -> None: ...

global___NotebooksInstanceXShieldedInstanceConfig = NotebooksInstanceXShieldedInstanceConfig

@typing_extensions.final
class NotebooksInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NotebooksInstanceXTimeouts = NotebooksInstanceXTimeouts

@typing_extensions.final
class NotebooksInstanceXVmImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FAMILY_FIELD_NUMBER: builtins.int
    IMAGE_NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    image_family: builtins.str
    image_name: builtins.str
    project: builtins.str
    def __init__(
        self,
        *,
        image_family: builtins.str = ...,
        image_name: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_family", b"image_family", "image_name", b"image_name", "project", b"project"]) -> None: ...

global___NotebooksInstanceXVmImage = NotebooksInstanceXVmImage

@typing_extensions.final
class NotebooksInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BOOT_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    BOOT_DISK_TYPE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    CUSTOM_GPU_DRIVER_PATH_FIELD_NUMBER: builtins.int
    DATA_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DATA_DISK_TYPE_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTALL_GPU_DRIVER_FIELD_NUMBER: builtins.int
    INSTANCE_OWNERS_FIELD_NUMBER: builtins.int
    KMS_KEY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NIC_TYPE_FIELD_NUMBER: builtins.int
    NO_PROXY_ACCESS_FIELD_NUMBER: builtins.int
    NO_PUBLIC_IP_FIELD_NUMBER: builtins.int
    NO_REMOVE_DATA_DISK_FIELD_NUMBER: builtins.int
    POST_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROXY_URI_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_SCOPES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    ACCELERATOR_CONFIG_FIELD_NUMBER: builtins.int
    CONTAINER_IMAGE_FIELD_NUMBER: builtins.int
    RESERVATION_AFFINITY_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VM_IMAGE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    boot_disk_size_gb: builtins.float
    boot_disk_type: builtins.str
    create_time: builtins.str
    custom_gpu_driver_path: builtins.str
    data_disk_size_gb: builtins.float
    data_disk_type: builtins.str
    disk_encryption: builtins.str
    id: builtins.str
    install_gpu_driver: builtins.bool
    @property
    def instance_owners(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    kms_key: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    network: builtins.str
    nic_type: builtins.str
    no_proxy_access: builtins.bool
    no_public_ip: builtins.bool
    no_remove_data_disk: builtins.bool
    post_startup_script: builtins.str
    project: builtins.str
    proxy_uri: builtins.str
    service_account: builtins.str
    @property
    def service_account_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    state: builtins.str
    subnet: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    update_time: builtins.str
    @property
    def accelerator_config(self) -> global___NotebooksInstanceXAcceleratorConfig: ...
    @property
    def container_image(self) -> global___NotebooksInstanceXContainerImage: ...
    @property
    def reservation_affinity(self) -> global___NotebooksInstanceXReservationAffinity: ...
    @property
    def shielded_instance_config(self) -> global___NotebooksInstanceXShieldedInstanceConfig: ...
    @property
    def timeouts(self) -> global___NotebooksInstanceXTimeouts: ...
    @property
    def vm_image(self) -> global___NotebooksInstanceXVmImage: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        boot_disk_size_gb: builtins.float = ...,
        boot_disk_type: builtins.str = ...,
        create_time: builtins.str = ...,
        custom_gpu_driver_path: builtins.str = ...,
        data_disk_size_gb: builtins.float = ...,
        data_disk_type: builtins.str = ...,
        disk_encryption: builtins.str = ...,
        id: builtins.str = ...,
        install_gpu_driver: builtins.bool = ...,
        instance_owners: collections.abc.Iterable[builtins.str] | None = ...,
        kms_key: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        nic_type: builtins.str = ...,
        no_proxy_access: builtins.bool = ...,
        no_public_ip: builtins.bool = ...,
        no_remove_data_disk: builtins.bool = ...,
        post_startup_script: builtins.str = ...,
        project: builtins.str = ...,
        proxy_uri: builtins.str = ...,
        service_account: builtins.str = ...,
        service_account_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        state: builtins.str = ...,
        subnet: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        update_time: builtins.str = ...,
        accelerator_config: global___NotebooksInstanceXAcceleratorConfig | None = ...,
        container_image: global___NotebooksInstanceXContainerImage | None = ...,
        reservation_affinity: global___NotebooksInstanceXReservationAffinity | None = ...,
        shielded_instance_config: global___NotebooksInstanceXShieldedInstanceConfig | None = ...,
        timeouts: global___NotebooksInstanceXTimeouts | None = ...,
        vm_image: global___NotebooksInstanceXVmImage | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accelerator_config", b"accelerator_config", "container_image", b"container_image", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "shielded_instance_config", b"shielded_instance_config", "timeouts", b"timeouts", "vm_image", b"vm_image"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_config", b"accelerator_config", "boot_disk_size_gb", b"boot_disk_size_gb", "boot_disk_type", b"boot_disk_type", "container_image", b"container_image", "create_time", b"create_time", "custom_gpu_driver_path", b"custom_gpu_driver_path", "data_disk_size_gb", b"data_disk_size_gb", "data_disk_type", b"data_disk_type", "disk_encryption", b"disk_encryption", "id", b"id", "install_gpu_driver", b"install_gpu_driver", "instance_owners", b"instance_owners", "kms_key", b"kms_key", "labels", b"labels", "location", b"location", "machine_type", b"machine_type", "metadata", b"metadata", "name", b"name", "network", b"network", "nic_type", b"nic_type", "no_proxy_access", b"no_proxy_access", "no_public_ip", b"no_public_ip", "no_remove_data_disk", b"no_remove_data_disk", "post_startup_script", b"post_startup_script", "project", b"project", "proxy_uri", b"proxy_uri", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "service_account", b"service_account", "service_account_scopes", b"service_account_scopes", "shielded_instance_config", b"shielded_instance_config", "state", b"state", "subnet", b"subnet", "tags", b"tags", "timeouts", b"timeouts", "update_time", b"update_time", "vm_image", b"vm_image"]) -> None: ...

global___NotebooksInstance = NotebooksInstance

@typing_extensions.final
class NotebooksInstanceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___NotebooksInstanceIamBindingXCondition = NotebooksInstanceIamBindingXCondition

@typing_extensions.final
class NotebooksInstanceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___NotebooksInstanceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___NotebooksInstanceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance_name", b"instance_name", "location", b"location", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___NotebooksInstanceIamBinding = NotebooksInstanceIamBinding

@typing_extensions.final
class NotebooksInstanceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___NotebooksInstanceIamMemberXCondition = NotebooksInstanceIamMemberXCondition

@typing_extensions.final
class NotebooksInstanceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___NotebooksInstanceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___NotebooksInstanceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance_name", b"instance_name", "location", b"location", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___NotebooksInstanceIamMember = NotebooksInstanceIamMember

@typing_extensions.final
class NotebooksInstanceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "instance_name", b"instance_name", "location", b"location", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___NotebooksInstanceIamPolicy = NotebooksInstanceIamPolicy

@typing_extensions.final
class NotebooksLocationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NotebooksLocationXTimeouts = NotebooksLocationXTimeouts

@typing_extensions.final
class NotebooksLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___NotebooksLocationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___NotebooksLocationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___NotebooksLocation = NotebooksLocation

@typing_extensions.final
class NotebooksRuntimeXAccessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TYPE_FIELD_NUMBER: builtins.int
    PROXY_URI_FIELD_NUMBER: builtins.int
    RUNTIME_OWNER_FIELD_NUMBER: builtins.int
    access_type: builtins.str
    proxy_uri: builtins.str
    runtime_owner: builtins.str
    def __init__(
        self,
        *,
        access_type: builtins.str = ...,
        proxy_uri: builtins.str = ...,
        runtime_owner: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_type", b"access_type", "proxy_uri", b"proxy_uri", "runtime_owner", b"runtime_owner"]) -> None: ...

global___NotebooksRuntimeXAccessConfig = NotebooksRuntimeXAccessConfig

@typing_extensions.final
class NotebooksRuntimeXSoftwareConfigXKernels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    repository: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository", "tag", b"tag"]) -> None: ...

global___NotebooksRuntimeXSoftwareConfigXKernels = NotebooksRuntimeXSoftwareConfigXKernels

@typing_extensions.final
class NotebooksRuntimeXSoftwareConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOM_GPU_DRIVER_PATH_FIELD_NUMBER: builtins.int
    ENABLE_HEALTH_MONITORING_FIELD_NUMBER: builtins.int
    IDLE_SHUTDOWN_FIELD_NUMBER: builtins.int
    IDLE_SHUTDOWN_TIMEOUT_FIELD_NUMBER: builtins.int
    INSTALL_GPU_DRIVER_FIELD_NUMBER: builtins.int
    NOTEBOOK_UPGRADE_SCHEDULE_FIELD_NUMBER: builtins.int
    POST_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    POST_STARTUP_SCRIPT_BEHAVIOR_FIELD_NUMBER: builtins.int
    UPGRADEABLE_FIELD_NUMBER: builtins.int
    KERNELS_FIELD_NUMBER: builtins.int
    custom_gpu_driver_path: builtins.str
    enable_health_monitoring: builtins.bool
    idle_shutdown: builtins.bool
    idle_shutdown_timeout: builtins.float
    install_gpu_driver: builtins.bool
    notebook_upgrade_schedule: builtins.str
    post_startup_script: builtins.str
    post_startup_script_behavior: builtins.str
    upgradeable: builtins.bool
    @property
    def kernels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebooksRuntimeXSoftwareConfigXKernels]: ...
    def __init__(
        self,
        *,
        custom_gpu_driver_path: builtins.str = ...,
        enable_health_monitoring: builtins.bool = ...,
        idle_shutdown: builtins.bool = ...,
        idle_shutdown_timeout: builtins.float = ...,
        install_gpu_driver: builtins.bool = ...,
        notebook_upgrade_schedule: builtins.str = ...,
        post_startup_script: builtins.str = ...,
        post_startup_script_behavior: builtins.str = ...,
        upgradeable: builtins.bool = ...,
        kernels: collections.abc.Iterable[global___NotebooksRuntimeXSoftwareConfigXKernels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_gpu_driver_path", b"custom_gpu_driver_path", "enable_health_monitoring", b"enable_health_monitoring", "idle_shutdown", b"idle_shutdown", "idle_shutdown_timeout", b"idle_shutdown_timeout", "install_gpu_driver", b"install_gpu_driver", "kernels", b"kernels", "notebook_upgrade_schedule", b"notebook_upgrade_schedule", "post_startup_script", b"post_startup_script", "post_startup_script_behavior", b"post_startup_script_behavior", "upgradeable", b"upgradeable"]) -> None: ...

global___NotebooksRuntimeXSoftwareConfig = NotebooksRuntimeXSoftwareConfig

@typing_extensions.final
class NotebooksRuntimeXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NotebooksRuntimeXTimeouts = NotebooksRuntimeXTimeouts

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORE_COUNT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    core_count: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        core_count: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["core_count", b"core_count", "type", b"type"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    repository: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository", "tag", b"tag"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISK_NAME_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DISK_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    description: builtins.str
    disk_name: builtins.str
    disk_size_gb: builtins.float
    disk_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disk_name: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        disk_type: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disk_name", b"disk_name", "disk_size_gb", b"disk_size_gb", "disk_type", b"disk_type", "labels", b"labels"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_DELETE_FIELD_NUMBER: builtins.int
    BOOT_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    GUEST_OS_FEATURES_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    INTERFACE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LICENSES_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    INITIALIZE_PARAMS_FIELD_NUMBER: builtins.int
    auto_delete: builtins.bool
    boot: builtins.bool
    device_name: builtins.str
    @property
    def guest_os_features(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    index: builtins.float
    interface: builtins.str
    kind: builtins.str
    @property
    def licenses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    mode: builtins.str
    source: builtins.str
    type: builtins.str
    @property
    def initialize_params(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams: ...
    def __init__(
        self,
        *,
        auto_delete: builtins.bool = ...,
        boot: builtins.bool = ...,
        device_name: builtins.str = ...,
        guest_os_features: collections.abc.Iterable[builtins.str] | None = ...,
        index: builtins.float = ...,
        interface: builtins.str = ...,
        kind: builtins.str = ...,
        licenses: collections.abc.Iterable[builtins.str] | None = ...,
        mode: builtins.str = ...,
        source: builtins.str = ...,
        type: builtins.str = ...,
        initialize_params: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["initialize_params", b"initialize_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete", b"auto_delete", "boot", b"boot", "device_name", b"device_name", "guest_os_features", b"guest_os_features", "index", b"index", "initialize_params", b"initialize_params", "interface", b"interface", "kind", b"kind", "licenses", b"licenses", "mode", b"mode", "source", b"source", "type", b"type"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_FIELD_NUMBER: builtins.int
    kms_key: builtins.str
    def __init__(
        self,
        *,
        kms_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key", b"kms_key"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    ENABLE_VTPM_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    enable_vtpm: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
        enable_vtpm: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot", "enable_vtpm", b"enable_vtpm"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GuestAttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    GUEST_ATTRIBUTES_FIELD_NUMBER: builtins.int
    INTERNAL_IP_ONLY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NIC_TYPE_FIELD_NUMBER: builtins.int
    RESERVED_IP_RANGE_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    ACCELERATOR_CONFIG_FIELD_NUMBER: builtins.int
    CONTAINER_IMAGES_FIELD_NUMBER: builtins.int
    DATA_DISK_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def guest_attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    internal_ip_only: builtins.bool
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    network: builtins.str
    nic_type: builtins.str
    reserved_ip_range: builtins.str
    subnet: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    zone: builtins.str
    @property
    def accelerator_config(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig: ...
    @property
    def container_images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages]: ...
    @property
    def data_disk(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk: ...
    @property
    def encryption_config(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig: ...
    @property
    def shielded_instance_config(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig: ...
    def __init__(
        self,
        *,
        guest_attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        internal_ip_only: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network: builtins.str = ...,
        nic_type: builtins.str = ...,
        reserved_ip_range: builtins.str = ...,
        subnet: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        zone: builtins.str = ...,
        accelerator_config: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig | None = ...,
        container_images: collections.abc.Iterable[global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages] | None = ...,
        data_disk: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk | None = ...,
        encryption_config: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig | None = ...,
        shielded_instance_config: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accelerator_config", b"accelerator_config", "data_disk", b"data_disk", "encryption_config", b"encryption_config", "shielded_instance_config", b"shielded_instance_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_config", b"accelerator_config", "container_images", b"container_images", "data_disk", b"data_disk", "encryption_config", b"encryption_config", "guest_attributes", b"guest_attributes", "internal_ip_only", b"internal_ip_only", "labels", b"labels", "machine_type", b"machine_type", "metadata", b"metadata", "network", b"network", "nic_type", b"nic_type", "reserved_ip_range", b"reserved_ip_range", "shielded_instance_config", b"shielded_instance_config", "subnet", b"subnet", "tags", b"tags", "zone", b"zone"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfig = NotebooksRuntimeXVirtualMachineXVirtualMachineConfig

@typing_extensions.final
class NotebooksRuntimeXVirtualMachine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_CONFIG_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    instance_name: builtins.str
    @property
    def virtual_machine_config(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfig: ...
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
        instance_name: builtins.str = ...,
        virtual_machine_config: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["virtual_machine_config", b"virtual_machine_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_id", b"instance_id", "instance_name", b"instance_name", "virtual_machine_config", b"virtual_machine_config"]) -> None: ...

global___NotebooksRuntimeXVirtualMachine = NotebooksRuntimeXVirtualMachine

@typing_extensions.final
class NotebooksRuntime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetricsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    HEALTH_STATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    SOFTWARE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    health_state: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def metrics(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    state: builtins.str
    @property
    def access_config(self) -> global___NotebooksRuntimeXAccessConfig: ...
    @property
    def software_config(self) -> global___NotebooksRuntimeXSoftwareConfig: ...
    @property
    def timeouts(self) -> global___NotebooksRuntimeXTimeouts: ...
    @property
    def virtual_machine(self) -> global___NotebooksRuntimeXVirtualMachine: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        health_state: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        metrics: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        access_config: global___NotebooksRuntimeXAccessConfig | None = ...,
        software_config: global___NotebooksRuntimeXSoftwareConfig | None = ...,
        timeouts: global___NotebooksRuntimeXTimeouts | None = ...,
        virtual_machine: global___NotebooksRuntimeXVirtualMachine | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_config", b"access_config", "resource_info", b"resource_info", "software_config", b"software_config", "timeouts", b"timeouts", "virtual_machine", b"virtual_machine"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_config", b"access_config", "health_state", b"health_state", "id", b"id", "location", b"location", "metrics", b"metrics", "name", b"name", "project", b"project", "resource_info", b"resource_info", "software_config", b"software_config", "state", b"state", "timeouts", b"timeouts", "virtual_machine", b"virtual_machine"]) -> None: ...

global___NotebooksRuntime = NotebooksRuntime

@typing_extensions.final
class NotebooksRuntimeIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___NotebooksRuntimeIamBindingXCondition = NotebooksRuntimeIamBindingXCondition

@typing_extensions.final
class NotebooksRuntimeIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    runtime_name: builtins.str
    @property
    def condition(self) -> global___NotebooksRuntimeIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        runtime_name: builtins.str = ...,
        condition: global___NotebooksRuntimeIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "runtime_name", b"runtime_name"]) -> None: ...

global___NotebooksRuntimeIamBinding = NotebooksRuntimeIamBinding

@typing_extensions.final
class NotebooksRuntimeIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___NotebooksRuntimeIamMemberXCondition = NotebooksRuntimeIamMemberXCondition

@typing_extensions.final
class NotebooksRuntimeIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    runtime_name: builtins.str
    @property
    def condition(self) -> global___NotebooksRuntimeIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        runtime_name: builtins.str = ...,
        condition: global___NotebooksRuntimeIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "runtime_name", b"runtime_name"]) -> None: ...

global___NotebooksRuntimeIamMember = NotebooksRuntimeIamMember

@typing_extensions.final
class NotebooksRuntimeIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    runtime_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        runtime_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "location", b"location", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "runtime_name", b"runtime_name"]) -> None: ...

global___NotebooksRuntimeIamPolicy = NotebooksRuntimeIamPolicy
