# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_greengrass.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_greengrass.proto\x12\x1aoak9.tython.aws.greengrass\x1a\x13shared/shared.proto\"\x8b\x02\n\x1c\x43onnectorDefinitionConnector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rconnector_arn\x18\x02 \x01(\t\x12\\\n\nparameters\x18\x03 \x03(\x0b\x32H.oak9.tython.aws.greengrass.ConnectorDefinitionConnector.ParametersEntry\x12\n\n\x02id\x18\x04 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n-ConnectorDefinitionConnectorDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\nconnectors\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.greengrass.ConnectorDefinitionConnector\"\xb6\x02\n\x13\x43onnectorDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x0finitial_version\x18\x02 \x01(\x0b\x32I.oak9.tython.aws.greengrass.ConnectorDefinitionConnectorDefinitionVersion\x12G\n\x04tags\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.greengrass.ConnectorDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\n\n\nGreengrass\x12M\n\x14\x63onnector_definition\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.greengrass.ConnectorDefinition\x12\\\n\x1c\x63onnector_definition_version\x18\x02 \x03(\x0b\x32\x36.oak9.tython.aws.greengrass.ConnectorDefinitionVersion\x12\x43\n\x0f\x63ore_definition\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.greengrass.CoreDefinition\x12R\n\x17\x63ore_definition_version\x18\x04 \x03(\x0b\x32\x31.oak9.tython.aws.greengrass.CoreDefinitionVersion\x12G\n\x11\x64\x65vice_definition\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.greengrass.DeviceDefinition\x12V\n\x19\x64\x65vice_definition_version\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.greengrass.DeviceDefinitionVersion\x12K\n\x13\x66unction_definition\x18\x07 \x03(\x0b\x32..oak9.tython.aws.greengrass.FunctionDefinition\x12Z\n\x1b\x66unction_definition_version\x18\x08 \x03(\x0b\x32\x35.oak9.tython.aws.greengrass.FunctionDefinitionVersion\x12\x30\n\x05group\x18\t \x03(\x0b\x32!.oak9.tython.aws.greengrass.Group\x12?\n\rgroup_version\x18\n \x03(\x0b\x32(.oak9.tython.aws.greengrass.GroupVersion\x12G\n\x11logger_definition\x18\x0b \x03(\x0b\x32,.oak9.tython.aws.greengrass.LoggerDefinition\x12V\n\x19logger_definition_version\x18\x0c \x03(\x0b\x32\x33.oak9.tython.aws.greengrass.LoggerDefinitionVersion\x12K\n\x13resource_definition\x18\r \x03(\x0b\x32..oak9.tython.aws.greengrass.ResourceDefinition\x12Z\n\x1bresource_definition_version\x18\x0e \x03(\x0b\x32\x35.oak9.tython.aws.greengrass.ResourceDefinitionVersion\x12S\n\x17subscription_definition\x18\x0f \x03(\x0b\x32\x32.oak9.tython.aws.greengrass.SubscriptionDefinition\x12\x62\n\x1fsubscription_definition_version\x18\x10 \x03(\x0b\x32\x39.oak9.tython.aws.greengrass.SubscriptionDefinitionVersion\"\x99\x02\n#ConnectorDefinitionVersionConnector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rconnector_arn\x18\x02 \x01(\t\x12\x63\n\nparameters\x18\x03 \x03(\x0b\x32O.oak9.tython.aws.greengrass.ConnectorDefinitionVersionConnector.ParametersEntry\x12\n\n\x02id\x18\x04 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x01\n\x1a\x43onnectorDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\nconnectors\x18\x02 \x03(\x0b\x32?.oak9.tython.aws.greengrass.ConnectorDefinitionVersionConnector\x12\x1f\n\x17\x63onnector_definition_id\x18\x03 \x01(\t\"\x9a\x01\n\x12\x43oreDefinitionCore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsync_shadow\x18\x02 \x01(\x08\x12\x11\n\tthing_arn\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\x9d\x01\n#CoreDefinitionCoreDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x05\x63ores\x18\x02 \x03(\x0b\x32..oak9.tython.aws.greengrass.CoreDefinitionCore\"\xa2\x02\n\x0e\x43oreDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x0finitial_version\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.greengrass.CoreDefinitionCoreDefinitionVersion\x12\x42\n\x04tags\x18\x03 \x03(\x0b\x32\x34.oak9.tython.aws.greengrass.CoreDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x01\n\x19\x43oreDefinitionVersionCore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsync_shadow\x18\x02 \x01(\x08\x12\x11\n\tthing_arn\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\xb2\x01\n\x15\x43oreDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x05\x63ores\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.greengrass.CoreDefinitionVersionCore\x12\x1a\n\x12\x63ore_definition_id\x18\x03 \x01(\t\"\x9e\x01\n\x16\x44\x65viceDefinitionDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsync_shadow\x18\x02 \x01(\x08\x12\x11\n\tthing_arn\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\xa7\x01\n\'DeviceDefinitionDeviceDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.greengrass.DeviceDefinitionDevice\"\xaa\x02\n\x10\x44\x65viceDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x0finitial_version\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.greengrass.DeviceDefinitionDeviceDefinitionVersion\x12\x44\n\x04tags\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.greengrass.DeviceDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x01\n\x1d\x44\x65viceDefinitionVersionDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsync_shadow\x18\x02 \x01(\x08\x12\x11\n\tthing_arn\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\xbc\x01\n\x17\x44\x65viceDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x65vice_definition_id\x18\x02 \x01(\t\x12J\n\x07\x64\x65vices\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.greengrass.DeviceDefinitionVersionDevice\"l\n\x17\x46unctionDefinitionRunAs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03uid\x18\x02 \x01(\x05\x12\x0b\n\x03gid\x18\x03 \x01(\x05\"\xb3\x01\n\x1b\x46unctionDefinitionExecution\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eisolation_mode\x18\x02 \x01(\t\x12\x43\n\x06run_as\x18\x03 \x01(\x0b\x32\x33.oak9.tython.aws.greengrass.FunctionDefinitionRunAs\"\xa6\x01\n\x1f\x46unctionDefinitionDefaultConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\texecution\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.greengrass.FunctionDefinitionExecution\"\x8a\x01\n&FunctionDefinitionResourceAccessPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x12\n\npermission\x18\x03 \x01(\t\"\xaf\x03\n\x1d\x46unctionDefinitionEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12[\n\tvariables\x18\x02 \x03(\x0b\x32H.oak9.tython.aws.greengrass.FunctionDefinitionEnvironment.VariablesEntry\x12J\n\texecution\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.greengrass.FunctionDefinitionExecution\x12\x64\n\x18resource_access_policies\x18\x04 \x03(\x0b\x32\x42.oak9.tython.aws.greengrass.FunctionDefinitionResourceAccessPolicy\x12\x14\n\x0c\x61\x63\x63\x65ss_sysfs\x18\x05 \x01(\x08\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x02\n\'FunctionDefinitionFunctionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmemory_size\x18\x02 \x01(\x05\x12\x0e\n\x06pinned\x18\x03 \x01(\x08\x12\x11\n\texec_args\x18\x04 \x01(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x15\n\rencoding_type\x18\x06 \x01(\t\x12N\n\x0b\x65nvironment\x18\x07 \x01(\x0b\x32\x39.oak9.tython.aws.greengrass.FunctionDefinitionEnvironment\x12\x12\n\nexecutable\x18\x08 \x01(\t\"\xdc\x01\n\x1a\x46unctionDefinitionFunction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66unction_arn\x18\x02 \x01(\t\x12\x63\n\x16\x66unction_configuration\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.greengrass.FunctionDefinitionFunctionConfiguration\x12\n\n\x02id\x18\x04 \x01(\t\"\x86\x02\n+FunctionDefinitionFunctionDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x0e\x64\x65\x66\x61ult_config\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.greengrass.FunctionDefinitionDefaultConfig\x12I\n\tfunctions\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.greengrass.FunctionDefinitionFunction\"\xb2\x02\n\x12\x46unctionDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x0finitial_version\x18\x02 \x01(\x0b\x32G.oak9.tython.aws.greengrass.FunctionDefinitionFunctionDefinitionVersion\x12\x46\n\x04tags\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.greengrass.FunctionDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"s\n\x1e\x46unctionDefinitionVersionRunAs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03uid\x18\x02 \x01(\x05\x12\x0b\n\x03gid\x18\x03 \x01(\x05\"\xc1\x01\n\"FunctionDefinitionVersionExecution\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eisolation_mode\x18\x02 \x01(\t\x12J\n\x06run_as\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.greengrass.FunctionDefinitionVersionRunAs\"\xb4\x01\n&FunctionDefinitionVersionDefaultConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\texecution\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.greengrass.FunctionDefinitionVersionExecution\"\x91\x01\n-FunctionDefinitionVersionResourceAccessPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x12\n\npermission\x18\x03 \x01(\t\"\xcb\x03\n$FunctionDefinitionVersionEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\tvariables\x18\x02 \x03(\x0b\x32O.oak9.tython.aws.greengrass.FunctionDefinitionVersionEnvironment.VariablesEntry\x12Q\n\texecution\x18\x03 \x01(\x0b\x32>.oak9.tython.aws.greengrass.FunctionDefinitionVersionExecution\x12k\n\x18resource_access_policies\x18\x04 \x03(\x0b\x32I.oak9.tython.aws.greengrass.FunctionDefinitionVersionResourceAccessPolicy\x12\x14\n\x0c\x61\x63\x63\x65ss_sysfs\x18\x05 \x01(\x08\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x02\n.FunctionDefinitionVersionFunctionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmemory_size\x18\x02 \x01(\x05\x12\x0e\n\x06pinned\x18\x03 \x01(\x08\x12\x11\n\texec_args\x18\x04 \x01(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x15\n\rencoding_type\x18\x06 \x01(\t\x12U\n\x0b\x65nvironment\x18\x07 \x01(\x0b\x32@.oak9.tython.aws.greengrass.FunctionDefinitionVersionEnvironment\x12\x12\n\nexecutable\x18\x08 \x01(\t\"\xea\x01\n!FunctionDefinitionVersionFunction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66unction_arn\x18\x02 \x01(\t\x12j\n\x16\x66unction_configuration\x18\x03 \x01(\x0b\x32J.oak9.tython.aws.greengrass.FunctionDefinitionVersionFunctionConfiguration\x12\n\n\x02id\x18\x04 \x01(\t\"\xa2\x02\n\x19\x46unctionDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x0e\x64\x65\x66\x61ult_config\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.greengrass.FunctionDefinitionVersionDefaultConfig\x12P\n\tfunctions\x18\x03 \x03(\x0b\x32=.oak9.tython.aws.greengrass.FunctionDefinitionVersionFunction\x12\x1e\n\x16\x66unction_definition_id\x18\x04 \x01(\t\"\xe8\x02\n\x11GroupGroupVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1dlogger_definition_version_arn\x18\x02 \x01(\t\x12%\n\x1d\x64\x65vice_definition_version_arn\x18\x03 \x01(\t\x12\'\n\x1f\x66unction_definition_version_arn\x18\x04 \x01(\t\x12#\n\x1b\x63ore_definition_version_arn\x18\x05 \x01(\t\x12\'\n\x1fresource_definition_version_arn\x18\x06 \x01(\t\x12(\n connector_definition_version_arn\x18\x07 \x01(\t\x12+\n#subscription_definition_version_arn\x18\x08 \x01(\t\"\x90\x02\n\x05Group\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\x0finitial_version\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.greengrass.GroupGroupVersion\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x39\n\x04tags\x18\x04 \x03(\x0b\x32+.oak9.tython.aws.greengrass.Group.TagsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x02\n\x0cGroupVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1dlogger_definition_version_arn\x18\x02 \x01(\t\x12%\n\x1d\x64\x65vice_definition_version_arn\x18\x03 \x01(\t\x12\'\n\x1f\x66unction_definition_version_arn\x18\x04 \x01(\t\x12#\n\x1b\x63ore_definition_version_arn\x18\x05 \x01(\t\x12\'\n\x1fresource_definition_version_arn\x18\x06 \x01(\t\x12(\n connector_definition_version_arn\x18\x07 \x01(\t\x12+\n#subscription_definition_version_arn\x18\x08 \x01(\t\x12\x10\n\x08group_id\x18\t \x01(\t\"\x8e\x01\n\x16LoggerDefinitionLogger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05space\x18\x02 \x01(\x05\x12\r\n\x05level\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x11\n\tcomponent\x18\x05 \x01(\t\"\xa7\x01\n\'LoggerDefinitionLoggerDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x07loggers\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.greengrass.LoggerDefinitionLogger\"\xaa\x02\n\x10LoggerDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x0finitial_version\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.greengrass.LoggerDefinitionLoggerDefinitionVersion\x12\x44\n\x04tags\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.greengrass.LoggerDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n\x1dLoggerDefinitionVersionLogger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05space\x18\x02 \x01(\x05\x12\r\n\x05level\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x11\n\tcomponent\x18\x05 \x01(\t\"\xbc\x01\n\x17LoggerDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14logger_definition_id\x18\x02 \x01(\t\x12J\n\x07loggers\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.greengrass.LoggerDefinitionVersionLogger\"\xa9\x01\n2ResourceDefinitionSecretsManagerSecretResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12-\n%additional_staging_labels_to_download\x18\x03 \x03(\t\"\x98\x01\n.ResourceDefinitionResourceDownloadOwnerSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bgroup_owner\x18\x02 \x01(\t\x12\x18\n\x10group_permission\x18\x03 \x01(\t\"\x8f\x02\n;ResourceDefinitionSageMakerMachineLearningModelResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\rowner_setting\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.greengrass.ResourceDefinitionResourceDownloadOwnerSetting\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x1a\n\x12sage_maker_job_arn\x18\x04 \x01(\t\"\x91\x01\n#ResourceDefinitionGroupOwnerSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x61uto_add_group_owner\x18\x02 \x01(\x08\x12\x13\n\x0bgroup_owner\x18\x03 \x01(\t\"\xf1\x01\n)ResourceDefinitionLocalVolumeResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\\\n\x13group_owner_setting\x18\x04 \x01(\x0b\x32?.oak9.tython.aws.greengrass.ResourceDefinitionGroupOwnerSetting\"\xd7\x01\n)ResourceDefinitionLocalDeviceResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\\\n\x13group_owner_setting\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.greengrass.ResourceDefinitionGroupOwnerSetting\"\xfc\x01\n4ResourceDefinitionS3MachineLearningModelResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\rowner_setting\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.greengrass.ResourceDefinitionResourceDownloadOwnerSetting\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x0e\n\x06s3_uri\x18\x04 \x01(\t\"\xcd\x05\n\'ResourceDefinitionResourceDataContainer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12|\n$secrets_manager_secret_resource_data\x18\x02 \x01(\x0b\x32N.oak9.tython.aws.greengrass.ResourceDefinitionSecretsManagerSecretResourceData\x12\x90\x01\n/sage_maker_machine_learning_model_resource_data\x18\x03 \x01(\x0b\x32W.oak9.tython.aws.greengrass.ResourceDefinitionSageMakerMachineLearningModelResourceData\x12i\n\x1alocal_volume_resource_data\x18\x04 \x01(\x0b\x32\x45.oak9.tython.aws.greengrass.ResourceDefinitionLocalVolumeResourceData\x12i\n\x1alocal_device_resource_data\x18\x05 \x01(\x0b\x32\x45.oak9.tython.aws.greengrass.ResourceDefinitionLocalDeviceResourceData\x12\x81\x01\n\'s3_machine_learning_model_resource_data\x18\x06 \x01(\x0b\x32P.oak9.tython.aws.greengrass.ResourceDefinitionS3MachineLearningModelResourceData\"\xdd\x01\n\"ResourceDefinitionResourceInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x64\n\x17resource_data_container\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.greengrass.ResourceDefinitionResourceDataContainer\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xb9\x01\n+ResourceDefinitionResourceDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\tresources\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.greengrass.ResourceDefinitionResourceInstance\"\xb2\x02\n\x12ResourceDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x0finitial_version\x18\x02 \x01(\x0b\x32G.oak9.tython.aws.greengrass.ResourceDefinitionResourceDefinitionVersion\x12\x46\n\x04tags\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.greengrass.ResourceDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb0\x01\n9ResourceDefinitionVersionSecretsManagerSecretResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12-\n%additional_staging_labels_to_download\x18\x03 \x03(\t\"\x9f\x01\n5ResourceDefinitionVersionResourceDownloadOwnerSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bgroup_owner\x18\x02 \x01(\t\x12\x18\n\x10group_permission\x18\x03 \x01(\t\"\x9d\x02\nBResourceDefinitionVersionSageMakerMachineLearningModelResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\rowner_setting\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.greengrass.ResourceDefinitionVersionResourceDownloadOwnerSetting\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x1a\n\x12sage_maker_job_arn\x18\x04 \x01(\t\"\x98\x01\n*ResourceDefinitionVersionGroupOwnerSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x61uto_add_group_owner\x18\x02 \x01(\x08\x12\x13\n\x0bgroup_owner\x18\x03 \x01(\t\"\xff\x01\n0ResourceDefinitionVersionLocalVolumeResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x63\n\x13group_owner_setting\x18\x04 \x01(\x0b\x32\x46.oak9.tython.aws.greengrass.ResourceDefinitionVersionGroupOwnerSetting\"\xe5\x01\n0ResourceDefinitionVersionLocalDeviceResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x63\n\x13group_owner_setting\x18\x03 \x01(\x0b\x32\x46.oak9.tython.aws.greengrass.ResourceDefinitionVersionGroupOwnerSetting\"\x8a\x02\n;ResourceDefinitionVersionS3MachineLearningModelResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\rowner_setting\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.greengrass.ResourceDefinitionVersionResourceDownloadOwnerSetting\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x0e\n\x06s3_uri\x18\x04 \x01(\t\"\xf8\x05\n.ResourceDefinitionVersionResourceDataContainer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x83\x01\n$secrets_manager_secret_resource_data\x18\x02 \x01(\x0b\x32U.oak9.tython.aws.greengrass.ResourceDefinitionVersionSecretsManagerSecretResourceData\x12\x97\x01\n/sage_maker_machine_learning_model_resource_data\x18\x03 \x01(\x0b\x32^.oak9.tython.aws.greengrass.ResourceDefinitionVersionSageMakerMachineLearningModelResourceData\x12p\n\x1alocal_volume_resource_data\x18\x04 \x01(\x0b\x32L.oak9.tython.aws.greengrass.ResourceDefinitionVersionLocalVolumeResourceData\x12p\n\x1alocal_device_resource_data\x18\x05 \x01(\x0b\x32L.oak9.tython.aws.greengrass.ResourceDefinitionVersionLocalDeviceResourceData\x12\x88\x01\n\'s3_machine_learning_model_resource_data\x18\x06 \x01(\x0b\x32W.oak9.tython.aws.greengrass.ResourceDefinitionVersionS3MachineLearningModelResourceData\"\xeb\x01\n)ResourceDefinitionVersionResourceInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12k\n\x17resource_data_container\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.greengrass.ResourceDefinitionVersionResourceDataContainer\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xce\x01\n\x19ResourceDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\tresources\x18\x02 \x03(\x0b\x32\x45.oak9.tython.aws.greengrass.ResourceDefinitionVersionResourceInstance\x12\x1e\n\x16resource_definition_id\x18\x03 \x01(\t\"\x9a\x01\n\"SubscriptionDefinitionSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x0f\n\x07subject\x18\x05 \x01(\t\"\xc5\x01\n3SubscriptionDefinitionSubscriptionDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\rsubscriptions\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.greengrass.SubscriptionDefinitionSubscription\"\xc2\x02\n\x16SubscriptionDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\x0finitial_version\x18\x02 \x01(\x0b\x32O.oak9.tython.aws.greengrass.SubscriptionDefinitionSubscriptionDefinitionVersion\x12J\n\x04tags\x18\x03 \x03(\x0b\x32<.oak9.tython.aws.greengrass.SubscriptionDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x01\n)SubscriptionDefinitionVersionSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x0f\n\x07subject\x18\x05 \x01(\t\"\xda\x01\n\x1dSubscriptionDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1asubscription_definition_id\x18\x02 \x01(\t\x12\\\n\rsubscriptions\x18\x03 \x03(\x0b\x32\x45.oak9.tython.aws.greengrass.SubscriptionDefinitionVersionSubscriptionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_greengrass_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONNECTORDEFINITIONCONNECTOR_PARAMETERSENTRY._options = None
  _CONNECTORDEFINITIONCONNECTOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _CONNECTORDEFINITION_TAGSENTRY._options = None
  _CONNECTORDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTORDEFINITIONVERSIONCONNECTOR_PARAMETERSENTRY._options = None
  _CONNECTORDEFINITIONVERSIONCONNECTOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _COREDEFINITION_TAGSENTRY._options = None
  _COREDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _DEVICEDEFINITION_TAGSENTRY._options = None
  _DEVICEDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _FUNCTIONDEFINITIONENVIRONMENT_VARIABLESENTRY._options = None
  _FUNCTIONDEFINITIONENVIRONMENT_VARIABLESENTRY._serialized_options = b'8\001'
  _FUNCTIONDEFINITION_TAGSENTRY._options = None
  _FUNCTIONDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT_VARIABLESENTRY._options = None
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT_VARIABLESENTRY._serialized_options = b'8\001'
  _GROUP_TAGSENTRY._options = None
  _GROUP_TAGSENTRY._serialized_options = b'8\001'
  _LOGGERDEFINITION_TAGSENTRY._options = None
  _LOGGERDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCEDEFINITION_TAGSENTRY._options = None
  _RESOURCEDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _SUBSCRIPTIONDEFINITION_TAGSENTRY._options = None
  _SUBSCRIPTIONDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTORDEFINITIONCONNECTOR._serialized_start=78
  _CONNECTORDEFINITIONCONNECTOR._serialized_end=345
  _CONNECTORDEFINITIONCONNECTOR_PARAMETERSENTRY._serialized_start=296
  _CONNECTORDEFINITIONCONNECTOR_PARAMETERSENTRY._serialized_end=345
  _CONNECTORDEFINITIONCONNECTORDEFINITIONVERSION._serialized_start=348
  _CONNECTORDEFINITIONCONNECTORDEFINITIONVERSION._serialized_end=530
  _CONNECTORDEFINITION._serialized_start=533
  _CONNECTORDEFINITION._serialized_end=843
  _CONNECTORDEFINITION_TAGSENTRY._serialized_start=800
  _CONNECTORDEFINITION_TAGSENTRY._serialized_end=843
  _GREENGRASS._serialized_start=846
  _GREENGRASS._serialized_end=2144
  _CONNECTORDEFINITIONVERSIONCONNECTOR._serialized_start=2147
  _CONNECTORDEFINITIONVERSIONCONNECTOR._serialized_end=2428
  _CONNECTORDEFINITIONVERSIONCONNECTOR_PARAMETERSENTRY._serialized_start=296
  _CONNECTORDEFINITIONVERSIONCONNECTOR_PARAMETERSENTRY._serialized_end=345
  _CONNECTORDEFINITIONVERSION._serialized_start=2431
  _CONNECTORDEFINITIONVERSION._serialized_end=2634
  _COREDEFINITIONCORE._serialized_start=2637
  _COREDEFINITIONCORE._serialized_end=2791
  _COREDEFINITIONCOREDEFINITIONVERSION._serialized_start=2794
  _COREDEFINITIONCOREDEFINITIONVERSION._serialized_end=2951
  _COREDEFINITION._serialized_start=2954
  _COREDEFINITION._serialized_end=3244
  _COREDEFINITION_TAGSENTRY._serialized_start=800
  _COREDEFINITION_TAGSENTRY._serialized_end=843
  _COREDEFINITIONVERSIONCORE._serialized_start=3247
  _COREDEFINITIONVERSIONCORE._serialized_end=3408
  _COREDEFINITIONVERSION._serialized_start=3411
  _COREDEFINITIONVERSION._serialized_end=3589
  _DEVICEDEFINITIONDEVICE._serialized_start=3592
  _DEVICEDEFINITIONDEVICE._serialized_end=3750
  _DEVICEDEFINITIONDEVICEDEFINITIONVERSION._serialized_start=3753
  _DEVICEDEFINITIONDEVICEDEFINITIONVERSION._serialized_end=3920
  _DEVICEDEFINITION._serialized_start=3923
  _DEVICEDEFINITION._serialized_end=4221
  _DEVICEDEFINITION_TAGSENTRY._serialized_start=800
  _DEVICEDEFINITION_TAGSENTRY._serialized_end=843
  _DEVICEDEFINITIONVERSIONDEVICE._serialized_start=4224
  _DEVICEDEFINITIONVERSIONDEVICE._serialized_end=4389
  _DEVICEDEFINITIONVERSION._serialized_start=4392
  _DEVICEDEFINITIONVERSION._serialized_end=4580
  _FUNCTIONDEFINITIONRUNAS._serialized_start=4582
  _FUNCTIONDEFINITIONRUNAS._serialized_end=4690
  _FUNCTIONDEFINITIONEXECUTION._serialized_start=4693
  _FUNCTIONDEFINITIONEXECUTION._serialized_end=4872
  _FUNCTIONDEFINITIONDEFAULTCONFIG._serialized_start=4875
  _FUNCTIONDEFINITIONDEFAULTCONFIG._serialized_end=5041
  _FUNCTIONDEFINITIONRESOURCEACCESSPOLICY._serialized_start=5044
  _FUNCTIONDEFINITIONRESOURCEACCESSPOLICY._serialized_end=5182
  _FUNCTIONDEFINITIONENVIRONMENT._serialized_start=5185
  _FUNCTIONDEFINITIONENVIRONMENT._serialized_end=5616
  _FUNCTIONDEFINITIONENVIRONMENT_VARIABLESENTRY._serialized_start=5568
  _FUNCTIONDEFINITIONENVIRONMENT_VARIABLESENTRY._serialized_end=5616
  _FUNCTIONDEFINITIONFUNCTIONCONFIGURATION._serialized_start=5619
  _FUNCTIONDEFINITIONFUNCTIONCONFIGURATION._serialized_end=5913
  _FUNCTIONDEFINITIONFUNCTION._serialized_start=5916
  _FUNCTIONDEFINITIONFUNCTION._serialized_end=6136
  _FUNCTIONDEFINITIONFUNCTIONDEFINITIONVERSION._serialized_start=6139
  _FUNCTIONDEFINITIONFUNCTIONDEFINITIONVERSION._serialized_end=6401
  _FUNCTIONDEFINITION._serialized_start=6404
  _FUNCTIONDEFINITION._serialized_end=6710
  _FUNCTIONDEFINITION_TAGSENTRY._serialized_start=800
  _FUNCTIONDEFINITION_TAGSENTRY._serialized_end=843
  _FUNCTIONDEFINITIONVERSIONRUNAS._serialized_start=6712
  _FUNCTIONDEFINITIONVERSIONRUNAS._serialized_end=6827
  _FUNCTIONDEFINITIONVERSIONEXECUTION._serialized_start=6830
  _FUNCTIONDEFINITIONVERSIONEXECUTION._serialized_end=7023
  _FUNCTIONDEFINITIONVERSIONDEFAULTCONFIG._serialized_start=7026
  _FUNCTIONDEFINITIONVERSIONDEFAULTCONFIG._serialized_end=7206
  _FUNCTIONDEFINITIONVERSIONRESOURCEACCESSPOLICY._serialized_start=7209
  _FUNCTIONDEFINITIONVERSIONRESOURCEACCESSPOLICY._serialized_end=7354
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT._serialized_start=7357
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT._serialized_end=7816
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT_VARIABLESENTRY._serialized_start=5568
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT_VARIABLESENTRY._serialized_end=5616
  _FUNCTIONDEFINITIONVERSIONFUNCTIONCONFIGURATION._serialized_start=7819
  _FUNCTIONDEFINITIONVERSIONFUNCTIONCONFIGURATION._serialized_end=8127
  _FUNCTIONDEFINITIONVERSIONFUNCTION._serialized_start=8130
  _FUNCTIONDEFINITIONVERSIONFUNCTION._serialized_end=8364
  _FUNCTIONDEFINITIONVERSION._serialized_start=8367
  _FUNCTIONDEFINITIONVERSION._serialized_end=8657
  _GROUPGROUPVERSION._serialized_start=8660
  _GROUPGROUPVERSION._serialized_end=9020
  _GROUP._serialized_start=9023
  _GROUP._serialized_end=9295
  _GROUP_TAGSENTRY._serialized_start=800
  _GROUP_TAGSENTRY._serialized_end=843
  _GROUPVERSION._serialized_start=9298
  _GROUPVERSION._serialized_end=9671
  _LOGGERDEFINITIONLOGGER._serialized_start=9674
  _LOGGERDEFINITIONLOGGER._serialized_end=9816
  _LOGGERDEFINITIONLOGGERDEFINITIONVERSION._serialized_start=9819
  _LOGGERDEFINITIONLOGGERDEFINITIONVERSION._serialized_end=9986
  _LOGGERDEFINITION._serialized_start=9989
  _LOGGERDEFINITION._serialized_end=10287
  _LOGGERDEFINITION_TAGSENTRY._serialized_start=800
  _LOGGERDEFINITION_TAGSENTRY._serialized_end=843
  _LOGGERDEFINITIONVERSIONLOGGER._serialized_start=10290
  _LOGGERDEFINITIONVERSIONLOGGER._serialized_end=10439
  _LOGGERDEFINITIONVERSION._serialized_start=10442
  _LOGGERDEFINITIONVERSION._serialized_end=10630
  _RESOURCEDEFINITIONSECRETSMANAGERSECRETRESOURCEDATA._serialized_start=10633
  _RESOURCEDEFINITIONSECRETSMANAGERSECRETRESOURCEDATA._serialized_end=10802
  _RESOURCEDEFINITIONRESOURCEDOWNLOADOWNERSETTING._serialized_start=10805
  _RESOURCEDEFINITIONRESOURCEDOWNLOADOWNERSETTING._serialized_end=10957
  _RESOURCEDEFINITIONSAGEMAKERMACHINELEARNINGMODELRESOURCEDATA._serialized_start=10960
  _RESOURCEDEFINITIONSAGEMAKERMACHINELEARNINGMODELRESOURCEDATA._serialized_end=11231
  _RESOURCEDEFINITIONGROUPOWNERSETTING._serialized_start=11234
  _RESOURCEDEFINITIONGROUPOWNERSETTING._serialized_end=11379
  _RESOURCEDEFINITIONLOCALVOLUMERESOURCEDATA._serialized_start=11382
  _RESOURCEDEFINITIONLOCALVOLUMERESOURCEDATA._serialized_end=11623
  _RESOURCEDEFINITIONLOCALDEVICERESOURCEDATA._serialized_start=11626
  _RESOURCEDEFINITIONLOCALDEVICERESOURCEDATA._serialized_end=11841
  _RESOURCEDEFINITIONS3MACHINELEARNINGMODELRESOURCEDATA._serialized_start=11844
  _RESOURCEDEFINITIONS3MACHINELEARNINGMODELRESOURCEDATA._serialized_end=12096
  _RESOURCEDEFINITIONRESOURCEDATACONTAINER._serialized_start=12099
  _RESOURCEDEFINITIONRESOURCEDATACONTAINER._serialized_end=12816
  _RESOURCEDEFINITIONRESOURCEINSTANCE._serialized_start=12819
  _RESOURCEDEFINITIONRESOURCEINSTANCE._serialized_end=13040
  _RESOURCEDEFINITIONRESOURCEDEFINITIONVERSION._serialized_start=13043
  _RESOURCEDEFINITIONRESOURCEDEFINITIONVERSION._serialized_end=13228
  _RESOURCEDEFINITION._serialized_start=13231
  _RESOURCEDEFINITION._serialized_end=13537
  _RESOURCEDEFINITION_TAGSENTRY._serialized_start=800
  _RESOURCEDEFINITION_TAGSENTRY._serialized_end=843
  _RESOURCEDEFINITIONVERSIONSECRETSMANAGERSECRETRESOURCEDATA._serialized_start=13540
  _RESOURCEDEFINITIONVERSIONSECRETSMANAGERSECRETRESOURCEDATA._serialized_end=13716
  _RESOURCEDEFINITIONVERSIONRESOURCEDOWNLOADOWNERSETTING._serialized_start=13719
  _RESOURCEDEFINITIONVERSIONRESOURCEDOWNLOADOWNERSETTING._serialized_end=13878
  _RESOURCEDEFINITIONVERSIONSAGEMAKERMACHINELEARNINGMODELRESOURCEDATA._serialized_start=13881
  _RESOURCEDEFINITIONVERSIONSAGEMAKERMACHINELEARNINGMODELRESOURCEDATA._serialized_end=14166
  _RESOURCEDEFINITIONVERSIONGROUPOWNERSETTING._serialized_start=14169
  _RESOURCEDEFINITIONVERSIONGROUPOWNERSETTING._serialized_end=14321
  _RESOURCEDEFINITIONVERSIONLOCALVOLUMERESOURCEDATA._serialized_start=14324
  _RESOURCEDEFINITIONVERSIONLOCALVOLUMERESOURCEDATA._serialized_end=14579
  _RESOURCEDEFINITIONVERSIONLOCALDEVICERESOURCEDATA._serialized_start=14582
  _RESOURCEDEFINITIONVERSIONLOCALDEVICERESOURCEDATA._serialized_end=14811
  _RESOURCEDEFINITIONVERSIONS3MACHINELEARNINGMODELRESOURCEDATA._serialized_start=14814
  _RESOURCEDEFINITIONVERSIONS3MACHINELEARNINGMODELRESOURCEDATA._serialized_end=15080
  _RESOURCEDEFINITIONVERSIONRESOURCEDATACONTAINER._serialized_start=15083
  _RESOURCEDEFINITIONVERSIONRESOURCEDATACONTAINER._serialized_end=15843
  _RESOURCEDEFINITIONVERSIONRESOURCEINSTANCE._serialized_start=15846
  _RESOURCEDEFINITIONVERSIONRESOURCEINSTANCE._serialized_end=16081
  _RESOURCEDEFINITIONVERSION._serialized_start=16084
  _RESOURCEDEFINITIONVERSION._serialized_end=16290
  _SUBSCRIPTIONDEFINITIONSUBSCRIPTION._serialized_start=16293
  _SUBSCRIPTIONDEFINITIONSUBSCRIPTION._serialized_end=16447
  _SUBSCRIPTIONDEFINITIONSUBSCRIPTIONDEFINITIONVERSION._serialized_start=16450
  _SUBSCRIPTIONDEFINITIONSUBSCRIPTIONDEFINITIONVERSION._serialized_end=16647
  _SUBSCRIPTIONDEFINITION._serialized_start=16650
  _SUBSCRIPTIONDEFINITION._serialized_end=16972
  _SUBSCRIPTIONDEFINITION_TAGSENTRY._serialized_start=800
  _SUBSCRIPTIONDEFINITION_TAGSENTRY._serialized_end=843
  _SUBSCRIPTIONDEFINITIONVERSIONSUBSCRIPTION._serialized_start=16975
  _SUBSCRIPTIONDEFINITIONVERSIONSUBSCRIPTION._serialized_end=17136
  _SUBSCRIPTIONDEFINITIONVERSION._serialized_start=17139
  _SUBSCRIPTIONDEFINITIONVERSION._serialized_end=17357
# @@protoc_insertion_point(module_scope)
