# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cloudtrail.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_cloudtrail.proto\x12\x1aoak9.tython.aws.cloudtrail\x1a\x13shared/shared.proto\"\\\n\x11TrailDataResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xd0\x01\n\x12TrailEventSelector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x0e\x64\x61ta_resources\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.cloudtrail.TrailDataResource\x12!\n\x19include_management_events\x18\x03 \x01(\x08\x12\x17\n\x0fread_write_type\x18\x04 \x01(\t\"\xa9\x04\n\x05Trail\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x63loud_watch_logs_log_group_arn\x18\x02 \x01(\t\x12!\n\x19\x63loud_watch_logs_role_arn\x18\x03 \x01(\t\x12\"\n\x1a\x65nable_log_file_validation\x18\x04 \x01(\x08\x12G\n\x0f\x65vent_selectors\x18\x05 \x03(\x0b\x32..oak9.tython.aws.cloudtrail.TrailEventSelector\x12%\n\x1dinclude_global_service_events\x18\x06 \x01(\x08\x12\x12\n\nis_logging\x18\x07 \x01(\x08\x12\x1d\n\x15is_multi_region_trail\x18\x08 \x01(\x08\x12\x12\n\nkms_key_id\x18\t \x01(\t\x12\x16\n\x0es3_bucket_name\x18\n \x01(\t\x12\x15\n\rs3_key_prefix\x18\x0b \x01(\t\x12\x16\n\x0esns_topic_name\x18\x0c \x01(\t\x12\x39\n\x04tags\x18\r \x03(\x0b\x32+.oak9.tython.aws.cloudtrail.Trail.TagsEntry\x12\x12\n\ntrail_name\x18\x0e \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\">\n\nCloudTrail\x12\x30\n\x05trail\x18\x01 \x01(\x0b\x32!.oak9.tython.aws.cloudtrail.Trailb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cloudtrail_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRAIL_TAGSENTRY._options = None
  _TRAIL_TAGSENTRY._serialized_options = b'8\001'
  _TRAILDATARESOURCE._serialized_start=77
  _TRAILDATARESOURCE._serialized_end=169
  _TRAILEVENTSELECTOR._serialized_start=172
  _TRAILEVENTSELECTOR._serialized_end=380
  _TRAIL._serialized_start=383
  _TRAIL._serialized_end=936
  _TRAIL_TAGSENTRY._serialized_start=893
  _TRAIL_TAGSENTRY._serialized_end=936
  _CLOUDTRAIL._serialized_start=938
  _CLOUDTRAIL._serialized_end=1000
# @@protoc_insertion_point(module_scope)
