"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeVpnGatewayXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeVpnGatewayXTimeouts = ComputeVpnGatewayXTimeouts

@typing_extensions.final
class ComputeVpnGateway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GATEWAY_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    gateway_id: builtins.float
    id: builtins.str
    name: builtins.str
    network: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeVpnGatewayXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        gateway_id: builtins.float = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeVpnGatewayXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "gateway_id", b"gateway_id", "id", b"id", "name", b"name", "network", b"network", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeVpnGateway = ComputeVpnGateway

@typing_extensions.final
class ComputeVpnTunnelXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeVpnTunnelXTimeouts = ComputeVpnTunnelXTimeouts

@typing_extensions.final
class ComputeVpnTunnel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DETAILED_STATUS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IKE_VERSION_FIELD_NUMBER: builtins.int
    LOCAL_TRAFFIC_SELECTOR_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PEER_EXTERNAL_GATEWAY_FIELD_NUMBER: builtins.int
    PEER_EXTERNAL_GATEWAY_INTERFACE_FIELD_NUMBER: builtins.int
    PEER_GCP_GATEWAY_FIELD_NUMBER: builtins.int
    PEER_IP_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    REMOTE_TRAFFIC_SELECTOR_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SHARED_SECRET_FIELD_NUMBER: builtins.int
    SHARED_SECRET_HASH_FIELD_NUMBER: builtins.int
    TARGET_VPN_GATEWAY_FIELD_NUMBER: builtins.int
    TUNNEL_ID_FIELD_NUMBER: builtins.int
    VPN_GATEWAY_FIELD_NUMBER: builtins.int
    VPN_GATEWAY_INTERFACE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    detailed_status: builtins.str
    id: builtins.str
    ike_version: builtins.float
    @property
    def local_traffic_selector(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    peer_external_gateway: builtins.str
    peer_external_gateway_interface: builtins.float
    peer_gcp_gateway: builtins.str
    peer_ip: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def remote_traffic_selector(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    router: builtins.str
    self_link: builtins.str
    shared_secret: builtins.str
    shared_secret_hash: builtins.str
    target_vpn_gateway: builtins.str
    tunnel_id: builtins.str
    vpn_gateway: builtins.str
    vpn_gateway_interface: builtins.float
    @property
    def timeouts(self) -> global___ComputeVpnTunnelXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        detailed_status: builtins.str = ...,
        id: builtins.str = ...,
        ike_version: builtins.float = ...,
        local_traffic_selector: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        peer_external_gateway: builtins.str = ...,
        peer_external_gateway_interface: builtins.float = ...,
        peer_gcp_gateway: builtins.str = ...,
        peer_ip: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        remote_traffic_selector: collections.abc.Iterable[builtins.str] | None = ...,
        router: builtins.str = ...,
        self_link: builtins.str = ...,
        shared_secret: builtins.str = ...,
        shared_secret_hash: builtins.str = ...,
        target_vpn_gateway: builtins.str = ...,
        tunnel_id: builtins.str = ...,
        vpn_gateway: builtins.str = ...,
        vpn_gateway_interface: builtins.float = ...,
        timeouts: global___ComputeVpnTunnelXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "detailed_status", b"detailed_status", "id", b"id", "ike_version", b"ike_version", "local_traffic_selector", b"local_traffic_selector", "name", b"name", "peer_external_gateway", b"peer_external_gateway", "peer_external_gateway_interface", b"peer_external_gateway_interface", "peer_gcp_gateway", b"peer_gcp_gateway", "peer_ip", b"peer_ip", "project", b"project", "region", b"region", "remote_traffic_selector", b"remote_traffic_selector", "resource_info", b"resource_info", "router", b"router", "self_link", b"self_link", "shared_secret", b"shared_secret", "shared_secret_hash", b"shared_secret_hash", "target_vpn_gateway", b"target_vpn_gateway", "timeouts", b"timeouts", "tunnel_id", b"tunnel_id", "vpn_gateway", b"vpn_gateway", "vpn_gateway_interface", b"vpn_gateway_interface"]) -> None: ...

global___ComputeVpnTunnel = ComputeVpnTunnel
