# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_monitoring.proto\x12\x1aoak9.tython.gcp.monitoring\x1a\x13shared/shared.proto\"K\n9MonitoringAlertPolicyXAlertStrategyXNotificationRateLimit\x12\x0e\n\x06period\x18\x01 \x01(\t\"\xb1\x01\n#MonitoringAlertPolicyXAlertStrategy\x12\x12\n\nauto_close\x18\x01 \x01(\t\x12v\n\x17notification_rate_limit\x18\x02 \x01(\x0b\x32U.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXAlertStrategyXNotificationRateLimit\"\xac\x01\n=MonitoringAlertPolicyXConditionsXConditionAbsentXAggregations\x12\x18\n\x10\x61lignment_period\x18\x01 \x01(\t\x12\x1c\n\x14\x63ross_series_reducer\x18\x02 \x01(\t\x12\x17\n\x0fgroup_by_fields\x18\x03 \x03(\t\x12\x1a\n\x12per_series_aligner\x18\x04 \x01(\t\"Z\n8MonitoringAlertPolicyXConditionsXConditionAbsentXTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xac\x02\n0MonitoringAlertPolicyXConditionsXConditionAbsent\x12\x10\n\x08\x64uration\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12o\n\x0c\x61ggregations\x18\x03 \x03(\x0b\x32Y.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionAbsentXAggregations\x12\x65\n\x07trigger\x18\x04 \x01(\x0b\x32T.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionAbsentXTrigger\"\xff\x01\n4MonitoringAlertPolicyXConditionsXConditionMatchedLog\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x7f\n\x10label_extractors\x18\x02 \x03(\x0b\x32\x65.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionMatchedLog.LabelExtractorsEntry\x1a\x36\n\x14LabelExtractorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\nIMonitoringAlertPolicyXConditionsXConditionMonitoringQueryLanguageXTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xfd\x01\nAMonitoringAlertPolicyXConditionsXConditionMonitoringQueryLanguage\x12\x10\n\x08\x64uration\x18\x01 \x01(\t\x12\x1f\n\x17\x65valuation_missing_data\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12v\n\x07trigger\x18\x04 \x01(\x0b\x32\x65.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionMonitoringQueryLanguageXTrigger\"\xaf\x01\n@MonitoringAlertPolicyXConditionsXConditionThresholdXAggregations\x12\x18\n\x10\x61lignment_period\x18\x01 \x01(\t\x12\x1c\n\x14\x63ross_series_reducer\x18\x02 \x01(\t\x12\x17\n\x0fgroup_by_fields\x18\x03 \x03(\t\x12\x1a\n\x12per_series_aligner\x18\x04 \x01(\t\"\xba\x01\nKMonitoringAlertPolicyXConditionsXConditionThresholdXDenominatorAggregations\x12\x18\n\x10\x61lignment_period\x18\x01 \x01(\t\x12\x1c\n\x14\x63ross_series_reducer\x18\x02 \x01(\t\x12\x17\n\x0fgroup_by_fields\x18\x03 \x03(\t\x12\x1a\n\x12per_series_aligner\x18\x04 \x01(\t\"]\n;MonitoringAlertPolicyXConditionsXConditionThresholdXTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xab\x04\n3MonitoringAlertPolicyXConditionsXConditionThreshold\x12\x12\n\ncomparison\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65nominator_filter\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\t\x12\x1f\n\x17\x65valuation_missing_data\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\x17\n\x0fthreshold_value\x18\x06 \x01(\x01\x12r\n\x0c\x61ggregations\x18\x07 \x03(\x0b\x32\\.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionThresholdXAggregations\x12\x89\x01\n\x18\x64\x65nominator_aggregations\x18\x08 \x03(\x0b\x32g.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionThresholdXDenominatorAggregations\x12h\n\x07trigger\x18\t \x01(\x0b\x32W.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionThresholdXTrigger\"\x9a\x04\n MonitoringAlertPolicyXConditions\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x66\n\x10\x63ondition_absent\x18\x03 \x01(\x0b\x32L.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionAbsent\x12o\n\x15\x63ondition_matched_log\x18\x04 \x01(\x0b\x32P.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionMatchedLog\x12\x8a\x01\n#condition_monitoring_query_language\x18\x05 \x01(\x0b\x32].oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionMonitoringQueryLanguage\x12l\n\x13\x63ondition_threshold\x18\x06 \x01(\x0b\x32O.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionThreshold\"I\n#MonitoringAlertPolicyXDocumentation\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\tmime_type\x18\x02 \x01(\t\"P\n\x1eMonitoringAlertPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc6\x06\n\x15MonitoringAlertPolicy\x12\x10\n\x08\x63ombiner\x18\x01 \x01(\t\x12^\n\x0f\x63reation_record\x18\x02 \x03(\x0b\x32\x45.oak9.tython.gcp.monitoring.MonitoringAlertPolicy.CreationRecordEntry\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1d\n\x15notification_channels\x18\x07 \x03(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12V\n\x0buser_labels\x18\t \x03(\x0b\x32\x41.oak9.tython.gcp.monitoring.MonitoringAlertPolicy.UserLabelsEntry\x12W\n\x0e\x61lert_strategy\x18\n \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXAlertStrategy\x12P\n\nconditions\x18\x0b \x03(\x0b\x32<.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditions\x12V\n\rdocumentation\x18\x0c \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXDocumentation\x12L\n\x08timeouts\x18\r \x01(\x0b\x32:.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x35\n\x13\x43reationRecordEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n!MonitoringCustomServiceXTelemetry\x12\x15\n\rresource_name\x18\x01 \x01(\t\"R\n MonitoringCustomServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x03\n\x17MonitoringCustomService\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x12\n\nservice_id\x18\x05 \x01(\t\x12X\n\x0buser_labels\x18\x06 \x03(\x0b\x32\x43.oak9.tython.gcp.monitoring.MonitoringCustomService.UserLabelsEntry\x12P\n\ttelemetry\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.monitoring.MonitoringCustomServiceXTelemetry\x12N\n\x08timeouts\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.monitoring.MonitoringCustomServiceXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"N\n\x1cMonitoringDashboardXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcf\x01\n\x13MonitoringDashboard\x12\x16\n\x0e\x64\x61shboard_json\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12J\n\x08timeouts\x18\x04 \x01(\x0b\x32\x38.oak9.tython.gcp.monitoring.MonitoringDashboardXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"J\n\x18MonitoringGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8c\x02\n\x0fMonitoringGroup\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x12\n\nis_cluster\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0bparent_name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x46\n\x08timeouts\x18\x08 \x01(\x0b\x32\x34.oak9.tython.gcp.monitoring.MonitoringGroupXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n!MonitoringMetricDescriptorXLabels\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x12\n\nvalue_type\x18\x03 \x01(\t\"R\n#MonitoringMetricDescriptorXMetadata\x12\x14\n\x0cingest_delay\x18\x01 \x01(\t\x12\x15\n\rsample_period\x18\x02 \x01(\t\"U\n#MonitoringMetricDescriptorXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9d\x04\n\x1aMonitoringMetricDescriptor\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x14\n\x0claunch_stage\x18\x04 \x01(\t\x12\x13\n\x0bmetric_kind\x18\x05 \x01(\t\x12 \n\x18monitored_resource_types\x18\x06 \x03(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12\x0c\n\x04unit\x18\n \x01(\t\x12\x12\n\nvalue_type\x18\x0b \x01(\t\x12M\n\x06labels\x18\x0c \x03(\x0b\x32=.oak9.tython.gcp.monitoring.MonitoringMetricDescriptorXLabels\x12Q\n\x08metadata\x18\r \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringMetricDescriptorXMetadata\x12Q\n\x08timeouts\x18\x0e \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringMetricDescriptorXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"E\n#MonitoringMonitoredProjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xee\x01\n\x1aMonitoringMonitoredProject\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rmetrics_scope\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12Q\n\x08timeouts\x18\x05 \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringMonitoredProjectXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"j\n-MonitoringNotificationChannelXSensitiveLabels\x12\x12\n\nauth_token\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x13\n\x0bservice_key\x18\x03 \x01(\t\"X\n&MonitoringNotificationChannelXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xbe\x05\n\x1dMonitoringNotificationChannel\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12U\n\x06labels\x18\x05 \x03(\x0b\x32\x45.oak9.tython.gcp.monitoring.MonitoringNotificationChannel.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12^\n\x0buser_labels\x18\t \x03(\x0b\x32I.oak9.tython.gcp.monitoring.MonitoringNotificationChannel.UserLabelsEntry\x12\x1b\n\x13verification_status\x18\n \x01(\t\x12\x63\n\x10sensitive_labels\x18\x0b \x01(\x0b\x32I.oak9.tython.gcp.monitoring.MonitoringNotificationChannelXSensitiveLabels\x12T\n\x08timeouts\x18\x0c \x01(\x0b\x32\x42.oak9.tython.gcp.monitoring.MonitoringNotificationChannelXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n#MonitoringSloXBasicSliXAvailability\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"3\n\x1eMonitoringSloXBasicSliXLatency\x12\x11\n\tthreshold\x18\x01 \x01(\t\"\xef\x01\n\x16MonitoringSloXBasicSli\x12\x10\n\x08location\x18\x01 \x03(\t\x12\x0e\n\x06method\x18\x02 \x03(\t\x12\x0f\n\x07version\x18\x03 \x03(\t\x12U\n\x0c\x61vailability\x18\x04 \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringSloXBasicSliXAvailability\x12K\n\x07latency\x18\x05 \x01(\x0b\x32:.oak9.tython.gcp.monitoring.MonitoringSloXBasicSliXLatency\"O\n3MonitoringSloXRequestBasedSliXDistributionCutXRange\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\"\xac\x01\n-MonitoringSloXRequestBasedSliXDistributionCut\x12\x1b\n\x13\x64istribution_filter\x18\x01 \x01(\t\x12^\n\x05range\x18\x02 \x01(\x0b\x32O.oak9.tython.gcp.monitoring.MonitoringSloXRequestBasedSliXDistributionCutXRange\"\x85\x01\n,MonitoringSloXRequestBasedSliXGoodTotalRatio\x12\x1a\n\x12\x62\x61\x64_service_filter\x18\x01 \x01(\t\x12\x1b\n\x13good_service_filter\x18\x02 \x01(\t\x12\x1c\n\x14total_service_filter\x18\x03 \x01(\t\"\xe8\x01\n\x1dMonitoringSloXRequestBasedSli\x12\x63\n\x10\x64istribution_cut\x18\x01 \x01(\x0b\x32I.oak9.tython.gcp.monitoring.MonitoringSloXRequestBasedSliXDistributionCut\x12\x62\n\x10good_total_ratio\x18\x02 \x01(\x0b\x32H.oak9.tython.gcp.monitoring.MonitoringSloXRequestBasedSliXGoodTotalRatio\"H\n\x16MonitoringSloXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"i\nVMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformanceXAvailability\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"f\nQMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformanceXLatency\x12\x11\n\tthreshold\x18\x01 \x01(\t\"\x89\x03\nIMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformance\x12\x10\n\x08location\x18\x01 \x03(\t\x12\x0e\n\x06method\x18\x02 \x03(\t\x12\x0f\n\x07version\x18\x03 \x03(\t\x12\x88\x01\n\x0c\x61vailability\x18\x04 \x01(\x0b\x32r.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformanceXAvailability\x12~\n\x07latency\x18\x05 \x01(\x0b\x32m.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformanceXLatency\"s\nWMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXDistributionCutXRange\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\"\xf5\x01\nQMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXDistributionCut\x12\x1b\n\x13\x64istribution_filter\x18\x01 \x01(\t\x12\x82\x01\n\x05range\x18\x02 \x01(\x0b\x32s.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXDistributionCutXRange\"\xa9\x01\nPMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXGoodTotalRatio\x12\x1a\n\x12\x62\x61\x64_service_filter\x18\x01 \x01(\t\x12\x1b\n\x13good_service_filter\x18\x02 \x01(\t\x12\x1c\n\x14total_service_filter\x18\x03 \x01(\t\"\xd6\x02\nAMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformance\x12\x87\x01\n\x10\x64istribution_cut\x18\x01 \x01(\x0b\x32m.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXDistributionCut\x12\x86\x01\n\x10good_total_ratio\x18\x02 \x01(\x0b\x32l.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXGoodTotalRatio\"\xc5\x02\n5MonitoringSloXWindowsBasedSliXGoodTotalRatioThreshold\x12\x11\n\tthreshold\x18\x01 \x01(\x01\x12\x84\x01\n\x15\x62\x61sic_sli_performance\x18\x02 \x01(\x0b\x32\x65.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformance\x12r\n\x0bperformance\x18\x03 \x01(\x0b\x32].oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformance\"Q\n5MonitoringSloXWindowsBasedSliXMetricMeanInRangeXRange\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\"\xa8\x01\n/MonitoringSloXWindowsBasedSliXMetricMeanInRange\x12\x13\n\x0btime_series\x18\x01 \x01(\t\x12`\n\x05range\x18\x02 \x01(\x0b\x32Q.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXMetricMeanInRangeXRange\"P\n4MonitoringSloXWindowsBasedSliXMetricSumInRangeXRange\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\"\xa6\x01\n.MonitoringSloXWindowsBasedSliXMetricSumInRange\x12\x13\n\x0btime_series\x18\x01 \x01(\t\x12_\n\x05range\x18\x02 \x01(\x0b\x32P.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXMetricSumInRangeXRange\"\xa1\x03\n\x1dMonitoringSloXWindowsBasedSli\x12\x1e\n\x16good_bad_metric_filter\x18\x01 \x01(\t\x12\x15\n\rwindow_period\x18\x02 \x01(\t\x12u\n\x1agood_total_ratio_threshold\x18\x03 \x01(\x0b\x32Q.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThreshold\x12i\n\x14metric_mean_in_range\x18\x04 \x01(\x0b\x32K.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXMetricMeanInRange\x12g\n\x13metric_sum_in_range\x18\x05 \x01(\x0b\x32J.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXMetricSumInRange\"\xaa\x05\n\rMonitoringSlo\x12\x17\n\x0f\x63\x61lendar_period\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0c\n\x04goal\x18\x03 \x01(\x01\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x1b\n\x13rolling_period_days\x18\x07 \x01(\x01\x12\x0f\n\x07service\x18\x08 \x01(\t\x12\x0e\n\x06slo_id\x18\t \x01(\t\x12N\n\x0buser_labels\x18\n \x03(\x0b\x32\x39.oak9.tython.gcp.monitoring.MonitoringSlo.UserLabelsEntry\x12\x45\n\tbasic_sli\x18\x0b \x01(\x0b\x32\x32.oak9.tython.gcp.monitoring.MonitoringSloXBasicSli\x12T\n\x11request_based_sli\x18\x0c \x01(\x0b\x32\x39.oak9.tython.gcp.monitoring.MonitoringSloXRequestBasedSli\x12\x44\n\x08timeouts\x18\r \x01(\x0b\x32\x32.oak9.tython.gcp.monitoring.MonitoringSloXTimeouts\x12T\n\x11windows_based_sli\x18\x0e \x01(\x0b\x32\x39.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSli\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n;MonitoringUptimeCheckConfigXContentMatchersXJsonPathMatcher\x12\x14\n\x0cjson_matcher\x18\x01 \x01(\t\x12\x11\n\tjson_path\x18\x02 \x01(\t\"\xc3\x01\n+MonitoringUptimeCheckConfigXContentMatchers\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0f\n\x07matcher\x18\x02 \x01(\t\x12r\n\x11json_path_matcher\x18\x03 \x01(\x0b\x32W.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXContentMatchersXJsonPathMatcher\"T\n.MonitoringUptimeCheckConfigXHttpCheckXAuthInfo\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\"\xac\x03\n%MonitoringUptimeCheckConfigXHttpCheck\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12_\n\x07headers\x18\x03 \x03(\x0b\x32N.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXHttpCheck.HeadersEntry\x12\x14\n\x0cmask_headers\x18\x04 \x01(\x08\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x01\x12\x16\n\x0erequest_method\x18\x07 \x01(\t\x12\x0f\n\x07use_ssl\x18\x08 \x01(\x08\x12\x14\n\x0cvalidate_ssl\x18\t \x01(\x08\x12]\n\tauth_info\x18\n \x01(\x0b\x32J.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXHttpCheckXAuthInfo\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd3\x01\n-MonitoringUptimeCheckConfigXMonitoredResource\x12\x65\n\x06labels\x18\x01 \x03(\x0b\x32U.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXMonitoredResource.LabelsEntry\x12\x0c\n\x04type\x18\x02 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n)MonitoringUptimeCheckConfigXResourceGroup\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\"4\n$MonitoringUptimeCheckConfigXTcpCheck\x12\x0c\n\x04port\x18\x01 \x01(\x01\"V\n$MonitoringUptimeCheckConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xaa\x06\n\x1bMonitoringUptimeCheckConfig\x12\x14\n\x0c\x63hecker_type\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x18\n\x10selected_regions\x18\x07 \x03(\t\x12\x0f\n\x07timeout\x18\x08 \x01(\t\x12\x17\n\x0fuptime_check_id\x18\t \x01(\t\x12\x61\n\x10\x63ontent_matchers\x18\n \x03(\x0b\x32G.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXContentMatchers\x12U\n\nhttp_check\x18\x0b \x01(\x0b\x32\x41.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXHttpCheck\x12\x65\n\x12monitored_resource\x18\x0c \x01(\x0b\x32I.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXMonitoredResource\x12]\n\x0eresource_group\x18\r \x01(\x0b\x32\x45.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXResourceGroup\x12S\n\ttcp_check\x18\x0e \x01(\x0b\x32@.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXTcpCheck\x12R\n\x08timeouts\x18\x0f \x01(\x0b\x32@.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_monitoring_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG_LABELEXTRACTORSENTRY._options = None
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG_LABELEXTRACTORSENTRY._serialized_options = b'8\001'
  _MONITORINGALERTPOLICY_CREATIONRECORDENTRY._options = None
  _MONITORINGALERTPOLICY_CREATIONRECORDENTRY._serialized_options = b'8\001'
  _MONITORINGALERTPOLICY_USERLABELSENTRY._options = None
  _MONITORINGALERTPOLICY_USERLABELSENTRY._serialized_options = b'8\001'
  _MONITORINGCUSTOMSERVICE_USERLABELSENTRY._options = None
  _MONITORINGCUSTOMSERVICE_USERLABELSENTRY._serialized_options = b'8\001'
  _MONITORINGNOTIFICATIONCHANNEL_LABELSENTRY._options = None
  _MONITORINGNOTIFICATIONCHANNEL_LABELSENTRY._serialized_options = b'8\001'
  _MONITORINGNOTIFICATIONCHANNEL_USERLABELSENTRY._options = None
  _MONITORINGNOTIFICATIONCHANNEL_USERLABELSENTRY._serialized_options = b'8\001'
  _MONITORINGSLO_USERLABELSENTRY._options = None
  _MONITORINGSLO_USERLABELSENTRY._serialized_options = b'8\001'
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK_HEADERSENTRY._options = None
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK_HEADERSENTRY._serialized_options = b'8\001'
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE_LABELSENTRY._options = None
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE_LABELSENTRY._serialized_options = b'8\001'
  _MONITORINGALERTPOLICYXALERTSTRATEGYXNOTIFICATIONRATELIMIT._serialized_start=77
  _MONITORINGALERTPOLICYXALERTSTRATEGYXNOTIFICATIONRATELIMIT._serialized_end=152
  _MONITORINGALERTPOLICYXALERTSTRATEGY._serialized_start=155
  _MONITORINGALERTPOLICYXALERTSTRATEGY._serialized_end=332
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENTXAGGREGATIONS._serialized_start=335
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENTXAGGREGATIONS._serialized_end=507
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENTXTRIGGER._serialized_start=509
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENTXTRIGGER._serialized_end=599
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENT._serialized_start=602
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENT._serialized_end=902
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG._serialized_start=905
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG._serialized_end=1160
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG_LABELEXTRACTORSENTRY._serialized_start=1106
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG_LABELEXTRACTORSENTRY._serialized_end=1160
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMONITORINGQUERYLANGUAGEXTRIGGER._serialized_start=1162
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMONITORINGQUERYLANGUAGEXTRIGGER._serialized_end=1269
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMONITORINGQUERYLANGUAGE._serialized_start=1272
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMONITORINGQUERYLANGUAGE._serialized_end=1525
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXAGGREGATIONS._serialized_start=1528
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXAGGREGATIONS._serialized_end=1703
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXDENOMINATORAGGREGATIONS._serialized_start=1706
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXDENOMINATORAGGREGATIONS._serialized_end=1892
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXTRIGGER._serialized_start=1894
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXTRIGGER._serialized_end=1987
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLD._serialized_start=1990
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLD._serialized_end=2545
  _MONITORINGALERTPOLICYXCONDITIONS._serialized_start=2548
  _MONITORINGALERTPOLICYXCONDITIONS._serialized_end=3086
  _MONITORINGALERTPOLICYXDOCUMENTATION._serialized_start=3088
  _MONITORINGALERTPOLICYXDOCUMENTATION._serialized_end=3161
  _MONITORINGALERTPOLICYXTIMEOUTS._serialized_start=3163
  _MONITORINGALERTPOLICYXTIMEOUTS._serialized_end=3243
  _MONITORINGALERTPOLICY._serialized_start=3246
  _MONITORINGALERTPOLICY._serialized_end=4084
  _MONITORINGALERTPOLICY_CREATIONRECORDENTRY._serialized_start=3980
  _MONITORINGALERTPOLICY_CREATIONRECORDENTRY._serialized_end=4033
  _MONITORINGALERTPOLICY_USERLABELSENTRY._serialized_start=4035
  _MONITORINGALERTPOLICY_USERLABELSENTRY._serialized_end=4084
  _MONITORINGCUSTOMSERVICEXTELEMETRY._serialized_start=4086
  _MONITORINGCUSTOMSERVICEXTELEMETRY._serialized_end=4144
  _MONITORINGCUSTOMSERVICEXTIMEOUTS._serialized_start=4146
  _MONITORINGCUSTOMSERVICEXTIMEOUTS._serialized_end=4228
  _MONITORINGCUSTOMSERVICE._serialized_start=4231
  _MONITORINGCUSTOMSERVICE._serialized_end=4701
  _MONITORINGCUSTOMSERVICE_USERLABELSENTRY._serialized_start=4035
  _MONITORINGCUSTOMSERVICE_USERLABELSENTRY._serialized_end=4084
  _MONITORINGDASHBOARDXTIMEOUTS._serialized_start=4703
  _MONITORINGDASHBOARDXTIMEOUTS._serialized_end=4781
  _MONITORINGDASHBOARD._serialized_start=4784
  _MONITORINGDASHBOARD._serialized_end=4991
  _MONITORINGGROUPXTIMEOUTS._serialized_start=4993
  _MONITORINGGROUPXTIMEOUTS._serialized_end=5067
  _MONITORINGGROUP._serialized_start=5070
  _MONITORINGGROUP._serialized_end=5338
  _MONITORINGMETRICDESCRIPTORXLABELS._serialized_start=5340
  _MONITORINGMETRICDESCRIPTORXLABELS._serialized_end=5429
  _MONITORINGMETRICDESCRIPTORXMETADATA._serialized_start=5431
  _MONITORINGMETRICDESCRIPTORXMETADATA._serialized_end=5513
  _MONITORINGMETRICDESCRIPTORXTIMEOUTS._serialized_start=5515
  _MONITORINGMETRICDESCRIPTORXTIMEOUTS._serialized_end=5600
  _MONITORINGMETRICDESCRIPTOR._serialized_start=5603
  _MONITORINGMETRICDESCRIPTOR._serialized_end=6144
  _MONITORINGMONITOREDPROJECTXTIMEOUTS._serialized_start=6146
  _MONITORINGMONITOREDPROJECTXTIMEOUTS._serialized_end=6215
  _MONITORINGMONITOREDPROJECT._serialized_start=6218
  _MONITORINGMONITOREDPROJECT._serialized_end=6456
  _MONITORINGNOTIFICATIONCHANNELXSENSITIVELABELS._serialized_start=6458
  _MONITORINGNOTIFICATIONCHANNELXSENSITIVELABELS._serialized_end=6564
  _MONITORINGNOTIFICATIONCHANNELXTIMEOUTS._serialized_start=6566
  _MONITORINGNOTIFICATIONCHANNELXTIMEOUTS._serialized_end=6654
  _MONITORINGNOTIFICATIONCHANNEL._serialized_start=6657
  _MONITORINGNOTIFICATIONCHANNEL._serialized_end=7359
  _MONITORINGNOTIFICATIONCHANNEL_LABELSENTRY._serialized_start=7263
  _MONITORINGNOTIFICATIONCHANNEL_LABELSENTRY._serialized_end=7308
  _MONITORINGNOTIFICATIONCHANNEL_USERLABELSENTRY._serialized_start=4035
  _MONITORINGNOTIFICATIONCHANNEL_USERLABELSENTRY._serialized_end=4084
  _MONITORINGSLOXBASICSLIXAVAILABILITY._serialized_start=7361
  _MONITORINGSLOXBASICSLIXAVAILABILITY._serialized_end=7415
  _MONITORINGSLOXBASICSLIXLATENCY._serialized_start=7417
  _MONITORINGSLOXBASICSLIXLATENCY._serialized_end=7468
  _MONITORINGSLOXBASICSLI._serialized_start=7471
  _MONITORINGSLOXBASICSLI._serialized_end=7710
  _MONITORINGSLOXREQUESTBASEDSLIXDISTRIBUTIONCUTXRANGE._serialized_start=7712
  _MONITORINGSLOXREQUESTBASEDSLIXDISTRIBUTIONCUTXRANGE._serialized_end=7791
  _MONITORINGSLOXREQUESTBASEDSLIXDISTRIBUTIONCUT._serialized_start=7794
  _MONITORINGSLOXREQUESTBASEDSLIXDISTRIBUTIONCUT._serialized_end=7966
  _MONITORINGSLOXREQUESTBASEDSLIXGOODTOTALRATIO._serialized_start=7969
  _MONITORINGSLOXREQUESTBASEDSLIXGOODTOTALRATIO._serialized_end=8102
  _MONITORINGSLOXREQUESTBASEDSLI._serialized_start=8105
  _MONITORINGSLOXREQUESTBASEDSLI._serialized_end=8337
  _MONITORINGSLOXTIMEOUTS._serialized_start=8339
  _MONITORINGSLOXTIMEOUTS._serialized_end=8411
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCEXAVAILABILITY._serialized_start=8413
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCEXAVAILABILITY._serialized_end=8518
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCEXLATENCY._serialized_start=8520
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCEXLATENCY._serialized_end=8622
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCE._serialized_start=8625
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCE._serialized_end=9018
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXDISTRIBUTIONCUTXRANGE._serialized_start=9020
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXDISTRIBUTIONCUTXRANGE._serialized_end=9135
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXDISTRIBUTIONCUT._serialized_start=9138
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXDISTRIBUTIONCUT._serialized_end=9383
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXGOODTOTALRATIO._serialized_start=9386
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXGOODTOTALRATIO._serialized_end=9555
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCE._serialized_start=9558
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCE._serialized_end=9900
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLD._serialized_start=9903
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLD._serialized_end=10228
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICMEANINRANGEXRANGE._serialized_start=10230
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICMEANINRANGEXRANGE._serialized_end=10311
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICMEANINRANGE._serialized_start=10314
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICMEANINRANGE._serialized_end=10482
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICSUMINRANGEXRANGE._serialized_start=10484
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICSUMINRANGEXRANGE._serialized_end=10564
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICSUMINRANGE._serialized_start=10567
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICSUMINRANGE._serialized_end=10733
  _MONITORINGSLOXWINDOWSBASEDSLI._serialized_start=10736
  _MONITORINGSLOXWINDOWSBASEDSLI._serialized_end=11153
  _MONITORINGSLO._serialized_start=11156
  _MONITORINGSLO._serialized_end=11838
  _MONITORINGSLO_USERLABELSENTRY._serialized_start=4035
  _MONITORINGSLO_USERLABELSENTRY._serialized_end=4084
  _MONITORINGUPTIMECHECKCONFIGXCONTENTMATCHERSXJSONPATHMATCHER._serialized_start=11840
  _MONITORINGUPTIMECHECKCONFIGXCONTENTMATCHERSXJSONPATHMATCHER._serialized_end=11942
  _MONITORINGUPTIMECHECKCONFIGXCONTENTMATCHERS._serialized_start=11945
  _MONITORINGUPTIMECHECKCONFIGXCONTENTMATCHERS._serialized_end=12140
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECKXAUTHINFO._serialized_start=12142
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECKXAUTHINFO._serialized_end=12226
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK._serialized_start=12229
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK._serialized_end=12657
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK_HEADERSENTRY._serialized_start=12611
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK_HEADERSENTRY._serialized_end=12657
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE._serialized_start=12660
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE._serialized_end=12871
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE_LABELSENTRY._serialized_start=7263
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE_LABELSENTRY._serialized_end=7308
  _MONITORINGUPTIMECHECKCONFIGXRESOURCEGROUP._serialized_start=12873
  _MONITORINGUPTIMECHECKCONFIGXRESOURCEGROUP._serialized_end=12957
  _MONITORINGUPTIMECHECKCONFIGXTCPCHECK._serialized_start=12959
  _MONITORINGUPTIMECHECKCONFIGXTCPCHECK._serialized_end=13011
  _MONITORINGUPTIMECHECKCONFIGXTIMEOUTS._serialized_start=13013
  _MONITORINGUPTIMECHECKCONFIGXTIMEOUTS._serialized_end=13099
  _MONITORINGUPTIMECHECKCONFIG._serialized_start=13102
  _MONITORINGUPTIMECHECKCONFIG._serialized_end=13912
# @@protoc_insertion_point(module_scope)
