# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codestarconnections.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!aws/aws_codestarconnections.proto\x12#oak9.tython.aws.codestarconnections\x1a\x13shared/shared.proto\"\xfd\x01\n\nConnection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63onnection_name\x18\x02 \x01(\t\x12\x15\n\rprovider_type\x18\x03 \x01(\t\x12\x10\n\x08host_arn\x18\x04 \x01(\t\x12G\n\x04tags\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.codestarconnections.Connection.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n\x13\x43odeStarConnections\x12\x43\n\nconnection\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.codestarconnections.Connectionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codestarconnections_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONNECTION_TAGSENTRY._options = None
  _CONNECTION_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTION._serialized_start=96
  _CONNECTION._serialized_end=349
  _CONNECTION_TAGSENTRY._serialized_start=306
  _CONNECTION_TAGSENTRY._serialized_end=349
  _CODESTARCONNECTIONS._serialized_start=351
  _CODESTARCONNECTIONS._serialized_end=441
# @@protoc_insertion_point(module_scope)
