"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_StreamAnalytics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAMINGJOBS_FIELD_NUMBER: builtins.int
    STREAMINGJOBS_FUNCTIONS_FIELD_NUMBER: builtins.int
    STREAMINGJOBS_INPUTS_FIELD_NUMBER: builtins.int
    STREAMINGJOBS_OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def streamingjobs(self) -> global___Streamingjobs: ...
    @property
    def streamingjobs_functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamingjobsFunctions]: ...
    @property
    def streamingjobs_inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamingjobsInputs]: ...
    @property
    def streamingjobs_outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamingjobsOutputs]: ...
    def __init__(
        self,
        *,
        streamingjobs: global___Streamingjobs | None = ...,
        streamingjobs_functions: collections.abc.Iterable[global___StreamingjobsFunctions] | None = ...,
        streamingjobs_inputs: collections.abc.Iterable[global___StreamingjobsInputs] | None = ...,
        streamingjobs_outputs: collections.abc.Iterable[global___StreamingjobsOutputs] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["streamingjobs", b"streamingjobs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["streamingjobs", b"streamingjobs", "streamingjobs_functions", b"streamingjobs_functions", "streamingjobs_inputs", b"streamingjobs_inputs", "streamingjobs_outputs", b"streamingjobs_outputs"]) -> None: ...

global___Microsoft_StreamAnalytics = Microsoft_StreamAnalytics

@typing_extensions.final
class StreamingjobsTransformations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    STREAMING_UNITS_FIELD_NUMBER: builtins.int
    VALID_STREAMING_UNITS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    query: builtins.str
    streaming_units: builtins.int
    @property
    def valid_streaming_units(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        query: builtins.str = ...,
        streaming_units: builtins.int = ...,
        valid_streaming_units: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "query", b"query", "resource_info", b"resource_info", "streaming_units", b"streaming_units", "valid_streaming_units", b"valid_streaming_units"]) -> None: ...

global___StreamingjobsTransformations = StreamingjobsTransformations

@typing_extensions.final
class StreamingjobsOutputs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATASOURCE_FIELD_NUMBER: builtins.int
    SERIALIZATION_FIELD_NUMBER: builtins.int
    SIZE_WINDOW_FIELD_NUMBER: builtins.int
    TIME_WINDOW_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def datasource(self) -> global___OutputDataSource: ...
    @property
    def serialization(self) -> global___Serialization: ...
    size_window: builtins.float
    time_window: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        datasource: global___OutputDataSource | None = ...,
        serialization: global___Serialization | None = ...,
        size_window: builtins.float = ...,
        time_window: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["datasource", b"datasource", "resource_info", b"resource_info", "serialization", b"serialization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["datasource", b"datasource", "name", b"name", "resource_info", b"resource_info", "serialization", b"serialization", "size_window", b"size_window", "time_window", b"time_window"]) -> None: ...

global___StreamingjobsOutputs = StreamingjobsOutputs

@typing_extensions.final
class StreamingjobsInputs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COMPRESSION_FIELD_NUMBER: builtins.int
    PARTITION_KEY_FIELD_NUMBER: builtins.int
    SERIALIZATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def compression(self) -> global___Compression: ...
    partition_key: builtins.str
    @property
    def serialization(self) -> global___Serialization: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        compression: global___Compression | None = ...,
        partition_key: builtins.str = ...,
        serialization: global___Serialization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compression", b"compression", "resource_info", b"resource_info", "serialization", b"serialization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compression", b"compression", "name", b"name", "partition_key", b"partition_key", "resource_info", b"resource_info", "serialization", b"serialization"]) -> None: ...

global___StreamingjobsInputs = StreamingjobsInputs

@typing_extensions.final
class StreamingjobsFunctions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BINDING_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def binding(self) -> global___FunctionBinding: ...
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FunctionInput]: ...
    @property
    def output(self) -> global___FunctionOutput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        binding: global___FunctionBinding | None = ...,
        inputs: collections.abc.Iterable[global___FunctionInput] | None = ...,
        output: global___FunctionOutput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["binding", b"binding", "output", b"output", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["binding", b"binding", "inputs", b"inputs", "name", b"name", "output", b"output", "resource_info", b"resource_info"]) -> None: ...

global___StreamingjobsFunctions = StreamingjobsFunctions

@typing_extensions.final
class Streamingjobs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_FIELD_NUMBER: builtins.int
    COMPATIBILITY_LEVEL_FIELD_NUMBER: builtins.int
    CONTENT_STORAGE_POLICY_FIELD_NUMBER: builtins.int
    DATA_LOCALE_FIELD_NUMBER: builtins.int
    EVENTS_LATE_ARRIVAL_MAX_DELAY_IN_SECONDS_FIELD_NUMBER: builtins.int
    EVENTS_OUT_OF_ORDER_MAX_DELAY_IN_SECONDS_FIELD_NUMBER: builtins.int
    EVENTS_OUT_OF_ORDER_POLICY_FIELD_NUMBER: builtins.int
    EXTERNALS_FIELD_NUMBER: builtins.int
    FUNCTIONS_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    JOB_STORAGE_ACCOUNT_FIELD_NUMBER: builtins.int
    JOB_TYPE_FIELD_NUMBER: builtins.int
    OUTPUT_ERROR_POLICY_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    OUTPUT_START_MODE_FIELD_NUMBER: builtins.int
    OUTPUT_START_TIME_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___Identity: ...
    location: builtins.str
    name: builtins.str
    @property
    def cluster(self) -> global___ClusterInfo: ...
    compatibility_level: builtins.str
    content_storage_policy: builtins.str
    data_locale: builtins.str
    events_late_arrival_max_delay_in_seconds: builtins.int
    events_out_of_order_max_delay_in_seconds: builtins.int
    events_out_of_order_policy: builtins.str
    @property
    def externals(self) -> global___External: ...
    @property
    def functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Function]: ...
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Input]: ...
    @property
    def job_storage_account(self) -> global___JobStorageAccount: ...
    job_type: builtins.str
    output_error_policy: builtins.str
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Output]: ...
    output_start_mode: builtins.str
    output_start_time: builtins.str
    @property
    def sku(self) -> global___Sku: ...
    @property
    def transformation(self) -> global___Transformation: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___Identity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        cluster: global___ClusterInfo | None = ...,
        compatibility_level: builtins.str = ...,
        content_storage_policy: builtins.str = ...,
        data_locale: builtins.str = ...,
        events_late_arrival_max_delay_in_seconds: builtins.int = ...,
        events_out_of_order_max_delay_in_seconds: builtins.int = ...,
        events_out_of_order_policy: builtins.str = ...,
        externals: global___External | None = ...,
        functions: collections.abc.Iterable[global___Function] | None = ...,
        inputs: collections.abc.Iterable[global___Input] | None = ...,
        job_storage_account: global___JobStorageAccount | None = ...,
        job_type: builtins.str = ...,
        output_error_policy: builtins.str = ...,
        outputs: collections.abc.Iterable[global___Output] | None = ...,
        output_start_mode: builtins.str = ...,
        output_start_time: builtins.str = ...,
        sku: global___Sku | None = ...,
        transformation: global___Transformation | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "externals", b"externals", "identity", b"identity", "job_storage_account", b"job_storage_account", "resource_info", b"resource_info", "sku", b"sku", "transformation", b"transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "compatibility_level", b"compatibility_level", "content_storage_policy", b"content_storage_policy", "data_locale", b"data_locale", "events_late_arrival_max_delay_in_seconds", b"events_late_arrival_max_delay_in_seconds", "events_out_of_order_max_delay_in_seconds", b"events_out_of_order_max_delay_in_seconds", "events_out_of_order_policy", b"events_out_of_order_policy", "externals", b"externals", "functions", b"functions", "identity", b"identity", "inputs", b"inputs", "job_storage_account", b"job_storage_account", "job_type", b"job_type", "location", b"location", "name", b"name", "output_error_policy", b"output_error_policy", "output_start_mode", b"output_start_mode", "output_start_time", b"output_start_time", "outputs", b"outputs", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "transformation", b"transformation"]) -> None: ...

global___Streamingjobs = Streamingjobs

@typing_extensions.final
class Transformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    STREAMING_UNITS_FIELD_NUMBER: builtins.int
    VALID_STREAMING_UNITS_FIELD_NUMBER: builtins.int
    name: builtins.str
    query: builtins.str
    streaming_units: builtins.int
    @property
    def valid_streaming_units(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        query: builtins.str = ...,
        streaming_units: builtins.int = ...,
        valid_streaming_units: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "query", b"query", "streaming_units", b"streaming_units", "valid_streaming_units", b"valid_streaming_units"]) -> None: ...

global___Transformation = Transformation

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class Output(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DATASOURCE_FIELD_NUMBER: builtins.int
    SERIALIZATION_FIELD_NUMBER: builtins.int
    SIZE_WINDOW_FIELD_NUMBER: builtins.int
    TIME_WINDOW_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def datasource(self) -> global___OutputDataSource: ...
    @property
    def serialization(self) -> global___Serialization: ...
    size_window: builtins.float
    time_window: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        datasource: global___OutputDataSource | None = ...,
        serialization: global___Serialization | None = ...,
        size_window: builtins.float = ...,
        time_window: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["datasource", b"datasource", "serialization", b"serialization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["datasource", b"datasource", "name", b"name", "serialization", b"serialization", "size_window", b"size_window", "time_window", b"time_window"]) -> None: ...

global___Output = Output

@typing_extensions.final
class OutputDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___OutputDataSource = OutputDataSource

@typing_extensions.final
class JobStorageAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_KEY_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_MODE_FIELD_NUMBER: builtins.int
    account_key: builtins.str
    account_name: builtins.str
    authentication_mode: builtins.str
    def __init__(
        self,
        *,
        account_key: builtins.str = ...,
        account_name: builtins.str = ...,
        authentication_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_key", b"account_key", "account_name", b"account_name", "authentication_mode", b"authentication_mode"]) -> None: ...

global___JobStorageAccount = JobStorageAccount

@typing_extensions.final
class Input(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    COMPRESSION_FIELD_NUMBER: builtins.int
    PARTITION_KEY_FIELD_NUMBER: builtins.int
    SERIALIZATION_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def compression(self) -> global___Compression: ...
    partition_key: builtins.str
    @property
    def serialization(self) -> global___Serialization: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        compression: global___Compression | None = ...,
        partition_key: builtins.str = ...,
        serialization: global___Serialization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compression", b"compression", "serialization", b"serialization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compression", b"compression", "name", b"name", "partition_key", b"partition_key", "serialization", b"serialization"]) -> None: ...

global___Input = Input

@typing_extensions.final
class Serialization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Serialization = Serialization

@typing_extensions.final
class Compression(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___Compression = Compression

@typing_extensions.final
class Function(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BINDING_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def binding(self) -> global___FunctionBinding: ...
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FunctionInput]: ...
    @property
    def output(self) -> global___FunctionOutput: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        binding: global___FunctionBinding | None = ...,
        inputs: collections.abc.Iterable[global___FunctionInput] | None = ...,
        output: global___FunctionOutput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["binding", b"binding", "output", b"output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["binding", b"binding", "inputs", b"inputs", "name", b"name", "output", b"output"]) -> None: ...

global___Function = Function

@typing_extensions.final
class FunctionOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_TYPE_FIELD_NUMBER: builtins.int
    data_type: builtins.str
    def __init__(
        self,
        *,
        data_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_type", b"data_type"]) -> None: ...

global___FunctionOutput = FunctionOutput

@typing_extensions.final
class FunctionInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_TYPE_FIELD_NUMBER: builtins.int
    IS_CONFIGURATION_PARAMETER_FIELD_NUMBER: builtins.int
    data_type: builtins.str
    is_configuration_parameter: builtins.bool
    def __init__(
        self,
        *,
        data_type: builtins.str = ...,
        is_configuration_parameter: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_type", b"data_type", "is_configuration_parameter", b"is_configuration_parameter"]) -> None: ...

global___FunctionInput = FunctionInput

@typing_extensions.final
class FunctionBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    name: builtins.str
    api_key: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "name", b"name"]) -> None: ...

global___FunctionBinding = FunctionBinding

@typing_extensions.final
class External(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_FIELD_NUMBER: builtins.int
    container: builtins.str
    path: builtins.str
    @property
    def storage_account(self) -> global___StorageAccount: ...
    def __init__(
        self,
        *,
        container: builtins.str = ...,
        path: builtins.str = ...,
        storage_account: global___StorageAccount | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["storage_account", b"storage_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container", b"container", "path", b"path", "storage_account", b"storage_account"]) -> None: ...

global___External = External

@typing_extensions.final
class StorageAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_KEY_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    account_key: builtins.str
    account_name: builtins.str
    def __init__(
        self,
        *,
        account_key: builtins.str = ...,
        account_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_key", b"account_key", "account_name", b"account_name"]) -> None: ...

global___StorageAccount = StorageAccount

@typing_extensions.final
class ClusterInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ClusterInfo = ClusterInfo

@typing_extensions.final
class Identity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRINCIPAL_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    principal_id: builtins.str
    tenant_id: builtins.str
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        principal_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["principal_id", b"principal_id", "tenant_id", b"tenant_id", "type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___Identity = Identity
