# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codegurureviewer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_codegurureviewer.proto\x12 oak9.tython.aws.codegurureviewer\x1a\x13shared/shared.proto\"\x93\x01\n\x15RepositoryAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\x12\x16\n\x0e\x63onnection_arn\x18\x05 \x01(\t\"k\n\x10\x43odeGuruReviewer\x12W\n\x16repository_association\x18\x01 \x03(\x0b\x32\x37.oak9.tython.aws.codegurureviewer.RepositoryAssociationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codegurureviewer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPOSITORYASSOCIATION._serialized_start=90
  _REPOSITORYASSOCIATION._serialized_end=237
  _CODEGURUREVIEWER._serialized_start=239
  _CODEGURUREVIEWER._serialized_end=346
# @@protoc_insertion_point(module_scope)
