"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MemberMemberFabricConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADMIN_USERNAME_FIELD_NUMBER: builtins.int
    ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    admin_username: builtins.str
    admin_password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        admin_username: builtins.str = ...,
        admin_password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_password", b"admin_password", "admin_username", b"admin_username", "resource_info", b"resource_info"]) -> None: ...

global___MemberMemberFabricConfiguration = MemberMemberFabricConfiguration

@typing_extensions.final
class MemberMemberFrameworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MEMBER_FABRIC_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def member_fabric_configuration(self) -> global___MemberMemberFabricConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        member_fabric_configuration: global___MemberMemberFabricConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["member_fabric_configuration", b"member_fabric_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["member_fabric_configuration", b"member_fabric_configuration", "resource_info", b"resource_info"]) -> None: ...

global___MemberMemberFrameworkConfiguration = MemberMemberFrameworkConfiguration

@typing_extensions.final
class MemberMemberConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MEMBER_FRAMEWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def member_framework_configuration(self) -> global___MemberMemberFrameworkConfiguration: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        member_framework_configuration: global___MemberMemberFrameworkConfiguration | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["member_framework_configuration", b"member_framework_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "member_framework_configuration", b"member_framework_configuration", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___MemberMemberConfiguration = MemberMemberConfiguration

@typing_extensions.final
class MemberApprovalThresholdPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    THRESHOLD_COMPARATOR_FIELD_NUMBER: builtins.int
    THRESHOLD_PERCENTAGE_FIELD_NUMBER: builtins.int
    PROPOSAL_DURATION_IN_HOURS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    threshold_comparator: builtins.str
    threshold_percentage: builtins.int
    proposal_duration_in_hours: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        threshold_comparator: builtins.str = ...,
        threshold_percentage: builtins.int = ...,
        proposal_duration_in_hours: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_duration_in_hours", b"proposal_duration_in_hours", "resource_info", b"resource_info", "threshold_comparator", b"threshold_comparator", "threshold_percentage", b"threshold_percentage"]) -> None: ...

global___MemberApprovalThresholdPolicy = MemberApprovalThresholdPolicy

@typing_extensions.final
class MemberVotingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPROVAL_THRESHOLD_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def approval_threshold_policy(self) -> global___MemberApprovalThresholdPolicy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        approval_threshold_policy: global___MemberApprovalThresholdPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["approval_threshold_policy", b"approval_threshold_policy", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_threshold_policy", b"approval_threshold_policy", "resource_info", b"resource_info"]) -> None: ...

global___MemberVotingPolicy = MemberVotingPolicy

@typing_extensions.final
class MemberNetworkFabricConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EDITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    edition: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        edition: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["edition", b"edition", "resource_info", b"resource_info"]) -> None: ...

global___MemberNetworkFabricConfiguration = MemberNetworkFabricConfiguration

@typing_extensions.final
class MemberNetworkFrameworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NETWORK_FABRIC_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def network_fabric_configuration(self) -> global___MemberNetworkFabricConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        network_fabric_configuration: global___MemberNetworkFabricConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_fabric_configuration", b"network_fabric_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_fabric_configuration", b"network_fabric_configuration", "resource_info", b"resource_info"]) -> None: ...

global___MemberNetworkFrameworkConfiguration = MemberNetworkFrameworkConfiguration

@typing_extensions.final
class MemberNetworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FRAMEWORK_VERSION_FIELD_NUMBER: builtins.int
    VOTING_POLICY_FIELD_NUMBER: builtins.int
    FRAMEWORK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FRAMEWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    framework_version: builtins.str
    @property
    def voting_policy(self) -> global___MemberVotingPolicy: ...
    framework: builtins.str
    name: builtins.str
    @property
    def network_framework_configuration(self) -> global___MemberNetworkFrameworkConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        framework_version: builtins.str = ...,
        voting_policy: global___MemberVotingPolicy | None = ...,
        framework: builtins.str = ...,
        name: builtins.str = ...,
        network_framework_configuration: global___MemberNetworkFrameworkConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_framework_configuration", b"network_framework_configuration", "resource_info", b"resource_info", "voting_policy", b"voting_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "framework", b"framework", "framework_version", b"framework_version", "name", b"name", "network_framework_configuration", b"network_framework_configuration", "resource_info", b"resource_info", "voting_policy", b"voting_policy"]) -> None: ...

global___MemberNetworkConfiguration = MemberNetworkConfiguration

@typing_extensions.final
class Member(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MEMBER_CONFIGURATION_FIELD_NUMBER: builtins.int
    NETWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    INVITATION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def member_configuration(self) -> global___MemberMemberConfiguration: ...
    @property
    def network_configuration(self) -> global___MemberNetworkConfiguration: ...
    network_id: builtins.str
    invitation_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        member_configuration: global___MemberMemberConfiguration | None = ...,
        network_configuration: global___MemberNetworkConfiguration | None = ...,
        network_id: builtins.str = ...,
        invitation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["member_configuration", b"member_configuration", "network_configuration", b"network_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation_id", b"invitation_id", "member_configuration", b"member_configuration", "network_configuration", b"network_configuration", "network_id", b"network_id", "resource_info", b"resource_info"]) -> None: ...

global___Member = Member

@typing_extensions.final
class ManagedBlockchain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBER_FIELD_NUMBER: builtins.int
    NODE_FIELD_NUMBER: builtins.int
    @property
    def member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Member]: ...
    @property
    def node(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Node]: ...
    def __init__(
        self,
        *,
        member: collections.abc.Iterable[global___Member] | None = ...,
        node: collections.abc.Iterable[global___Node] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["member", b"member", "node", b"node"]) -> None: ...

global___ManagedBlockchain = ManagedBlockchain

@typing_extensions.final
class NodeNodeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    availability_zone: builtins.str
    instance_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        availability_zone: builtins.str = ...,
        instance_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zone", b"availability_zone", "instance_type", b"instance_type", "resource_info", b"resource_info"]) -> None: ...

global___NodeNodeConfiguration = NodeNodeConfiguration

@typing_extensions.final
class Node(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MEMBER_ID_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    NODE_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    member_id: builtins.str
    network_id: builtins.str
    @property
    def node_configuration(self) -> global___NodeNodeConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        member_id: builtins.str = ...,
        network_id: builtins.str = ...,
        node_configuration: global___NodeNodeConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["node_configuration", b"node_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["member_id", b"member_id", "network_id", b"network_id", "node_configuration", b"node_configuration", "resource_info", b"resource_info"]) -> None: ...

global___Node = Node
