# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_workspaces.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_workspaces.proto\x12\x1aoak9.tython.aws.workspaces\x1a\x13shared/shared.proto\"\xf7\x01\n\x1cWorkspaceWorkspaceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63ompute_type_name\x18\x02 \x01(\t\x12\x1c\n\x14root_volume_size_gib\x18\x03 \x01(\x05\x12\x14\n\x0crunning_mode\x18\x04 \x01(\t\x12\x31\n)running_mode_auto_stop_timeout_in_minutes\x18\x05 \x01(\x05\x12\x1c\n\x14user_volume_size_gib\x18\x06 \x01(\x05\"\xb3\x03\n\tWorkspace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tbundle_id\x18\x02 \x01(\t\x12\x14\n\x0c\x64irectory_id\x18\x03 \x01(\t\x12&\n\x1eroot_volume_encryption_enabled\x18\x04 \x01(\x08\x12=\n\x04tags\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.workspaces.Workspace.TagsEntry\x12\x11\n\tuser_name\x18\x06 \x01(\t\x12&\n\x1euser_volume_encryption_enabled\x18\x07 \x01(\x08\x12\x1d\n\x15volume_encryption_key\x18\x08 \x01(\t\x12V\n\x14workspace_properties\x18\t \x01(\x0b\x32\x38.oak9.tython.aws.workspaces.WorkspaceWorkspaceProperties\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\nWorkSpaces\x12\x38\n\tworkspace\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.workspaces.Workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_workspaces_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKSPACE_TAGSENTRY._options = None
  _WORKSPACE_TAGSENTRY._serialized_options = b'8\001'
  _WORKSPACEWORKSPACEPROPERTIES._serialized_start=78
  _WORKSPACEWORKSPACEPROPERTIES._serialized_end=325
  _WORKSPACE._serialized_start=328
  _WORKSPACE._serialized_end=763
  _WORKSPACE_TAGSENTRY._serialized_start=720
  _WORKSPACE_TAGSENTRY._serialized_end=763
  _WORKSPACES._serialized_start=765
  _WORKSPACES._serialized_end=835
# @@protoc_insertion_point(module_scope)
