# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_applicationautoscaling.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$aws/aws_applicationautoscaling.proto\x12&oak9.tython.aws.applicationautoscaling\x1a\x13shared/shared.proto\"\x89\x01\n\"ScalableTargetScalableTargetAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x03 \x01(\x05\"\x9b\x02\n\x1dScalableTargetScheduledAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\x12j\n\x16scalable_target_action\x18\x03 \x01(\x0b\x32J.oak9.tython.aws.applicationautoscaling.ScalableTargetScalableTargetAction\x12\x10\n\x08schedule\x18\x04 \x01(\t\x12\x1d\n\x15scheduled_action_name\x18\x05 \x01(\t\x12\x12\n\nstart_time\x18\x06 \x01(\t\"\xc9\x01\n\x1cScalableTargetSuspendedState\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12$\n\x1c\x64ynamic_scaling_in_suspended\x18\x02 \x01(\x08\x12%\n\x1d\x64ynamic_scaling_out_suspended\x18\x03 \x01(\x08\x12#\n\x1bscheduled_scaling_suspended\x18\x04 \x01(\x08\"\x94\x03\n\x0eScalableTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x03 \x01(\x05\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\x12\x1a\n\x12scalable_dimension\x18\x06 \x01(\t\x12`\n\x11scheduled_actions\x18\x07 \x03(\x0b\x32\x45.oak9.tython.aws.applicationautoscaling.ScalableTargetScheduledAction\x12\x19\n\x11service_namespace\x18\x08 \x01(\t\x12]\n\x0fsuspended_state\x18\t \x01(\x0b\x32\x44.oak9.tython.aws.applicationautoscaling.ScalableTargetSuspendedState\"\xb8\x01\n\x16\x41pplicationAutoScaling\x12O\n\x0fscalable_target\x18\x01 \x03(\x0b\x32\x36.oak9.tython.aws.applicationautoscaling.ScalableTarget\x12M\n\x0escaling_policy\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.applicationautoscaling.ScalingPolicy\"\xbc\x01\n\x1bScalingPolicyStepAdjustment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1bmetric_interval_lower_bound\x18\x02 \x01(\x01\x12#\n\x1bmetric_interval_upper_bound\x18\x03 \x01(\x01\x12\x1a\n\x12scaling_adjustment\x18\x04 \x01(\x05\"\xb3\x02\n+ScalingPolicyStepScalingPolicyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x64justment_type\x18\x02 \x01(\t\x12\x10\n\x08\x63ooldown\x18\x03 \x01(\x05\x12\x1f\n\x17metric_aggregation_type\x18\x04 \x01(\t\x12 \n\x18min_adjustment_magnitude\x18\x05 \x01(\x05\x12]\n\x10step_adjustments\x18\x06 \x03(\x0b\x32\x43.oak9.tython.aws.applicationautoscaling.ScalingPolicyStepAdjustment\"t\n\x1cScalingPolicyMetricDimension\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x88\x02\n*ScalingPolicyCustomizedMetricSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\ndimensions\x18\x02 \x03(\x0b\x32\x44.oak9.tython.aws.applicationautoscaling.ScalingPolicyMetricDimension\x12\x13\n\x0bmetric_name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x11\n\tstatistic\x18\x05 \x01(\t\x12\x0c\n\x04unit\x18\x06 \x01(\t\"\x9d\x01\n*ScalingPolicyPredefinedMetricSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16predefined_metric_type\x18\x02 \x01(\t\x12\x16\n\x0eresource_label\x18\x03 \x01(\t\"\xd1\x03\n5ScalingPolicyTargetTrackingScalingPolicyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12{\n\x1f\x63ustomized_metric_specification\x18\x02 \x01(\x0b\x32R.oak9.tython.aws.applicationautoscaling.ScalingPolicyCustomizedMetricSpecification\x12\x18\n\x10\x64isable_scale_in\x18\x03 \x01(\x08\x12{\n\x1fpredefined_metric_specification\x18\x04 \x01(\x0b\x32R.oak9.tython.aws.applicationautoscaling.ScalingPolicyPredefinedMetricSpecification\x12\x19\n\x11scale_in_cooldown\x18\x05 \x01(\x05\x12\x1a\n\x12scale_out_cooldown\x18\x06 \x01(\x05\x12\x14\n\x0ctarget_value\x18\x07 \x01(\x01\"\xef\x03\n\rScalingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_type\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x1a\n\x12scalable_dimension\x18\x05 \x01(\t\x12\x19\n\x11scaling_target_id\x18\x06 \x01(\t\x12\x19\n\x11service_namespace\x18\x07 \x01(\t\x12~\n!step_scaling_policy_configuration\x18\x08 \x01(\x0b\x32S.oak9.tython.aws.applicationautoscaling.ScalingPolicyStepScalingPolicyConfiguration\x12\x93\x01\n,target_tracking_scaling_policy_configuration\x18\t \x01(\x0b\x32].oak9.tython.aws.applicationautoscaling.ScalingPolicyTargetTrackingScalingPolicyConfigurationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_applicationautoscaling_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCALABLETARGETSCALABLETARGETACTION._serialized_start=102
  _SCALABLETARGETSCALABLETARGETACTION._serialized_end=239
  _SCALABLETARGETSCHEDULEDACTION._serialized_start=242
  _SCALABLETARGETSCHEDULEDACTION._serialized_end=525
  _SCALABLETARGETSUSPENDEDSTATE._serialized_start=528
  _SCALABLETARGETSUSPENDEDSTATE._serialized_end=729
  _SCALABLETARGET._serialized_start=732
  _SCALABLETARGET._serialized_end=1136
  _APPLICATIONAUTOSCALING._serialized_start=1139
  _APPLICATIONAUTOSCALING._serialized_end=1323
  _SCALINGPOLICYSTEPADJUSTMENT._serialized_start=1326
  _SCALINGPOLICYSTEPADJUSTMENT._serialized_end=1514
  _SCALINGPOLICYSTEPSCALINGPOLICYCONFIGURATION._serialized_start=1517
  _SCALINGPOLICYSTEPSCALINGPOLICYCONFIGURATION._serialized_end=1824
  _SCALINGPOLICYMETRICDIMENSION._serialized_start=1826
  _SCALINGPOLICYMETRICDIMENSION._serialized_end=1942
  _SCALINGPOLICYCUSTOMIZEDMETRICSPECIFICATION._serialized_start=1945
  _SCALINGPOLICYCUSTOMIZEDMETRICSPECIFICATION._serialized_end=2209
  _SCALINGPOLICYPREDEFINEDMETRICSPECIFICATION._serialized_start=2212
  _SCALINGPOLICYPREDEFINEDMETRICSPECIFICATION._serialized_end=2369
  _SCALINGPOLICYTARGETTRACKINGSCALINGPOLICYCONFIGURATION._serialized_start=2372
  _SCALINGPOLICYTARGETTRACKINGSCALINGPOLICYCONFIGURATION._serialized_end=2837
  _SCALINGPOLICY._serialized_start=2840
  _SCALINGPOLICY._serialized_end=3335
# @@protoc_insertion_point(module_scope)
