# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iotevents.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_iotevents.proto\x12\x19oak9.tython.aws.iotevents\x1a\x13shared/shared.proto\"k\n\x14\x44\x65tectorModelPayload\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63ontent_expression\x18\x02 \x01(\t\"\xa7\x01\n\x16\x44\x65tectorModelIotEvents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ninput_name\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"\xc3\x01\n\x15\x44\x65tectorModelFirehose\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x65livery_stream_name\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\x12\x11\n\tseparator\x18\x04 \x01(\t\"\xad\x01\n\x1c\x44\x65tectorModelIotTopicPublish\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nmqtt_topic\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"\xe1\x02\n\x15\x44\x65tectorModelDynamoDB\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x15\n\rpayload_field\x18\x03 \x01(\t\x12\x17\n\x0frange_key_field\x18\x04 \x01(\t\x12\x16\n\x0ehash_key_field\x18\x05 \x01(\t\x12\x17\n\x0frange_key_value\x18\x06 \x01(\t\x12\x16\n\x0erange_key_type\x18\x07 \x01(\t\x12\x15\n\rhash_key_type\x18\x08 \x01(\t\x12\x16\n\x0ehash_key_value\x18\t \x01(\t\x12@\n\x07payload\x18\n \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\x12\x11\n\toperation\x18\x0b \x01(\t\"\xa8\x01\n\x17\x44\x65tectorModelDynamoDBv2\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"\xb6\x01\n!DetectorModelAssetPropertyVariant\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x64ouble_value\x18\x02 \x01(\t\x12\x15\n\rinteger_value\x18\x03 \x01(\t\x12\x15\n\rboolean_value\x18\x04 \x01(\t\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\"\x90\x01\n#DetectorModelAssetPropertyTimestamp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0ftime_in_seconds\x18\x02 \x01(\t\x12\x17\n\x0foffset_in_nanos\x18\x03 \x01(\t\"\x8b\x02\n\x1f\x44\x65tectorModelAssetPropertyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07quality\x18\x02 \x01(\t\x12K\n\x05value\x18\x03 \x01(\x0b\x32<.oak9.tython.aws.iotevents.DetectorModelAssetPropertyVariant\x12Q\n\ttimestamp\x18\x04 \x01(\x0b\x32>.oak9.tython.aws.iotevents.DetectorModelAssetPropertyTimestamp\"\xf8\x01\n\x18\x44\x65tectorModelIotSiteWise\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65ntry_id\x18\x02 \x01(\t\x12\x16\n\x0eproperty_alias\x18\x03 \x01(\t\x12R\n\x0eproperty_value\x18\x04 \x01(\x0b\x32:.oak9.tython.aws.iotevents.DetectorModelAssetPropertyValue\x12\x10\n\x08\x61sset_id\x18\x05 \x01(\t\x12\x13\n\x0bproperty_id\x18\x06 \x01(\t\"f\n\x17\x44\x65tectorModelResetTimer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntimer_name\x18\x02 \x01(\t\"\xb4\x01\n\x10\x44\x65tectorModelSqs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nuse_base64\x18\x02 \x01(\x08\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\x12\x11\n\tqueue_url\x18\x04 \x01(\t\"\xa1\x01\n\x10\x44\x65tectorModelSns\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntarget_arn\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"\x92\x01\n\x15\x44\x65tectorModelSetTimer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07seconds\x18\x02 \x01(\x05\x12\x12\n\ntimer_name\x18\x03 \x01(\t\x12\x1b\n\x13\x64uration_expression\x18\x04 \x01(\t\"f\n\x17\x44\x65tectorModelClearTimer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntimer_name\x18\x02 \x01(\t\"\xa6\x01\n\x13\x44\x65tectorModelLambda\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66unction_arn\x18\x02 \x01(\t\x12@\n\x07payload\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelPayload\"y\n\x18\x44\x65tectorModelSetVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rvariable_name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xdd\x07\n\x13\x44\x65tectorModelAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\niot_events\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.iotevents.DetectorModelIotEvents\x12\x42\n\x08\x66irehose\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.iotevents.DetectorModelFirehose\x12R\n\x11iot_topic_publish\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.iotevents.DetectorModelIotTopicPublish\x12\x43\n\tdynamo_db\x18\x05 \x01(\x0b\x32\x30.oak9.tython.aws.iotevents.DetectorModelDynamoDB\x12G\n\x0b\x64ynamo_dbv2\x18\x06 \x01(\x0b\x32\x32.oak9.tython.aws.iotevents.DetectorModelDynamoDBv2\x12J\n\riot_site_wise\x18\x07 \x01(\x0b\x32\x33.oak9.tython.aws.iotevents.DetectorModelIotSiteWise\x12G\n\x0breset_timer\x18\x08 \x01(\x0b\x32\x32.oak9.tython.aws.iotevents.DetectorModelResetTimer\x12\x38\n\x03sqs\x18\t \x01(\x0b\x32+.oak9.tython.aws.iotevents.DetectorModelSqs\x12\x38\n\x03sns\x18\n \x01(\x0b\x32+.oak9.tython.aws.iotevents.DetectorModelSns\x12\x43\n\tset_timer\x18\x0b \x01(\x0b\x32\x30.oak9.tython.aws.iotevents.DetectorModelSetTimer\x12G\n\x0b\x63lear_timer\x18\x0c \x01(\x0b\x32\x32.oak9.tython.aws.iotevents.DetectorModelClearTimer\x12>\n\x06lambda\x18\r \x01(\x0b\x32..oak9.tython.aws.iotevents.DetectorModelLambda\x12I\n\x0cset_variable\x18\x0e \x01(\x0b\x32\x33.oak9.tython.aws.iotevents.DetectorModelSetVariable\"\xb5\x01\n\x12\x44\x65tectorModelEvent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tcondition\x18\x02 \x01(\t\x12?\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32..oak9.tython.aws.iotevents.DetectorModelAction\x12\x12\n\nevent_name\x18\x04 \x01(\t\"\xd3\x01\n\x1c\x44\x65tectorModelTransitionEvent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tcondition\x18\x02 \x01(\t\x12?\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32..oak9.tython.aws.iotevents.DetectorModelAction\x12\x12\n\nnext_state\x18\x04 \x01(\t\x12\x12\n\nevent_name\x18\x05 \x01(\t\"\xe2\x01\n\x14\x44\x65tectorModelOnInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06\x65vents\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotevents.DetectorModelEvent\x12R\n\x11transition_events\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.iotevents.DetectorModelTransitionEvent\"\x8d\x01\n\x13\x44\x65tectorModelOnExit\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06\x65vents\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotevents.DetectorModelEvent\"\x8e\x01\n\x14\x44\x65tectorModelOnEnter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06\x65vents\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotevents.DetectorModelEvent\"\xa8\x02\n\x12\x44\x65tectorModelState\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x08on_input\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelOnInput\x12?\n\x07on_exit\x18\x03 \x01(\x0b\x32..oak9.tython.aws.iotevents.DetectorModelOnExit\x12\x12\n\nstate_name\x18\x04 \x01(\t\x12\x41\n\x08on_enter\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.iotevents.DetectorModelOnEnter\"\xba\x01\n$DetectorModelDetectorModelDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x06states\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotevents.DetectorModelState\x12\x1a\n\x12initial_state_name\x18\x03 \x01(\t\"\x96\x03\n\rDetectorModel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x19\x64\x65tector_model_definition\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.iotevents.DetectorModelDetectorModelDefinition\x12\x19\n\x11\x65valuation_method\x18\x03 \x01(\t\x12\x1b\n\x13\x64\x65tector_model_name\x18\x04 \x01(\t\x12\"\n\x1a\x64\x65tector_model_description\x18\x05 \x01(\t\x12\x0b\n\x03key\x18\x06 \x01(\t\x12\x10\n\x08role_arn\x18\x07 \x01(\t\x12@\n\x04tags\x18\x08 \x03(\x0b\x32\x32.oak9.tython.aws.iotevents.DetectorModel.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\tIoTEvents\x12@\n\x0e\x64\x65tector_model\x18\x01 \x03(\x0b\x32(.oak9.tython.aws.iotevents.DetectorModel\x12/\n\x05input\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.iotevents.Input\"\\\n\x0eInputAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tjson_path\x18\x02 \x01(\t\"\x8e\x01\n\x14InputInputDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\nattributes\x18\x02 \x03(\x0b\x32).oak9.tython.aws.iotevents.InputAttribute\"\xa1\x02\n\x05Input\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x10input_definition\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.iotevents.InputInputDefinition\x12\x12\n\ninput_name\x18\x03 \x01(\t\x12\x19\n\x11input_description\x18\x04 \x01(\t\x12\x38\n\x04tags\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.iotevents.Input.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iotevents_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETECTORMODEL_TAGSENTRY._options = None
  _DETECTORMODEL_TAGSENTRY._serialized_options = b'8\001'
  _INPUT_TAGSENTRY._options = None
  _INPUT_TAGSENTRY._serialized_options = b'8\001'
  _DETECTORMODELPAYLOAD._serialized_start=75
  _DETECTORMODELPAYLOAD._serialized_end=182
  _DETECTORMODELIOTEVENTS._serialized_start=185
  _DETECTORMODELIOTEVENTS._serialized_end=352
  _DETECTORMODELFIREHOSE._serialized_start=355
  _DETECTORMODELFIREHOSE._serialized_end=550
  _DETECTORMODELIOTTOPICPUBLISH._serialized_start=553
  _DETECTORMODELIOTTOPICPUBLISH._serialized_end=726
  _DETECTORMODELDYNAMODB._serialized_start=729
  _DETECTORMODELDYNAMODB._serialized_end=1082
  _DETECTORMODELDYNAMODBV2._serialized_start=1085
  _DETECTORMODELDYNAMODBV2._serialized_end=1253
  _DETECTORMODELASSETPROPERTYVARIANT._serialized_start=1256
  _DETECTORMODELASSETPROPERTYVARIANT._serialized_end=1438
  _DETECTORMODELASSETPROPERTYTIMESTAMP._serialized_start=1441
  _DETECTORMODELASSETPROPERTYTIMESTAMP._serialized_end=1585
  _DETECTORMODELASSETPROPERTYVALUE._serialized_start=1588
  _DETECTORMODELASSETPROPERTYVALUE._serialized_end=1855
  _DETECTORMODELIOTSITEWISE._serialized_start=1858
  _DETECTORMODELIOTSITEWISE._serialized_end=2106
  _DETECTORMODELRESETTIMER._serialized_start=2108
  _DETECTORMODELRESETTIMER._serialized_end=2210
  _DETECTORMODELSQS._serialized_start=2213
  _DETECTORMODELSQS._serialized_end=2393
  _DETECTORMODELSNS._serialized_start=2396
  _DETECTORMODELSNS._serialized_end=2557
  _DETECTORMODELSETTIMER._serialized_start=2560
  _DETECTORMODELSETTIMER._serialized_end=2706
  _DETECTORMODELCLEARTIMER._serialized_start=2708
  _DETECTORMODELCLEARTIMER._serialized_end=2810
  _DETECTORMODELLAMBDA._serialized_start=2813
  _DETECTORMODELLAMBDA._serialized_end=2979
  _DETECTORMODELSETVARIABLE._serialized_start=2981
  _DETECTORMODELSETVARIABLE._serialized_end=3102
  _DETECTORMODELACTION._serialized_start=3105
  _DETECTORMODELACTION._serialized_end=4094
  _DETECTORMODELEVENT._serialized_start=4097
  _DETECTORMODELEVENT._serialized_end=4278
  _DETECTORMODELTRANSITIONEVENT._serialized_start=4281
  _DETECTORMODELTRANSITIONEVENT._serialized_end=4492
  _DETECTORMODELONINPUT._serialized_start=4495
  _DETECTORMODELONINPUT._serialized_end=4721
  _DETECTORMODELONEXIT._serialized_start=4724
  _DETECTORMODELONEXIT._serialized_end=4865
  _DETECTORMODELONENTER._serialized_start=4868
  _DETECTORMODELONENTER._serialized_end=5010
  _DETECTORMODELSTATE._serialized_start=5013
  _DETECTORMODELSTATE._serialized_end=5309
  _DETECTORMODELDETECTORMODELDEFINITION._serialized_start=5312
  _DETECTORMODELDETECTORMODELDEFINITION._serialized_end=5498
  _DETECTORMODEL._serialized_start=5501
  _DETECTORMODEL._serialized_end=5907
  _DETECTORMODEL_TAGSENTRY._serialized_start=5864
  _DETECTORMODEL_TAGSENTRY._serialized_end=5907
  _IOTEVENTS._serialized_start=5909
  _IOTEVENTS._serialized_end=6035
  _INPUTATTRIBUTE._serialized_start=6037
  _INPUTATTRIBUTE._serialized_end=6129
  _INPUTINPUTDEFINITION._serialized_start=6132
  _INPUTINPUTDEFINITION._serialized_end=6274
  _INPUT._serialized_start=6277
  _INPUT._serialized_end=6566
  _INPUT_TAGSENTRY._serialized_start=5864
  _INPUT_TAGSENTRY._serialized_end=5907
# @@protoc_insertion_point(module_scope)
