# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_privatelinkservices.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7azure/azure_microsoft_network_privatelinkservices.proto\x12\x37oak9.tython.azure.microsoft_network_privatelinkservices\x1a\x13shared/shared.proto\"\xb9\x02\n%Microsoft_Network_privateLinkServices\x12k\n\x15private_link_services\x18\x01 \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_privatelinkservices.PrivateLinkServices\x12\xa2\x01\n2private_link_services_private_endpoint_connections\x18\x02 \x03(\x0b\x32\x66.oak9.tython.azure.microsoft_network_privatelinkservices.PrivateLinkServicesPrivateEndpointConnections\"\x82\x02\n-PrivateLinkServicesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x89\x01\n%private_link_service_connection_state\x18\x03 \x01(\x0b\x32Z.oak9.tython.azure.microsoft_network_privatelinkservices.PrivateLinkServiceConnectionState\"b\n!PrivateLinkServiceConnectionState\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10\x61\x63tions_required\x18\x03 \x01(\t\"\xad\x06\n\x13PrivateLinkServices\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x64\n\x04tags\x18\x04 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_privatelinkservices.PrivateLinkServices.TagsEntry\x12\x64\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32I.oak9.tython.azure.microsoft_network_privatelinkservices.ExtendedLocation\x12\x30\n(load_balancer_frontend_ip_configurations\x18\x06 \x03(\t\x12u\n\x11ip_configurations\x18\x07 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_privatelinkservices.PrivateLinkServiceIpConfiguration\x12s\n\nvisibility\x18\x08 \x01(\x0b\x32_.oak9.tython.azure.microsoft_network_privatelinkservices.PrivateLinkServicePropertiesVisibility\x12x\n\rauto_approval\x18\t \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_network_privatelinkservices.PrivateLinkServicePropertiesAutoApproval\x12\r\n\x05\x66qdns\x18\n \x03(\t\x12\x1d\n\x15\x65nable_proxy_protocol\x18\x0b \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n(PrivateLinkServicePropertiesAutoApproval\x12\x15\n\rsubscriptions\x18\x01 \x03(\t\"?\n&PrivateLinkServicePropertiesVisibility\x12\x15\n\rsubscriptions\x18\x01 \x03(\t\"\xb8\x01\n!PrivateLinkServiceIpConfiguration\x12\x1a\n\x12private_ip_address\x18\x01 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x02 \x01(\t\x12\x0e\n\x06subnet\x18\x03 \x01(\t\x12\x0f\n\x07primary\x18\x04 \x01(\x08\x12\"\n\x1aprivate_ip_address_version\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_privatelinkservices_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVATELINKSERVICES_TAGSENTRY._options = None
  _PRIVATELINKSERVICES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_PRIVATELINKSERVICES._serialized_start=138
  _MICROSOFT_NETWORK_PRIVATELINKSERVICES._serialized_end=451
  _PRIVATELINKSERVICESPRIVATEENDPOINTCONNECTIONS._serialized_start=454
  _PRIVATELINKSERVICESPRIVATEENDPOINTCONNECTIONS._serialized_end=712
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=714
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=812
  _PRIVATELINKSERVICES._serialized_start=815
  _PRIVATELINKSERVICES._serialized_end=1628
  _PRIVATELINKSERVICES_TAGSENTRY._serialized_start=1585
  _PRIVATELINKSERVICES_TAGSENTRY._serialized_end=1628
  _PRIVATELINKSERVICEPROPERTIESAUTOAPPROVAL._serialized_start=1630
  _PRIVATELINKSERVICEPROPERTIESAUTOAPPROVAL._serialized_end=1695
  _PRIVATELINKSERVICEPROPERTIESVISIBILITY._serialized_start=1697
  _PRIVATELINKSERVICEPROPERTIESVISIBILITY._serialized_end=1760
  _PRIVATELINKSERVICEIPCONFIGURATION._serialized_start=1763
  _PRIVATELINKSERVICEIPCONFIGURATION._serialized_end=1947
  _EXTENDEDLOCATION._serialized_start=1949
  _EXTENDEDLOCATION._serialized_end=1995
# @@protoc_insertion_point(module_scope)
