# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_stepfunctions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_stepfunctions.proto\x12\x1doak9.tython.aws.stepfunctions\x1a\x13shared/shared.proto\"h\n\x11\x41\x63tivityTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x90\x01\n\x08\x41\x63tivity\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12>\n\x04tags\x18\x03 \x03(\x0b\x32\x30.oak9.tython.aws.stepfunctions.ActivityTagsEntry\"\x8e\x01\n\rStepFunctions\x12\x39\n\x08\x61\x63tivity\x18\x01 \x03(\x0b\x32\'.oak9.tython.aws.stepfunctions.Activity\x12\x42\n\rstate_machine\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.stepfunctions.StateMachine\"t\n\"StateMachineCloudWatchLogsLogGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rlog_group_arn\x18\x02 \x01(\t\"\xbc\x01\n\x1aStateMachineLogDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x65\n\x1a\x63loud_watch_logs_log_group\x18\x02 \x01(\x0b\x32\x41.oak9.tython.aws.stepfunctions.StateMachineCloudWatchLogsLogGroup\"\xdb\x01\n StateMachineLoggingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05level\x18\x02 \x01(\t\x12\x1e\n\x16include_execution_data\x18\x03 \x01(\x08\x12O\n\x0c\x64\x65stinations\x18\x04 \x03(\x0b\x32\x39.oak9.tython.aws.stepfunctions.StateMachineLogDestination\"l\n StateMachineTracingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\x7f\n\x16StateMachineS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"^\n#StateMachineDefinitionSubstitutions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n\x15StateMachineTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xed\x04\n\x0cStateMachine\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x64\x65\x66inition_string\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x1a\n\x12state_machine_name\x18\x04 \x01(\t\x12\x1a\n\x12state_machine_type\x18\x05 \x01(\t\x12^\n\x15logging_configuration\x18\x06 \x01(\x0b\x32?.oak9.tython.aws.stepfunctions.StateMachineLoggingConfiguration\x12^\n\x15tracing_configuration\x18\x07 \x01(\x0b\x32?.oak9.tython.aws.stepfunctions.StateMachineTracingConfiguration\x12U\n\x16\x64\x65\x66inition_s3_location\x18\x08 \x01(\x0b\x32\x35.oak9.tython.aws.stepfunctions.StateMachineS3Location\x12\x64\n\x18\x64\x65\x66inition_substitutions\x18\t \x01(\x0b\x32\x42.oak9.tython.aws.stepfunctions.StateMachineDefinitionSubstitutions\x12\x42\n\x04tags\x18\n \x03(\x0b\x32\x34.oak9.tython.aws.stepfunctions.StateMachineTagsEntryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_stepfunctions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACTIVITYTAGSENTRY._serialized_start=83
  _ACTIVITYTAGSENTRY._serialized_end=187
  _ACTIVITY._serialized_start=190
  _ACTIVITY._serialized_end=334
  _STEPFUNCTIONS._serialized_start=337
  _STEPFUNCTIONS._serialized_end=479
  _STATEMACHINECLOUDWATCHLOGSLOGGROUP._serialized_start=481
  _STATEMACHINECLOUDWATCHLOGSLOGGROUP._serialized_end=597
  _STATEMACHINELOGDESTINATION._serialized_start=600
  _STATEMACHINELOGDESTINATION._serialized_end=788
  _STATEMACHINELOGGINGCONFIGURATION._serialized_start=791
  _STATEMACHINELOGGINGCONFIGURATION._serialized_end=1010
  _STATEMACHINETRACINGCONFIGURATION._serialized_start=1012
  _STATEMACHINETRACINGCONFIGURATION._serialized_end=1120
  _STATEMACHINES3LOCATION._serialized_start=1122
  _STATEMACHINES3LOCATION._serialized_end=1249
  _STATEMACHINEDEFINITIONSUBSTITUTIONS._serialized_start=1251
  _STATEMACHINEDEFINITIONSUBSTITUTIONS._serialized_end=1345
  _STATEMACHINETAGSENTRY._serialized_start=1347
  _STATEMACHINETAGSENTRY._serialized_end=1455
  _STATEMACHINE._serialized_start=1458
  _STATEMACHINE._serialized_end=2079
# @@protoc_insertion_point(module_scope)
