"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AccessPointAccessPointTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___AccessPointAccessPointTag = AccessPointAccessPointTag

@typing_extensions.final
class AccessPointPosixUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    GID_FIELD_NUMBER: builtins.int
    SECONDARY_GIDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    uid: builtins.str
    gid: builtins.str
    @property
    def secondary_gids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        uid: builtins.str = ...,
        gid: builtins.str = ...,
        secondary_gids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gid", b"gid", "resource_info", b"resource_info", "secondary_gids", b"secondary_gids", "uid", b"uid"]) -> None: ...

global___AccessPointPosixUser = AccessPointPosixUser

@typing_extensions.final
class AccessPointCreationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OWNER_UID_FIELD_NUMBER: builtins.int
    OWNER_GID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    owner_uid: builtins.str
    owner_gid: builtins.str
    permissions: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        owner_uid: builtins.str = ...,
        owner_gid: builtins.str = ...,
        permissions: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner_gid", b"owner_gid", "owner_uid", b"owner_uid", "permissions", b"permissions", "resource_info", b"resource_info"]) -> None: ...

global___AccessPointCreationInfo = AccessPointCreationInfo

@typing_extensions.final
class AccessPointRootDirectory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    CREATION_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    path: builtins.str
    @property
    def creation_info(self) -> global___AccessPointCreationInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        path: builtins.str = ...,
        creation_info: global___AccessPointCreationInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_info", b"creation_info", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_info", b"creation_info", "path", b"path", "resource_info", b"resource_info"]) -> None: ...

global___AccessPointRootDirectory = AccessPointRootDirectory

@typing_extensions.final
class AccessPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_TOKEN_FIELD_NUMBER: builtins.int
    ACCESS_POINT_TAGS_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_ID_FIELD_NUMBER: builtins.int
    POSIX_USER_FIELD_NUMBER: builtins.int
    ROOT_DIRECTORY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_token: builtins.str
    @property
    def access_point_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessPointAccessPointTag]: ...
    file_system_id: builtins.str
    @property
    def posix_user(self) -> global___AccessPointPosixUser: ...
    @property
    def root_directory(self) -> global___AccessPointRootDirectory: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_token: builtins.str = ...,
        access_point_tags: collections.abc.Iterable[global___AccessPointAccessPointTag] | None = ...,
        file_system_id: builtins.str = ...,
        posix_user: global___AccessPointPosixUser | None = ...,
        root_directory: global___AccessPointRootDirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["posix_user", b"posix_user", "resource_info", b"resource_info", "root_directory", b"root_directory"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_point_tags", b"access_point_tags", "client_token", b"client_token", "file_system_id", b"file_system_id", "posix_user", b"posix_user", "resource_info", b"resource_info", "root_directory", b"root_directory"]) -> None: ...

global___AccessPoint = AccessPoint

@typing_extensions.final
class EFS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_POINT_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_FIELD_NUMBER: builtins.int
    MOUNT_TARGET_FIELD_NUMBER: builtins.int
    @property
    def access_point(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessPoint]: ...
    @property
    def file_system(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileSystem]: ...
    @property
    def mount_target(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MountTarget]: ...
    def __init__(
        self,
        *,
        access_point: collections.abc.Iterable[global___AccessPoint] | None = ...,
        file_system: collections.abc.Iterable[global___FileSystem] | None = ...,
        mount_target: collections.abc.Iterable[global___MountTarget] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_point", b"access_point", "file_system", b"file_system", "mount_target", b"mount_target"]) -> None: ...

global___EFS = EFS

@typing_extensions.final
class FileSystemElasticFileSystemTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___FileSystemElasticFileSystemTag = FileSystemElasticFileSystemTag

@typing_extensions.final
class FileSystemLifecyclePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TRANSITION_TO_I_A_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    transition_to_i_a: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        transition_to_i_a: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "transition_to_i_a", b"transition_to_i_a"]) -> None: ...

global___FileSystemLifecyclePolicy = FileSystemLifecyclePolicy

@typing_extensions.final
class FileSystemBackupPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___FileSystemBackupPolicy = FileSystemBackupPolicy

@typing_extensions.final
class FileSystem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class FileSystemPolicyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_TAGS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_POLICIES_FIELD_NUMBER: builtins.int
    PERFORMANCE_MODE_FIELD_NUMBER: builtins.int
    PROVISIONED_THROUGHPUT_IN_MIBPS_FIELD_NUMBER: builtins.int
    THROUGHPUT_MODE_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_POLICY_FIELD_NUMBER: builtins.int
    BACKUP_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    encrypted: builtins.bool
    @property
    def file_system_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileSystemElasticFileSystemTag]: ...
    kms_key_id: builtins.str
    @property
    def lifecycle_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileSystemLifecyclePolicy]: ...
    performance_mode: builtins.str
    provisioned_throughput_in_mibps: builtins.float
    throughput_mode: builtins.str
    @property
    def file_system_policy(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def backup_policy(self) -> global___FileSystemBackupPolicy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encrypted: builtins.bool = ...,
        file_system_tags: collections.abc.Iterable[global___FileSystemElasticFileSystemTag] | None = ...,
        kms_key_id: builtins.str = ...,
        lifecycle_policies: collections.abc.Iterable[global___FileSystemLifecyclePolicy] | None = ...,
        performance_mode: builtins.str = ...,
        provisioned_throughput_in_mibps: builtins.float = ...,
        throughput_mode: builtins.str = ...,
        file_system_policy: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        backup_policy: global___FileSystemBackupPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backup_policy", b"backup_policy", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_policy", b"backup_policy", "encrypted", b"encrypted", "file_system_policy", b"file_system_policy", "file_system_tags", b"file_system_tags", "kms_key_id", b"kms_key_id", "lifecycle_policies", b"lifecycle_policies", "performance_mode", b"performance_mode", "provisioned_throughput_in_mibps", b"provisioned_throughput_in_mibps", "resource_info", b"resource_info", "throughput_mode", b"throughput_mode"]) -> None: ...

global___FileSystem = FileSystem

@typing_extensions.final
class MountTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    file_system_id: builtins.str
    ip_address: builtins.str
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        file_system_id: builtins.str = ...,
        ip_address: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_system_id", b"file_system_id", "ip_address", b"ip_address", "resource_info", b"resource_info", "security_groups", b"security_groups", "subnet_id", b"subnet_id"]) -> None: ...

global___MountTarget = MountTarget
