"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DatastoreIndexXProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIRECTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    direction: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        direction: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["direction", b"direction", "name", b"name"]) -> None: ...

global___DatastoreIndexXProperties = DatastoreIndexXProperties

@typing_extensions.final
class DatastoreIndexXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___DatastoreIndexXTimeouts = DatastoreIndexXTimeouts

@typing_extensions.final
class DatastoreIndex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANCESTOR_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INDEX_ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ancestor: builtins.str
    id: builtins.str
    index_id: builtins.str
    kind: builtins.str
    project: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatastoreIndexXProperties]: ...
    @property
    def timeouts(self) -> global___DatastoreIndexXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ancestor: builtins.str = ...,
        id: builtins.str = ...,
        index_id: builtins.str = ...,
        kind: builtins.str = ...,
        project: builtins.str = ...,
        properties: collections.abc.Iterable[global___DatastoreIndexXProperties] | None = ...,
        timeouts: global___DatastoreIndexXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ancestor", b"ancestor", "id", b"id", "index_id", b"index_id", "kind", b"kind", "project", b"project", "properties", b"properties", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DatastoreIndex = DatastoreIndex
