# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_trafficmanager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2azure/azure_microsoft_network_trafficmanager.proto\x12\x32oak9.tython.azure.microsoft_network_trafficmanager\x1a\x13shared/shared.proto\"\x90\x01\n Microsoft_Network_TrafficManager\x12l\n\x18traffic_manager_profiles\x18\x01 \x01(\x0b\x32J.oak9.tython.azure.microsoft_network_trafficmanager.TrafficManagerProfiles\"\x81\x05\n\x16TrafficManagerProfiles\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x62\n\x04tags\x18\x04 \x03(\x0b\x32T.oak9.tython.azure.microsoft_network_trafficmanager.TrafficManagerProfiles.TagsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x16\n\x0eprofile_status\x18\x06 \x01(\t\x12\x1e\n\x16traffic_routing_method\x18\x07 \x01(\t\x12Q\n\ndns_config\x18\x08 \x01(\x0b\x32=.oak9.tython.azure.microsoft_network_trafficmanager.DnsConfig\x12Y\n\x0emonitor_config\x18\t \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_trafficmanager.MonitorConfig\x12O\n\tendpoints\x18\n \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_trafficmanager.Endpoint\x12&\n\x1etraffic_view_enrollment_status\x18\x0b \x01(\t\x12\x12\n\nmax_return\x18\x0c \x01(\x05\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdc\x03\n\x08\x45ndpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x1a\n\x12target_resource_id\x18\x04 \x01(\t\x12\x0e\n\x06target\x18\x05 \x01(\t\x12\x17\n\x0f\x65ndpoint_status\x18\x06 \x01(\t\x12\x0e\n\x06weight\x18\x07 \x01(\x05\x12\x10\n\x08priority\x18\x08 \x01(\x05\x12\x19\n\x11\x65ndpoint_location\x18\t \x01(\t\x12\x1f\n\x17\x65ndpoint_monitor_status\x18\n \x01(\t\x12\x1b\n\x13min_child_endpoints\x18\x0b \x01(\x05\x12\x13\n\x0bgeo_mapping\x18\x0c \x03(\t\x12\x62\n\x07subnets\x18\r \x03(\x0b\x32Q.oak9.tython.azure.microsoft_network_trafficmanager.EndpointPropertiesSubnetsItem\x12o\n\x0e\x63ustom_headers\x18\x0e \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_trafficmanager.EndpointPropertiesCustomHeadersItem\"B\n#EndpointPropertiesCustomHeadersItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"K\n\x1d\x45ndpointPropertiesSubnetsItem\x12\r\n\x05\x66irst\x18\x01 \x01(\t\x12\x0c\n\x04last\x18\x02 \x01(\t\x12\r\n\x05scope\x18\x03 \x01(\x05\"\xad\x03\n\rMonitorConfig\x12\x1e\n\x16profile_monitor_status\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x1b\n\x13interval_in_seconds\x18\x05 \x01(\x05\x12\x1a\n\x12timeout_in_seconds\x18\x06 \x01(\x05\x12$\n\x1ctolerated_number_of_failures\x18\x07 \x01(\x05\x12j\n\x0e\x63ustom_headers\x18\x08 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_trafficmanager.MonitorConfigCustomHeadersItem\x12\x82\x01\n\x1b\x65xpected_status_code_ranges\x18\t \x03(\x0b\x32].oak9.tython.azure.microsoft_network_trafficmanager.MonitorConfigExpectedStatusCodeRangesItem\"E\n)MonitorConfigExpectedStatusCodeRangesItem\x12\x0b\n\x03min\x18\x01 \x01(\x05\x12\x0b\n\x03max\x18\x02 \x01(\x05\"=\n\x1eMonitorConfigCustomHeadersItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"/\n\tDnsConfig\x12\x15\n\rrelative_name\x18\x01 \x01(\t\x12\x0b\n\x03ttl\x18\x02 \x01(\x05\"\xd2\x04\n\x08VpnSites\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12T\n\x04tags\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_trafficmanager.VpnSites.TagsEntry\x12\x15\n\rvirtual_w_a_n\x18\x05 \x01(\t\x12_\n\x11\x64\x65vice_properties\x18\x06 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_network_trafficmanager.DeviceProperties\x12\x12\n\nip_address\x18\x07 \x01(\t\x12\x10\n\x08site_key\x18\x08 \x01(\t\x12W\n\raddress_space\x18\t \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_trafficmanager.AddressSpace\x12W\n\x0e\x62gp_properties\x18\n \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_trafficmanager.BgpSettings\x12\x1a\n\x12provisioning_state\x18\x0b \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n\x10\x44\x65viceProperties\x12\x15\n\rdevice_vendor\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x02 \x01(\t\x12\x1a\n\x12link_speed_in_mbps\x18\x03 \x01(\x05\"\xcb\x02\n\x19VpnGatewaysVpnConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fremote_vpn_site\x18\x03 \x01(\t\x12\x16\n\x0erouting_weight\x18\x04 \x01(\x05\x12\x19\n\x11\x63onnection_status\x18\x05 \x01(\t\x12\x12\n\nshared_key\x18\x06 \x01(\t\x12\x12\n\nenable_bgp\x18\x07 \x01(\x08\x12W\n\x0eipsec_policies\x18\x08 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_trafficmanager.IpsecPolicy\x12\x1a\n\x12provisioning_state\x18\t \x01(\t\"\x9c\x04\n\x0bVpnGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12W\n\x04tags\x18\x04 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network_trafficmanager.VpnGateways.TagsEntry\x12\x13\n\x0bvirtual_hub\x18\x05 \x01(\t\x12V\n\x0b\x63onnections\x18\x06 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network_trafficmanager.VpnConnection\x12U\n\x0c\x62gp_settings\x18\x07 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_trafficmanager.BgpSettings\x12\x1a\n\x12provisioning_state\x18\x08 \x01(\t\x12N\n\x08policies\x18\t \x01(\x0b\x32<.oak9.tython.azure.microsoft_network_trafficmanager.Policies\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x08Policies\x12&\n\x1e\x61llow_branch_to_branch_traffic\x18\x01 \x01(\x08\x12\"\n\x1a\x61llow_vnet_to_vnet_traffic\x18\x02 \x01(\x08\"\x86\x02\n\rVpnConnection\x12\x17\n\x0fremote_vpn_site\x18\x01 \x01(\t\x12\x16\n\x0erouting_weight\x18\x02 \x01(\x05\x12\x19\n\x11\x63onnection_status\x18\x03 \x01(\t\x12\x12\n\nshared_key\x18\x04 \x01(\t\x12\x12\n\nenable_bgp\x18\x05 \x01(\x08\x12W\n\x0eipsec_policies\x18\x06 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_trafficmanager.IpsecPolicy\x12\x1a\n\x12provisioning_state\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\"\xa8\x02\n\x0bVirtualWans\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12W\n\x04tags\x18\x04 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network_trafficmanager.VirtualWans.TagsEntry\x12\x1e\n\x16\x64isable_vpn_encryption\x18\x05 \x01(\x08\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xad\x06\n\x16VirtualNetworkGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x62\n\x04tags\x18\x04 \x03(\x0b\x32T.oak9.tython.azure.microsoft_network_trafficmanager.VirtualNetworkGateways.TagsEntry\x12s\n\x11ip_configurations\x18\x05 \x03(\x0b\x32X.oak9.tython.azure.microsoft_network_trafficmanager.VirtualNetworkGatewayIPConfiguration\x12\x14\n\x0cgateway_type\x18\x06 \x01(\t\x12\x10\n\x08vpn_type\x18\x07 \x01(\t\x12\x12\n\nenable_bgp\x18\x08 \x01(\x08\x12\x15\n\ractive_active\x18\t \x01(\x08\x12\x1c\n\x14gateway_default_site\x18\n \x01(\t\x12Y\n\x03sku\x18\x0b \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_trafficmanager.VirtualNetworkGatewaySku\x12l\n\x18vpn_client_configuration\x18\x0c \x01(\x0b\x32J.oak9.tython.azure.microsoft_network_trafficmanager.VpnClientConfiguration\x12U\n\x0c\x62gp_settings\x18\r \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_trafficmanager.BgpSettings\x12\x15\n\rresource_guid\x18\x0e \x01(\t\x12\x0c\n\x04\x65tag\x18\x0f \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x04\n\x16VpnClientConfiguration\x12\x61\n\x17vpn_client_address_pool\x18\x01 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_trafficmanager.AddressSpace\x12r\n\x1cvpn_client_root_certificates\x18\x02 \x03(\x0b\x32L.oak9.tython.azure.microsoft_network_trafficmanager.VpnClientRootCertificate\x12x\n\x1fvpn_client_revoked_certificates\x18\x03 \x03(\x0b\x32O.oak9.tython.azure.microsoft_network_trafficmanager.VpnClientRevokedCertificate\x12\x1c\n\x14vpn_client_protocols\x18\x04 \x03(\t\x12\x62\n\x19vpn_client_ipsec_policies\x18\x05 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_trafficmanager.IpsecPolicy\x12\x1d\n\x15radius_server_address\x18\x06 \x01(\t\x12\x1c\n\x14radius_server_secret\x18\x07 \x01(\t\"M\n\x1bVpnClientRevokedCertificate\x12\x12\n\nthumbprint\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\"P\n\x18VpnClientRootCertificate\x12\x18\n\x10public_cert_data\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\"H\n\x18VirtualNetworkGatewaySku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\x03 \x01(\x05\"\x93\x01\n$VirtualNetworkGatewayIPConfiguration\x12$\n\x1cprivate_ip_allocation_method\x18\x01 \x01(\t\x12\x0e\n\x06subnet\x18\x02 \x01(\t\x12\x19\n\x11public_ip_address\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04\x65tag\x18\x05 \x01(\t\"\xaf\x03\n\x0bVirtualHubs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12W\n\x04tags\x18\x04 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network_trafficmanager.VirtualHubs.TagsEntry\x12\x13\n\x0bvirtual_wan\x18\x05 \x01(\t\x12x\n\x1fhub_virtual_network_connections\x18\x06 \x03(\x0b\x32O.oak9.tython.azure.microsoft_network_trafficmanager.HubVirtualNetworkConnection\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x07 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x02\n\x1bHubVirtualNetworkConnection\x12\x10\n\x08location\x18\x01 \x01(\t\x12g\n\x04tags\x18\x02 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_network_trafficmanager.HubVirtualNetworkConnection.TagsEntry\x12\x1e\n\x16remote_virtual_network\x18\x03 \x01(\t\x12(\n allow_hub_to_remote_vnet_transit\x18\x04 \x01(\x08\x12\x32\n*allow_remote_vnet_to_use_hub_vnet_gateways\x18\x05 \x01(\x08\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x1cRouteFiltersRouteFilterRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x03 \x01(\t\x12\x1e\n\x16route_filter_rule_type\x18\x04 \x01(\t\x12\x13\n\x0b\x63ommunities\x18\x05 \x03(\t\x12\x10\n\x08location\x18\x06 \x01(\t\"\xd4\x02\n\x0cRouteFilters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12X\n\x04tags\x18\x04 \x03(\x0b\x32J.oak9.tython.azure.microsoft_network_trafficmanager.RouteFilters.TagsEntry\x12R\n\x05rules\x18\x05 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network_trafficmanager.RouteFilterRule\x12\x10\n\x08peerings\x18\x06 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\x0fRouteFilterRule\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x01 \x01(\t\x12\x1e\n\x16route_filter_rule_type\x18\x02 \x01(\t\x12\x13\n\x0b\x63ommunities\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\"\xcc\x05\n\x11PublicIPAddresses\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12]\n\x04tags\x18\x04 \x03(\x0b\x32O.oak9.tython.azure.microsoft_network_trafficmanager.PublicIPAddresses.TagsEntry\x12S\n\x03sku\x18\x05 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network_trafficmanager.PublicIPAddressSku\x12#\n\x1bpublic_ip_allocation_method\x18\x06 \x01(\t\x12!\n\x19public_ip_address_version\x18\x07 \x01(\t\x12\x64\n\x0c\x64ns_settings\x18\x08 \x01(\x0b\x32N.oak9.tython.azure.microsoft_network_trafficmanager.PublicIPAddressDnsSettings\x12J\n\x07ip_tags\x18\t \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_trafficmanager.IpTag\x12\x12\n\nip_address\x18\n \x01(\t\x12\x1f\n\x17idle_timeout_in_minutes\x18\x0b \x01(\x05\x12\x15\n\rresource_guid\x18\x0c \x01(\t\x12\x1a\n\x12provisioning_state\x18\r \x01(\t\x12\x0c\n\x04\x65tag\x18\x0e \x01(\t\x12\r\n\x05zones\x18\x0f \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x05IpTag\x12\x13\n\x0bip_tag_type\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"[\n\x1aPublicIPAddressDnsSettings\x12\x19\n\x11\x64omain_name_label\x18\x01 \x01(\t\x12\x0c\n\x04\x66qdn\x18\x02 \x01(\t\x12\x14\n\x0creverse_fqdn\x18\x03 \x01(\t\"\"\n\x12PublicIPAddressSku\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa1\x03\n\x1dNetworkWatchersPacketCaptures\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12#\n\x1b\x62ytes_to_capture_per_packet\x18\x04 \x01(\x05\x12\x1f\n\x17total_bytes_per_session\x18\x05 \x01(\x05\x12\x1d\n\x15time_limit_in_seconds\x18\x06 \x01(\x05\x12j\n\x10storage_location\x18\x07 \x01(\x0b\x32P.oak9.tython.azure.microsoft_network_trafficmanager.PacketCaptureStorageLocation\x12X\n\x07\x66ilters\x18\x08 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_trafficmanager.PacketCaptureFilter\"\x85\x01\n\x13PacketCaptureFilter\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x18\n\x10local_ip_address\x18\x02 \x01(\t\x12\x19\n\x11remote_ip_address\x18\x03 \x01(\t\x12\x12\n\nlocal_port\x18\x04 \x01(\t\x12\x13\n\x0bremote_port\x18\x05 \x01(\t\"[\n\x1cPacketCaptureStorageLocation\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x14\n\x0cstorage_path\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\"\x98\x04\n!NetworkWatchersConnectionMonitors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12m\n\x04tags\x18\x04 \x03(\x0b\x32_.oak9.tython.azure.microsoft_network_trafficmanager.NetworkWatchersConnectionMonitors.TagsEntry\x12[\n\x06source\x18\x05 \x01(\x0b\x32K.oak9.tython.azure.microsoft_network_trafficmanager.ConnectionMonitorSource\x12\x65\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32P.oak9.tython.azure.microsoft_network_trafficmanager.ConnectionMonitorDestination\x12\x12\n\nauto_start\x18\x07 \x01(\x08\x12&\n\x1emonitoring_interval_in_seconds\x18\x08 \x01(\x05\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n\x1c\x43onnectionMonitorDestination\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\"<\n\x17\x43onnectionMonitorSource\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\x85\x04\n\x0fNetworkWatchers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12[\n\x04tags\x18\x04 \x03(\x0b\x32M.oak9.tython.azure.microsoft_network_trafficmanager.NetworkWatchers.TagsEntry\x12\x0c\n\x04\x65tag\x18\x05 \x01(\t\x12\x83\x01\n$network_watchers_connection_monitors\x18\x06 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_trafficmanager.NetworkWatchersConnectionMonitors\x12{\n network_watchers_packet_captures\x18\x07 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_network_trafficmanager.NetworkWatchersPacketCaptures\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x05\n\x11NetworkInterfaces\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12]\n\x04tags\x18\x04 \x03(\x0b\x32O.oak9.tython.azure.microsoft_network_trafficmanager.NetworkInterfaces.TagsEntry\x12\x17\n\x0fvirtual_machine\x18\x05 \x01(\t\x12\x1e\n\x16network_security_group\x18\x06 \x01(\t\x12n\n\x11ip_configurations\x18\x07 \x03(\x0b\x32S.oak9.tython.azure.microsoft_network_trafficmanager.NetworkInterfaceIPConfiguration\x12\x65\n\x0c\x64ns_settings\x18\x08 \x01(\x0b\x32O.oak9.tython.azure.microsoft_network_trafficmanager.NetworkInterfaceDnsSettings\x12\x13\n\x0bmac_address\x18\t \x01(\t\x12\x0f\n\x07primary\x18\n \x01(\x08\x12%\n\x1d\x65nable_accelerated_networking\x18\x0b \x01(\x08\x12\x1c\n\x14\x65nable_ip_forwarding\x18\x0c \x01(\x08\x12\x15\n\rresource_guid\x18\r \x01(\t\x12\x1a\n\x12provisioning_state\x18\x0e \x01(\t\x12\x0c\n\x04\x65tag\x18\x0f \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x01\n\x1bNetworkInterfaceDnsSettings\x12\x13\n\x0b\x64ns_servers\x18\x01 \x03(\t\x12\x1b\n\x13\x61pplied_dns_servers\x18\x02 \x03(\t\x12\x1f\n\x17internal_dns_name_label\x18\x03 \x01(\t\x12\x15\n\rinternal_fqdn\x18\x04 \x01(\t\x12#\n\x1binternal_domain_name_suffix\x18\x05 \x01(\t\"\xa9\x03\n\x1fNetworkInterfaceIPConfiguration\x12\x31\n)application_gateway_backend_address_pools\x18\x01 \x03(\t\x12+\n#load_balancer_backend_address_pools\x18\x02 \x03(\t\x12\'\n\x1fload_balancer_inbound_nat_rules\x18\x03 \x03(\t\x12\x1a\n\x12private_ip_address\x18\x04 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x05 \x01(\t\x12\"\n\x1aprivate_ip_address_version\x18\x06 \x01(\t\x12\x0e\n\x06subnet\x18\x07 \x01(\t\x12\x0f\n\x07primary\x18\x08 \x01(\x08\x12\x19\n\x11public_ip_address\x18\t \x01(\t\x12#\n\x1b\x61pplication_security_groups\x18\n \x03(\t\x12\x1a\n\x12provisioning_state\x18\x0b \x01(\t\x12\x0c\n\x04name\x18\x0c \x01(\t\x12\x0c\n\x04\x65tag\x18\r \x01(\t\"\xfd\x03\n\x14LocalNetworkGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12`\n\x04tags\x18\x04 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_trafficmanager.LocalNetworkGateways.TagsEntry\x12\x65\n\x1blocal_network_address_space\x18\x05 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_trafficmanager.AddressSpace\x12\x1a\n\x12gateway_ip_address\x18\x06 \x01(\t\x12U\n\x0c\x62gp_settings\x18\x07 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_trafficmanager.BgpSettings\x12\x15\n\rresource_guid\x18\x08 \x01(\t\x12\x0c\n\x04\x65tag\x18\t \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x0b\x42gpSettings\x12\x0b\n\x03\x61sn\x18\x01 \x01(\x05\x12\x1b\n\x13\x62gp_peering_address\x18\x02 \x01(\t\x12\x13\n\x0bpeer_weight\x18\x03 \x01(\x05\"(\n\x0c\x41\x64\x64ressSpace\x12\x18\n\x10\x61\x64\x64ress_prefixes\x18\x01 \x03(\t\"\xbc\x04\n$ExpressRouteCrossConnectionsPeerings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cpeering_type\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x10\n\x08peer_asn\x18\x05 \x01(\x05\x12#\n\x1bprimary_peer_address_prefix\x18\x06 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x07 \x01(\t\x12\x12\n\nshared_key\x18\x08 \x01(\t\x12\x0f\n\x07vlan_id\x18\t \x01(\x05\x12v\n\x18microsoft_peering_config\x18\n \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitPeeringConfig\x12\x1c\n\x14gateway_manager_etag\x18\x0b \x01(\t\x12\x18\n\x10last_modified_by\x18\x0c \x01(\t\x12u\n\x13ipv6_peering_config\x18\r \x01(\x0b\x32X.oak9.tython.azure.microsoft_network_trafficmanager.Ipv6ExpressRouteCircuitPeeringConfig\"\xf8\x05\n\x1c\x45xpressRouteCrossConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12h\n\x04tags\x18\x04 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCrossConnections.TagsEntry\x12\x18\n\x10peering_location\x18\x05 \x01(\t\x12\x19\n\x11\x62\x61ndwidth_in_mbps\x18\x06 \x01(\x05\x12o\n\x15\x65xpress_route_circuit\x18\x07 \x01(\x0b\x32P.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitReference\x12+\n#service_provider_provisioning_state\x18\x08 \x01(\t\x12\x1e\n\x16service_provider_notes\x18\t \x01(\t\x12h\n\x08peerings\x18\n \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCrossConnectionPeering\x12\x8a\x01\n(express_route_cross_connections_peerings\x18\x0b \x03(\x0b\x32X.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCrossConnectionsPeerings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x04\n\"ExpressRouteCrossConnectionPeering\x12\x14\n\x0cpeering_type\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x10\n\x08peer_asn\x18\x03 \x01(\x05\x12#\n\x1bprimary_peer_address_prefix\x18\x04 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x05 \x01(\t\x12\x12\n\nshared_key\x18\x06 \x01(\t\x12\x0f\n\x07vlan_id\x18\x07 \x01(\x05\x12v\n\x18microsoft_peering_config\x18\x08 \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitPeeringConfig\x12\x1c\n\x14gateway_manager_etag\x18\t \x01(\t\x12\x18\n\x10last_modified_by\x18\n \x01(\t\x12u\n\x13ipv6_peering_config\x18\x0b \x01(\x0b\x32X.oak9.tython.azure.microsoft_network_trafficmanager.Ipv6ExpressRouteCircuitPeeringConfig\x12\x0c\n\x04name\x18\x0c \x01(\t\"*\n\x1c\x45xpressRouteCircuitReference\x12\n\n\x02id\x18\x01 \x01(\t\"\xf6\x01\n\'ExpressRouteCircuitsPeeringsConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x1d\x65xpress_route_circuit_peering\x18\x03 \x01(\t\x12*\n\"peer_express_route_circuit_peering\x18\x04 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x05 \x01(\t\x12\x19\n\x11\x61uthorization_key\x18\x06 \x01(\t\"\x8b\x08\n\x1c\x45xpressRouteCircuitsPeerings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cpeering_type\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x11\n\tazure_asn\x18\x05 \x01(\x05\x12\x10\n\x08peer_asn\x18\x06 \x01(\x05\x12#\n\x1bprimary_peer_address_prefix\x18\x07 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x08 \x01(\t\x12\x1a\n\x12primary_azure_port\x18\t \x01(\t\x12\x1c\n\x14secondary_azure_port\x18\n \x01(\t\x12\x12\n\nshared_key\x18\x0b \x01(\t\x12\x0f\n\x07vlan_id\x18\x0c \x01(\x05\x12v\n\x18microsoft_peering_config\x18\r \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitPeeringConfig\x12[\n\x05stats\x18\x0e \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitStats\x12\x1a\n\x12provisioning_state\x18\x0f \x01(\t\x12\x1c\n\x14gateway_manager_etag\x18\x10 \x01(\t\x12\x18\n\x10last_modified_by\x18\x11 \x01(\t\x12\x14\n\x0croute_filter\x18\x12 \x01(\t\x12u\n\x13ipv6_peering_config\x18\x13 \x01(\x0b\x32X.oak9.tython.azure.microsoft_network_trafficmanager.Ipv6ExpressRouteCircuitPeeringConfig\x12\x66\n\x0b\x63onnections\x18\x14 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitConnection\x12\x90\x01\n+express_route_circuits_peerings_connections\x18\x15 \x03(\x0b\x32[.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitsPeeringsConnections\"\xc4\x01\n\"ExpressRouteCircuitsAuthorizations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x61uthorization_key\x18\x03 \x01(\t\x12 \n\x18\x61uthorization_use_status\x18\x04 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x05 \x01(\t\"\x94\t\n\x14\x45xpressRouteCircuits\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12`\n\x04tags\x18\x04 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuits.TagsEntry\x12W\n\x03sku\x18\x05 \x01(\x0b\x32J.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitSku\x12 \n\x18\x61llow_classic_operations\x18\x06 \x01(\x08\x12\"\n\x1a\x63ircuit_provisioning_state\x18\x07 \x01(\t\x12+\n#service_provider_provisioning_state\x18\x08 \x01(\t\x12l\n\x0e\x61uthorizations\x18\t \x03(\x0b\x32T.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitAuthorization\x12`\n\x08peerings\x18\n \x03(\x0b\x32N.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitPeering\x12\x13\n\x0bservice_key\x18\x0b \x01(\t\x12\x1e\n\x16service_provider_notes\x18\x0c \x01(\t\x12\x85\x01\n\x1bservice_provider_properties\x18\r \x01(\x0b\x32`.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitServiceProviderProperties\x12\x1a\n\x12provisioning_state\x18\x0e \x01(\t\x12\x1c\n\x14gateway_manager_etag\x18\x0f \x01(\t\x12y\n\x1f\x65xpress_route_circuits_peerings\x18\x10 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitsPeerings\x12\x85\x01\n%express_route_circuits_authorizations\x18\x11 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitsAuthorizations\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n,ExpressRouteCircuitServiceProviderProperties\x12\x1d\n\x15service_provider_name\x18\x01 \x01(\t\x12\x18\n\x10peering_location\x18\x02 \x01(\t\x12\x19\n\x11\x62\x61ndwidth_in_mbps\x18\x03 \x01(\x05\"\xbd\x06\n\x1a\x45xpressRouteCircuitPeering\x12\x14\n\x0cpeering_type\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x11\n\tazure_asn\x18\x03 \x01(\x05\x12\x10\n\x08peer_asn\x18\x04 \x01(\x05\x12#\n\x1bprimary_peer_address_prefix\x18\x05 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x06 \x01(\t\x12\x1a\n\x12primary_azure_port\x18\x07 \x01(\t\x12\x1c\n\x14secondary_azure_port\x18\x08 \x01(\t\x12\x12\n\nshared_key\x18\t \x01(\t\x12\x0f\n\x07vlan_id\x18\n \x01(\x05\x12v\n\x18microsoft_peering_config\x18\x0b \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitPeeringConfig\x12[\n\x05stats\x18\x0c \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitStats\x12\x1a\n\x12provisioning_state\x18\r \x01(\t\x12\x1c\n\x14gateway_manager_etag\x18\x0e \x01(\t\x12\x18\n\x10last_modified_by\x18\x0f \x01(\t\x12\x14\n\x0croute_filter\x18\x10 \x01(\t\x12u\n\x13ipv6_peering_config\x18\x11 \x01(\x0b\x32X.oak9.tython.azure.microsoft_network_trafficmanager.Ipv6ExpressRouteCircuitPeeringConfig\x12\x66\n\x0b\x63onnections\x18\x12 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitConnection\x12\x0c\n\x04name\x18\x13 \x01(\t\"\xb3\x01\n\x1d\x45xpressRouteCircuitConnection\x12%\n\x1d\x65xpress_route_circuit_peering\x18\x01 \x01(\t\x12*\n\"peer_express_route_circuit_peering\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x03 \x01(\t\x12\x19\n\x11\x61uthorization_key\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\x8f\x02\n$Ipv6ExpressRouteCircuitPeeringConfig\x12#\n\x1bprimary_peer_address_prefix\x18\x01 \x01(\t\x12%\n\x1dsecondary_peer_address_prefix\x18\x02 \x01(\t\x12v\n\x18microsoft_peering_config\x18\x03 \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_trafficmanager.ExpressRouteCircuitPeeringConfig\x12\x14\n\x0croute_filter\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\"\x84\x01\n\x18\x45xpressRouteCircuitStats\x12\x17\n\x0fprimarybytes_in\x18\x01 \x01(\x05\x12\x18\n\x10primarybytes_out\x18\x02 \x01(\x05\x12\x19\n\x11secondarybytes_in\x18\x03 \x01(\x05\x12\x1a\n\x12secondarybytes_out\x18\x04 \x01(\x05\"\xda\x01\n ExpressRouteCircuitPeeringConfig\x12\"\n\x1a\x61\x64vertised_public_prefixes\x18\x01 \x03(\t\x12\x1e\n\x16\x61\x64vertised_communities\x18\x02 \x03(\t\x12(\n advertised_public_prefixes_state\x18\x03 \x01(\t\x12\x13\n\x0blegacy_mode\x18\x04 \x01(\x05\x12\x14\n\x0c\x63ustomer_asn\x18\x05 \x01(\x05\x12\x1d\n\x15routing_registry_name\x18\x06 \x01(\t\"\x89\x01\n ExpressRouteCircuitAuthorization\x12\x19\n\x11\x61uthorization_key\x18\x01 \x01(\t\x12 \n\x18\x61uthorization_use_status\x18\x02 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"D\n\x16\x45xpressRouteCircuitSku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\"\xfc\x01\n\x13\x44\x64osProtectionPlans\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12_\n\x04tags\x18\x04 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_network_trafficmanager.DdosProtectionPlans.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfc\x04\n\x0b\x43onnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12W\n\x04tags\x18\x04 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network_trafficmanager.Connections.TagsEntry\x12\x19\n\x11\x61uthorization_key\x18\x05 \x01(\t\x12 \n\x18virtual_network_gateway1\x18\x06 \x01(\t\x12 \n\x18virtual_network_gateway2\x18\x07 \x01(\t\x12\x1e\n\x16local_network_gateway2\x18\x08 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\t \x01(\t\x12\x16\n\x0erouting_weight\x18\n \x01(\x05\x12\x12\n\nshared_key\x18\x0b \x01(\t\x12\x0c\n\x04peer\x18\x0c \x01(\t\x12\x12\n\nenable_bgp\x18\r \x01(\x08\x12*\n\"use_policy_based_traffic_selectors\x18\x0e \x01(\x08\x12W\n\x0eipsec_policies\x18\x0f \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_trafficmanager.IpsecPolicy\x12\x15\n\rresource_guid\x18\x10 \x01(\t\x12\x0c\n\x04\x65tag\x18\x11 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd2\x01\n\x0bIpsecPolicy\x12\x1c\n\x14sa_life_time_seconds\x18\x01 \x01(\x05\x12\x1e\n\x16sa_data_size_kilobytes\x18\x02 \x01(\x05\x12\x18\n\x10ipsec_encryption\x18\x03 \x01(\t\x12\x17\n\x0fipsec_integrity\x18\x04 \x01(\t\x12\x16\n\x0eike_encryption\x18\x05 \x01(\t\x12\x15\n\rike_integrity\x18\x06 \x01(\t\x12\x10\n\x08\x64h_group\x18\x07 \x01(\t\x12\x11\n\tpfs_group\x18\x08 \x01(\t\"\xf8\x04\n\x0e\x41zureFirewalls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12Z\n\x04tags\x18\x04 \x03(\x0b\x32L.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewalls.TagsEntry\x12\x80\x01\n\x1c\x61pplication_rule_collections\x18\x05 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewallApplicationRuleCollection\x12x\n\x18network_rule_collections\x18\x06 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewallNetworkRuleCollection\x12k\n\x11ip_configurations\x18\x07 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewallIPConfiguration\x12\x1a\n\x12provisioning_state\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc1\x01\n\x1c\x41zureFirewallIPConfiguration\x12\x1a\n\x12private_ip_address\x18\x01 \x01(\t\x12\x0e\n\x06subnet\x18\x02 \x01(\t\x12\"\n\x1ainternal_public_ip_address\x18\x03 \x01(\t\x12\x19\n\x11public_ip_address\x18\x04 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04\x65tag\x18\x07 \x01(\t\"\x98\x02\n\"AzureFirewallNetworkRuleCollection\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12Y\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32I.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewallRCAction\x12[\n\x05rules\x18\x03 \x03(\x0b\x32L.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewallNetworkRule\x12\x1a\n\x12provisioning_state\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\xa4\x01\n\x18\x41zureFirewallNetworkRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tprotocols\x18\x03 \x03(\t\x12\x18\n\x10source_addresses\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x65stination_addresses\x18\x05 \x03(\t\x12\x19\n\x11\x64\x65stination_ports\x18\x06 \x03(\t\"\xa0\x02\n&AzureFirewallApplicationRuleCollection\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12Y\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32I.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewallRCAction\x12_\n\x05rules\x18\x03 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewallApplicationRule\x12\x1a\n\x12provisioning_state\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\xdd\x01\n\x1c\x41zureFirewallApplicationRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10source_addresses\x18\x03 \x03(\t\x12k\n\tprotocols\x18\x04 \x03(\x0b\x32X.oak9.tython.azure.microsoft_network_trafficmanager.AzureFirewallApplicationRuleProtocol\x12\x13\n\x0btarget_urls\x18\x05 \x03(\t\"K\n$AzureFirewallApplicationRuleProtocol\x12\x15\n\rprotocol_type\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"%\n\x15\x41zureFirewallRCAction\x12\x0c\n\x04type\x18\x01 \x01(\t\"\x88\x02\n\x19\x41pplicationSecurityGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x65\n\x04tags\x18\x04 \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_trafficmanager.ApplicationSecurityGroups.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_trafficmanager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRAFFICMANAGERPROFILES_TAGSENTRY._options = None
  _TRAFFICMANAGERPROFILES_TAGSENTRY._serialized_options = b'8\001'
  _VPNSITES_TAGSENTRY._options = None
  _VPNSITES_TAGSENTRY._serialized_options = b'8\001'
  _VPNGATEWAYS_TAGSENTRY._options = None
  _VPNGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALWANS_TAGSENTRY._options = None
  _VIRTUALWANS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALNETWORKGATEWAYS_TAGSENTRY._options = None
  _VIRTUALNETWORKGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALHUBS_TAGSENTRY._options = None
  _VIRTUALHUBS_TAGSENTRY._serialized_options = b'8\001'
  _HUBVIRTUALNETWORKCONNECTION_TAGSENTRY._options = None
  _HUBVIRTUALNETWORKCONNECTION_TAGSENTRY._serialized_options = b'8\001'
  _ROUTEFILTERS_TAGSENTRY._options = None
  _ROUTEFILTERS_TAGSENTRY._serialized_options = b'8\001'
  _PUBLICIPADDRESSES_TAGSENTRY._options = None
  _PUBLICIPADDRESSES_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKWATCHERSCONNECTIONMONITORS_TAGSENTRY._options = None
  _NETWORKWATCHERSCONNECTIONMONITORS_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKWATCHERS_TAGSENTRY._options = None
  _NETWORKWATCHERS_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKINTERFACES_TAGSENTRY._options = None
  _NETWORKINTERFACES_TAGSENTRY._serialized_options = b'8\001'
  _LOCALNETWORKGATEWAYS_TAGSENTRY._options = None
  _LOCALNETWORKGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _EXPRESSROUTECROSSCONNECTIONS_TAGSENTRY._options = None
  _EXPRESSROUTECROSSCONNECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _EXPRESSROUTECIRCUITS_TAGSENTRY._options = None
  _EXPRESSROUTECIRCUITS_TAGSENTRY._serialized_options = b'8\001'
  _DDOSPROTECTIONPLANS_TAGSENTRY._options = None
  _DDOSPROTECTIONPLANS_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTIONS_TAGSENTRY._options = None
  _CONNECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _AZUREFIREWALLS_TAGSENTRY._options = None
  _AZUREFIREWALLS_TAGSENTRY._serialized_options = b'8\001'
  _APPLICATIONSECURITYGROUPS_TAGSENTRY._options = None
  _APPLICATIONSECURITYGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_TRAFFICMANAGER._serialized_start=128
  _MICROSOFT_NETWORK_TRAFFICMANAGER._serialized_end=272
  _TRAFFICMANAGERPROFILES._serialized_start=275
  _TRAFFICMANAGERPROFILES._serialized_end=916
  _TRAFFICMANAGERPROFILES_TAGSENTRY._serialized_start=873
  _TRAFFICMANAGERPROFILES_TAGSENTRY._serialized_end=916
  _ENDPOINT._serialized_start=919
  _ENDPOINT._serialized_end=1395
  _ENDPOINTPROPERTIESCUSTOMHEADERSITEM._serialized_start=1397
  _ENDPOINTPROPERTIESCUSTOMHEADERSITEM._serialized_end=1463
  _ENDPOINTPROPERTIESSUBNETSITEM._serialized_start=1465
  _ENDPOINTPROPERTIESSUBNETSITEM._serialized_end=1540
  _MONITORCONFIG._serialized_start=1543
  _MONITORCONFIG._serialized_end=1972
  _MONITORCONFIGEXPECTEDSTATUSCODERANGESITEM._serialized_start=1974
  _MONITORCONFIGEXPECTEDSTATUSCODERANGESITEM._serialized_end=2043
  _MONITORCONFIGCUSTOMHEADERSITEM._serialized_start=2045
  _MONITORCONFIGCUSTOMHEADERSITEM._serialized_end=2106
  _DNSCONFIG._serialized_start=2108
  _DNSCONFIG._serialized_end=2155
  _VPNSITES._serialized_start=2158
  _VPNSITES._serialized_end=2752
  _VPNSITES_TAGSENTRY._serialized_start=873
  _VPNSITES_TAGSENTRY._serialized_end=916
  _DEVICEPROPERTIES._serialized_start=2754
  _DEVICEPROPERTIES._serialized_end=2845
  _VPNGATEWAYSVPNCONNECTIONS._serialized_start=2848
  _VPNGATEWAYSVPNCONNECTIONS._serialized_end=3179
  _VPNGATEWAYS._serialized_start=3182
  _VPNGATEWAYS._serialized_end=3722
  _VPNGATEWAYS_TAGSENTRY._serialized_start=873
  _VPNGATEWAYS_TAGSENTRY._serialized_end=916
  _POLICIES._serialized_start=3724
  _POLICIES._serialized_end=3810
  _VPNCONNECTION._serialized_start=3813
  _VPNCONNECTION._serialized_end=4075
  _VIRTUALWANS._serialized_start=4078
  _VIRTUALWANS._serialized_end=4374
  _VIRTUALWANS_TAGSENTRY._serialized_start=873
  _VIRTUALWANS_TAGSENTRY._serialized_end=916
  _VIRTUALNETWORKGATEWAYS._serialized_start=4377
  _VIRTUALNETWORKGATEWAYS._serialized_end=5190
  _VIRTUALNETWORKGATEWAYS_TAGSENTRY._serialized_start=873
  _VIRTUALNETWORKGATEWAYS_TAGSENTRY._serialized_end=916
  _VPNCLIENTCONFIGURATION._serialized_start=5193
  _VPNCLIENTCONFIGURATION._serialized_end=5745
  _VPNCLIENTREVOKEDCERTIFICATE._serialized_start=5747
  _VPNCLIENTREVOKEDCERTIFICATE._serialized_end=5824
  _VPNCLIENTROOTCERTIFICATE._serialized_start=5826
  _VPNCLIENTROOTCERTIFICATE._serialized_end=5906
  _VIRTUALNETWORKGATEWAYSKU._serialized_start=5908
  _VIRTUALNETWORKGATEWAYSKU._serialized_end=5980
  _VIRTUALNETWORKGATEWAYIPCONFIGURATION._serialized_start=5983
  _VIRTUALNETWORKGATEWAYIPCONFIGURATION._serialized_end=6130
  _VIRTUALHUBS._serialized_start=6133
  _VIRTUALHUBS._serialized_end=6564
  _VIRTUALHUBS_TAGSENTRY._serialized_start=873
  _VIRTUALHUBS_TAGSENTRY._serialized_end=916
  _HUBVIRTUALNETWORKCONNECTION._serialized_start=6567
  _HUBVIRTUALNETWORKCONNECTION._serialized_end=6918
  _HUBVIRTUALNETWORKCONNECTION_TAGSENTRY._serialized_start=873
  _HUBVIRTUALNETWORKCONNECTION_TAGSENTRY._serialized_end=916
  _ROUTEFILTERSROUTEFILTERRULES._serialized_start=6921
  _ROUTEFILTERSROUTEFILTERRULES._serialized_end=7109
  _ROUTEFILTERS._serialized_start=7112
  _ROUTEFILTERS._serialized_end=7452
  _ROUTEFILTERS_TAGSENTRY._serialized_start=873
  _ROUTEFILTERS_TAGSENTRY._serialized_end=916
  _ROUTEFILTERRULE._serialized_start=7454
  _ROUTEFILTERRULE._serialized_end=7572
  _PUBLICIPADDRESSES._serialized_start=7575
  _PUBLICIPADDRESSES._serialized_end=8291
  _PUBLICIPADDRESSES_TAGSENTRY._serialized_start=873
  _PUBLICIPADDRESSES_TAGSENTRY._serialized_end=916
  _IPTAG._serialized_start=8293
  _IPTAG._serialized_end=8334
  _PUBLICIPADDRESSDNSSETTINGS._serialized_start=8336
  _PUBLICIPADDRESSDNSSETTINGS._serialized_end=8427
  _PUBLICIPADDRESSSKU._serialized_start=8429
  _PUBLICIPADDRESSSKU._serialized_end=8463
  _NETWORKWATCHERSPACKETCAPTURES._serialized_start=8466
  _NETWORKWATCHERSPACKETCAPTURES._serialized_end=8883
  _PACKETCAPTUREFILTER._serialized_start=8886
  _PACKETCAPTUREFILTER._serialized_end=9019
  _PACKETCAPTURESTORAGELOCATION._serialized_start=9021
  _PACKETCAPTURESTORAGELOCATION._serialized_end=9112
  _NETWORKWATCHERSCONNECTIONMONITORS._serialized_start=9115
  _NETWORKWATCHERSCONNECTIONMONITORS._serialized_end=9651
  _NETWORKWATCHERSCONNECTIONMONITORS_TAGSENTRY._serialized_start=873
  _NETWORKWATCHERSCONNECTIONMONITORS_TAGSENTRY._serialized_end=916
  _CONNECTIONMONITORDESTINATION._serialized_start=9653
  _CONNECTIONMONITORDESTINATION._serialized_end=9735
  _CONNECTIONMONITORSOURCE._serialized_start=9737
  _CONNECTIONMONITORSOURCE._serialized_end=9797
  _NETWORKWATCHERS._serialized_start=9800
  _NETWORKWATCHERS._serialized_end=10317
  _NETWORKWATCHERS_TAGSENTRY._serialized_start=873
  _NETWORKWATCHERS_TAGSENTRY._serialized_end=916
  _NETWORKINTERFACES._serialized_start=10320
  _NETWORKINTERFACES._serialized_end=11012
  _NETWORKINTERFACES_TAGSENTRY._serialized_start=873
  _NETWORKINTERFACES_TAGSENTRY._serialized_end=916
  _NETWORKINTERFACEDNSSETTINGS._serialized_start=11015
  _NETWORKINTERFACEDNSSETTINGS._serialized_end=11187
  _NETWORKINTERFACEIPCONFIGURATION._serialized_start=11190
  _NETWORKINTERFACEIPCONFIGURATION._serialized_end=11615
  _LOCALNETWORKGATEWAYS._serialized_start=11618
  _LOCALNETWORKGATEWAYS._serialized_end=12127
  _LOCALNETWORKGATEWAYS_TAGSENTRY._serialized_start=873
  _LOCALNETWORKGATEWAYS_TAGSENTRY._serialized_end=916
  _BGPSETTINGS._serialized_start=12129
  _BGPSETTINGS._serialized_end=12205
  _ADDRESSSPACE._serialized_start=12207
  _ADDRESSSPACE._serialized_end=12247
  _EXPRESSROUTECROSSCONNECTIONSPEERINGS._serialized_start=12250
  _EXPRESSROUTECROSSCONNECTIONSPEERINGS._serialized_end=12822
  _EXPRESSROUTECROSSCONNECTIONS._serialized_start=12825
  _EXPRESSROUTECROSSCONNECTIONS._serialized_end=13585
  _EXPRESSROUTECROSSCONNECTIONS_TAGSENTRY._serialized_start=873
  _EXPRESSROUTECROSSCONNECTIONS_TAGSENTRY._serialized_end=916
  _EXPRESSROUTECROSSCONNECTIONPEERING._serialized_start=13588
  _EXPRESSROUTECROSSCONNECTIONPEERING._serialized_end=14101
  _EXPRESSROUTECIRCUITREFERENCE._serialized_start=14103
  _EXPRESSROUTECIRCUITREFERENCE._serialized_end=14145
  _EXPRESSROUTECIRCUITSPEERINGSCONNECTIONS._serialized_start=14148
  _EXPRESSROUTECIRCUITSPEERINGSCONNECTIONS._serialized_end=14394
  _EXPRESSROUTECIRCUITSPEERINGS._serialized_start=14397
  _EXPRESSROUTECIRCUITSPEERINGS._serialized_end=15432
  _EXPRESSROUTECIRCUITSAUTHORIZATIONS._serialized_start=15435
  _EXPRESSROUTECIRCUITSAUTHORIZATIONS._serialized_end=15631
  _EXPRESSROUTECIRCUITS._serialized_start=15634
  _EXPRESSROUTECIRCUITS._serialized_end=16806
  _EXPRESSROUTECIRCUITS_TAGSENTRY._serialized_start=873
  _EXPRESSROUTECIRCUITS_TAGSENTRY._serialized_end=916
  _EXPRESSROUTECIRCUITSERVICEPROVIDERPROPERTIES._serialized_start=16809
  _EXPRESSROUTECIRCUITSERVICEPROVIDERPROPERTIES._serialized_end=16939
  _EXPRESSROUTECIRCUITPEERING._serialized_start=16942
  _EXPRESSROUTECIRCUITPEERING._serialized_end=17771
  _EXPRESSROUTECIRCUITCONNECTION._serialized_start=17774
  _EXPRESSROUTECIRCUITCONNECTION._serialized_end=17953
  _IPV6EXPRESSROUTECIRCUITPEERINGCONFIG._serialized_start=17956
  _IPV6EXPRESSROUTECIRCUITPEERINGCONFIG._serialized_end=18227
  _EXPRESSROUTECIRCUITSTATS._serialized_start=18230
  _EXPRESSROUTECIRCUITSTATS._serialized_end=18362
  _EXPRESSROUTECIRCUITPEERINGCONFIG._serialized_start=18365
  _EXPRESSROUTECIRCUITPEERINGCONFIG._serialized_end=18583
  _EXPRESSROUTECIRCUITAUTHORIZATION._serialized_start=18586
  _EXPRESSROUTECIRCUITAUTHORIZATION._serialized_end=18723
  _EXPRESSROUTECIRCUITSKU._serialized_start=18725
  _EXPRESSROUTECIRCUITSKU._serialized_end=18793
  _DDOSPROTECTIONPLANS._serialized_start=18796
  _DDOSPROTECTIONPLANS._serialized_end=19048
  _DDOSPROTECTIONPLANS_TAGSENTRY._serialized_start=873
  _DDOSPROTECTIONPLANS_TAGSENTRY._serialized_end=916
  _CONNECTIONS._serialized_start=19051
  _CONNECTIONS._serialized_end=19687
  _CONNECTIONS_TAGSENTRY._serialized_start=873
  _CONNECTIONS_TAGSENTRY._serialized_end=916
  _IPSECPOLICY._serialized_start=19690
  _IPSECPOLICY._serialized_end=19900
  _AZUREFIREWALLS._serialized_start=19903
  _AZUREFIREWALLS._serialized_end=20535
  _AZUREFIREWALLS_TAGSENTRY._serialized_start=873
  _AZUREFIREWALLS_TAGSENTRY._serialized_end=916
  _AZUREFIREWALLIPCONFIGURATION._serialized_start=20538
  _AZUREFIREWALLIPCONFIGURATION._serialized_end=20731
  _AZUREFIREWALLNETWORKRULECOLLECTION._serialized_start=20734
  _AZUREFIREWALLNETWORKRULECOLLECTION._serialized_end=21014
  _AZUREFIREWALLNETWORKRULE._serialized_start=21017
  _AZUREFIREWALLNETWORKRULE._serialized_end=21181
  _AZUREFIREWALLAPPLICATIONRULECOLLECTION._serialized_start=21184
  _AZUREFIREWALLAPPLICATIONRULECOLLECTION._serialized_end=21472
  _AZUREFIREWALLAPPLICATIONRULE._serialized_start=21475
  _AZUREFIREWALLAPPLICATIONRULE._serialized_end=21696
  _AZUREFIREWALLAPPLICATIONRULEPROTOCOL._serialized_start=21698
  _AZUREFIREWALLAPPLICATIONRULEPROTOCOL._serialized_end=21773
  _AZUREFIREWALLRCACTION._serialized_start=21775
  _AZUREFIREWALLRCACTION._serialized_end=21812
  _APPLICATIONSECURITYGROUPS._serialized_start=21815
  _APPLICATIONSECURITYGROUPS._serialized_end=22079
  _APPLICATIONSECURITYGROUPS_TAGSENTRY._serialized_start=873
  _APPLICATIONSECURITYGROUPS_TAGSENTRY._serialized_end=916
# @@protoc_insertion_point(module_scope)
