# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_resourcegroups.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_resourcegroups.proto\x12\x1eoak9.tython.aws.resourcegroups\x1a\x13shared/shared.proto\"f\n\x0eGroupTagFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xc3\x01\n\nGroupQuery\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15resource_type_filters\x18\x02 \x03(\t\x12\x18\n\x10stack_identifier\x18\x03 \x01(\t\x12\x43\n\x0btag_filters\x18\x04 \x03(\x0b\x32..oak9.tython.aws.resourcegroups.GroupTagFilter\"\x88\x01\n\x12GroupResourceQuery\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x39\n\x05query\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.resourcegroups.GroupQuery\"\x9b\x02\n\x05Group\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12J\n\x0eresource_query\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.resourcegroups.GroupResourceQuery\x12=\n\x04tags\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.resourcegroups.Group.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x0eResourceGroups\x12\x34\n\x05group\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.resourcegroups.Groupb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_resourcegroups_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUP_TAGSENTRY._options = None
  _GROUP_TAGSENTRY._serialized_options = b'8\001'
  _GROUPTAGFILTER._serialized_start=85
  _GROUPTAGFILTER._serialized_end=187
  _GROUPQUERY._serialized_start=190
  _GROUPQUERY._serialized_end=385
  _GROUPRESOURCEQUERY._serialized_start=388
  _GROUPRESOURCEQUERY._serialized_end=524
  _GROUP._serialized_start=527
  _GROUP._serialized_end=810
  _GROUP_TAGSENTRY._serialized_start=767
  _GROUP_TAGSENTRY._serialized_end=810
  _RESOURCEGROUPS._serialized_start=812
  _RESOURCEGROUPS._serialized_end=882
# @@protoc_insertion_point(module_scope)
