"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeAddressXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeAddressXTimeouts = ComputeAddressXTimeouts

@typing_extensions.final
class ComputeAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    ADDRESS_TYPE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_TIER_FIELD_NUMBER: builtins.int
    PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PURPOSE_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    address: builtins.str
    address_type: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    network_tier: builtins.str
    prefix_length: builtins.float
    project: builtins.str
    purpose: builtins.str
    region: builtins.str
    self_link: builtins.str
    subnetwork: builtins.str
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def timeouts(self) -> global___ComputeAddressXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        address_type: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_tier: builtins.str = ...,
        prefix_length: builtins.float = ...,
        project: builtins.str = ...,
        purpose: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        subnetwork: builtins.str = ...,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        timeouts: global___ComputeAddressXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "address_type", b"address_type", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "network", b"network", "network_tier", b"network_tier", "prefix_length", b"prefix_length", "project", b"project", "purpose", b"purpose", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "subnetwork", b"subnetwork", "timeouts", b"timeouts", "users", b"users"]) -> None: ...

global___ComputeAddress = ComputeAddress
