# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_vpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_ec2_vpc.proto\x12\x17oak9.tython.aws.ec2_vpc\x1a\x13shared/shared.proto\"\x89\x02\n\x03VPC\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncidr_block\x18\x02 \x01(\t\x12\x1c\n\x14\x65nable_dns_hostnames\x18\x03 \x01(\x08\x12\x1a\n\x12\x65nable_dns_support\x18\x04 \x01(\x08\x12\x18\n\x10instance_tenancy\x18\x05 \x01(\t\x12\x34\n\x04tags\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.ec2_vpc.VPC.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x02\n\x07\x45\x43\x32_VPC\x12)\n\x03vpc\x18\x01 \x01(\x0b\x32\x1c.oak9.tython.aws.ec2_vpc.VPC\x12=\n\x0evpc_cidr_block\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.ec2_vpc.VPCCidrBlock\x12X\n\x1cvpc_dhcp_options_association\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.ec2_vpc.VPCDHCPOptionsAssociation\x12M\n\x16vpc_peering_connection\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.ec2_vpc.VPCPeeringConnection\"\x94\x01\n\x0cVPCCidrBlock\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1f\x61mazon_provided_ipv6_cidr_block\x18\x02 \x01(\x08\x12\x12\n\ncidr_block\x18\x03 \x01(\t\x12\x0e\n\x06vpc_id\x18\x04 \x01(\t\"}\n\x19VPCDHCPOptionsAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64hcp_options_id\x18\x02 \x01(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\"\xab\x02\n\x14VPCPeeringConnection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rpeer_owner_id\x18\x02 \x01(\t\x12\x13\n\x0bpeer_region\x18\x03 \x01(\t\x12\x15\n\rpeer_role_arn\x18\x04 \x01(\t\x12\x13\n\x0bpeer_vpc_id\x18\x05 \x01(\t\x12\x45\n\x04tags\x18\x06 \x03(\x0b\x32\x37.oak9.tython.aws.ec2_vpc.VPCPeeringConnection.TagsEntry\x12\x0e\n\x06vpc_id\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_vpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VPC_TAGSENTRY._options = None
  _VPC_TAGSENTRY._serialized_options = b'8\001'
  _VPCPEERINGCONNECTION_TAGSENTRY._options = None
  _VPCPEERINGCONNECTION_TAGSENTRY._serialized_options = b'8\001'
  _VPC._serialized_start=72
  _VPC._serialized_end=337
  _VPC_TAGSENTRY._serialized_start=294
  _VPC_TAGSENTRY._serialized_end=337
  _EC2_VPC._serialized_start=340
  _EC2_VPC._serialized_end=624
  _VPCCIDRBLOCK._serialized_start=627
  _VPCCIDRBLOCK._serialized_end=775
  _VPCDHCPOPTIONSASSOCIATION._serialized_start=777
  _VPCDHCPOPTIONSASSOCIATION._serialized_end=902
  _VPCPEERINGCONNECTION._serialized_start=905
  _VPCPEERINGCONNECTION._serialized_end=1204
  _VPCPEERINGCONNECTION_TAGSENTRY._serialized_start=294
  _VPCPEERINGCONNECTION_TAGSENTRY._serialized_end=337
# @@protoc_insertion_point(module_scope)
