# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_networkacl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_ec2_networkacl.proto\x12\x1eoak9.tython.aws.ec2_networkacl\x1a\x13shared/shared.proto\"\xc6\x01\n\nNetworkAcl\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\x04tags\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.ec2_networkacl.NetworkAcl.TagsEntry\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9d\x01\n\x0e\x45\x43\x32_NetworkACL\x12?\n\x0bnetwork_acl\x18\x01 \x01(\x0b\x32*.oak9.tython.aws.ec2_networkacl.NetworkAcl\x12J\n\x11network_acl_entry\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.ec2_networkacl.NetworkAclEntry\"\\\n\x13NetworkAclEntryIcmp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\"m\n\x18NetworkAclEntryPortRange\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\x12\n\n\x02to\x18\x03 \x01(\x05\"\xec\x02\n\x0fNetworkAclEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncidr_block\x18\x02 \x01(\t\x12\x0e\n\x06\x65gress\x18\x03 \x01(\x08\x12\x41\n\x04icmp\x18\x04 \x01(\x0b\x32\x33.oak9.tython.aws.ec2_networkacl.NetworkAclEntryIcmp\x12\x17\n\x0fipv6_cidr_block\x18\x05 \x01(\t\x12\x16\n\x0enetwork_acl_id\x18\x06 \x01(\t\x12L\n\nport_range\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.ec2_networkacl.NetworkAclEntryPortRange\x12\x10\n\x08protocol\x18\x08 \x01(\x05\x12\x13\n\x0brule_action\x18\t \x01(\t\x12\x13\n\x0brule_number\x18\n \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_networkacl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKACL_TAGSENTRY._options = None
  _NETWORKACL_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKACL._serialized_start=86
  _NETWORKACL._serialized_end=284
  _NETWORKACL_TAGSENTRY._serialized_start=241
  _NETWORKACL_TAGSENTRY._serialized_end=284
  _EC2_NETWORKACL._serialized_start=287
  _EC2_NETWORKACL._serialized_end=444
  _NETWORKACLENTRYICMP._serialized_start=446
  _NETWORKACLENTRYICMP._serialized_end=538
  _NETWORKACLENTRYPORTRANGE._serialized_start=540
  _NETWORKACLENTRYPORTRANGE._serialized_end=649
  _NETWORKACLENTRY._serialized_start=652
  _NETWORKACLENTRY._serialized_end=1016
# @@protoc_insertion_point(module_scope)
