# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_servicediscovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_servicediscovery.proto\x12 oak9.tython.aws.servicediscovery\x1a\x13shared/shared.proto\"\xe1\x01\n\rHttpNamespace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12G\n\x04tags\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.servicediscovery.HttpNamespace.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xff\x02\n\x10ServiceDiscovery\x12G\n\x0ehttp_namespace\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.servicediscovery.HttpNamespace\x12<\n\x08instance\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.servicediscovery.Instance\x12T\n\x15private_dns_namespace\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.servicediscovery.PrivateDnsNamespace\x12R\n\x14public_dns_namespace\x18\x04 \x03(\x0b\x32\x34.oak9.tython.aws.servicediscovery.PublicDnsNamespace\x12:\n\x07service\x18\x05 \x03(\x0b\x32).oak9.tython.aws.servicediscovery.Service\"\x88\x02\n\x08Instance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12_\n\x13instance_attributes\x18\x02 \x03(\x0b\x32\x42.oak9.tython.aws.servicediscovery.Instance.InstanceAttributesEntry\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x12\n\nservice_id\x18\x04 \x01(\t\x1a\x39\n\x17InstanceAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfa\x01\n\x13PrivateDnsNamespace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03vpc\x18\x03 \x01(\t\x12M\n\x04tags\x18\x04 \x03(\x0b\x32?.oak9.tython.aws.servicediscovery.PrivateDnsNamespace.TagsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n\x12PublicDnsNamespace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\x04tags\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.servicediscovery.PublicDnsNamespace.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x1eServiceHealthCheckCustomConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x66\x61ilure_threshold\x18\x02 \x01(\x01\"X\n\x10ServiceDnsRecord\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03ttl\x18\x02 \x01(\x01\"\xc2\x01\n\x10ServiceDnsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x0b\x64ns_records\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.servicediscovery.ServiceDnsRecord\x12\x16\n\x0erouting_policy\x18\x03 \x01(\t\x12\x14\n\x0cnamespace_id\x18\x04 \x01(\t\"\x85\x01\n\x18ServiceHealthCheckConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_path\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61ilure_threshold\x18\x03 \x01(\x01\"\xf2\x03\n\x07Service\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x64\n\x1ahealth_check_custom_config\x18\x03 \x01(\x0b\x32@.oak9.tython.aws.servicediscovery.ServiceHealthCheckCustomConfig\x12\x46\n\ndns_config\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.servicediscovery.ServiceDnsConfig\x12\x14\n\x0cnamespace_id\x18\x05 \x01(\t\x12W\n\x13health_check_config\x18\x06 \x01(\x0b\x32:.oak9.tython.aws.servicediscovery.ServiceHealthCheckConfig\x12\x41\n\x04tags\x18\x07 \x03(\x0b\x32\x33.oak9.tython.aws.servicediscovery.Service.TagsEntry\x12\x0c\n\x04name\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_servicediscovery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HTTPNAMESPACE_TAGSENTRY._options = None
  _HTTPNAMESPACE_TAGSENTRY._serialized_options = b'8\001'
  _INSTANCE_INSTANCEATTRIBUTESENTRY._options = None
  _INSTANCE_INSTANCEATTRIBUTESENTRY._serialized_options = b'8\001'
  _PRIVATEDNSNAMESPACE_TAGSENTRY._options = None
  _PRIVATEDNSNAMESPACE_TAGSENTRY._serialized_options = b'8\001'
  _PUBLICDNSNAMESPACE_TAGSENTRY._options = None
  _PUBLICDNSNAMESPACE_TAGSENTRY._serialized_options = b'8\001'
  _SERVICE_TAGSENTRY._options = None
  _SERVICE_TAGSENTRY._serialized_options = b'8\001'
  _HTTPNAMESPACE._serialized_start=90
  _HTTPNAMESPACE._serialized_end=315
  _HTTPNAMESPACE_TAGSENTRY._serialized_start=272
  _HTTPNAMESPACE_TAGSENTRY._serialized_end=315
  _SERVICEDISCOVERY._serialized_start=318
  _SERVICEDISCOVERY._serialized_end=701
  _INSTANCE._serialized_start=704
  _INSTANCE._serialized_end=968
  _INSTANCE_INSTANCEATTRIBUTESENTRY._serialized_start=911
  _INSTANCE_INSTANCEATTRIBUTESENTRY._serialized_end=968
  _PRIVATEDNSNAMESPACE._serialized_start=971
  _PRIVATEDNSNAMESPACE._serialized_end=1221
  _PRIVATEDNSNAMESPACE_TAGSENTRY._serialized_start=272
  _PRIVATEDNSNAMESPACE_TAGSENTRY._serialized_end=315
  _PUBLICDNSNAMESPACE._serialized_start=1224
  _PUBLICDNSNAMESPACE._serialized_end=1459
  _PUBLICDNSNAMESPACE_TAGSENTRY._serialized_start=272
  _PUBLICDNSNAMESPACE_TAGSENTRY._serialized_end=315
  _SERVICEHEALTHCHECKCUSTOMCONFIG._serialized_start=1461
  _SERVICEHEALTHCHECKCUSTOMCONFIG._serialized_end=1577
  _SERVICEDNSRECORD._serialized_start=1579
  _SERVICEDNSRECORD._serialized_end=1667
  _SERVICEDNSCONFIG._serialized_start=1670
  _SERVICEDNSCONFIG._serialized_end=1864
  _SERVICEHEALTHCHECKCONFIG._serialized_start=1867
  _SERVICEHEALTHCHECKCONFIG._serialized_end=2000
  _SERVICE._serialized_start=2003
  _SERVICE._serialized_end=2501
  _SERVICE_TAGSENTRY._serialized_start=272
  _SERVICE_TAGSENTRY._serialized_end=315
# @@protoc_insertion_point(module_scope)
