# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticloadbalancingv2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$aws/aws_elasticloadbalancingv2.proto\x12&oak9.tython.aws.elasticloadbalancingv2\x1a\x13shared/shared.proto\"}\n\x13ListenerCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x02 \x01(\t\x12\x14\n\x0clistener_arn\x18\x03 \x01(\t\"\xfb\x03\n!ListenerAuthenticateCognitoConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x9c\x01\n#authentication_request_extra_params\x18\x02 \x03(\x0b\x32o.oak9.tython.aws.elasticloadbalancingv2.ListenerAuthenticateCognitoConfig.AuthenticationRequestExtraParamsEntry\x12\"\n\x1aon_unauthenticated_request\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1b\n\x13session_cookie_name\x18\x05 \x01(\t\x12\x17\n\x0fsession_timeout\x18\x06 \x01(\x05\x12\x15\n\ruser_pool_arn\x18\x07 \x01(\t\x12\x1b\n\x13user_pool_client_id\x18\x08 \x01(\t\x12\x18\n\x10user_pool_domain\x18\t \x01(\t\x1aG\n%AuthenticationRequestExtraParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb5\x04\n\x1eListenerAuthenticateOidcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x99\x01\n#authentication_request_extra_params\x18\x02 \x03(\x0b\x32l.oak9.tython.aws.elasticloadbalancingv2.ListenerAuthenticateOidcConfig.AuthenticationRequestExtraParamsEntry\x12\x1e\n\x16\x61uthorization_endpoint\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\"\n\x1aon_unauthenticated_request\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x1b\n\x13session_cookie_name\x18\t \x01(\t\x12\x17\n\x0fsession_timeout\x18\n \x01(\x05\x12\x16\n\x0etoken_endpoint\x18\x0b \x01(\t\x12\x1a\n\x12user_info_endpoint\x18\x0c \x01(\t\x1aG\n%AuthenticationRequestExtraParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x1bListenerFixedResponseConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x14\n\x0cmessage_body\x18\x03 \x01(\t\x12\x13\n\x0bstatus_code\x18\x04 \x01(\t\"\x89\x01\n#ListenerTargetGroupStickinessConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x64uration_seconds\x18\x02 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"}\n\x18ListenerTargetGroupTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10target_group_arn\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\"\x9e\x02\n\x15ListenerForwardConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12s\n\x1etarget_group_stickiness_config\x18\x02 \x01(\x0b\x32K.oak9.tython.aws.elasticloadbalancingv2.ListenerTargetGroupStickinessConfig\x12W\n\rtarget_groups\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.elasticloadbalancingv2.ListenerTargetGroupTuple\"\xb1\x01\n\x16ListenerRedirectConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\t\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12\r\n\x05query\x18\x06 \x01(\t\x12\x13\n\x0bstatus_code\x18\x07 \x01(\t\"\x9b\x05\n\x0eListenerAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12n\n\x1b\x61uthenticate_cognito_config\x18\x02 \x01(\x0b\x32I.oak9.tython.aws.elasticloadbalancingv2.ListenerAuthenticateCognitoConfig\x12h\n\x18\x61uthenticate_oidc_config\x18\x03 \x01(\x0b\x32\x46.oak9.tython.aws.elasticloadbalancingv2.ListenerAuthenticateOidcConfig\x12\x62\n\x15\x66ixed_response_config\x18\x04 \x01(\x0b\x32\x43.oak9.tython.aws.elasticloadbalancingv2.ListenerFixedResponseConfig\x12U\n\x0e\x66orward_config\x18\x05 \x01(\x0b\x32=.oak9.tython.aws.elasticloadbalancingv2.ListenerForwardConfig\x12\r\n\x05order\x18\x06 \x01(\x05\x12W\n\x0fredirect_config\x18\x07 \x01(\x0b\x32>.oak9.tython.aws.elasticloadbalancingv2.ListenerRedirectConfig\x12\x18\n\x10target_group_arn\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12+\n#authentication_request_extra_params\x18\n \x01(\t\"\xe1\x02\n\x08Listener\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61lpn_policy\x18\x02 \x03(\t\x12Q\n\x0c\x63\x65rtificates\x18\x03 \x03(\x0b\x32;.oak9.tython.aws.elasticloadbalancingv2.ListenerCertificate\x12O\n\x0f\x64\x65\x66\x61ult_actions\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.elasticloadbalancingv2.ListenerAction\x12\x19\n\x11load_balancer_arn\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12\x10\n\x08protocol\x18\x07 \x01(\t\x12\x12\n\nssl_policy\x18\x08 \x01(\t\x12\x14\n\x0clistener_arn\x18\t \x01(\t\"\x9c\x03\n\x16\x45lasticLoadBalancingV2\x12\x42\n\x08listener\x18\x01 \x03(\x0b\x32\x30.oak9.tython.aws.elasticloadbalancingv2.Listener\x12Y\n\x14listener_certificate\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.elasticloadbalancingv2.ListenerCertificate\x12K\n\rlistener_rule\x18\x03 \x03(\x0b\x32\x34.oak9.tython.aws.elasticloadbalancingv2.ListenerRule\x12K\n\rload_balancer\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.elasticloadbalancingv2.LoadBalancer\x12I\n\x0ctarget_group\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.elasticloadbalancingv2.TargetGroup\"r\n\x1eListenerCertificateCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x02 \x01(\t\"\x83\x04\n%ListenerRuleAuthenticateCognitoConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\xa0\x01\n#authentication_request_extra_params\x18\x02 \x03(\x0b\x32s.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAuthenticateCognitoConfig.AuthenticationRequestExtraParamsEntry\x12\"\n\x1aon_unauthenticated_request\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1b\n\x13session_cookie_name\x18\x05 \x01(\t\x12\x17\n\x0fsession_timeout\x18\x06 \x01(\x05\x12\x15\n\ruser_pool_arn\x18\x07 \x01(\t\x12\x1b\n\x13user_pool_client_id\x18\x08 \x01(\t\x12\x18\n\x10user_pool_domain\x18\t \x01(\t\x1aG\n%AuthenticationRequestExtraParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x04\n\"ListenerRuleAuthenticateOidcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x9d\x01\n#authentication_request_extra_params\x18\x02 \x03(\x0b\x32p.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAuthenticateOidcConfig.AuthenticationRequestExtraParamsEntry\x12\x1e\n\x16\x61uthorization_endpoint\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\"\n\x1aon_unauthenticated_request\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x1b\n\x13session_cookie_name\x18\t \x01(\t\x12\x17\n\x0fsession_timeout\x18\n \x01(\x05\x12\x16\n\x0etoken_endpoint\x18\x0b \x01(\t\x12\x1a\n\x12user_info_endpoint\x18\x0c \x01(\t\x1aG\n%AuthenticationRequestExtraParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9b\x01\n\x1fListenerRuleFixedResponseConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x14\n\x0cmessage_body\x18\x03 \x01(\t\x12\x13\n\x0bstatus_code\x18\x04 \x01(\t\"\x8d\x01\n\'ListenerRuleTargetGroupStickinessConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x64uration_seconds\x18\x02 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"\x81\x01\n\x1cListenerRuleTargetGroupTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10target_group_arn\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\"\xaa\x02\n\x19ListenerRuleForwardConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12w\n\x1etarget_group_stickiness_config\x18\x02 \x01(\x0b\x32O.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleTargetGroupStickinessConfig\x12[\n\rtarget_groups\x18\x03 \x03(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleTargetGroupTuple\"\xb5\x01\n\x1aListenerRuleRedirectConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\t\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12\r\n\x05query\x18\x06 \x01(\t\x12\x13\n\x0bstatus_code\x18\x07 \x01(\t\"\x86\x05\n\x12ListenerRuleAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12r\n\x1b\x61uthenticate_cognito_config\x18\x02 \x01(\x0b\x32M.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAuthenticateCognitoConfig\x12l\n\x18\x61uthenticate_oidc_config\x18\x03 \x01(\x0b\x32J.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAuthenticateOidcConfig\x12\x66\n\x15\x66ixed_response_config\x18\x04 \x01(\x0b\x32G.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleFixedResponseConfig\x12Y\n\x0e\x66orward_config\x18\x05 \x01(\x0b\x32\x41.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleForwardConfig\x12\r\n\x05order\x18\x06 \x01(\x05\x12[\n\x0fredirect_config\x18\x07 \x01(\x0b\x32\x42.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleRedirectConfig\x12\x18\n\x10target_group_arn\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\"g\n\x1cListenerRuleHostHeaderConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"\x81\x01\n\x1cListenerRuleHttpHeaderConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10http_header_name\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"n\n#ListenerRuleHttpRequestMethodConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"h\n\x1dListenerRulePathPatternConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"v\n\x1fListenerRuleQueryStringKeyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb1\x01\n\x1dListenerRuleQueryStringConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x06values\x18\x02 \x03(\x0b\x32G.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleQueryStringKeyValue\"e\n\x1aListenerRuleSourceIpConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xce\x05\n\x19ListenerRuleRuleCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12`\n\x12host_header_config\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleHostHeaderConfig\x12`\n\x12http_header_config\x18\x04 \x01(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleHttpHeaderConfig\x12o\n\x1ahttp_request_method_config\x18\x05 \x01(\x0b\x32K.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleHttpRequestMethodConfig\x12\x62\n\x13path_pattern_config\x18\x06 \x01(\x0b\x32\x45.oak9.tython.aws.elasticloadbalancingv2.ListenerRulePathPatternConfig\x12\x62\n\x13query_string_config\x18\x07 \x01(\x0b\x32\x45.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleQueryStringConfig\x12\\\n\x10source_ip_config\x18\x08 \x01(\x0b\x32\x42.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleSourceIpConfig\x12\x0e\n\x06values\x18\t \x03(\t\"\x93\x02\n\x0cListenerRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAction\x12U\n\nconditions\x18\x03 \x03(\x0b\x32\x41.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleRuleCondition\x12\x14\n\x0clistener_arn\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\"x\n!LoadBalancerLoadBalancerAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x9c\x01\n\x19LoadBalancerSubnetMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rallocation_id\x18\x02 \x01(\t\x12\x1c\n\x14private_ipv4_address\x18\x03 \x01(\t\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\"\xfa\x03\n\x0cLoadBalancer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fip_address_type\x18\x02 \x01(\t\x12k\n\x18load_balancer_attributes\x18\x03 \x03(\x0b\x32I.oak9.tython.aws.elasticloadbalancingv2.LoadBalancerLoadBalancerAttribute\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06scheme\x18\x05 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x06 \x03(\t\x12Z\n\x0fsubnet_mappings\x18\x07 \x03(\x0b\x32\x41.oak9.tython.aws.elasticloadbalancingv2.LoadBalancerSubnetMapping\x12\x0f\n\x07subnets\x18\x08 \x03(\t\x12L\n\x04tags\x18\t \x03(\x0b\x32>.oak9.tython.aws.elasticloadbalancingv2.LoadBalancer.TagsEntry\x12\x0c\n\x04type\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x12TargetGroupMatcher\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\thttp_code\x18\x02 \x01(\t\"v\n\x1fTargetGroupTargetGroupAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x8c\x01\n\x1cTargetGroupTargetDescription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\"\xa5\x06\n\x0bTargetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14health_check_enabled\x18\x02 \x01(\x08\x12%\n\x1dhealth_check_interval_seconds\x18\x03 \x01(\x05\x12\x19\n\x11health_check_path\x18\x04 \x01(\t\x12\x19\n\x11health_check_port\x18\x05 \x01(\t\x12\x1d\n\x15health_check_protocol\x18\x06 \x01(\t\x12$\n\x1chealth_check_timeout_seconds\x18\x07 \x01(\x05\x12\x1f\n\x17healthy_threshold_count\x18\x08 \x01(\x05\x12K\n\x07matcher\x18\t \x01(\x0b\x32:.oak9.tython.aws.elasticloadbalancingv2.TargetGroupMatcher\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0c\n\x04port\x18\x0b \x01(\x05\x12\x10\n\x08protocol\x18\x0c \x01(\t\x12K\n\x04tags\x18\r \x03(\x0b\x32=.oak9.tython.aws.elasticloadbalancingv2.TargetGroup.TagsEntry\x12h\n\x17target_group_attributes\x18\x0e \x03(\x0b\x32G.oak9.tython.aws.elasticloadbalancingv2.TargetGroupTargetGroupAttribute\x12\x13\n\x0btarget_type\x18\x0f \x01(\t\x12U\n\x07targets\x18\x10 \x03(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancingv2.TargetGroupTargetDescription\x12!\n\x19unhealthy_threshold_count\x18\x11 \x01(\x05\x12\x0e\n\x06vpc_id\x18\x12 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticloadbalancingv2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LISTENERAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._options = None
  _LISTENERAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_options = b'8\001'
  _LISTENERAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._options = None
  _LISTENERAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_options = b'8\001'
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._options = None
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_options = b'8\001'
  _LISTENERRULEAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._options = None
  _LISTENERRULEAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_options = b'8\001'
  _LOADBALANCER_TAGSENTRY._options = None
  _LOADBALANCER_TAGSENTRY._serialized_options = b'8\001'
  _TARGETGROUP_TAGSENTRY._options = None
  _TARGETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _LISTENERCERTIFICATE._serialized_start=101
  _LISTENERCERTIFICATE._serialized_end=226
  _LISTENERAUTHENTICATECOGNITOCONFIG._serialized_start=229
  _LISTENERAUTHENTICATECOGNITOCONFIG._serialized_end=736
  _LISTENERAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_start=665
  _LISTENERAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_end=736
  _LISTENERAUTHENTICATEOIDCCONFIG._serialized_start=739
  _LISTENERAUTHENTICATEOIDCCONFIG._serialized_end=1304
  _LISTENERAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_start=665
  _LISTENERAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_end=736
  _LISTENERFIXEDRESPONSECONFIG._serialized_start=1307
  _LISTENERFIXEDRESPONSECONFIG._serialized_end=1458
  _LISTENERTARGETGROUPSTICKINESSCONFIG._serialized_start=1461
  _LISTENERTARGETGROUPSTICKINESSCONFIG._serialized_end=1598
  _LISTENERTARGETGROUPTUPLE._serialized_start=1600
  _LISTENERTARGETGROUPTUPLE._serialized_end=1725
  _LISTENERFORWARDCONFIG._serialized_start=1728
  _LISTENERFORWARDCONFIG._serialized_end=2014
  _LISTENERREDIRECTCONFIG._serialized_start=2017
  _LISTENERREDIRECTCONFIG._serialized_end=2194
  _LISTENERACTION._serialized_start=2197
  _LISTENERACTION._serialized_end=2864
  _LISTENER._serialized_start=2867
  _LISTENER._serialized_end=3220
  _ELASTICLOADBALANCINGV2._serialized_start=3223
  _ELASTICLOADBALANCINGV2._serialized_end=3635
  _LISTENERCERTIFICATECERTIFICATE._serialized_start=3637
  _LISTENERCERTIFICATECERTIFICATE._serialized_end=3751
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG._serialized_start=3754
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG._serialized_end=4269
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_start=665
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_end=736
  _LISTENERRULEAUTHENTICATEOIDCCONFIG._serialized_start=4272
  _LISTENERRULEAUTHENTICATEOIDCCONFIG._serialized_end=4845
  _LISTENERRULEAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_start=665
  _LISTENERRULEAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_end=736
  _LISTENERRULEFIXEDRESPONSECONFIG._serialized_start=4848
  _LISTENERRULEFIXEDRESPONSECONFIG._serialized_end=5003
  _LISTENERRULETARGETGROUPSTICKINESSCONFIG._serialized_start=5006
  _LISTENERRULETARGETGROUPSTICKINESSCONFIG._serialized_end=5147
  _LISTENERRULETARGETGROUPTUPLE._serialized_start=5150
  _LISTENERRULETARGETGROUPTUPLE._serialized_end=5279
  _LISTENERRULEFORWARDCONFIG._serialized_start=5282
  _LISTENERRULEFORWARDCONFIG._serialized_end=5580
  _LISTENERRULEREDIRECTCONFIG._serialized_start=5583
  _LISTENERRULEREDIRECTCONFIG._serialized_end=5764
  _LISTENERRULEACTION._serialized_start=5767
  _LISTENERRULEACTION._serialized_end=6413
  _LISTENERRULEHOSTHEADERCONFIG._serialized_start=6415
  _LISTENERRULEHOSTHEADERCONFIG._serialized_end=6518
  _LISTENERRULEHTTPHEADERCONFIG._serialized_start=6521
  _LISTENERRULEHTTPHEADERCONFIG._serialized_end=6650
  _LISTENERRULEHTTPREQUESTMETHODCONFIG._serialized_start=6652
  _LISTENERRULEHTTPREQUESTMETHODCONFIG._serialized_end=6762
  _LISTENERRULEPATHPATTERNCONFIG._serialized_start=6764
  _LISTENERRULEPATHPATTERNCONFIG._serialized_end=6868
  _LISTENERRULEQUERYSTRINGKEYVALUE._serialized_start=6870
  _LISTENERRULEQUERYSTRINGKEYVALUE._serialized_end=6988
  _LISTENERRULEQUERYSTRINGCONFIG._serialized_start=6991
  _LISTENERRULEQUERYSTRINGCONFIG._serialized_end=7168
  _LISTENERRULESOURCEIPCONFIG._serialized_start=7170
  _LISTENERRULESOURCEIPCONFIG._serialized_end=7271
  _LISTENERRULERULECONDITION._serialized_start=7274
  _LISTENERRULERULECONDITION._serialized_end=7992
  _LISTENERRULE._serialized_start=7995
  _LISTENERRULE._serialized_end=8270
  _LOADBALANCERLOADBALANCERATTRIBUTE._serialized_start=8272
  _LOADBALANCERLOADBALANCERATTRIBUTE._serialized_end=8392
  _LOADBALANCERSUBNETMAPPING._serialized_start=8395
  _LOADBALANCERSUBNETMAPPING._serialized_end=8551
  _LOADBALANCER._serialized_start=8554
  _LOADBALANCER._serialized_end=9060
  _LOADBALANCER_TAGSENTRY._serialized_start=9017
  _LOADBALANCER_TAGSENTRY._serialized_end=9060
  _TARGETGROUPMATCHER._serialized_start=9062
  _TARGETGROUPMATCHER._serialized_end=9158
  _TARGETGROUPTARGETGROUPATTRIBUTE._serialized_start=9160
  _TARGETGROUPTARGETGROUPATTRIBUTE._serialized_end=9278
  _TARGETGROUPTARGETDESCRIPTION._serialized_start=9281
  _TARGETGROUPTARGETDESCRIPTION._serialized_end=9421
  _TARGETGROUP._serialized_start=9424
  _TARGETGROUP._serialized_end=10229
  _TARGETGROUP_TAGSENTRY._serialized_start=9017
  _TARGETGROUP_TAGSENTRY._serialized_end=9060
# @@protoc_insertion_point(module_scope)
