# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_active.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_active.proto\x12\x16oak9.tython.gcp.active\x1a\x13shared/shared.proto\"P\n\x1e\x41\x63tiveDirectoryDomainXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xbc\x03\n\x15\x41\x63tiveDirectoryDomain\x12\r\n\x05\x61\x64min\x18\x01 \x01(\t\x12\x1b\n\x13\x61uthorized_networks\x18\x02 \x03(\t\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x0c\n\x04\x66qdn\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12I\n\x06labels\x18\x06 \x03(\x0b\x32\x39.oak9.tython.gcp.active.ActiveDirectoryDomain.LabelsEntry\x12\x11\n\tlocations\x18\x07 \x03(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x19\n\x11reserved_ip_range\x18\n \x01(\t\x12H\n\x08timeouts\x18\x0b \x01(\x0b\x32\x36.oak9.tython.gcp.active.ActiveDirectoryDomainXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n#ActiveDirectoryDomainTrustXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfd\x02\n\x1a\x41\x63tiveDirectoryDomainTrust\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12 \n\x18selective_authentication\x18\x04 \x01(\x08\x12\x1f\n\x17target_dns_ip_addresses\x18\x05 \x03(\t\x12\x1a\n\x12target_domain_name\x18\x06 \x01(\t\x12\x17\n\x0ftrust_direction\x18\x07 \x01(\t\x12\x1e\n\x16trust_handshake_secret\x18\x08 \x01(\t\x12\x12\n\ntrust_type\x18\t \x01(\t\x12M\n\x08timeouts\x18\n \x01(\x0b\x32;.oak9.tython.gcp.active.ActiveDirectoryDomainTrustXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_active_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACTIVEDIRECTORYDOMAIN_LABELSENTRY._options = None
  _ACTIVEDIRECTORYDOMAIN_LABELSENTRY._serialized_options = b'8\001'
  _ACTIVEDIRECTORYDOMAINXTIMEOUTS._serialized_start=69
  _ACTIVEDIRECTORYDOMAINXTIMEOUTS._serialized_end=149
  _ACTIVEDIRECTORYDOMAIN._serialized_start=152
  _ACTIVEDIRECTORYDOMAIN._serialized_end=596
  _ACTIVEDIRECTORYDOMAIN_LABELSENTRY._serialized_start=551
  _ACTIVEDIRECTORYDOMAIN_LABELSENTRY._serialized_end=596
  _ACTIVEDIRECTORYDOMAINTRUSTXTIMEOUTS._serialized_start=598
  _ACTIVEDIRECTORYDOMAINTRUSTXTIMEOUTS._serialized_end=683
  _ACTIVEDIRECTORYDOMAINTRUST._serialized_start=686
  _ACTIVEDIRECTORYDOMAINTRUST._serialized_end=1067
# @@protoc_insertion_point(module_scope)
