"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_ServiceBus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACES_FIELD_NUMBER: builtins.int
    NAMESPACES_QUEUES_FIELD_NUMBER: builtins.int
    NAMESPACES_TOPICS_FIELD_NUMBER: builtins.int
    @property
    def namespaces(self) -> global___Namespaces: ...
    @property
    def namespaces_queues(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesQueues]: ...
    @property
    def namespaces_topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesTopics]: ...
    def __init__(
        self,
        *,
        namespaces: global___Namespaces | None = ...,
        namespaces_queues: collections.abc.Iterable[global___NamespacesQueues] | None = ...,
        namespaces_topics: collections.abc.Iterable[global___NamespacesTopics] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["namespaces", b"namespaces"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespaces", b"namespaces", "namespaces_queues", b"namespaces_queues", "namespaces_topics", b"namespaces_topics"]) -> None: ...

global___Microsoft_ServiceBus = Microsoft_ServiceBus

@typing_extensions.final
class NamespacesTopicsSubscriptionsRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    CORRELATION_FILTER_FIELD_NUMBER: builtins.int
    FILTER_TYPE_FIELD_NUMBER: builtins.int
    SQL_FILTER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def action(self) -> global___Action: ...
    @property
    def correlation_filter(self) -> global___CorrelationFilter: ...
    filter_type: builtins.str
    @property
    def sql_filter(self) -> global___SqlFilter: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        action: global___Action | None = ...,
        correlation_filter: global___CorrelationFilter | None = ...,
        filter_type: builtins.str = ...,
        sql_filter: global___SqlFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "correlation_filter", b"correlation_filter", "resource_info", b"resource_info", "sql_filter", b"sql_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "correlation_filter", b"correlation_filter", "filter_type", b"filter_type", "name", b"name", "resource_info", b"resource_info", "sql_filter", b"sql_filter"]) -> None: ...

global___NamespacesTopicsSubscriptionsRules = NamespacesTopicsSubscriptionsRules

@typing_extensions.final
class SqlFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPATIBILITY_LEVEL_FIELD_NUMBER: builtins.int
    REQUIRES_PREPROCESSING_FIELD_NUMBER: builtins.int
    SQL_EXPRESSION_FIELD_NUMBER: builtins.int
    compatibility_level: builtins.int
    requires_preprocessing: builtins.bool
    sql_expression: builtins.str
    def __init__(
        self,
        *,
        compatibility_level: builtins.int = ...,
        requires_preprocessing: builtins.bool = ...,
        sql_expression: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compatibility_level", b"compatibility_level", "requires_preprocessing", b"requires_preprocessing", "sql_expression", b"sql_expression"]) -> None: ...

global___SqlFilter = SqlFilter

@typing_extensions.final
class CorrelationFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    REPLY_TO_FIELD_NUMBER: builtins.int
    REPLY_TO_SESSION_ID_FIELD_NUMBER: builtins.int
    REQUIRES_PREPROCESSING_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    content_type: builtins.str
    correlation_id: builtins.str
    label: builtins.str
    message_id: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    reply_to: builtins.str
    reply_to_session_id: builtins.str
    requires_preprocessing: builtins.bool
    session_id: builtins.str
    to: builtins.str
    def __init__(
        self,
        *,
        content_type: builtins.str = ...,
        correlation_id: builtins.str = ...,
        label: builtins.str = ...,
        message_id: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        reply_to: builtins.str = ...,
        reply_to_session_id: builtins.str = ...,
        requires_preprocessing: builtins.bool = ...,
        session_id: builtins.str = ...,
        to: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "correlation_id", b"correlation_id", "label", b"label", "message_id", b"message_id", "properties", b"properties", "reply_to", b"reply_to", "reply_to_session_id", b"reply_to_session_id", "requires_preprocessing", b"requires_preprocessing", "session_id", b"session_id", "to", b"to"]) -> None: ...

global___CorrelationFilter = CorrelationFilter

@typing_extensions.final
class Action(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPATIBILITY_LEVEL_FIELD_NUMBER: builtins.int
    REQUIRES_PREPROCESSING_FIELD_NUMBER: builtins.int
    SQL_EXPRESSION_FIELD_NUMBER: builtins.int
    compatibility_level: builtins.int
    requires_preprocessing: builtins.bool
    sql_expression: builtins.str
    def __init__(
        self,
        *,
        compatibility_level: builtins.int = ...,
        requires_preprocessing: builtins.bool = ...,
        sql_expression: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compatibility_level", b"compatibility_level", "requires_preprocessing", b"requires_preprocessing", "sql_expression", b"sql_expression"]) -> None: ...

global___Action = Action

@typing_extensions.final
class NamespacesTopicsSubscriptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_DELETE_ON_IDLE_FIELD_NUMBER: builtins.int
    CLIENT_AFFINE_PROPERTIES_FIELD_NUMBER: builtins.int
    DEAD_LETTERING_ON_FILTER_EVALUATION_EXCEPTIONS_FIELD_NUMBER: builtins.int
    DEAD_LETTERING_ON_MESSAGE_EXPIRATION_FIELD_NUMBER: builtins.int
    DEFAULT_MESSAGE_TIME_TO_LIVE_FIELD_NUMBER: builtins.int
    DUPLICATE_DETECTION_HISTORY_TIME_WINDOW_FIELD_NUMBER: builtins.int
    ENABLE_BATCHED_OPERATIONS_FIELD_NUMBER: builtins.int
    FORWARD_DEAD_LETTERED_MESSAGES_TO_FIELD_NUMBER: builtins.int
    FORWARD_TO_FIELD_NUMBER: builtins.int
    IS_CLIENT_AFFINE_FIELD_NUMBER: builtins.int
    LOCK_DURATION_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_COUNT_FIELD_NUMBER: builtins.int
    REQUIRES_SESSION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAMESPACES_TOPICS_SUBSCRIPTIONS_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_delete_on_idle: builtins.str
    @property
    def client_affine_properties(self) -> global___SBClientAffineProperties: ...
    dead_lettering_on_filter_evaluation_exceptions: builtins.bool
    dead_lettering_on_message_expiration: builtins.bool
    default_message_time_to_live: builtins.str
    duplicate_detection_history_time_window: builtins.str
    enable_batched_operations: builtins.bool
    forward_dead_lettered_messages_to: builtins.str
    forward_to: builtins.str
    is_client_affine: builtins.bool
    lock_duration: builtins.str
    max_delivery_count: builtins.int
    requires_session: builtins.bool
    status: builtins.str
    @property
    def namespaces_topics_subscriptions_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesTopicsSubscriptionsRules]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_delete_on_idle: builtins.str = ...,
        client_affine_properties: global___SBClientAffineProperties | None = ...,
        dead_lettering_on_filter_evaluation_exceptions: builtins.bool = ...,
        dead_lettering_on_message_expiration: builtins.bool = ...,
        default_message_time_to_live: builtins.str = ...,
        duplicate_detection_history_time_window: builtins.str = ...,
        enable_batched_operations: builtins.bool = ...,
        forward_dead_lettered_messages_to: builtins.str = ...,
        forward_to: builtins.str = ...,
        is_client_affine: builtins.bool = ...,
        lock_duration: builtins.str = ...,
        max_delivery_count: builtins.int = ...,
        requires_session: builtins.bool = ...,
        status: builtins.str = ...,
        namespaces_topics_subscriptions_rules: collections.abc.Iterable[global___NamespacesTopicsSubscriptionsRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_affine_properties", b"client_affine_properties", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete_on_idle", b"auto_delete_on_idle", "client_affine_properties", b"client_affine_properties", "dead_lettering_on_filter_evaluation_exceptions", b"dead_lettering_on_filter_evaluation_exceptions", "dead_lettering_on_message_expiration", b"dead_lettering_on_message_expiration", "default_message_time_to_live", b"default_message_time_to_live", "duplicate_detection_history_time_window", b"duplicate_detection_history_time_window", "enable_batched_operations", b"enable_batched_operations", "forward_dead_lettered_messages_to", b"forward_dead_lettered_messages_to", "forward_to", b"forward_to", "is_client_affine", b"is_client_affine", "lock_duration", b"lock_duration", "max_delivery_count", b"max_delivery_count", "name", b"name", "namespaces_topics_subscriptions_rules", b"namespaces_topics_subscriptions_rules", "requires_session", b"requires_session", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___NamespacesTopicsSubscriptions = NamespacesTopicsSubscriptions

@typing_extensions.final
class SBClientAffineProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    IS_DURABLE_FIELD_NUMBER: builtins.int
    IS_SHARED_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    is_durable: builtins.bool
    is_shared: builtins.bool
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        is_durable: builtins.bool = ...,
        is_shared: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "is_durable", b"is_durable", "is_shared", b"is_shared"]) -> None: ...

global___SBClientAffineProperties = SBClientAffineProperties

@typing_extensions.final
class NamespacesTopicsAuthorizationRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def rights(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        rights: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "rights", b"rights"]) -> None: ...

global___NamespacesTopicsAuthorizationRules = NamespacesTopicsAuthorizationRules

@typing_extensions.final
class NamespacesTopics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_DELETE_ON_IDLE_FIELD_NUMBER: builtins.int
    DEFAULT_MESSAGE_TIME_TO_LIVE_FIELD_NUMBER: builtins.int
    DUPLICATE_DETECTION_HISTORY_TIME_WINDOW_FIELD_NUMBER: builtins.int
    ENABLE_BATCHED_OPERATIONS_FIELD_NUMBER: builtins.int
    ENABLE_EXPRESS_FIELD_NUMBER: builtins.int
    ENABLE_PARTITIONING_FIELD_NUMBER: builtins.int
    MAX_MESSAGE_SIZE_IN_KILOBYTES_FIELD_NUMBER: builtins.int
    MAX_SIZE_IN_MEGABYTES_FIELD_NUMBER: builtins.int
    REQUIRES_DUPLICATE_DETECTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SUPPORT_ORDERING_FIELD_NUMBER: builtins.int
    NAMESPACES_TOPICS_AUTHORIZATION_RULES_FIELD_NUMBER: builtins.int
    NAMESPACES_TOPICS_SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_delete_on_idle: builtins.str
    default_message_time_to_live: builtins.str
    duplicate_detection_history_time_window: builtins.str
    enable_batched_operations: builtins.bool
    enable_express: builtins.bool
    enable_partitioning: builtins.bool
    max_message_size_in_kilobytes: builtins.int
    max_size_in_megabytes: builtins.int
    requires_duplicate_detection: builtins.bool
    status: builtins.str
    support_ordering: builtins.bool
    @property
    def namespaces_topics_authorization_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesTopicsAuthorizationRules]: ...
    @property
    def namespaces_topics_subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesTopicsSubscriptions]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_delete_on_idle: builtins.str = ...,
        default_message_time_to_live: builtins.str = ...,
        duplicate_detection_history_time_window: builtins.str = ...,
        enable_batched_operations: builtins.bool = ...,
        enable_express: builtins.bool = ...,
        enable_partitioning: builtins.bool = ...,
        max_message_size_in_kilobytes: builtins.int = ...,
        max_size_in_megabytes: builtins.int = ...,
        requires_duplicate_detection: builtins.bool = ...,
        status: builtins.str = ...,
        support_ordering: builtins.bool = ...,
        namespaces_topics_authorization_rules: collections.abc.Iterable[global___NamespacesTopicsAuthorizationRules] | None = ...,
        namespaces_topics_subscriptions: collections.abc.Iterable[global___NamespacesTopicsSubscriptions] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete_on_idle", b"auto_delete_on_idle", "default_message_time_to_live", b"default_message_time_to_live", "duplicate_detection_history_time_window", b"duplicate_detection_history_time_window", "enable_batched_operations", b"enable_batched_operations", "enable_express", b"enable_express", "enable_partitioning", b"enable_partitioning", "max_message_size_in_kilobytes", b"max_message_size_in_kilobytes", "max_size_in_megabytes", b"max_size_in_megabytes", "name", b"name", "namespaces_topics_authorization_rules", b"namespaces_topics_authorization_rules", "namespaces_topics_subscriptions", b"namespaces_topics_subscriptions", "requires_duplicate_detection", b"requires_duplicate_detection", "resource_info", b"resource_info", "status", b"status", "support_ordering", b"support_ordering"]) -> None: ...

global___NamespacesTopics = NamespacesTopics

@typing_extensions.final
class NamespacesQueuesAuthorizationRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def rights(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        rights: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "rights", b"rights"]) -> None: ...

global___NamespacesQueuesAuthorizationRules = NamespacesQueuesAuthorizationRules

@typing_extensions.final
class NamespacesQueues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_DELETE_ON_IDLE_FIELD_NUMBER: builtins.int
    DEAD_LETTERING_ON_MESSAGE_EXPIRATION_FIELD_NUMBER: builtins.int
    DEFAULT_MESSAGE_TIME_TO_LIVE_FIELD_NUMBER: builtins.int
    DUPLICATE_DETECTION_HISTORY_TIME_WINDOW_FIELD_NUMBER: builtins.int
    ENABLE_BATCHED_OPERATIONS_FIELD_NUMBER: builtins.int
    ENABLE_EXPRESS_FIELD_NUMBER: builtins.int
    ENABLE_PARTITIONING_FIELD_NUMBER: builtins.int
    FORWARD_DEAD_LETTERED_MESSAGES_TO_FIELD_NUMBER: builtins.int
    FORWARD_TO_FIELD_NUMBER: builtins.int
    LOCK_DURATION_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_COUNT_FIELD_NUMBER: builtins.int
    MAX_MESSAGE_SIZE_IN_KILOBYTES_FIELD_NUMBER: builtins.int
    MAX_SIZE_IN_MEGABYTES_FIELD_NUMBER: builtins.int
    REQUIRES_DUPLICATE_DETECTION_FIELD_NUMBER: builtins.int
    REQUIRES_SESSION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAMESPACES_QUEUES_AUTHORIZATION_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_delete_on_idle: builtins.str
    dead_lettering_on_message_expiration: builtins.bool
    default_message_time_to_live: builtins.str
    duplicate_detection_history_time_window: builtins.str
    enable_batched_operations: builtins.bool
    enable_express: builtins.bool
    enable_partitioning: builtins.bool
    forward_dead_lettered_messages_to: builtins.str
    forward_to: builtins.str
    lock_duration: builtins.str
    max_delivery_count: builtins.int
    max_message_size_in_kilobytes: builtins.int
    max_size_in_megabytes: builtins.int
    requires_duplicate_detection: builtins.bool
    requires_session: builtins.bool
    status: builtins.str
    @property
    def namespaces_queues_authorization_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesQueuesAuthorizationRules]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_delete_on_idle: builtins.str = ...,
        dead_lettering_on_message_expiration: builtins.bool = ...,
        default_message_time_to_live: builtins.str = ...,
        duplicate_detection_history_time_window: builtins.str = ...,
        enable_batched_operations: builtins.bool = ...,
        enable_express: builtins.bool = ...,
        enable_partitioning: builtins.bool = ...,
        forward_dead_lettered_messages_to: builtins.str = ...,
        forward_to: builtins.str = ...,
        lock_duration: builtins.str = ...,
        max_delivery_count: builtins.int = ...,
        max_message_size_in_kilobytes: builtins.int = ...,
        max_size_in_megabytes: builtins.int = ...,
        requires_duplicate_detection: builtins.bool = ...,
        requires_session: builtins.bool = ...,
        status: builtins.str = ...,
        namespaces_queues_authorization_rules: collections.abc.Iterable[global___NamespacesQueuesAuthorizationRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete_on_idle", b"auto_delete_on_idle", "dead_lettering_on_message_expiration", b"dead_lettering_on_message_expiration", "default_message_time_to_live", b"default_message_time_to_live", "duplicate_detection_history_time_window", b"duplicate_detection_history_time_window", "enable_batched_operations", b"enable_batched_operations", "enable_express", b"enable_express", "enable_partitioning", b"enable_partitioning", "forward_dead_lettered_messages_to", b"forward_dead_lettered_messages_to", "forward_to", b"forward_to", "lock_duration", b"lock_duration", "max_delivery_count", b"max_delivery_count", "max_message_size_in_kilobytes", b"max_message_size_in_kilobytes", "max_size_in_megabytes", b"max_size_in_megabytes", "name", b"name", "namespaces_queues_authorization_rules", b"namespaces_queues_authorization_rules", "requires_duplicate_detection", b"requires_duplicate_detection", "requires_session", b"requires_session", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___NamespacesQueues = NamespacesQueues

@typing_extensions.final
class NamespacesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___ConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___ConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___NamespacesPrivateEndpointConnections = NamespacesPrivateEndpointConnections

@typing_extensions.final
class NamespacesNetworkRuleSets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    TRUSTED_SERVICE_ACCESS_ENABLED_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NWRuleSetIpRules]: ...
    public_network_access: builtins.str
    trusted_service_access_enabled: builtins.bool
    @property
    def virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NWRuleSetVirtualNetworkRules]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___NWRuleSetIpRules] | None = ...,
        public_network_access: builtins.str = ...,
        trusted_service_access_enabled: builtins.bool = ...,
        virtual_network_rules: collections.abc.Iterable[global___NWRuleSetVirtualNetworkRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_action", b"default_action", "ip_rules", b"ip_rules", "name", b"name", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "trusted_service_access_enabled", b"trusted_service_access_enabled", "virtual_network_rules", b"virtual_network_rules"]) -> None: ...

global___NamespacesNetworkRuleSets = NamespacesNetworkRuleSets

@typing_extensions.final
class NWRuleSetVirtualNetworkRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IGNORE_MISSING_VNET_SERVICE_ENDPOINT_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    ignore_missing_vnet_service_endpoint: builtins.bool
    @property
    def subnet(self) -> global___Subnet: ...
    def __init__(
        self,
        *,
        ignore_missing_vnet_service_endpoint: builtins.bool = ...,
        subnet: global___Subnet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_missing_vnet_service_endpoint", b"ignore_missing_vnet_service_endpoint", "subnet", b"subnet"]) -> None: ...

global___NWRuleSetVirtualNetworkRules = NWRuleSetVirtualNetworkRules

@typing_extensions.final
class Subnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___Subnet = Subnet

@typing_extensions.final
class NWRuleSetIpRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    IP_MASK_FIELD_NUMBER: builtins.int
    action: builtins.str
    ip_mask: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        ip_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "ip_mask", b"ip_mask"]) -> None: ...

global___NWRuleSetIpRules = NWRuleSetIpRules

@typing_extensions.final
class NamespacesMigrationConfigurations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POST_MIGRATION_NAME_FIELD_NUMBER: builtins.int
    TARGET_NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    post_migration_name: builtins.str
    target_namespace: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        post_migration_name: builtins.str = ...,
        target_namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "post_migration_name", b"post_migration_name", "resource_info", b"resource_info", "target_namespace", b"target_namespace"]) -> None: ...

global___NamespacesMigrationConfigurations = NamespacesMigrationConfigurations

@typing_extensions.final
class NamespacesDisasterRecoveryConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALTERNATE_NAME_FIELD_NUMBER: builtins.int
    PARTNER_NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    alternate_name: builtins.str
    partner_namespace: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        alternate_name: builtins.str = ...,
        partner_namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alternate_name", b"alternate_name", "name", b"name", "partner_namespace", b"partner_namespace", "resource_info", b"resource_info"]) -> None: ...

global___NamespacesDisasterRecoveryConfigs = NamespacesDisasterRecoveryConfigs

@typing_extensions.final
class NamespacesAuthorizationRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def rights(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        rights: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "rights", b"rights"]) -> None: ...

global___NamespacesAuthorizationRules = NamespacesAuthorizationRules

@typing_extensions.final
class Namespaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALTERNATE_NAME_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAMESPACES_NETWORK_RULE_SETS_FIELD_NUMBER: builtins.int
    NAMESPACES__AUTHORIZATION_RULES_FIELD_NUMBER: builtins.int
    NAMESPACES_DISASTER_RECOVERY_CONFIGS_FIELD_NUMBER: builtins.int
    NAMESPACES_MIGRATION_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    MINIMUM_TLS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___Identity: ...
    location: builtins.str
    name: builtins.str
    alternate_name: builtins.str
    disable_local_auth: builtins.bool
    @property
    def encryption(self) -> global___Encryption: ...
    @property
    def private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateEndpointConnection]: ...
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___SBSku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def namespaces_network_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesNetworkRuleSets]: ...
    @property
    def namespaces__authorization_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesAuthorizationRules]: ...
    @property
    def namespaces_disaster_recovery_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesDisasterRecoveryConfigs]: ...
    @property
    def namespaces_migration_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesMigrationConfigurations]: ...
    minimum_tls_version: builtins.str
    public_network_access: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___Identity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        alternate_name: builtins.str = ...,
        disable_local_auth: builtins.bool = ...,
        encryption: global___Encryption | None = ...,
        private_endpoint_connections: collections.abc.Iterable[global___PrivateEndpointConnection] | None = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___SBSku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        namespaces_network_rule_sets: collections.abc.Iterable[global___NamespacesNetworkRuleSets] | None = ...,
        namespaces__authorization_rules: collections.abc.Iterable[global___NamespacesAuthorizationRules] | None = ...,
        namespaces_disaster_recovery_configs: collections.abc.Iterable[global___NamespacesDisasterRecoveryConfigs] | None = ...,
        namespaces_migration_configurations: collections.abc.Iterable[global___NamespacesMigrationConfigurations] | None = ...,
        minimum_tls_version: builtins.str = ...,
        public_network_access: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption", b"encryption", "identity", b"identity", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alternate_name", b"alternate_name", "disable_local_auth", b"disable_local_auth", "encryption", b"encryption", "identity", b"identity", "location", b"location", "minimum_tls_version", b"minimum_tls_version", "name", b"name", "namespaces__authorization_rules", b"namespaces__authorization_rules", "namespaces_disaster_recovery_configs", b"namespaces_disaster_recovery_configs", "namespaces_migration_configurations", b"namespaces_migration_configurations", "namespaces_network_rule_sets", b"namespaces_network_rule_sets", "private_endpoint_connections", b"private_endpoint_connections", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "zone_redundant", b"zone_redundant"]) -> None: ...

global___Namespaces = Namespaces

@typing_extensions.final
class SBSku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    name: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        name: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "name", b"name", "tier", b"tier"]) -> None: ...

global___SBSku = SBSku

@typing_extensions.final
class PrivateEndpointConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___ConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___ConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state"]) -> None: ...

global___PrivateEndpointConnection = PrivateEndpointConnection

@typing_extensions.final
class ConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "status", b"status"]) -> None: ...

global___ConnectionState = ConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class Encryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_SOURCE_FIELD_NUMBER: builtins.int
    KEY_VAULT_PROPERTIES_FIELD_NUMBER: builtins.int
    REQUIRE_INFRASTRUCTURE_ENCRYPTION_FIELD_NUMBER: builtins.int
    key_source: builtins.str
    @property
    def key_vault_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeyVaultProperties]: ...
    require_infrastructure_encryption: builtins.bool
    def __init__(
        self,
        *,
        key_source: builtins.str = ...,
        key_vault_properties: collections.abc.Iterable[global___KeyVaultProperties] | None = ...,
        require_infrastructure_encryption: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_source", b"key_source", "key_vault_properties", b"key_vault_properties", "require_infrastructure_encryption", b"require_infrastructure_encryption"]) -> None: ...

global___Encryption = Encryption

@typing_extensions.final
class KeyVaultProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    KEY_VAULT_URI_FIELD_NUMBER: builtins.int
    KEY_VERSION_FIELD_NUMBER: builtins.int
    @property
    def identity(self) -> global___UserAssignedIdentityProperties: ...
    key_name: builtins.str
    key_vault_uri: builtins.str
    key_version: builtins.str
    def __init__(
        self,
        *,
        identity: global___UserAssignedIdentityProperties | None = ...,
        key_name: builtins.str = ...,
        key_vault_uri: builtins.str = ...,
        key_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "key_name", b"key_name", "key_vault_uri", b"key_vault_uri", "key_version", b"key_version"]) -> None: ...

global___KeyVaultProperties = KeyVaultProperties

@typing_extensions.final
class UserAssignedIdentityProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    user_assigned_identity: builtins.str
    def __init__(
        self,
        *,
        user_assigned_identity: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_assigned_identity", b"user_assigned_identity"]) -> None: ...

global___UserAssignedIdentityProperties = UserAssignedIdentityProperties

@typing_extensions.final
class Identity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___Identity = Identity
