"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Event(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    API_VERSION_FIELD_NUMBER: builtins.int
    DEPRECATED_COUNT_FIELD_NUMBER: builtins.int
    DEPRECATED_FIRST_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPRECATED_LAST_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPRECATED_SOURCE_FIELD_NUMBER: builtins.int
    EVENT_TIME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NOTE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    REGARDING_FIELD_NUMBER: builtins.int
    RELATED_FIELD_NUMBER: builtins.int
    REPORTING_CONTROLLER_FIELD_NUMBER: builtins.int
    REPORTING_INSTANCE_FIELD_NUMBER: builtins.int
    SERIES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    action: builtins.str
    api_version: builtins.str
    deprecated_count: builtins.int
    @property
    def deprecated_first_timestamp(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def deprecated_last_timestamp(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def deprecated_source(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.EventSource: ...
    @property
    def event_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    note: builtins.str
    reason: builtins.str
    @property
    def regarding(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference: ...
    @property
    def related(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference: ...
    reporting_controller: builtins.str
    reporting_instance: builtins.str
    @property
    def series(self) -> global___EventSeries: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        api_version: builtins.str = ...,
        deprecated_count: builtins.int = ...,
        deprecated_first_timestamp: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        deprecated_last_timestamp: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        deprecated_source: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.EventSource | None = ...,
        event_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        note: builtins.str = ...,
        reason: builtins.str = ...,
        regarding: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference | None = ...,
        related: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference | None = ...,
        reporting_controller: builtins.str = ...,
        reporting_instance: builtins.str = ...,
        series: global___EventSeries | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deprecated_first_timestamp", b"deprecated_first_timestamp", "deprecated_last_timestamp", b"deprecated_last_timestamp", "deprecated_source", b"deprecated_source", "event_time", b"event_time", "metadata", b"metadata", "regarding", b"regarding", "related", b"related", "resource_info", b"resource_info", "series", b"series"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "api_version", b"api_version", "deprecated_count", b"deprecated_count", "deprecated_first_timestamp", b"deprecated_first_timestamp", "deprecated_last_timestamp", b"deprecated_last_timestamp", "deprecated_source", b"deprecated_source", "event_time", b"event_time", "kind", b"kind", "metadata", b"metadata", "note", b"note", "reason", b"reason", "regarding", b"regarding", "related", b"related", "reporting_controller", b"reporting_controller", "reporting_instance", b"reporting_instance", "resource_info", b"resource_info", "series", b"series", "type", b"type"]) -> None: ...

global___Event = Event

@typing_extensions.final
class EventList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Event] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___EventList = EventList

@typing_extensions.final
class EventSeries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    LAST_OBSERVED_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    count: builtins.int
    @property
    def last_observed_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        last_observed_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_observed_time", b"last_observed_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "last_observed_time", b"last_observed_time", "resource_info", b"resource_info"]) -> None: ...

global___EventSeries = EventSeries
