"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EnvironmentEC2Repository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATH_COMPONENT_FIELD_NUMBER: builtins.int
    REPOSITORY_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    path_component: builtins.str
    repository_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        path_component: builtins.str = ...,
        repository_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["path_component", b"path_component", "repository_url", b"repository_url", "resource_info", b"resource_info"]) -> None: ...

global___EnvironmentEC2Repository = EnvironmentEC2Repository

@typing_extensions.final
class EnvironmentEC2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPOSITORIES_FIELD_NUMBER: builtins.int
    OWNER_ARN_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    AUTOMATIC_STOP_TIME_MINUTES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def repositories(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentEC2Repository]: ...
    owner_arn: builtins.str
    description: builtins.str
    connection_type: builtins.str
    automatic_stop_time_minutes: builtins.int
    subnet_id: builtins.str
    instance_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        repositories: collections.abc.Iterable[global___EnvironmentEC2Repository] | None = ...,
        owner_arn: builtins.str = ...,
        description: builtins.str = ...,
        connection_type: builtins.str = ...,
        automatic_stop_time_minutes: builtins.int = ...,
        subnet_id: builtins.str = ...,
        instance_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic_stop_time_minutes", b"automatic_stop_time_minutes", "connection_type", b"connection_type", "description", b"description", "instance_type", b"instance_type", "name", b"name", "owner_arn", b"owner_arn", "repositories", b"repositories", "resource_info", b"resource_info", "subnet_id", b"subnet_id", "tags", b"tags"]) -> None: ...

global___EnvironmentEC2 = EnvironmentEC2

@typing_extensions.final
class Cloud9(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_E_C2_FIELD_NUMBER: builtins.int
    @property
    def environment_e_c2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentEC2]: ...
    def __init__(
        self,
        *,
        environment_e_c2: collections.abc.Iterable[global___EnvironmentEC2] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_e_c2", b"environment_e_c2"]) -> None: ...

global___Cloud9 = Cloud9
