# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_imagebuilder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_imagebuilder.proto\x12\x1coak9.tython.aws.imagebuilder\x1a\x13shared/shared.proto\"\xe2\x02\n\tComponent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1a\n\x12\x63hange_description\x18\x05 \x01(\t\x12\x10\n\x08platform\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x12\n\nkms_key_id\x18\x08 \x01(\t\x12?\n\x04tags\x18\t \x03(\x0b\x32\x31.oak9.tython.aws.imagebuilder.Component.TagsEntry\x12\x0b\n\x03uri\x18\n \x01(\t\x12\x1d\n\x15supported_os_versions\x18\x0b \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x04\n\x0cImageBuilder\x12:\n\tcomponent\x18\x01 \x03(\x0b\x32\'.oak9.tython.aws.imagebuilder.Component\x12[\n\x1a\x64istribution_configuration\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.imagebuilder.DistributionConfiguration\x12\x32\n\x05image\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.imagebuilder.Image\x12\x43\n\x0eimage_pipeline\x18\x04 \x03(\x0b\x32+.oak9.tython.aws.imagebuilder.ImagePipeline\x12?\n\x0cimage_recipe\x18\x05 \x03(\x0b\x32).oak9.tython.aws.imagebuilder.ImageRecipe\x12_\n\x1cinfrastructure_configuration\x18\x06 \x03(\x0b\x32\x39.oak9.tython.aws.imagebuilder.InfrastructureConfiguration\x12n\n$infrastructure_configuration_logging\x18\x07 \x03(\x0b\x32@.oak9.tython.aws.imagebuilder.InfrastructureConfigurationLogging\"\xe9\x02\n%DistributionConfigurationDistribution\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x8d\x01\n\x1e\x61mi_distribution_configuration\x18\x03 \x03(\x0b\x32\x65.oak9.tython.aws.imagebuilder.DistributionConfigurationDistribution.AmiDistributionConfigurationEntry\x12\"\n\x1alicense_configuration_arns\x18\x04 \x03(\t\x1a\x43\n!AmiDistributionConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd1\x02\n\x19\x44istributionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12Z\n\rdistributions\x18\x04 \x03(\x0b\x32\x43.oak9.tython.aws.imagebuilder.DistributionConfigurationDistribution\x12O\n\x04tags\x18\x05 \x03(\x0b\x32\x41.oak9.tython.aws.imagebuilder.DistributionConfiguration.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x1cImageImageTestsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13image_tests_enabled\x18\x02 \x01(\x08\x12\x17\n\x0ftimeout_minutes\x18\x03 \x01(\x05\"\x9e\x03\n\x05Image\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x19image_tests_configuration\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.imagebuilder.ImageImageTestsConfiguration\x12\x18\n\x10image_recipe_arn\x18\x03 \x01(\t\x12&\n\x1e\x64istribution_configuration_arn\x18\x04 \x01(\t\x12(\n infrastructure_configuration_arn\x18\x05 \x01(\t\x12\'\n\x1f\x65nhanced_image_metadata_enabled\x18\x06 \x01(\x08\x12;\n\x04tags\x18\x07 \x03(\x0b\x32-.oak9.tython.aws.imagebuilder.Image.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n$ImagePipelineImageTestsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13image_tests_enabled\x18\x02 \x01(\x08\x12\x17\n\x0ftimeout_minutes\x18\x03 \x01(\x05\"\x99\x01\n\x15ImagePipelineSchedule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13schedule_expression\x18\x02 \x01(\t\x12*\n\"pipeline_execution_start_condition\x18\x03 \x01(\t\"\xb0\x04\n\rImagePipeline\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x65\n\x19image_tests_configuration\x18\x04 \x01(\x0b\x32\x42.oak9.tython.aws.imagebuilder.ImagePipelineImageTestsConfiguration\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x45\n\x08schedule\x18\x06 \x01(\x0b\x32\x33.oak9.tython.aws.imagebuilder.ImagePipelineSchedule\x12\x18\n\x10image_recipe_arn\x18\x07 \x01(\t\x12&\n\x1e\x64istribution_configuration_arn\x18\x08 \x01(\t\x12(\n infrastructure_configuration_arn\x18\t \x01(\t\x12\'\n\x1f\x65nhanced_image_metadata_enabled\x18\n \x01(\x08\x12\x43\n\x04tags\x18\x0b \x03(\x0b\x32\x35.oak9.tython.aws.imagebuilder.ImagePipeline.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"s\n!ImageRecipeComponentConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcomponent_arn\x18\x02 \x01(\t\"\xfc\x01\n.ImageRecipeEbsInstanceBlockDeviceSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tencrypted\x18\x02 \x01(\x08\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x03 \x01(\x08\x12\x0c\n\x04iops\x18\x04 \x01(\x05\x12\x12\n\nkms_key_id\x18\x05 \x01(\t\x12\x13\n\x0bsnapshot_id\x18\x06 \x01(\t\x12\x13\n\x0bvolume_size\x18\x07 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x08 \x01(\t\"\xf9\x01\n%ImageRecipeInstanceBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x14\n\x0cvirtual_name\x18\x03 \x01(\t\x12\x11\n\tno_device\x18\x04 \x01(\t\x12Y\n\x03\x65\x62s\x18\x05 \x01(\x0b\x32L.oak9.tython.aws.imagebuilder.ImageRecipeEbsInstanceBlockDeviceSpecification\"\xd4\x03\n\x0bImageRecipe\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12S\n\ncomponents\x18\x05 \x03(\x0b\x32?.oak9.tython.aws.imagebuilder.ImageRecipeComponentConfiguration\x12\x62\n\x15\x62lock_device_mappings\x18\x06 \x03(\x0b\x32\x43.oak9.tython.aws.imagebuilder.ImageRecipeInstanceBlockDeviceMapping\x12\x14\n\x0cparent_image\x18\x07 \x01(\t\x12\x19\n\x11working_directory\x18\x08 \x01(\t\x12\x41\n\x04tags\x18\t \x03(\x0b\x32\x33.oak9.tython.aws.imagebuilder.ImageRecipe.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd1\x05\n\x1bInfrastructureConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0einstance_types\x18\x04 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\t\x12W\n\x07logging\x18\x06 \x03(\x0b\x32\x46.oak9.tython.aws.imagebuilder.InfrastructureConfiguration.LoggingEntry\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x10\n\x08key_pair\x18\x08 \x01(\t\x12%\n\x1dterminate_instance_on_failure\x18\t \x01(\x08\x12\x1d\n\x15instance_profile_name\x18\n \x01(\t\x12\x15\n\rsns_topic_arn\x18\x0b \x01(\t\x12\x62\n\rresource_tags\x18\x0c \x03(\x0b\x32K.oak9.tython.aws.imagebuilder.InfrastructureConfiguration.ResourceTagsEntry\x12Q\n\x04tags\x18\r \x03(\x0b\x32\x43.oak9.tython.aws.imagebuilder.InfrastructureConfiguration.TagsEntry\x1a.\n\x0cLoggingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11ResourceTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n!InfrastructureConfigurationS3Logs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0es3_bucket_name\x18\x02 \x01(\t\x12\x15\n\rs3_key_prefix\x18\x03 \x01(\t\"\xaf\x01\n\"InfrastructureConfigurationLogging\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x07s3_logs\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.imagebuilder.InfrastructureConfigurationS3Logsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_imagebuilder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPONENT_TAGSENTRY._options = None
  _COMPONENT_TAGSENTRY._serialized_options = b'8\001'
  _DISTRIBUTIONCONFIGURATIONDISTRIBUTION_AMIDISTRIBUTIONCONFIGURATIONENTRY._options = None
  _DISTRIBUTIONCONFIGURATIONDISTRIBUTION_AMIDISTRIBUTIONCONFIGURATIONENTRY._serialized_options = b'8\001'
  _DISTRIBUTIONCONFIGURATION_TAGSENTRY._options = None
  _DISTRIBUTIONCONFIGURATION_TAGSENTRY._serialized_options = b'8\001'
  _IMAGE_TAGSENTRY._options = None
  _IMAGE_TAGSENTRY._serialized_options = b'8\001'
  _IMAGEPIPELINE_TAGSENTRY._options = None
  _IMAGEPIPELINE_TAGSENTRY._serialized_options = b'8\001'
  _IMAGERECIPE_TAGSENTRY._options = None
  _IMAGERECIPE_TAGSENTRY._serialized_options = b'8\001'
  _INFRASTRUCTURECONFIGURATION_LOGGINGENTRY._options = None
  _INFRASTRUCTURECONFIGURATION_LOGGINGENTRY._serialized_options = b'8\001'
  _INFRASTRUCTURECONFIGURATION_RESOURCETAGSENTRY._options = None
  _INFRASTRUCTURECONFIGURATION_RESOURCETAGSENTRY._serialized_options = b'8\001'
  _INFRASTRUCTURECONFIGURATION_TAGSENTRY._options = None
  _INFRASTRUCTURECONFIGURATION_TAGSENTRY._serialized_options = b'8\001'
  _COMPONENT._serialized_start=82
  _COMPONENT._serialized_end=436
  _COMPONENT_TAGSENTRY._serialized_start=393
  _COMPONENT_TAGSENTRY._serialized_end=436
  _IMAGEBUILDER._serialized_start=439
  _IMAGEBUILDER._serialized_end=1001
  _DISTRIBUTIONCONFIGURATIONDISTRIBUTION._serialized_start=1004
  _DISTRIBUTIONCONFIGURATIONDISTRIBUTION._serialized_end=1365
  _DISTRIBUTIONCONFIGURATIONDISTRIBUTION_AMIDISTRIBUTIONCONFIGURATIONENTRY._serialized_start=1298
  _DISTRIBUTIONCONFIGURATIONDISTRIBUTION_AMIDISTRIBUTIONCONFIGURATIONENTRY._serialized_end=1365
  _DISTRIBUTIONCONFIGURATION._serialized_start=1368
  _DISTRIBUTIONCONFIGURATION._serialized_end=1705
  _DISTRIBUTIONCONFIGURATION_TAGSENTRY._serialized_start=393
  _DISTRIBUTIONCONFIGURATION_TAGSENTRY._serialized_end=436
  _IMAGEIMAGETESTSCONFIGURATION._serialized_start=1708
  _IMAGEIMAGETESTSCONFIGURATION._serialized_end=1849
  _IMAGE._serialized_start=1852
  _IMAGE._serialized_end=2266
  _IMAGE_TAGSENTRY._serialized_start=393
  _IMAGE_TAGSENTRY._serialized_end=436
  _IMAGEPIPELINEIMAGETESTSCONFIGURATION._serialized_start=2269
  _IMAGEPIPELINEIMAGETESTSCONFIGURATION._serialized_end=2418
  _IMAGEPIPELINESCHEDULE._serialized_start=2421
  _IMAGEPIPELINESCHEDULE._serialized_end=2574
  _IMAGEPIPELINE._serialized_start=2577
  _IMAGEPIPELINE._serialized_end=3137
  _IMAGEPIPELINE_TAGSENTRY._serialized_start=393
  _IMAGEPIPELINE_TAGSENTRY._serialized_end=436
  _IMAGERECIPECOMPONENTCONFIGURATION._serialized_start=3139
  _IMAGERECIPECOMPONENTCONFIGURATION._serialized_end=3254
  _IMAGERECIPEEBSINSTANCEBLOCKDEVICESPECIFICATION._serialized_start=3257
  _IMAGERECIPEEBSINSTANCEBLOCKDEVICESPECIFICATION._serialized_end=3509
  _IMAGERECIPEINSTANCEBLOCKDEVICEMAPPING._serialized_start=3512
  _IMAGERECIPEINSTANCEBLOCKDEVICEMAPPING._serialized_end=3761
  _IMAGERECIPE._serialized_start=3764
  _IMAGERECIPE._serialized_end=4232
  _IMAGERECIPE_TAGSENTRY._serialized_start=393
  _IMAGERECIPE_TAGSENTRY._serialized_end=436
  _INFRASTRUCTURECONFIGURATION._serialized_start=4235
  _INFRASTRUCTURECONFIGURATION._serialized_end=4956
  _INFRASTRUCTURECONFIGURATION_LOGGINGENTRY._serialized_start=4812
  _INFRASTRUCTURECONFIGURATION_LOGGINGENTRY._serialized_end=4858
  _INFRASTRUCTURECONFIGURATION_RESOURCETAGSENTRY._serialized_start=4860
  _INFRASTRUCTURECONFIGURATION_RESOURCETAGSENTRY._serialized_end=4911
  _INFRASTRUCTURECONFIGURATION_TAGSENTRY._serialized_start=393
  _INFRASTRUCTURECONFIGURATION_TAGSENTRY._serialized_end=436
  _INFRASTRUCTURECONFIGURATIONS3LOGS._serialized_start=4959
  _INFRASTRUCTURECONFIGURATIONS3LOGS._serialized_end=5098
  _INFRASTRUCTURECONFIGURATIONLOGGING._serialized_start=5101
  _INFRASTRUCTURECONFIGURATIONLOGGING._serialized_end=5276
# @@protoc_insertion_point(module_scope)
