"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_App_containerApps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_APPS_FIELD_NUMBER: builtins.int
    CONTAINER_APPS_AUTH_CONFIGS_FIELD_NUMBER: builtins.int
    CONTAINER_APPS_SOURCECONTROLS_FIELD_NUMBER: builtins.int
    @property
    def container_apps(self) -> global___ContainerApps: ...
    @property
    def container_apps_auth_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAppsAuthConfigs]: ...
    @property
    def container_apps_sourcecontrols(self) -> global___ContainerAppsSourcecontrols: ...
    def __init__(
        self,
        *,
        container_apps: global___ContainerApps | None = ...,
        container_apps_auth_configs: collections.abc.Iterable[global___ContainerAppsAuthConfigs] | None = ...,
        container_apps_sourcecontrols: global___ContainerAppsSourcecontrols | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_apps", b"container_apps", "container_apps_sourcecontrols", b"container_apps_sourcecontrols"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_apps", b"container_apps", "container_apps_auth_configs", b"container_apps_auth_configs", "container_apps_sourcecontrols", b"container_apps_sourcecontrols"]) -> None: ...

global___Microsoft_App_containerApps = Microsoft_App_containerApps

@typing_extensions.final
class ContainerAppsSourcecontrols(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    GITHUB_ACTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    REPO_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    branch: builtins.str
    @property
    def github_action_configuration(self) -> global___GithubActionConfiguration: ...
    repo_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        branch: builtins.str = ...,
        github_action_configuration: global___GithubActionConfiguration | None = ...,
        repo_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["github_action_configuration", b"github_action_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "github_action_configuration", b"github_action_configuration", "name", b"name", "repo_url", b"repo_url", "resource_info", b"resource_info"]) -> None: ...

global___ContainerAppsSourcecontrols = ContainerAppsSourcecontrols

@typing_extensions.final
class GithubActionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_CREDENTIALS_FIELD_NUMBER: builtins.int
    CONTEXT_PATH_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    PUBLISH_TYPE_FIELD_NUMBER: builtins.int
    REGISTRY_INFO_FIELD_NUMBER: builtins.int
    RUNTIME_STACK_FIELD_NUMBER: builtins.int
    RUNTIME_VERSION_FIELD_NUMBER: builtins.int
    @property
    def azure_credentials(self) -> global___AzureCredentials: ...
    context_path: builtins.str
    image: builtins.str
    os: builtins.str
    publish_type: builtins.str
    @property
    def registry_info(self) -> global___RegistryInfo: ...
    runtime_stack: builtins.str
    runtime_version: builtins.str
    def __init__(
        self,
        *,
        azure_credentials: global___AzureCredentials | None = ...,
        context_path: builtins.str = ...,
        image: builtins.str = ...,
        os: builtins.str = ...,
        publish_type: builtins.str = ...,
        registry_info: global___RegistryInfo | None = ...,
        runtime_stack: builtins.str = ...,
        runtime_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_credentials", b"azure_credentials", "registry_info", b"registry_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_credentials", b"azure_credentials", "context_path", b"context_path", "image", b"image", "os", b"os", "publish_type", b"publish_type", "registry_info", b"registry_info", "runtime_stack", b"runtime_stack", "runtime_version", b"runtime_version"]) -> None: ...

global___GithubActionConfiguration = GithubActionConfiguration

@typing_extensions.final
class RegistryInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_PASSWORD_FIELD_NUMBER: builtins.int
    REGISTRY_URL_FIELD_NUMBER: builtins.int
    REGISTRY_USER_NAME_FIELD_NUMBER: builtins.int
    registry_password: builtins.str
    registry_url: builtins.str
    registry_user_name: builtins.str
    def __init__(
        self,
        *,
        registry_password: builtins.str = ...,
        registry_url: builtins.str = ...,
        registry_user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["registry_password", b"registry_password", "registry_url", b"registry_url", "registry_user_name", b"registry_user_name"]) -> None: ...

global___RegistryInfo = RegistryInfo

@typing_extensions.final
class AzureCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    subscription_id: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        subscription_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "subscription_id", b"subscription_id", "tenant_id", b"tenant_id"]) -> None: ...

global___AzureCredentials = AzureCredentials

@typing_extensions.final
class ContainerAppsAuthConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GLOBAL_VALIDATION_FIELD_NUMBER: builtins.int
    HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    IDENTITY_PROVIDERS_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def global_validation(self) -> global___GlobalValidation: ...
    @property
    def http_settings(self) -> global___HttpSettings: ...
    @property
    def identity_providers(self) -> global___IdentityProviders: ...
    @property
    def login(self) -> global___Login: ...
    @property
    def platform(self) -> global___AuthPlatform: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        global_validation: global___GlobalValidation | None = ...,
        http_settings: global___HttpSettings | None = ...,
        identity_providers: global___IdentityProviders | None = ...,
        login: global___Login | None = ...,
        platform: global___AuthPlatform | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["global_validation", b"global_validation", "http_settings", b"http_settings", "identity_providers", b"identity_providers", "login", b"login", "platform", b"platform", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["global_validation", b"global_validation", "http_settings", b"http_settings", "identity_providers", b"identity_providers", "login", b"login", "name", b"name", "platform", b"platform", "resource_info", b"resource_info"]) -> None: ...

global___ContainerAppsAuthConfigs = ContainerAppsAuthConfigs

@typing_extensions.final
class AuthPlatform(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    RUNTIME_VERSION_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    runtime_version: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        runtime_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "runtime_version", b"runtime_version"]) -> None: ...

global___AuthPlatform = AuthPlatform

@typing_extensions.final
class Login(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_EXTERNAL_REDIRECT_URLS_FIELD_NUMBER: builtins.int
    COOKIE_EXPIRATION_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    PRESERVE_URL_FRAGMENTS_FOR_LOGINS_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    @property
    def allowed_external_redirect_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def cookie_expiration(self) -> global___CookieExpiration: ...
    @property
    def nonce(self) -> global___Nonce: ...
    preserve_url_fragments_for_logins: builtins.bool
    @property
    def routes(self) -> global___LoginRoutes: ...
    def __init__(
        self,
        *,
        allowed_external_redirect_urls: collections.abc.Iterable[builtins.str] | None = ...,
        cookie_expiration: global___CookieExpiration | None = ...,
        nonce: global___Nonce | None = ...,
        preserve_url_fragments_for_logins: builtins.bool = ...,
        routes: global___LoginRoutes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cookie_expiration", b"cookie_expiration", "nonce", b"nonce", "routes", b"routes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_external_redirect_urls", b"allowed_external_redirect_urls", "cookie_expiration", b"cookie_expiration", "nonce", b"nonce", "preserve_url_fragments_for_logins", b"preserve_url_fragments_for_logins", "routes", b"routes"]) -> None: ...

global___Login = Login

@typing_extensions.final
class LoginRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGOUT_ENDPOINT_FIELD_NUMBER: builtins.int
    logout_endpoint: builtins.str
    def __init__(
        self,
        *,
        logout_endpoint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["logout_endpoint", b"logout_endpoint"]) -> None: ...

global___LoginRoutes = LoginRoutes

@typing_extensions.final
class Nonce(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NONCE_EXPIRATION_INTERVAL_FIELD_NUMBER: builtins.int
    VALIDATE_NONCE_FIELD_NUMBER: builtins.int
    nonce_expiration_interval: builtins.str
    validate_nonce: builtins.bool
    def __init__(
        self,
        *,
        nonce_expiration_interval: builtins.str = ...,
        validate_nonce: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nonce_expiration_interval", b"nonce_expiration_interval", "validate_nonce", b"validate_nonce"]) -> None: ...

global___Nonce = Nonce

@typing_extensions.final
class CookieExpiration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVENTION_FIELD_NUMBER: builtins.int
    TIME_TO_EXPIRATION_FIELD_NUMBER: builtins.int
    convention: builtins.str
    time_to_expiration: builtins.str
    def __init__(
        self,
        *,
        convention: builtins.str = ...,
        time_to_expiration: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["convention", b"convention", "time_to_expiration", b"time_to_expiration"]) -> None: ...

global___CookieExpiration = CookieExpiration

@typing_extensions.final
class IdentityProviders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CustomOpenIdConnectProvidersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APPLE_FIELD_NUMBER: builtins.int
    AZURE_ACTIVE_DIRECTORY_FIELD_NUMBER: builtins.int
    AZURE_STATIC_WEB_APPS_FIELD_NUMBER: builtins.int
    CUSTOM_OPEN_ID_CONNECT_PROVIDERS_FIELD_NUMBER: builtins.int
    FACEBOOK_FIELD_NUMBER: builtins.int
    GIT_HUB_FIELD_NUMBER: builtins.int
    GOOGLE_FIELD_NUMBER: builtins.int
    TWITTER_FIELD_NUMBER: builtins.int
    @property
    def apple(self) -> global___Apple: ...
    @property
    def azure_active_directory(self) -> global___AzureActiveDirectory: ...
    @property
    def azure_static_web_apps(self) -> global___AzureStaticWebApps: ...
    @property
    def custom_open_id_connect_providers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def facebook(self) -> global___Facebook: ...
    @property
    def git_hub(self) -> global___GitHub: ...
    @property
    def google(self) -> global___Google: ...
    @property
    def twitter(self) -> global___Twitter: ...
    def __init__(
        self,
        *,
        apple: global___Apple | None = ...,
        azure_active_directory: global___AzureActiveDirectory | None = ...,
        azure_static_web_apps: global___AzureStaticWebApps | None = ...,
        custom_open_id_connect_providers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        facebook: global___Facebook | None = ...,
        git_hub: global___GitHub | None = ...,
        google: global___Google | None = ...,
        twitter: global___Twitter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apple", b"apple", "azure_active_directory", b"azure_active_directory", "azure_static_web_apps", b"azure_static_web_apps", "facebook", b"facebook", "git_hub", b"git_hub", "google", b"google", "twitter", b"twitter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apple", b"apple", "azure_active_directory", b"azure_active_directory", "azure_static_web_apps", b"azure_static_web_apps", "custom_open_id_connect_providers", b"custom_open_id_connect_providers", "facebook", b"facebook", "git_hub", b"git_hub", "google", b"google", "twitter", b"twitter"]) -> None: ...

global___IdentityProviders = IdentityProviders

@typing_extensions.final
class Twitter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    REGISTRATION_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def registration(self) -> global___TwitterRegistration: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        registration: global___TwitterRegistration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["registration", b"registration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "registration", b"registration"]) -> None: ...

global___Twitter = Twitter

@typing_extensions.final
class TwitterRegistration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUMER_KEY_FIELD_NUMBER: builtins.int
    CONSUMER_SECRET_SETTING_NAME_FIELD_NUMBER: builtins.int
    consumer_key: builtins.str
    consumer_secret_setting_name: builtins.str
    def __init__(
        self,
        *,
        consumer_key: builtins.str = ...,
        consumer_secret_setting_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["consumer_key", b"consumer_key", "consumer_secret_setting_name", b"consumer_secret_setting_name"]) -> None: ...

global___TwitterRegistration = TwitterRegistration

@typing_extensions.final
class Google(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    REGISTRATION_FIELD_NUMBER: builtins.int
    VALIDATION_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def login(self) -> global___LoginScopes: ...
    @property
    def registration(self) -> global___ClientRegistration: ...
    @property
    def validation(self) -> global___AllowedAudiencesValidation: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        login: global___LoginScopes | None = ...,
        registration: global___ClientRegistration | None = ...,
        validation: global___AllowedAudiencesValidation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["login", b"login", "registration", b"registration", "validation", b"validation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "login", b"login", "registration", b"registration", "validation", b"validation"]) -> None: ...

global___Google = Google

@typing_extensions.final
class AllowedAudiencesValidation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_AUDIENCES_FIELD_NUMBER: builtins.int
    @property
    def allowed_audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_audiences: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_audiences", b"allowed_audiences"]) -> None: ...

global___AllowedAudiencesValidation = AllowedAudiencesValidation

@typing_extensions.final
class GitHub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    REGISTRATION_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def login(self) -> global___LoginScopes: ...
    @property
    def registration(self) -> global___ClientRegistration: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        login: global___LoginScopes | None = ...,
        registration: global___ClientRegistration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["login", b"login", "registration", b"registration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "login", b"login", "registration", b"registration"]) -> None: ...

global___GitHub = GitHub

@typing_extensions.final
class ClientRegistration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_SETTING_NAME_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret_setting_name: builtins.str
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret_setting_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret_setting_name", b"client_secret_setting_name"]) -> None: ...

global___ClientRegistration = ClientRegistration

@typing_extensions.final
class Facebook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    GRAPH_API_VERSION_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    REGISTRATION_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    graph_api_version: builtins.str
    @property
    def login(self) -> global___LoginScopes: ...
    @property
    def registration(self) -> global___AppRegistration: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        graph_api_version: builtins.str = ...,
        login: global___LoginScopes | None = ...,
        registration: global___AppRegistration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["login", b"login", "registration", b"registration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "graph_api_version", b"graph_api_version", "login", b"login", "registration", b"registration"]) -> None: ...

global___Facebook = Facebook

@typing_extensions.final
class AppRegistration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    APP_SECRET_SETTING_NAME_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    app_secret_setting_name: builtins.str
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        app_secret_setting_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "app_secret_setting_name", b"app_secret_setting_name"]) -> None: ...

global___AppRegistration = AppRegistration

@typing_extensions.final
class AzureStaticWebApps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    REGISTRATION_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def registration(self) -> global___AzureStaticWebAppsRegistration: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        registration: global___AzureStaticWebAppsRegistration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["registration", b"registration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "registration", b"registration"]) -> None: ...

global___AzureStaticWebApps = AzureStaticWebApps

@typing_extensions.final
class AzureStaticWebAppsRegistration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id"]) -> None: ...

global___AzureStaticWebAppsRegistration = AzureStaticWebAppsRegistration

@typing_extensions.final
class AzureActiveDirectory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    IS_AUTO_PROVISIONED_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    REGISTRATION_FIELD_NUMBER: builtins.int
    VALIDATION_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    is_auto_provisioned: builtins.bool
    @property
    def login(self) -> global___AzureActiveDirectoryLogin: ...
    @property
    def registration(self) -> global___AzureActiveDirectoryRegistration: ...
    @property
    def validation(self) -> global___AzureActiveDirectoryValidation: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        is_auto_provisioned: builtins.bool = ...,
        login: global___AzureActiveDirectoryLogin | None = ...,
        registration: global___AzureActiveDirectoryRegistration | None = ...,
        validation: global___AzureActiveDirectoryValidation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["login", b"login", "registration", b"registration", "validation", b"validation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "is_auto_provisioned", b"is_auto_provisioned", "login", b"login", "registration", b"registration", "validation", b"validation"]) -> None: ...

global___AzureActiveDirectory = AzureActiveDirectory

@typing_extensions.final
class AzureActiveDirectoryValidation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_AUDIENCES_FIELD_NUMBER: builtins.int
    DEFAULT_AUTHORIZATION_POLICY_FIELD_NUMBER: builtins.int
    JWT_CLAIM_CHECKS_FIELD_NUMBER: builtins.int
    @property
    def allowed_audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def default_authorization_policy(self) -> global___DefaultAuthorizationPolicy: ...
    @property
    def jwt_claim_checks(self) -> global___JwtClaimChecks: ...
    def __init__(
        self,
        *,
        allowed_audiences: collections.abc.Iterable[builtins.str] | None = ...,
        default_authorization_policy: global___DefaultAuthorizationPolicy | None = ...,
        jwt_claim_checks: global___JwtClaimChecks | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_authorization_policy", b"default_authorization_policy", "jwt_claim_checks", b"jwt_claim_checks"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_audiences", b"allowed_audiences", "default_authorization_policy", b"default_authorization_policy", "jwt_claim_checks", b"jwt_claim_checks"]) -> None: ...

global___AzureActiveDirectoryValidation = AzureActiveDirectoryValidation

@typing_extensions.final
class JwtClaimChecks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_CLIENT_APPLICATIONS_FIELD_NUMBER: builtins.int
    ALLOWED_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def allowed_client_applications(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allowed_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_client_applications: collections.abc.Iterable[builtins.str] | None = ...,
        allowed_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_client_applications", b"allowed_client_applications", "allowed_groups", b"allowed_groups"]) -> None: ...

global___JwtClaimChecks = JwtClaimChecks

@typing_extensions.final
class DefaultAuthorizationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_APPLICATIONS_FIELD_NUMBER: builtins.int
    ALLOWED_PRINCIPALS_FIELD_NUMBER: builtins.int
    @property
    def allowed_applications(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allowed_principals(self) -> global___AllowedPrincipals: ...
    def __init__(
        self,
        *,
        allowed_applications: collections.abc.Iterable[builtins.str] | None = ...,
        allowed_principals: global___AllowedPrincipals | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allowed_principals", b"allowed_principals"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_applications", b"allowed_applications", "allowed_principals", b"allowed_principals"]) -> None: ...

global___DefaultAuthorizationPolicy = DefaultAuthorizationPolicy

@typing_extensions.final
class AllowedPrincipals(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPS_FIELD_NUMBER: builtins.int
    IDENTITIES_FIELD_NUMBER: builtins.int
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def identities(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        identities: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["groups", b"groups", "identities", b"identities"]) -> None: ...

global___AllowedPrincipals = AllowedPrincipals

@typing_extensions.final
class AzureActiveDirectoryRegistration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_CERTIFICATE_ISSUER_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_CERTIFICATE_SUBJECT_ALTERNATIVE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_CERTIFICATE_THUMBPRINT_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_SETTING_NAME_FIELD_NUMBER: builtins.int
    OPEN_ID_ISSUER_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret_certificate_issuer: builtins.str
    client_secret_certificate_subject_alternative_name: builtins.str
    client_secret_certificate_thumbprint: builtins.str
    client_secret_setting_name: builtins.str
    open_id_issuer: builtins.str
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret_certificate_issuer: builtins.str = ...,
        client_secret_certificate_subject_alternative_name: builtins.str = ...,
        client_secret_certificate_thumbprint: builtins.str = ...,
        client_secret_setting_name: builtins.str = ...,
        open_id_issuer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret_certificate_issuer", b"client_secret_certificate_issuer", "client_secret_certificate_subject_alternative_name", b"client_secret_certificate_subject_alternative_name", "client_secret_certificate_thumbprint", b"client_secret_certificate_thumbprint", "client_secret_setting_name", b"client_secret_setting_name", "open_id_issuer", b"open_id_issuer"]) -> None: ...

global___AzureActiveDirectoryRegistration = AzureActiveDirectoryRegistration

@typing_extensions.final
class AzureActiveDirectoryLogin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_W_W_W_AUTHENTICATE_FIELD_NUMBER: builtins.int
    LOGIN_PARAMETERS_FIELD_NUMBER: builtins.int
    disable_w_w_w_authenticate: builtins.bool
    @property
    def login_parameters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        disable_w_w_w_authenticate: builtins.bool = ...,
        login_parameters: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_w_w_w_authenticate", b"disable_w_w_w_authenticate", "login_parameters", b"login_parameters"]) -> None: ...

global___AzureActiveDirectoryLogin = AzureActiveDirectoryLogin

@typing_extensions.final
class Apple(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    REGISTRATION_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def login(self) -> global___LoginScopes: ...
    @property
    def registration(self) -> global___AppleRegistration: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        login: global___LoginScopes | None = ...,
        registration: global___AppleRegistration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["login", b"login", "registration", b"registration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "login", b"login", "registration", b"registration"]) -> None: ...

global___Apple = Apple

@typing_extensions.final
class AppleRegistration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_SETTING_NAME_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret_setting_name: builtins.str
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret_setting_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret_setting_name", b"client_secret_setting_name"]) -> None: ...

global___AppleRegistration = AppleRegistration

@typing_extensions.final
class LoginScopes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCOPES_FIELD_NUMBER: builtins.int
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scopes", b"scopes"]) -> None: ...

global___LoginScopes = LoginScopes

@typing_extensions.final
class HttpSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORWARD_PROXY_FIELD_NUMBER: builtins.int
    REQUIRE_HTTPS_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    @property
    def forward_proxy(self) -> global___ForwardProxy: ...
    require_https: builtins.bool
    @property
    def routes(self) -> global___HttpSettingsRoutes: ...
    def __init__(
        self,
        *,
        forward_proxy: global___ForwardProxy | None = ...,
        require_https: builtins.bool = ...,
        routes: global___HttpSettingsRoutes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["forward_proxy", b"forward_proxy", "routes", b"routes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["forward_proxy", b"forward_proxy", "require_https", b"require_https", "routes", b"routes"]) -> None: ...

global___HttpSettings = HttpSettings

@typing_extensions.final
class HttpSettingsRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_PREFIX_FIELD_NUMBER: builtins.int
    api_prefix: builtins.str
    def __init__(
        self,
        *,
        api_prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_prefix", b"api_prefix"]) -> None: ...

global___HttpSettingsRoutes = HttpSettingsRoutes

@typing_extensions.final
class ForwardProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVENTION_FIELD_NUMBER: builtins.int
    CUSTOM_HOST_HEADER_NAME_FIELD_NUMBER: builtins.int
    CUSTOM_PROTO_HEADER_NAME_FIELD_NUMBER: builtins.int
    convention: builtins.str
    custom_host_header_name: builtins.str
    custom_proto_header_name: builtins.str
    def __init__(
        self,
        *,
        convention: builtins.str = ...,
        custom_host_header_name: builtins.str = ...,
        custom_proto_header_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["convention", b"convention", "custom_host_header_name", b"custom_host_header_name", "custom_proto_header_name", b"custom_proto_header_name"]) -> None: ...

global___ForwardProxy = ForwardProxy

@typing_extensions.final
class GlobalValidation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUDED_PATHS_FIELD_NUMBER: builtins.int
    REDIRECT_TO_PROVIDER_FIELD_NUMBER: builtins.int
    UNAUTHENTICATED_CLIENT_ACTION_FIELD_NUMBER: builtins.int
    @property
    def excluded_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    redirect_to_provider: builtins.str
    unauthenticated_client_action: builtins.str
    def __init__(
        self,
        *,
        excluded_paths: collections.abc.Iterable[builtins.str] | None = ...,
        redirect_to_provider: builtins.str = ...,
        unauthenticated_client_action: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["excluded_paths", b"excluded_paths", "redirect_to_provider", b"redirect_to_provider", "unauthenticated_client_action", b"unauthenticated_client_action"]) -> None: ...

global___GlobalValidation = GlobalValidation

@typing_extensions.final
class ContainerApps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    MANAGED_ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    WORKLOAD_PROFILE_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def configuration(self) -> global___Configuration: ...
    environment_id: builtins.str
    managed_environment_id: builtins.str
    @property
    def template(self) -> global___Template: ...
    workload_profile_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        configuration: global___Configuration | None = ...,
        environment_id: builtins.str = ...,
        managed_environment_id: builtins.str = ...,
        template: global___Template | None = ...,
        workload_profile_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "extended_location", b"extended_location", "identity", b"identity", "resource_info", b"resource_info", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "environment_id", b"environment_id", "extended_location", b"extended_location", "identity", b"identity", "location", b"location", "managed_environment_id", b"managed_environment_id", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "template", b"template", "workload_profile_type", b"workload_profile_type"]) -> None: ...

global___ContainerApps = ContainerApps

@typing_extensions.final
class Template(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINERS_FIELD_NUMBER: builtins.int
    INIT_CONTAINERS_FIELD_NUMBER: builtins.int
    REVISION_SUFFIX_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    @property
    def containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Container]: ...
    @property
    def init_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InitContainer]: ...
    revision_suffix: builtins.str
    @property
    def scale(self) -> global___Scale: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Volume]: ...
    def __init__(
        self,
        *,
        containers: collections.abc.Iterable[global___Container] | None = ...,
        init_containers: collections.abc.Iterable[global___InitContainer] | None = ...,
        revision_suffix: builtins.str = ...,
        scale: global___Scale | None = ...,
        volumes: collections.abc.Iterable[global___Volume] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["scale", b"scale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["containers", b"containers", "init_containers", b"init_containers", "revision_suffix", b"revision_suffix", "scale", b"scale", "volumes", b"volumes"]) -> None: ...

global___Template = Template

@typing_extensions.final
class Volume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STORAGE_NAME_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    storage_name: builtins.str
    storage_type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        storage_name: builtins.str = ...,
        storage_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "storage_name", b"storage_name", "storage_type", b"storage_type"]) -> None: ...

global___Volume = Volume

@typing_extensions.final
class Scale(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_REPLICAS_FIELD_NUMBER: builtins.int
    MIN_REPLICAS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    max_replicas: builtins.int
    min_replicas: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRule]: ...
    def __init__(
        self,
        *,
        max_replicas: builtins.int = ...,
        min_replicas: builtins.int = ...,
        rules: collections.abc.Iterable[global___ScaleRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_replicas", b"max_replicas", "min_replicas", b"min_replicas", "rules", b"rules"]) -> None: ...

global___Scale = Scale

@typing_extensions.final
class ScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_QUEUE_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TCP_FIELD_NUMBER: builtins.int
    @property
    def azure_queue(self) -> global___QueueScaleRule: ...
    @property
    def custom(self) -> global___CustomScaleRule: ...
    @property
    def http(self) -> global___HttpScaleRule: ...
    name: builtins.str
    @property
    def tcp(self) -> global___TcpScaleRule: ...
    def __init__(
        self,
        *,
        azure_queue: global___QueueScaleRule | None = ...,
        custom: global___CustomScaleRule | None = ...,
        http: global___HttpScaleRule | None = ...,
        name: builtins.str = ...,
        tcp: global___TcpScaleRule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_queue", b"azure_queue", "custom", b"custom", "http", b"http", "tcp", b"tcp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_queue", b"azure_queue", "custom", b"custom", "http", b"http", "name", b"name", "tcp", b"tcp"]) -> None: ...

global___ScaleRule = ScaleRule

@typing_extensions.final
class TcpScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTH_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRuleAuth]: ...
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        auth: collections.abc.Iterable[global___ScaleRuleAuth] | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "metadata", b"metadata"]) -> None: ...

global___TcpScaleRule = TcpScaleRule

@typing_extensions.final
class HttpScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTH_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRuleAuth]: ...
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        auth: collections.abc.Iterable[global___ScaleRuleAuth] | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "metadata", b"metadata"]) -> None: ...

global___HttpScaleRule = HttpScaleRule

@typing_extensions.final
class CustomScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTH_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRuleAuth]: ...
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        auth: collections.abc.Iterable[global___ScaleRuleAuth] | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "metadata", b"metadata", "type", b"type"]) -> None: ...

global___CustomScaleRule = CustomScaleRule

@typing_extensions.final
class QueueScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_FIELD_NUMBER: builtins.int
    QUEUE_LENGTH_FIELD_NUMBER: builtins.int
    QUEUE_NAME_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRuleAuth]: ...
    queue_length: builtins.int
    queue_name: builtins.str
    def __init__(
        self,
        *,
        auth: collections.abc.Iterable[global___ScaleRuleAuth] | None = ...,
        queue_length: builtins.int = ...,
        queue_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "queue_length", b"queue_length", "queue_name", b"queue_name"]) -> None: ...

global___QueueScaleRule = QueueScaleRule

@typing_extensions.final
class ScaleRuleAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_REF_FIELD_NUMBER: builtins.int
    TRIGGER_PARAMETER_FIELD_NUMBER: builtins.int
    secret_ref: builtins.str
    trigger_parameter: builtins.str
    def __init__(
        self,
        *,
        secret_ref: builtins.str = ...,
        trigger_parameter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_ref", b"secret_ref", "trigger_parameter", b"trigger_parameter"]) -> None: ...

global___ScaleRuleAuth = ScaleRuleAuth

@typing_extensions.final
class InitContainer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VOLUME_MOUNTS_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentVar]: ...
    image: builtins.str
    name: builtins.str
    @property
    def volume_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VolumeMount]: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        env: collections.abc.Iterable[global___EnvironmentVar] | None = ...,
        image: builtins.str = ...,
        name: builtins.str = ...,
        volume_mounts: collections.abc.Iterable[global___VolumeMount] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "command", b"command", "env", b"env", "image", b"image", "name", b"name", "volume_mounts", b"volume_mounts"]) -> None: ...

global___InitContainer = InitContainer

@typing_extensions.final
class Container(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROBES_FIELD_NUMBER: builtins.int
    VOLUME_MOUNTS_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentVar]: ...
    image: builtins.str
    name: builtins.str
    @property
    def probes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAppProbe]: ...
    @property
    def volume_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VolumeMount]: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        env: collections.abc.Iterable[global___EnvironmentVar] | None = ...,
        image: builtins.str = ...,
        name: builtins.str = ...,
        probes: collections.abc.Iterable[global___ContainerAppProbe] | None = ...,
        volume_mounts: collections.abc.Iterable[global___VolumeMount] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "command", b"command", "env", b"env", "image", b"image", "name", b"name", "probes", b"probes", "volume_mounts", b"volume_mounts"]) -> None: ...

global___Container = Container

@typing_extensions.final
class VolumeMount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOUNT_PATH_FIELD_NUMBER: builtins.int
    VOLUME_NAME_FIELD_NUMBER: builtins.int
    mount_path: builtins.str
    volume_name: builtins.str
    def __init__(
        self,
        *,
        mount_path: builtins.str = ...,
        volume_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount_path", b"mount_path", "volume_name", b"volume_name"]) -> None: ...

global___VolumeMount = VolumeMount

@typing_extensions.final
class ContainerAppProbe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILURE_THRESHOLD_FIELD_NUMBER: builtins.int
    HTTP_GET_FIELD_NUMBER: builtins.int
    INITIAL_DELAY_SECONDS_FIELD_NUMBER: builtins.int
    PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    SUCCESS_THRESHOLD_FIELD_NUMBER: builtins.int
    TCP_SOCKET_FIELD_NUMBER: builtins.int
    TERMINATION_GRACE_PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    failure_threshold: builtins.int
    @property
    def http_get(self) -> global___ContainerAppProbeHttpGet: ...
    initial_delay_seconds: builtins.int
    period_seconds: builtins.int
    success_threshold: builtins.int
    @property
    def tcp_socket(self) -> global___ContainerAppProbeTcpSocket: ...
    termination_grace_period_seconds: builtins.int
    timeout_seconds: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        failure_threshold: builtins.int = ...,
        http_get: global___ContainerAppProbeHttpGet | None = ...,
        initial_delay_seconds: builtins.int = ...,
        period_seconds: builtins.int = ...,
        success_threshold: builtins.int = ...,
        tcp_socket: global___ContainerAppProbeTcpSocket | None = ...,
        termination_grace_period_seconds: builtins.int = ...,
        timeout_seconds: builtins.int = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["http_get", b"http_get", "tcp_socket", b"tcp_socket"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_threshold", b"failure_threshold", "http_get", b"http_get", "initial_delay_seconds", b"initial_delay_seconds", "period_seconds", b"period_seconds", "success_threshold", b"success_threshold", "tcp_socket", b"tcp_socket", "termination_grace_period_seconds", b"termination_grace_period_seconds", "timeout_seconds", b"timeout_seconds", "type", b"type"]) -> None: ...

global___ContainerAppProbe = ContainerAppProbe

@typing_extensions.final
class ContainerAppProbeTcpSocket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.int
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port"]) -> None: ...

global___ContainerAppProbeTcpSocket = ContainerAppProbeTcpSocket

@typing_extensions.final
class ContainerAppProbeHttpGet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    HTTP_HEADERS_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    host: builtins.str
    @property
    def http_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAppProbeHttpGetHttpHeadersItem]: ...
    path: builtins.str
    port: builtins.int
    scheme: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        http_headers: collections.abc.Iterable[global___ContainerAppProbeHttpGetHttpHeadersItem] | None = ...,
        path: builtins.str = ...,
        port: builtins.int = ...,
        scheme: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "http_headers", b"http_headers", "path", b"path", "port", b"port", "scheme", b"scheme"]) -> None: ...

global___ContainerAppProbeHttpGet = ContainerAppProbeHttpGet

@typing_extensions.final
class ContainerAppProbeHttpGetHttpHeadersItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___ContainerAppProbeHttpGetHttpHeadersItem = ContainerAppProbeHttpGetHttpHeadersItem

@typing_extensions.final
class EnvironmentVar(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    secret_ref: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        secret_ref: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "secret_ref", b"secret_ref", "value", b"value"]) -> None: ...

global___EnvironmentVar = EnvironmentVar

@typing_extensions.final
class Configuration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_REVISIONS_MODE_FIELD_NUMBER: builtins.int
    DAPR_FIELD_NUMBER: builtins.int
    INGRESS_FIELD_NUMBER: builtins.int
    MAX_INACTIVE_REVISIONS_FIELD_NUMBER: builtins.int
    REGISTRIES_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    active_revisions_mode: builtins.str
    @property
    def dapr(self) -> global___Dapr: ...
    @property
    def ingress(self) -> global___Ingress: ...
    max_inactive_revisions: builtins.int
    @property
    def registries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistryCredentials]: ...
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Secret]: ...
    def __init__(
        self,
        *,
        active_revisions_mode: builtins.str = ...,
        dapr: global___Dapr | None = ...,
        ingress: global___Ingress | None = ...,
        max_inactive_revisions: builtins.int = ...,
        registries: collections.abc.Iterable[global___RegistryCredentials] | None = ...,
        secrets: collections.abc.Iterable[global___Secret] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dapr", b"dapr", "ingress", b"ingress"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active_revisions_mode", b"active_revisions_mode", "dapr", b"dapr", "ingress", b"ingress", "max_inactive_revisions", b"max_inactive_revisions", "registries", b"registries", "secrets", b"secrets"]) -> None: ...

global___Configuration = Configuration

@typing_extensions.final
class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___Secret = Secret

@typing_extensions.final
class RegistryCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_FIELD_NUMBER: builtins.int
    PASSWORD_SECRET_REF_FIELD_NUMBER: builtins.int
    SERVER_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    identity: builtins.str
    password_secret_ref: builtins.str
    server: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        identity: builtins.str = ...,
        password_secret_ref: builtins.str = ...,
        server: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "password_secret_ref", b"password_secret_ref", "server", b"server", "username", b"username"]) -> None: ...

global___RegistryCredentials = RegistryCredentials

@typing_extensions.final
class Ingress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_INSECURE_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAINS_FIELD_NUMBER: builtins.int
    EXPOSED_PORT_FIELD_NUMBER: builtins.int
    EXTERNAL_FIELD_NUMBER: builtins.int
    IP_SECURITY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    TARGET_PORT_FIELD_NUMBER: builtins.int
    TRAFFIC_FIELD_NUMBER: builtins.int
    TRANSPORT_FIELD_NUMBER: builtins.int
    allow_insecure: builtins.bool
    @property
    def custom_domains(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomDomain]: ...
    exposed_port: builtins.int
    external: builtins.bool
    @property
    def ip_security_restrictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IpSecurityRestrictionRule]: ...
    target_port: builtins.int
    @property
    def traffic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TrafficWeight]: ...
    transport: builtins.str
    def __init__(
        self,
        *,
        allow_insecure: builtins.bool = ...,
        custom_domains: collections.abc.Iterable[global___CustomDomain] | None = ...,
        exposed_port: builtins.int = ...,
        external: builtins.bool = ...,
        ip_security_restrictions: collections.abc.Iterable[global___IpSecurityRestrictionRule] | None = ...,
        target_port: builtins.int = ...,
        traffic: collections.abc.Iterable[global___TrafficWeight] | None = ...,
        transport: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_insecure", b"allow_insecure", "custom_domains", b"custom_domains", "exposed_port", b"exposed_port", "external", b"external", "ip_security_restrictions", b"ip_security_restrictions", "target_port", b"target_port", "traffic", b"traffic", "transport", b"transport"]) -> None: ...

global___Ingress = Ingress

@typing_extensions.final
class TrafficWeight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    LATEST_REVISION_FIELD_NUMBER: builtins.int
    REVISION_NAME_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    label: builtins.str
    latest_revision: builtins.bool
    revision_name: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        label: builtins.str = ...,
        latest_revision: builtins.bool = ...,
        revision_name: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["label", b"label", "latest_revision", b"latest_revision", "revision_name", b"revision_name", "weight", b"weight"]) -> None: ...

global___TrafficWeight = TrafficWeight

@typing_extensions.final
class IpSecurityRestrictionRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IP_ADDRESS_RANGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    action: builtins.str
    description: builtins.str
    ip_address_range: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        description: builtins.str = ...,
        ip_address_range: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "ip_address_range", b"ip_address_range", "name", b"name"]) -> None: ...

global___IpSecurityRestrictionRule = IpSecurityRestrictionRule

@typing_extensions.final
class CustomDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BINDING_TYPE_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    binding_type: builtins.str
    certificate_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        binding_type: builtins.str = ...,
        certificate_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["binding_type", b"binding_type", "certificate_id", b"certificate_id", "name", b"name"]) -> None: ...

global___CustomDomain = CustomDomain

@typing_extensions.final
class Dapr(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    APP_PORT_FIELD_NUMBER: builtins.int
    APP_PROTOCOL_FIELD_NUMBER: builtins.int
    ENABLE_API_LOGGING_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    HTTP_MAX_REQUEST_SIZE_FIELD_NUMBER: builtins.int
    HTTP_READ_BUFFER_SIZE_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    app_port: builtins.int
    app_protocol: builtins.str
    enable_api_logging: builtins.bool
    enabled: builtins.bool
    http_max_request_size: builtins.int
    http_read_buffer_size: builtins.int
    log_level: builtins.str
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        app_port: builtins.int = ...,
        app_protocol: builtins.str = ...,
        enable_api_logging: builtins.bool = ...,
        enabled: builtins.bool = ...,
        http_max_request_size: builtins.int = ...,
        http_read_buffer_size: builtins.int = ...,
        log_level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "app_port", b"app_port", "app_protocol", b"app_protocol", "enable_api_logging", b"enable_api_logging", "enabled", b"enabled", "http_max_request_size", b"http_max_request_size", "http_read_buffer_size", b"http_read_buffer_size", "log_level", b"log_level"]) -> None: ...

global___Dapr = Dapr

@typing_extensions.final
class ManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ManagedServiceIdentity = ManagedServiceIdentity

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation
