# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_synthetics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_synthetics.proto\x12\x1aoak9.tython.aws.synthetics\x1a\x13shared/shared.proto\"\xa4\x01\n\nCanaryCode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x0e\n\x06s3_key\x18\x03 \x01(\t\x12\x19\n\x11s3_object_version\x18\x04 \x01(\t\x12\x0e\n\x06script\x18\x05 \x01(\t\x12\x0f\n\x07handler\x18\x06 \x01(\t\"z\n\x0e\x43\x61narySchedule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x1b\n\x13\x64uration_in_seconds\x18\x03 \x01(\t\"\x8a\x01\n\x0f\x43\x61naryVPCConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x04 \x03(\t\"|\n\x0f\x43\x61naryRunConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12timeout_in_seconds\x18\x02 \x01(\x05\x12\x14\n\x0cmemory_in_mb\x18\x03 \x01(\x05\"\xea\x04\n\x06\x43\x61nary\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x34\n\x04\x63ode\x18\x03 \x01(\x0b\x32&.oak9.tython.aws.synthetics.CanaryCode\x12\x1c\n\x14\x61rtifact_s3_location\x18\x04 \x01(\t\x12<\n\x08schedule\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.synthetics.CanarySchedule\x12\x1a\n\x12\x65xecution_role_arn\x18\x06 \x01(\t\x12\x17\n\x0fruntime_version\x18\x07 \x01(\t\x12 \n\x18success_retention_period\x18\x08 \x01(\x05\x12 \n\x18\x66\x61ilure_retention_period\x18\t \x01(\x05\x12:\n\x04tags\x18\n \x03(\x0b\x32,.oak9.tython.aws.synthetics.Canary.TagsEntry\x12?\n\nvpc_config\x18\x0b \x01(\x0b\x32+.oak9.tython.aws.synthetics.CanaryVPCConfig\x12?\n\nrun_config\x18\x0c \x01(\x0b\x32+.oak9.tython.aws.synthetics.CanaryRunConfig\x12#\n\x1bstart_canary_after_creation\x18\r \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\nSynthetics\x12\x32\n\x06\x63\x61nary\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.synthetics.Canaryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_synthetics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CANARY_TAGSENTRY._options = None
  _CANARY_TAGSENTRY._serialized_options = b'8\001'
  _CANARYCODE._serialized_start=78
  _CANARYCODE._serialized_end=242
  _CANARYSCHEDULE._serialized_start=244
  _CANARYSCHEDULE._serialized_end=366
  _CANARYVPCCONFIG._serialized_start=369
  _CANARYVPCCONFIG._serialized_end=507
  _CANARYRUNCONFIG._serialized_start=509
  _CANARYRUNCONFIG._serialized_end=633
  _CANARY._serialized_start=636
  _CANARY._serialized_end=1254
  _CANARY_TAGSENTRY._serialized_start=1211
  _CANARY_TAGSENTRY._serialized_end=1254
  _SYNTHETICS._serialized_start=1256
  _SYNTHETICS._serialized_end=1320
# @@protoc_insertion_point(module_scope)
