# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_kubernetes_namespaced_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.apps import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_apps_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.autoscaling import v2_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_autoscaling_dot_v2__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.rbac import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_rbac_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.networking import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_networking_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8kubernetes/kubernetes_kubernetes_namespaced_bundle.proto\x12+sac_kubernetes.kubernetes_namespaced_bundle\x1a\x13shared/shared.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.apps.v1.proto\x1a\x35kubernetes/kubernetes_io.k8s.api.autoscaling.v2.proto\x1a.kubernetes/kubernetes_io.k8s.api.rbac.v1.proto\x1a\x34kubernetes/kubernetes_io.k8s.api.networking.v1.proto\"\xfa\x07\n\x15Kubernetes_Namespaced\x12\x35\n\x07\x62inding\x18\x01 \x03(\x0b\x32$.oak9.tython.k8s.api.core.v1.Binding\x12:\n\nconfig_map\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.ConfigMap\x12-\n\x03pod\x18\x03 \x03(\x0b\x32 .oak9.tython.k8s.api.core.v1.Pod\x12\x44\n\x0fservice_account\x18\x04 \x03(\x0b\x32+.oak9.tython.k8s.api.core.v1.ServiceAccount\x12\x35\n\x07service\x18\x05 \x03(\x0b\x32$.oak9.tython.k8s.api.core.v1.Service\x12:\n\ndaemon_set\x18\x06 \x03(\x0b\x32&.oak9.tython.k8s.api.apps.v1.DaemonSet\x12;\n\ndeployment\x18\x07 \x03(\x0b\x32\'.oak9.tython.k8s.api.apps.v1.Deployment\x12<\n\x0breplica_set\x18\x08 \x03(\x0b\x32\'.oak9.tython.k8s.api.apps.v1.ReplicaSet\x12>\n\x0cstateful_set\x18\t \x03(\x0b\x32(.oak9.tython.k8s.api.apps.v1.StatefulSet\x12^\n\x19horizontal_pod_autoscaler\x18\n \x03(\x0b\x32;.oak9.tython.k8s.api.autoscaling.v2.HorizontalPodAutoscaler\x12>\n\x0cpod_template\x18\x0b \x03(\x0b\x32(.oak9.tython.k8s.api.core.v1.PodTemplate\x12\x33\n\x06secret\x18\x0c \x03(\x0b\x32#.oak9.tython.k8s.api.core.v1.Secret\x12>\n\x0crole_binding\x18\r \x03(\x0b\x32(.oak9.tython.k8s.api.rbac.v1.RoleBinding\x12/\n\x04role\x18\x0e \x03(\x0b\x32!.oak9.tython.k8s.api.rbac.v1.Role\x12;\n\x07ingress\x18\x0f \x03(\x0b\x32*.oak9.tython.k8s.api.networking.v1.Ingress\x12H\n\x0enetwork_policy\x18\x10 \x03(\x0b\x32\x30.oak9.tython.k8s.api.networking.v1.NetworkPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_kubernetes_namespaced_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KUBERNETES_NAMESPACED._serialized_start=380
  _KUBERNETES_NAMESPACED._serialized_end=1398
# @@protoc_insertion_point(module_scope)
