# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_accessanalyzer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_accessanalyzer.proto\x12\x1eoak9.tython.aws.accessanalyzer\x1a\x13shared/shared.proto\"\x96\x01\n\x0e\x41nalyzerFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63ontains\x18\x02 \x03(\t\x12\n\n\x02\x65q\x18\x03 \x03(\t\x12\x0e\n\x06\x65xists\x18\x04 \x01(\x08\x12\x10\n\x08property\x18\x05 \x01(\t\x12\x0b\n\x03neq\x18\x06 \x03(\t\"\xa1\x01\n\x13\x41nalyzerArchiveRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12>\n\x06\x66ilter\x18\x02 \x03(\x0b\x32..oak9.tython.aws.accessanalyzer.AnalyzerFilter\x12\x11\n\trule_name\x18\x03 \x01(\t\"\xa3\x02\n\x08\x41nalyzer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\ranalyzer_name\x18\x02 \x01(\t\x12J\n\rarchive_rules\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.accessanalyzer.AnalyzerArchiveRule\x12@\n\x04tags\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.accessanalyzer.Analyzer.TagsEntry\x12\x0c\n\x04type\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x0e\x41\x63\x63\x65ssAnalyzer\x12:\n\x08\x61nalyzer\x18\x01 \x03(\x0b\x32(.oak9.tython.aws.accessanalyzer.Analyzerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_accessanalyzer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANALYZER_TAGSENTRY._options = None
  _ANALYZER_TAGSENTRY._serialized_options = b'8\001'
  _ANALYZERFILTER._serialized_start=86
  _ANALYZERFILTER._serialized_end=236
  _ANALYZERARCHIVERULE._serialized_start=239
  _ANALYZERARCHIVERULE._serialized_end=400
  _ANALYZER._serialized_start=403
  _ANALYZER._serialized_end=694
  _ANALYZER_TAGSENTRY._serialized_start=651
  _ANALYZER_TAGSENTRY._serialized_end=694
  _ACCESSANALYZER._serialized_start=696
  _ACCESSANALYZER._serialized_end=772
# @@protoc_insertion_point(module_scope)
