# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_kinesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_kinesis.proto\x12\x17oak9.tython.aws.kinesis\x1a\x13shared/shared.proto\"z\n\x16StreamStreamEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x65ncryption_type\x18\x02 \x01(\t\x12\x0e\n\x06key_id\x18\x03 \x01(\t\"\xb6\x02\n\x06Stream\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16retention_period_hours\x18\x03 \x01(\x05\x12\x13\n\x0bshard_count\x18\x04 \x01(\x05\x12J\n\x11stream_encryption\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.kinesis.StreamStreamEncryption\x12\x37\n\x04tags\x18\x06 \x03(\x0b\x32).oak9.tython.aws.kinesis.Stream.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x07Kinesis\x12/\n\x06stream\x18\x01 \x01(\x0b\x32\x1f.oak9.tython.aws.kinesis.Stream\"t\n\x0eStreamConsumer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rconsumer_name\x18\x02 \x01(\t\x12\x12\n\nstream_arn\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_kinesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STREAM_TAGSENTRY._options = None
  _STREAM_TAGSENTRY._serialized_options = b'8\001'
  _STREAMSTREAMENCRYPTION._serialized_start=71
  _STREAMSTREAMENCRYPTION._serialized_end=193
  _STREAM._serialized_start=196
  _STREAM._serialized_end=506
  _STREAM_TAGSENTRY._serialized_start=463
  _STREAM_TAGSENTRY._serialized_end=506
  _KINESIS._serialized_start=508
  _KINESIS._serialized_end=566
  _STREAMCONSUMER._serialized_start=568
  _STREAMCONSUMER._serialized_end=684
# @@protoc_insertion_point(module_scope)
