# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_pubsub.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_pubsub.proto\x12\x16oak9.tython.gcp.pubsub\x1a\x13shared/shared.proto\"P\n\x1ePubsubLiteReservationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf2\x01\n\x15PubsubLiteReservation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\x12\x1b\n\x13throughput_capacity\x18\x05 \x01(\x01\x12H\n\x08timeouts\x18\x06 \x01(\x0b\x32\x36.oak9.tython.gcp.pubsub.PubsubLiteReservationXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"E\n%PubsubLiteSubscriptionXDeliveryConfig\x12\x1c\n\x14\x64\x65livery_requirement\x18\x01 \x01(\t\"Q\n\x1fPubsubLiteSubscriptionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcc\x02\n\x16PubsubLiteSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\x12\r\n\x05topic\x18\x05 \x01(\t\x12\x0c\n\x04zone\x18\x06 \x01(\t\x12V\n\x0f\x64\x65livery_config\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.pubsub.PubsubLiteSubscriptionXDeliveryConfig\x12I\n\x08timeouts\x18\x08 \x01(\x0b\x32\x37.oak9.tython.gcp.pubsub.PubsubLiteSubscriptionXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"f\n(PubsubLiteTopicXPartitionConfigXCapacity\x12\x1b\n\x13publish_mib_per_sec\x18\x01 \x01(\x01\x12\x1d\n\x15subscribe_mib_per_sec\x18\x02 \x01(\x01\"\x84\x01\n\x1fPubsubLiteTopicXPartitionConfig\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12R\n\x08\x63\x61pacity\x18\x02 \x01(\x0b\x32@.oak9.tython.gcp.pubsub.PubsubLiteTopicXPartitionConfigXCapacity\"C\n!PubsubLiteTopicXReservationConfig\x12\x1e\n\x16throughput_reservation\x18\x01 \x01(\t\"N\n\x1fPubsubLiteTopicXRetentionConfig\x12\x1b\n\x13per_partition_bytes\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\"J\n\x18PubsubLiteTopicXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd4\x03\n\x0fPubsubLiteTopic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\x12\x0c\n\x04zone\x18\x05 \x01(\t\x12Q\n\x10partition_config\x18\x06 \x01(\x0b\x32\x37.oak9.tython.gcp.pubsub.PubsubLiteTopicXPartitionConfig\x12U\n\x12reservation_config\x18\x07 \x01(\x0b\x32\x39.oak9.tython.gcp.pubsub.PubsubLiteTopicXReservationConfig\x12Q\n\x10retention_config\x18\x08 \x01(\x0b\x32\x37.oak9.tython.gcp.pubsub.PubsubLiteTopicXRetentionConfig\x12\x42\n\x08timeouts\x18\t \x01(\x0b\x32\x30.oak9.tython.gcp.pubsub.PubsubLiteTopicXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"7\n\x15PubsubSchemaXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xd5\x01\n\x0cPubsubSchema\x12\x12\n\ndefinition\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12?\n\x08timeouts\x18\x06 \x01(\x0b\x32-.oak9.tython.gcp.pubsub.PubsubSchemaXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n#PubsubSubscriptionXDeadLetterPolicy\x12\x19\n\x11\x64\x65\x61\x64_letter_topic\x18\x01 \x01(\t\x12\x1d\n\x15max_delivery_attempts\x18\x02 \x01(\x01\"2\n#PubsubSubscriptionXExpirationPolicy\x12\x0b\n\x03ttl\x18\x01 \x01(\t\"Z\n\'PubsubSubscriptionXPushConfigXOidcToken\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x1d\n\x15service_account_email\x18\x02 \x01(\t\"\x99\x02\n\x1dPubsubSubscriptionXPushConfig\x12Y\n\nattributes\x18\x01 \x03(\x0b\x32\x45.oak9.tython.gcp.pubsub.PubsubSubscriptionXPushConfig.AttributesEntry\x12\x15\n\rpush_endpoint\x18\x02 \x01(\t\x12S\n\noidc_token\x18\x03 \x01(\x0b\x32?.oak9.tython.gcp.pubsub.PubsubSubscriptionXPushConfigXOidcToken\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n\x1ePubsubSubscriptionXRetryPolicy\x12\x17\n\x0fmaximum_backoff\x18\x01 \x01(\t\x12\x17\n\x0fminimum_backoff\x18\x02 \x01(\t\"M\n\x1bPubsubSubscriptionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc8\x06\n\x12PubsubSubscription\x12\x1c\n\x14\x61\x63k_deadline_seconds\x18\x01 \x01(\x01\x12$\n\x1c\x65nable_exactly_once_delivery\x18\x02 \x01(\x08\x12\x1f\n\x17\x65nable_message_ordering\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x06labels\x18\x06 \x03(\x0b\x32\x36.oak9.tython.gcp.pubsub.PubsubSubscription.LabelsEntry\x12\"\n\x1amessage_retention_duration\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x1d\n\x15retain_acked_messages\x18\n \x01(\x08\x12\r\n\x05topic\x18\x0b \x01(\t\x12W\n\x12\x64\x65\x61\x64_letter_policy\x18\x0c \x01(\x0b\x32;.oak9.tython.gcp.pubsub.PubsubSubscriptionXDeadLetterPolicy\x12V\n\x11\x65xpiration_policy\x18\r \x01(\x0b\x32;.oak9.tython.gcp.pubsub.PubsubSubscriptionXExpirationPolicy\x12J\n\x0bpush_config\x18\x0e \x01(\x0b\x32\x35.oak9.tython.gcp.pubsub.PubsubSubscriptionXPushConfig\x12L\n\x0cretry_policy\x18\x0f \x01(\x0b\x32\x36.oak9.tython.gcp.pubsub.PubsubSubscriptionXRetryPolicy\x12\x45\n\x08timeouts\x18\x10 \x01(\x0b\x32\x33.oak9.tython.gcp.pubsub.PubsubSubscriptionXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n&PubsubSubscriptionIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8a\x02\n\x1cPubsubSubscriptionIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x14\n\x0csubscription\x18\x06 \x01(\t\x12Q\n\tcondition\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.pubsub.PubsubSubscriptionIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n%PubsubSubscriptionIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x87\x02\n\x1bPubsubSubscriptionIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x14\n\x0csubscription\x18\x06 \x01(\t\x12P\n\tcondition\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.pubsub.PubsubSubscriptionIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xac\x01\n\x1bPubsubSubscriptionIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x14\n\x0csubscription\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"G\n PubsubTopicXMessageStoragePolicy\x12#\n\x1b\x61llowed_persistence_regions\x18\x01 \x03(\t\">\n\x1aPubsubTopicXSchemaSettings\x12\x10\n\x08\x65ncoding\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\"F\n\x14PubsubTopicXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x82\x04\n\x0bPubsubTopic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x02 \x01(\t\x12?\n\x06labels\x18\x03 \x03(\x0b\x32/.oak9.tython.gcp.pubsub.PubsubTopic.LabelsEntry\x12\"\n\x1amessage_retention_duration\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12X\n\x16message_storage_policy\x18\x07 \x01(\x0b\x32\x38.oak9.tython.gcp.pubsub.PubsubTopicXMessageStoragePolicy\x12K\n\x0fschema_settings\x18\x08 \x01(\x0b\x32\x32.oak9.tython.gcp.pubsub.PubsubTopicXSchemaSettings\x12>\n\x08timeouts\x18\t \x01(\x0b\x32,.oak9.tython.gcp.pubsub.PubsubTopicXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x1fPubsubTopicIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf5\x01\n\x15PubsubTopicIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\r\n\x05topic\x18\x06 \x01(\t\x12J\n\tcondition\x18\x07 \x01(\x0b\x32\x37.oak9.tython.gcp.pubsub.PubsubTopicIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"X\n\x1ePubsubTopicIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf2\x01\n\x14PubsubTopicIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\r\n\x05topic\x18\x06 \x01(\t\x12I\n\tcondition\x18\x07 \x01(\x0b\x32\x36.oak9.tython.gcp.pubsub.PubsubTopicIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9e\x01\n\x14PubsubTopicIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\r\n\x05topic\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_pubsub_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG_ATTRIBUTESENTRY._options = None
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _PUBSUBSUBSCRIPTION_LABELSENTRY._options = None
  _PUBSUBSUBSCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _PUBSUBTOPIC_LABELSENTRY._options = None
  _PUBSUBTOPIC_LABELSENTRY._serialized_options = b'8\001'
  _PUBSUBLITERESERVATIONXTIMEOUTS._serialized_start=69
  _PUBSUBLITERESERVATIONXTIMEOUTS._serialized_end=149
  _PUBSUBLITERESERVATION._serialized_start=152
  _PUBSUBLITERESERVATION._serialized_end=394
  _PUBSUBLITESUBSCRIPTIONXDELIVERYCONFIG._serialized_start=396
  _PUBSUBLITESUBSCRIPTIONXDELIVERYCONFIG._serialized_end=465
  _PUBSUBLITESUBSCRIPTIONXTIMEOUTS._serialized_start=467
  _PUBSUBLITESUBSCRIPTIONXTIMEOUTS._serialized_end=548
  _PUBSUBLITESUBSCRIPTION._serialized_start=551
  _PUBSUBLITESUBSCRIPTION._serialized_end=883
  _PUBSUBLITETOPICXPARTITIONCONFIGXCAPACITY._serialized_start=885
  _PUBSUBLITETOPICXPARTITIONCONFIGXCAPACITY._serialized_end=987
  _PUBSUBLITETOPICXPARTITIONCONFIG._serialized_start=990
  _PUBSUBLITETOPICXPARTITIONCONFIG._serialized_end=1122
  _PUBSUBLITETOPICXRESERVATIONCONFIG._serialized_start=1124
  _PUBSUBLITETOPICXRESERVATIONCONFIG._serialized_end=1191
  _PUBSUBLITETOPICXRETENTIONCONFIG._serialized_start=1193
  _PUBSUBLITETOPICXRETENTIONCONFIG._serialized_end=1271
  _PUBSUBLITETOPICXTIMEOUTS._serialized_start=1273
  _PUBSUBLITETOPICXTIMEOUTS._serialized_end=1347
  _PUBSUBLITETOPIC._serialized_start=1350
  _PUBSUBLITETOPIC._serialized_end=1818
  _PUBSUBSCHEMAXTIMEOUTS._serialized_start=1820
  _PUBSUBSCHEMAXTIMEOUTS._serialized_end=1875
  _PUBSUBSCHEMA._serialized_start=1878
  _PUBSUBSCHEMA._serialized_end=2091
  _PUBSUBSUBSCRIPTIONXDEADLETTERPOLICY._serialized_start=2093
  _PUBSUBSUBSCRIPTIONXDEADLETTERPOLICY._serialized_end=2188
  _PUBSUBSUBSCRIPTIONXEXPIRATIONPOLICY._serialized_start=2190
  _PUBSUBSUBSCRIPTIONXEXPIRATIONPOLICY._serialized_end=2240
  _PUBSUBSUBSCRIPTIONXPUSHCONFIGXOIDCTOKEN._serialized_start=2242
  _PUBSUBSUBSCRIPTIONXPUSHCONFIGXOIDCTOKEN._serialized_end=2332
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG._serialized_start=2335
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG._serialized_end=2616
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG_ATTRIBUTESENTRY._serialized_start=2567
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG_ATTRIBUTESENTRY._serialized_end=2616
  _PUBSUBSUBSCRIPTIONXRETRYPOLICY._serialized_start=2618
  _PUBSUBSUBSCRIPTIONXRETRYPOLICY._serialized_end=2700
  _PUBSUBSUBSCRIPTIONXTIMEOUTS._serialized_start=2702
  _PUBSUBSUBSCRIPTIONXTIMEOUTS._serialized_end=2779
  _PUBSUBSUBSCRIPTION._serialized_start=2782
  _PUBSUBSUBSCRIPTION._serialized_end=3622
  _PUBSUBSUBSCRIPTION_LABELSENTRY._serialized_start=3577
  _PUBSUBSUBSCRIPTION_LABELSENTRY._serialized_end=3622
  _PUBSUBSUBSCRIPTIONIAMBINDINGXCONDITION._serialized_start=3624
  _PUBSUBSUBSCRIPTIONIAMBINDINGXCONDITION._serialized_end=3720
  _PUBSUBSUBSCRIPTIONIAMBINDING._serialized_start=3723
  _PUBSUBSUBSCRIPTIONIAMBINDING._serialized_end=3989
  _PUBSUBSUBSCRIPTIONIAMMEMBERXCONDITION._serialized_start=3991
  _PUBSUBSUBSCRIPTIONIAMMEMBERXCONDITION._serialized_end=4086
  _PUBSUBSUBSCRIPTIONIAMMEMBER._serialized_start=4089
  _PUBSUBSUBSCRIPTIONIAMMEMBER._serialized_end=4352
  _PUBSUBSUBSCRIPTIONIAMPOLICY._serialized_start=4355
  _PUBSUBSUBSCRIPTIONIAMPOLICY._serialized_end=4527
  _PUBSUBTOPICXMESSAGESTORAGEPOLICY._serialized_start=4529
  _PUBSUBTOPICXMESSAGESTORAGEPOLICY._serialized_end=4600
  _PUBSUBTOPICXSCHEMASETTINGS._serialized_start=4602
  _PUBSUBTOPICXSCHEMASETTINGS._serialized_end=4664
  _PUBSUBTOPICXTIMEOUTS._serialized_start=4666
  _PUBSUBTOPICXTIMEOUTS._serialized_end=4736
  _PUBSUBTOPIC._serialized_start=4739
  _PUBSUBTOPIC._serialized_end=5253
  _PUBSUBTOPIC_LABELSENTRY._serialized_start=3577
  _PUBSUBTOPIC_LABELSENTRY._serialized_end=3622
  _PUBSUBTOPICIAMBINDINGXCONDITION._serialized_start=5255
  _PUBSUBTOPICIAMBINDINGXCONDITION._serialized_end=5344
  _PUBSUBTOPICIAMBINDING._serialized_start=5347
  _PUBSUBTOPICIAMBINDING._serialized_end=5592
  _PUBSUBTOPICIAMMEMBERXCONDITION._serialized_start=5594
  _PUBSUBTOPICIAMMEMBERXCONDITION._serialized_end=5682
  _PUBSUBTOPICIAMMEMBER._serialized_start=5685
  _PUBSUBTOPICIAMMEMBER._serialized_end=5927
  _PUBSUBTOPICIAMPOLICY._serialized_start=5930
  _PUBSUBTOPICIAMPOLICY._serialized_end=6088
# @@protoc_insertion_point(module_scope)
