# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg import runtime_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_runtime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x12-oak9.tython.k8s.apimachinery.pkg.apis.meta.v1\x1a\x13shared/shared.proto\x1a;kubernetes/kubernetes_io.k8s.apimachinery.pkg.runtime.proto\"\xa5\x03\n\x08\x41PIGroup\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x62\n\x11preferred_version\x18\x04 \x01(\x0b\x32G.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery\x12p\n\x1eserver_address_by_client_cidrs\x18\x05 \x03(\x0b\x32H.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR\x12Y\n\x08versions\x18\x06 \x03(\x0b\x32G.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x01\n\x0c\x41PIGroupList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12G\n\x06groups\x18\x02 \x03(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.APIGroup\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x02\n\x0b\x41PIResource\x12\x12\n\ncategories\x18\x01 \x03(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x12\n\nnamespaced\x18\x05 \x01(\x08\x12\x13\n\x0bshort_names\x18\x06 \x03(\t\x12\x15\n\rsingular_name\x18\x07 \x01(\t\x12\x1c\n\x14storage_version_hash\x18\x08 \x01(\t\x12\r\n\x05verbs\x18\t \x03(\t\x12\x0f\n\x07version\x18\n \x01(\t\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd3\x01\n\x0f\x41PIResourceList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x15\n\rgroup_version\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12M\n\tresources\x18\x04 \x03(\x0b\x32:.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.APIResource\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\x0b\x41PIVersions\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12p\n\x1eserver_address_by_client_cidrs\x18\x03 \x03(\x0b\x32H.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR\x12\x10\n\x08versions\x18\x04 \x03(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf3\x01\n\tCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x1b\n\x13observed_generation\x18\x03 \x01(\x05\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x02\n\rDeleteOptions\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x02 \x03(\t\x12\x1c\n\x14grace_period_seconds\x18\x03 \x01(\x05\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x19\n\x11orphan_dependents\x18\x05 \x01(\x08\x12S\n\rpreconditions\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Preconditions\x12\x1a\n\x12propagation_policy\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n\x08\x46ieldsV1\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"{\n\x18GroupVersionForDiscovery\x12\x15\n\rgroup_version\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc5\x02\n\rLabelSelector\x12\x62\n\x11match_expressions\x18\x01 \x03(\x0b\x32G.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement\x12\x63\n\x0cmatch_labels\x18\x02 \x03(\x0b\x32M.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10MatchLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x18LabelSelectorRequirement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa0\x01\n\x08ListMeta\x12\x10\n\x08\x63ontinue\x18\x01 \x01(\t\x12\x1c\n\x14remaining_item_count\x18\x02 \x01(\x05\x12\x18\n\x10resource_version\x18\x03 \x01(\t\x12\x11\n\tself_link\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x02\n\x12ManagedFieldsEntry\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x13\n\x0b\x66ields_type\x18\x02 \x01(\t\x12J\n\tfields_v1\x18\x03 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.FieldsV1\x12\x0f\n\x07manager\x18\x04 \x01(\t\x12\x11\n\toperation\x18\x05 \x01(\t\x12\x13\n\x0bsubresource\x18\x06 \x01(\t\x12\x41\n\x04time\x18\x07 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"D\n\tMicroTime\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf7\x06\n\nObjectMeta\x12_\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32J.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry\x12O\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12%\n\x1d\x64\x65letion_grace_period_seconds\x18\x03 \x01(\x05\x12O\n\x12\x64\x65letion_timestamp\x18\x04 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x12\n\nfinalizers\x18\x05 \x03(\t\x12\x15\n\rgenerate_name\x18\x06 \x01(\t\x12\x12\n\ngeneration\x18\x07 \x01(\x05\x12U\n\x06labels\x18\x08 \x03(\x0b\x32\x45.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry\x12Y\n\x0emanaged_fields\x18\t \x03(\x0b\x32\x41.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry\x12\x0c\n\x04name\x18\n \x01(\t\x12\x11\n\tnamespace\x18\x0b \x01(\t\x12W\n\x10owner_references\x18\x0c \x03(\x0b\x32=.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.OwnerReference\x12\x18\n\x10resource_version\x18\r \x01(\t\x12\x11\n\tself_link\x18\x0e \x01(\t\x12\x0b\n\x03uid\x18\x0f \x01(\t\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb9\x01\n\x0eOwnerReference\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x1c\n\x14\x62lock_owner_deletion\x18\x02 \x01(\x08\x12\x12\n\ncontroller\x18\x03 \x01(\x08\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"@\n\x05Patch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"o\n\rPreconditions\x12\x18\n\x10resource_version\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x01\n\x19ServerAddressByClientCIDR\x12\x13\n\x0b\x63lient_cidr\x18\x01 \x01(\t\x12\x16\n\x0eserver_address\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbd\x02\n\x06Status\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12M\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.StatusDetails\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12I\n\x08metadata\x18\x06 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x0e\n\x06reason\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"v\n\x0bStatusCause\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe9\x01\n\rStatusDetails\x12J\n\x06\x63\x61uses\x18\x01 \x03(\x0b\x32:.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.StatusCause\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13retry_after_seconds\x18\x05 \x01(\x05\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"?\n\x04Time\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x01\n\nWatchEvent\x12\x46\n\x06object\x18\x01 \x01(\x0b\x32\x36.oak9.tython.k8s.apimachinery.pkg.runtime.RawExtension\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LABELSELECTOR_MATCHLABELSENTRY._options = None
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_options = b'8\001'
  _OBJECTMETA_ANNOTATIONSENTRY._options = None
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _OBJECTMETA_LABELSENTRY._options = None
  _OBJECTMETA_LABELSENTRY._serialized_options = b'8\001'
  _APIGROUP._serialized_start=198
  _APIGROUP._serialized_end=619
  _APIGROUPLIST._serialized_start=622
  _APIGROUPLIST._serialized_end=801
  _APIRESOURCE._serialized_start=804
  _APIRESOURCE._serialized_end=1063
  _APIRESOURCELIST._serialized_start=1066
  _APIRESOURCELIST._serialized_end=1277
  _APIVERSIONS._serialized_start=1280
  _APIVERSIONS._serialized_end=1517
  _CONDITION._serialized_start=1520
  _CONDITION._serialized_end=1763
  _DELETEOPTIONS._serialized_start=1766
  _DELETEOPTIONS._serialized_end=2060
  _FIELDSV1._serialized_start=2062
  _FIELDSV1._serialized_end=2129
  _GROUPVERSIONFORDISCOVERY._serialized_start=2131
  _GROUPVERSIONFORDISCOVERY._serialized_end=2254
  _LABELSELECTOR._serialized_start=2257
  _LABELSELECTOR._serialized_end=2582
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_start=2532
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_end=2582
  _LABELSELECTORREQUIREMENT._serialized_start=2585
  _LABELSELECTORREQUIREMENT._serialized_end=2715
  _LISTMETA._serialized_start=2718
  _LISTMETA._serialized_end=2878
  _MANAGEDFIELDSENTRY._serialized_start=2881
  _MANAGEDFIELDSENTRY._serialized_end=3200
  _MICROTIME._serialized_start=3202
  _MICROTIME._serialized_end=3270
  _OBJECTMETA._serialized_start=3273
  _OBJECTMETA._serialized_end=4160
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_start=4063
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_end=4113
  _OBJECTMETA_LABELSENTRY._serialized_start=4115
  _OBJECTMETA_LABELSENTRY._serialized_end=4160
  _OWNERREFERENCE._serialized_start=4163
  _OWNERREFERENCE._serialized_end=4348
  _PATCH._serialized_start=4350
  _PATCH._serialized_end=4414
  _PRECONDITIONS._serialized_start=4416
  _PRECONDITIONS._serialized_end=4527
  _SERVERADDRESSBYCLIENTCIDR._serialized_start=4530
  _SERVERADDRESSBYCLIENTCIDR._serialized_end=4659
  _STATUS._serialized_start=4662
  _STATUS._serialized_end=4979
  _STATUSCAUSE._serialized_start=4981
  _STATUSCAUSE._serialized_end=5099
  _STATUSDETAILS._serialized_start=5102
  _STATUSDETAILS._serialized_end=5335
  _TIME._serialized_start=5337
  _TIME._serialized_end=5400
  _WATCHEVENT._serialized_start=5403
  _WATCHEVENT._serialized_end=5558
# @@protoc_insertion_point(module_scope)
