# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_scc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_scc.proto\x12\x13oak9.tython.gcp.scc\x1a\x13shared/shared.proto\"7\n%SccNotificationConfigXStreamingConfig\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\"P\n\x1eSccNotificationConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf4\x02\n\x15SccNotificationConfig\x12\x11\n\tconfig_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0corganization\x18\x05 \x01(\t\x12\x14\n\x0cpubsub_topic\x18\x06 \x01(\t\x12\x17\n\x0fservice_account\x18\x07 \x01(\t\x12T\n\x10streaming_config\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.scc.SccNotificationConfigXStreamingConfig\x12\x45\n\x08timeouts\x18\t \x01(\x0b\x32\x33.oak9.tython.gcp.scc.SccNotificationConfigXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"D\n\x12SccSourceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xda\x01\n\tSccSource\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0corganization\x18\x05 \x01(\t\x12\x39\n\x08timeouts\x18\x06 \x01(\x0b\x32\'.oak9.tython.gcp.scc.SccSourceXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_scc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCCNOTIFICATIONCONFIGXSTREAMINGCONFIG._serialized_start=63
  _SCCNOTIFICATIONCONFIGXSTREAMINGCONFIG._serialized_end=118
  _SCCNOTIFICATIONCONFIGXTIMEOUTS._serialized_start=120
  _SCCNOTIFICATIONCONFIGXTIMEOUTS._serialized_end=200
  _SCCNOTIFICATIONCONFIG._serialized_start=203
  _SCCNOTIFICATIONCONFIG._serialized_end=575
  _SCCSOURCEXTIMEOUTS._serialized_start=577
  _SCCSOURCEXTIMEOUTS._serialized_end=645
  _SCCSOURCE._serialized_start=648
  _SCCSOURCE._serialized_end=866
# @@protoc_insertion_point(module_scope)
