# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgcp/gcp_compute_network.proto\x12\x1foak9.tython.gcp.compute_network\x1a\x13shared/shared.proto\"I\n\x17\x43omputeNetworkXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xaa\x03\n\x0e\x43omputeNetwork\x12\x1f\n\x17\x61uto_create_subnetworks\x18\x01 \x01(\x08\x12\'\n\x1f\x64\x65lete_default_routes_on_create\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12 \n\x18\x65nable_ula_internal_ipv6\x18\x04 \x01(\x08\x12\x14\n\x0cgateway_ipv4\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x1b\n\x13internal_ipv6_range\x18\x07 \x01(\t\x12\x0b\n\x03mtu\x18\x08 \x01(\x01\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\x14\n\x0crouting_mode\x18\x0b \x01(\t\x12\x11\n\tself_link\x18\x0c \x01(\t\x12J\n\x08timeouts\x18\r \x01(\x0b\x32\x38.oak9.tython.gcp.compute_network.ComputeNetworkXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"A\n\x1f\x43omputeNetworkEndpointXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xa4\x02\n\x16\x43omputeNetworkEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x12\n\nip_address\x18\x03 \x01(\t\x12\x1e\n\x16network_endpoint_group\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x01\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12R\n\x08timeouts\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.compute_network.ComputeNetworkEndpointXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"F\n$ComputeNetworkEndpointGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xf8\x02\n\x1b\x43omputeNetworkEndpointGroup\x12\x14\n\x0c\x64\x65\x66\x61ult_port\x18\x01 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x1d\n\x15network_endpoint_type\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x01\x12\x12\n\nsubnetwork\x18\n \x01(\t\x12\x0c\n\x04zone\x18\x0b \x01(\t\x12W\n\x08timeouts\x18\x0c \x01(\x0b\x32\x45.oak9.tython.gcp.compute_network.ComputeNetworkEndpointGroupXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x1e\x43omputeNetworkPeeringXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa0\x03\n\x15\x43omputeNetworkPeering\x12\x1c\n\x14\x65xport_custom_routes\x18\x01 \x01(\x08\x12+\n#export_subnet_routes_with_public_ip\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x1c\n\x14import_custom_routes\x18\x04 \x01(\x08\x12+\n#import_subnet_routes_with_public_ip\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07network\x18\x07 \x01(\t\x12\x14\n\x0cpeer_network\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12\x15\n\rstate_details\x18\n \x01(\t\x12Q\n\x08timeouts\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.compute_network.ComputeNetworkPeeringXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n*ComputeNetworkPeeringRoutesConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb6\x02\n!ComputeNetworkPeeringRoutesConfig\x12\x1c\n\x14\x65xport_custom_routes\x18\x01 \x01(\x08\x12\n\n\x02id\x18\x02 \x01(\t\x12\x1c\n\x14import_custom_routes\x18\x03 \x01(\x08\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x0f\n\x07peering\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12]\n\x08timeouts\x18\x07 \x01(\x0b\x32K.oak9.tython.gcp.compute_network.ComputeNetworkPeeringRoutesConfigXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_network_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTENETWORKXTIMEOUTS._serialized_start=87
  _COMPUTENETWORKXTIMEOUTS._serialized_end=160
  _COMPUTENETWORK._serialized_start=163
  _COMPUTENETWORK._serialized_end=589
  _COMPUTENETWORKENDPOINTXTIMEOUTS._serialized_start=591
  _COMPUTENETWORKENDPOINTXTIMEOUTS._serialized_end=656
  _COMPUTENETWORKENDPOINT._serialized_start=659
  _COMPUTENETWORKENDPOINT._serialized_end=951
  _COMPUTENETWORKENDPOINTGROUPXTIMEOUTS._serialized_start=953
  _COMPUTENETWORKENDPOINTGROUPXTIMEOUTS._serialized_end=1023
  _COMPUTENETWORKENDPOINTGROUP._serialized_start=1026
  _COMPUTENETWORKENDPOINTGROUP._serialized_end=1402
  _COMPUTENETWORKPEERINGXTIMEOUTS._serialized_start=1404
  _COMPUTENETWORKPEERINGXTIMEOUTS._serialized_end=1484
  _COMPUTENETWORKPEERING._serialized_start=1487
  _COMPUTENETWORKPEERING._serialized_end=1903
  _COMPUTENETWORKPEERINGROUTESCONFIGXTIMEOUTS._serialized_start=1905
  _COMPUTENETWORKPEERINGROUTESCONFIGXTIMEOUTS._serialized_end=1997
  _COMPUTENETWORKPEERINGROUTESCONFIG._serialized_start=2000
  _COMPUTENETWORKPEERINGROUTESCONFIG._serialized_end=2310
# @@protoc_insertion_point(module_scope)
