# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_compute_firewall_policy_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_firewall_pb2 as gcp_dot_gcp__compute__firewall__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3gcp/gcp_google_compute_firewall_policy_bundle.proto\x12\x35oak9.tython.gcp.google_compute_firewall_policy_bundle\x1a\x13shared/shared.proto\x1a\x1egcp/gcp_compute_firewall.proto\"\xcb\x02\n\x1bGoogleComputeFirewallPolicy\x12X\n\x17\x63ompute_firewall_policy\x18\x01 \x01(\x0b\x32\x37.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicy\x12o\n#compute_firewall_policy_association\x18\x02 \x03(\x0b\x32\x42.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyAssociation\x12\x61\n\x1c\x63ompute_firewall_policy_rule\x18\x03 \x03(\x0b\x32;.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyRuleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_compute_firewall_policy_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECOMPUTEFIREWALLPOLICY._serialized_start=164
  _GOOGLECOMPUTEFIREWALLPOLICY._serialized_end=495
# @@protoc_insertion_point(module_scope)
