"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeRouteXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeRouteXTimeouts = ComputeRouteXTimeouts

@typing_extensions.final
class ComputeRoute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEST_RANGE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NEXT_HOP_GATEWAY_FIELD_NUMBER: builtins.int
    NEXT_HOP_ILB_FIELD_NUMBER: builtins.int
    NEXT_HOP_INSTANCE_FIELD_NUMBER: builtins.int
    NEXT_HOP_INSTANCE_ZONE_FIELD_NUMBER: builtins.int
    NEXT_HOP_IP_FIELD_NUMBER: builtins.int
    NEXT_HOP_NETWORK_FIELD_NUMBER: builtins.int
    NEXT_HOP_VPN_TUNNEL_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    dest_range: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    next_hop_gateway: builtins.str
    next_hop_ilb: builtins.str
    next_hop_instance: builtins.str
    next_hop_instance_zone: builtins.str
    next_hop_ip: builtins.str
    next_hop_network: builtins.str
    next_hop_vpn_tunnel: builtins.str
    priority: builtins.float
    project: builtins.str
    self_link: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def timeouts(self) -> global___ComputeRouteXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        dest_range: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        next_hop_gateway: builtins.str = ...,
        next_hop_ilb: builtins.str = ...,
        next_hop_instance: builtins.str = ...,
        next_hop_instance_zone: builtins.str = ...,
        next_hop_ip: builtins.str = ...,
        next_hop_network: builtins.str = ...,
        next_hop_vpn_tunnel: builtins.str = ...,
        priority: builtins.float = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        timeouts: global___ComputeRouteXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "dest_range", b"dest_range", "id", b"id", "name", b"name", "network", b"network", "next_hop_gateway", b"next_hop_gateway", "next_hop_ilb", b"next_hop_ilb", "next_hop_instance", b"next_hop_instance", "next_hop_instance_zone", b"next_hop_instance_zone", "next_hop_ip", b"next_hop_ip", "next_hop_network", b"next_hop_network", "next_hop_vpn_tunnel", b"next_hop_vpn_tunnel", "priority", b"priority", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "tags", b"tags", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRoute = ComputeRoute
