"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SlackChannelConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SLACK_WORKSPACE_ID_FIELD_NUMBER: builtins.int
    SLACK_CHANNEL_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_NAME_FIELD_NUMBER: builtins.int
    IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    SNS_TOPIC_ARNS_FIELD_NUMBER: builtins.int
    LOGGING_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    slack_workspace_id: builtins.str
    slack_channel_id: builtins.str
    configuration_name: builtins.str
    iam_role_arn: builtins.str
    @property
    def sns_topic_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    logging_level: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        slack_workspace_id: builtins.str = ...,
        slack_channel_id: builtins.str = ...,
        configuration_name: builtins.str = ...,
        iam_role_arn: builtins.str = ...,
        sns_topic_arns: collections.abc.Iterable[builtins.str] | None = ...,
        logging_level: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration_name", b"configuration_name", "iam_role_arn", b"iam_role_arn", "logging_level", b"logging_level", "resource_info", b"resource_info", "slack_channel_id", b"slack_channel_id", "slack_workspace_id", b"slack_workspace_id", "sns_topic_arns", b"sns_topic_arns"]) -> None: ...

global___SlackChannelConfiguration = SlackChannelConfiguration

@typing_extensions.final
class Chatbot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLACK_CHANNEL_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def slack_channel_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SlackChannelConfiguration]: ...
    def __init__(
        self,
        *,
        slack_channel_configuration: collections.abc.Iterable[global___SlackChannelConfiguration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["slack_channel_configuration", b"slack_channel_configuration"]) -> None: ...

global___Chatbot = Chatbot
