# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_dnszones.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,azure/azure_microsoft_network_dnszones.proto\x12,oak9.tython.azure.microsoft_network_dnszones\x1a\x13shared/shared.proto\"\xb5\x01\n\x1aMicrosoft_Network_dnsZones\x12I\n\tdns_zones\x18\x01 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.DnsZones\x12L\n\x0b\x64ns_zones_a\x18\x02 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.DnsZonesA\"\x9c\x08\n\x0b\x44nsZonesTXT\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesTXT.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x08\n\x0b\x44nsZonesSRV\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesSRV.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x08\n\x0b\x44nsZonesSOA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesSOA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x08\n\x0b\x44nsZonesPTR\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesPTR.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x08\n\nDnsZonesNS\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12X\n\x08metadata\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_dnszones.DnsZonesNS.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x08\n\nDnsZonesMX\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12X\n\x08metadata\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_dnszones.DnsZonesMX.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x08\n\rDnsZonesCNAME\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12[\n\x08metadata\x18\x04 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network_dnszones.DnsZonesCNAME.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x08\n\x0b\x44nsZonesCAA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesCAA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x08\n\x0c\x44nsZonesAAAA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Z\n\x08metadata\x18\x04 \x03(\x0b\x32H.oak9.tython.azure.microsoft_network_dnszones.DnsZonesAAAA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x08\n\tDnsZonesA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12W\n\x08metadata\x18\x04 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network_dnszones.DnsZonesA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\tCaaRecord\x12\r\n\x05\x66lags\x18\x01 \x01(\x05\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x93\x01\n\tSoaRecord\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\x05\x12\x14\n\x0crefresh_time\x18\x04 \x01(\x05\x12\x12\n\nretry_time\x18\x05 \x01(\x05\x12\x13\n\x0b\x65xpire_time\x18\x06 \x01(\x05\x12\x13\n\x0bminimum_ttl\x18\x07 \x01(\x05\"\x1c\n\x0b\x43nameRecord\x12\r\n\x05\x63name\x18\x01 \x01(\t\"\x1a\n\tTxtRecord\x12\r\n\x05value\x18\x01 \x03(\t\"K\n\tSrvRecord\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12\x0e\n\x06weight\x18\x02 \x01(\x05\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0e\n\x06target\x18\x04 \x01(\t\"\x1d\n\tPtrRecord\x12\x10\n\x08ptrdname\x18\x01 \x01(\t\"\x1b\n\x08NsRecord\x12\x0f\n\x07nsdname\x18\x01 \x01(\t\"0\n\x08MxRecord\x12\x12\n\npreference\x18\x01 \x01(\x05\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\"\"\n\nAaaaRecord\x12\x14\n\x0cipv6_address\x18\x01 \x01(\t\"\x1f\n\x07\x41Record\x12\x14\n\x0cipv4_address\x18\x01 \x01(\t\"\xbb\x08\n\x08\x44nsZones\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12N\n\x04tags\x18\x04 \x03(\x0b\x32@.oak9.tython.azure.microsoft_network_dnszones.DnsZones.TagsEntry\x12\x0c\n\x04\x65tag\x18\x05 \x01(\t\x12\x11\n\tzone_type\x18\x06 \x01(\t\x12%\n\x1dregistration_virtual_networks\x18\x07 \x03(\t\x12#\n\x1bresolution_virtual_networks\x18\x08 \x03(\t\x12Q\n\x0e\x64ns_zones__txt\x18\t \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesTXT\x12Q\n\x0e\x64ns_zones__srv\x18\n \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesSRV\x12Q\n\x0e\x64ns_zones__soa\x18\x0b \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesSOA\x12Q\n\x0e\x64ns_zones__ptr\x18\x0c \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesPTR\x12O\n\rdns_zones__ns\x18\r \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.DnsZonesNS\x12O\n\rdns_zones__mx\x18\x0e \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.DnsZonesMX\x12U\n\x10\x64ns_zones__cname\x18\x0f \x03(\x0b\x32;.oak9.tython.azure.microsoft_network_dnszones.DnsZonesCNAME\x12R\n\x0f\x64ns_zones__ca_a\x18\x10 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesCAA\x12S\n\x0f\x64ns_zones__aaaa\x18\x11 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network_dnszones.DnsZonesAAAA\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_dnszones_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DNSZONESTXT_METADATAENTRY._options = None
  _DNSZONESTXT_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESSRV_METADATAENTRY._options = None
  _DNSZONESSRV_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESSOA_METADATAENTRY._options = None
  _DNSZONESSOA_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESPTR_METADATAENTRY._options = None
  _DNSZONESPTR_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESNS_METADATAENTRY._options = None
  _DNSZONESNS_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESMX_METADATAENTRY._options = None
  _DNSZONESMX_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESCNAME_METADATAENTRY._options = None
  _DNSZONESCNAME_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESCAA_METADATAENTRY._options = None
  _DNSZONESCAA_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESAAAA_METADATAENTRY._options = None
  _DNSZONESAAAA_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESA_METADATAENTRY._options = None
  _DNSZONESA_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONES_TAGSENTRY._options = None
  _DNSZONES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_DNSZONES._serialized_start=116
  _MICROSOFT_NETWORK_DNSZONES._serialized_end=297
  _DNSZONESTXT._serialized_start=300
  _DNSZONESTXT._serialized_end=1352
  _DNSZONESTXT_METADATAENTRY._serialized_start=1305
  _DNSZONESTXT_METADATAENTRY._serialized_end=1352
  _DNSZONESSRV._serialized_start=1355
  _DNSZONESSRV._serialized_end=2407
  _DNSZONESSRV_METADATAENTRY._serialized_start=1305
  _DNSZONESSRV_METADATAENTRY._serialized_end=1352
  _DNSZONESSOA._serialized_start=2410
  _DNSZONESSOA._serialized_end=3462
  _DNSZONESSOA_METADATAENTRY._serialized_start=1305
  _DNSZONESSOA_METADATAENTRY._serialized_end=1352
  _DNSZONESPTR._serialized_start=3465
  _DNSZONESPTR._serialized_end=4517
  _DNSZONESPTR_METADATAENTRY._serialized_start=1305
  _DNSZONESPTR_METADATAENTRY._serialized_end=1352
  _DNSZONESNS._serialized_start=4520
  _DNSZONESNS._serialized_end=5570
  _DNSZONESNS_METADATAENTRY._serialized_start=1305
  _DNSZONESNS_METADATAENTRY._serialized_end=1352
  _DNSZONESMX._serialized_start=5573
  _DNSZONESMX._serialized_end=6623
  _DNSZONESMX_METADATAENTRY._serialized_start=1305
  _DNSZONESMX_METADATAENTRY._serialized_end=1352
  _DNSZONESCNAME._serialized_start=6626
  _DNSZONESCNAME._serialized_end=7682
  _DNSZONESCNAME_METADATAENTRY._serialized_start=1305
  _DNSZONESCNAME_METADATAENTRY._serialized_end=1352
  _DNSZONESCAA._serialized_start=7685
  _DNSZONESCAA._serialized_end=8737
  _DNSZONESCAA_METADATAENTRY._serialized_start=1305
  _DNSZONESCAA_METADATAENTRY._serialized_end=1352
  _DNSZONESAAAA._serialized_start=8740
  _DNSZONESAAAA._serialized_end=9794
  _DNSZONESAAAA_METADATAENTRY._serialized_start=1305
  _DNSZONESAAAA_METADATAENTRY._serialized_end=1352
  _DNSZONESA._serialized_start=9797
  _DNSZONESA._serialized_end=10845
  _DNSZONESA_METADATAENTRY._serialized_start=1305
  _DNSZONESA_METADATAENTRY._serialized_end=1352
  _CAARECORD._serialized_start=10847
  _CAARECORD._serialized_end=10901
  _SOARECORD._serialized_start=10904
  _SOARECORD._serialized_end=11051
  _CNAMERECORD._serialized_start=11053
  _CNAMERECORD._serialized_end=11081
  _TXTRECORD._serialized_start=11083
  _TXTRECORD._serialized_end=11109
  _SRVRECORD._serialized_start=11111
  _SRVRECORD._serialized_end=11186
  _PTRRECORD._serialized_start=11188
  _PTRRECORD._serialized_end=11217
  _NSRECORD._serialized_start=11219
  _NSRECORD._serialized_end=11246
  _MXRECORD._serialized_start=11248
  _MXRECORD._serialized_end=11296
  _AAAARECORD._serialized_start=11298
  _AAAARECORD._serialized_end=11332
  _ARECORD._serialized_start=11334
  _ARECORD._serialized_end=11365
  _DNSZONES._serialized_start=11368
  _DNSZONES._serialized_end=12451
  _DNSZONES_TAGSENTRY._serialized_start=12408
  _DNSZONES_TAGSENTRY._serialized_end=12451
# @@protoc_insertion_point(module_scope)
