# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_bigtable.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_bigtable.proto\x12\x18oak9.tython.gcp.bigtable\x1a\x13shared/shared.proto\"a\n\'BigtableAppProfileXSingleClusterRouting\x12\"\n\x1a\x61llow_transactional_writes\x18\x01 \x01(\x08\x12\x12\n\ncluster_id\x18\x02 \x01(\t\"M\n\x1b\x42igtableAppProfileXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xce\x03\n\x12\x42igtableAppProfile\x12\x16\n\x0e\x61pp_profile_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x17\n\x0fignore_warnings\x18\x04 \x01(\x08\x12\x10\n\x08instance\x18\x05 \x01(\t\x12)\n!multi_cluster_routing_cluster_ids\x18\x06 \x03(\t\x12%\n\x1dmulti_cluster_routing_use_any\x18\x07 \x01(\x08\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x61\n\x16single_cluster_routing\x18\n \x01(\x0b\x32\x41.oak9.tython.gcp.bigtable.BigtableAppProfileXSingleClusterRouting\x12G\n\x08timeouts\x18\x0b \x01(\x0b\x32\x35.oak9.tython.gcp.bigtable.BigtableAppProfileXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"9\n\x17\x42igtableGcPolicyXMaxAge\x12\x0c\n\x04\x64\x61ys\x18\x01 \x01(\x01\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\"-\n\x1b\x42igtableGcPolicyXMaxVersion\x12\x0e\n\x06number\x18\x01 \x01(\x01\"\xd5\x02\n\x10\x42igtableGcPolicy\x12\x15\n\rcolumn_family\x18\x01 \x01(\t\x12\x10\n\x08gc_rules\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x15\n\rinstance_name\x18\x04 \x01(\t\x12\x0c\n\x04mode\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\r\n\x05table\x18\x07 \x01(\t\x12\x42\n\x07max_age\x18\x08 \x01(\x0b\x32\x31.oak9.tython.gcp.bigtable.BigtableGcPolicyXMaxAge\x12J\n\x0bmax_version\x18\t \x03(\x0b\x32\x35.oak9.tython.gcp.bigtable.BigtableGcPolicyXMaxVersion\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"f\n*BigtableInstanceXClusterXAutoscalingConfig\x12\x12\n\ncpu_target\x18\x01 \x01(\x01\x12\x11\n\tmax_nodes\x18\x02 \x01(\x01\x12\x11\n\tmin_nodes\x18\x03 \x01(\x01\"\xdd\x01\n\x18\x42igtableInstanceXCluster\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x02 \x01(\t\x12\x11\n\tnum_nodes\x18\x03 \x01(\x01\x12\x14\n\x0cstorage_type\x18\x04 \x01(\t\x12\x0c\n\x04zone\x18\x05 \x01(\t\x12`\n\x12\x61utoscaling_config\x18\x06 \x01(\x0b\x32\x44.oak9.tython.gcp.bigtable.BigtableInstanceXClusterXAutoscalingConfig\"\xfc\x02\n\x10\x42igtableInstance\x12\x1b\n\x13\x64\x65letion_protection\x18\x01 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x15\n\rinstance_type\x18\x04 \x01(\t\x12\x46\n\x06labels\x18\x05 \x03(\x0b\x32\x36.oak9.tython.gcp.bigtable.BigtableInstance.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x43\n\x07\x63luster\x18\x08 \x03(\x0b\x32\x32.oak9.tython.gcp.bigtable.BigtableInstanceXCluster\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n$BigtableInstanceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x84\x02\n\x1a\x42igtableInstanceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12Q\n\tcondition\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.bigtable.BigtableInstanceIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#BigtableInstanceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x81\x02\n\x19\x42igtableInstanceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12P\n\tcondition\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.bigtable.BigtableInstanceIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x01\n\x19\x42igtableInstanceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\",\n\x1a\x42igtableTableXColumnFamily\x12\x0e\n\x06\x66\x61mily\x18\x01 \x01(\t\"\xeb\x01\n\rBigtableTable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x12\n\nsplit_keys\x18\x05 \x03(\t\x12K\n\rcolumn_family\x18\x06 \x03(\x0b\x32\x34.oak9.tython.gcp.bigtable.BigtableTableXColumnFamily\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n!BigtableTableIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n\x17\x42igtableTableIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\r\n\x05table\x18\x07 \x01(\t\x12N\n\tcondition\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.bigtable.BigtableTableIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n BigtableTableIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8a\x02\n\x16\x42igtableTableIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\r\n\x05table\x18\x07 \x01(\t\x12M\n\tcondition\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.bigtable.BigtableTableIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x01\n\x16\x42igtableTableIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\r\n\x05table\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_bigtable_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BIGTABLEINSTANCE_LABELSENTRY._options = None
  _BIGTABLEINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _BIGTABLEAPPPROFILEXSINGLECLUSTERROUTING._serialized_start=73
  _BIGTABLEAPPPROFILEXSINGLECLUSTERROUTING._serialized_end=170
  _BIGTABLEAPPPROFILEXTIMEOUTS._serialized_start=172
  _BIGTABLEAPPPROFILEXTIMEOUTS._serialized_end=249
  _BIGTABLEAPPPROFILE._serialized_start=252
  _BIGTABLEAPPPROFILE._serialized_end=714
  _BIGTABLEGCPOLICYXMAXAGE._serialized_start=716
  _BIGTABLEGCPOLICYXMAXAGE._serialized_end=773
  _BIGTABLEGCPOLICYXMAXVERSION._serialized_start=775
  _BIGTABLEGCPOLICYXMAXVERSION._serialized_end=820
  _BIGTABLEGCPOLICY._serialized_start=823
  _BIGTABLEGCPOLICY._serialized_end=1164
  _BIGTABLEINSTANCEXCLUSTERXAUTOSCALINGCONFIG._serialized_start=1166
  _BIGTABLEINSTANCEXCLUSTERXAUTOSCALINGCONFIG._serialized_end=1268
  _BIGTABLEINSTANCEXCLUSTER._serialized_start=1271
  _BIGTABLEINSTANCEXCLUSTER._serialized_end=1492
  _BIGTABLEINSTANCE._serialized_start=1495
  _BIGTABLEINSTANCE._serialized_end=1875
  _BIGTABLEINSTANCE_LABELSENTRY._serialized_start=1830
  _BIGTABLEINSTANCE_LABELSENTRY._serialized_end=1875
  _BIGTABLEINSTANCEIAMBINDINGXCONDITION._serialized_start=1877
  _BIGTABLEINSTANCEIAMBINDINGXCONDITION._serialized_end=1971
  _BIGTABLEINSTANCEIAMBINDING._serialized_start=1974
  _BIGTABLEINSTANCEIAMBINDING._serialized_end=2234
  _BIGTABLEINSTANCEIAMMEMBERXCONDITION._serialized_start=2236
  _BIGTABLEINSTANCEIAMMEMBERXCONDITION._serialized_end=2329
  _BIGTABLEINSTANCEIAMMEMBER._serialized_start=2332
  _BIGTABLEINSTANCEIAMMEMBER._serialized_end=2589
  _BIGTABLEINSTANCEIAMPOLICY._serialized_start=2592
  _BIGTABLEINSTANCEIAMPOLICY._serialized_end=2758
  _BIGTABLETABLEXCOLUMNFAMILY._serialized_start=2760
  _BIGTABLETABLEXCOLUMNFAMILY._serialized_end=2804
  _BIGTABLETABLE._serialized_start=2807
  _BIGTABLETABLE._serialized_end=3042
  _BIGTABLETABLEIAMBINDINGXCONDITION._serialized_start=3044
  _BIGTABLETABLEIAMBINDINGXCONDITION._serialized_end=3135
  _BIGTABLETABLEIAMBINDING._serialized_start=3138
  _BIGTABLETABLEIAMBINDING._serialized_end=3407
  _BIGTABLETABLEIAMMEMBERXCONDITION._serialized_start=3409
  _BIGTABLETABLEIAMMEMBERXCONDITION._serialized_end=3499
  _BIGTABLETABLEIAMMEMBER._serialized_start=3502
  _BIGTABLETABLEIAMMEMBER._serialized_end=3768
  _BIGTABLETABLEIAMPOLICY._serialized_start=3771
  _BIGTABLETABLEIAMPOLICY._serialized_end=3949
# @@protoc_insertion_point(module_scope)
