# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_organization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agcp/gcp_organization.proto\x12\x1coak9.tython.gcp.organization\x1a\x13shared/shared.proto\"f\n3OrganizationAccessApprovalSettingsXEnrolledServices\x12\x15\n\rcloud_product\x18\x01 \x01(\t\x12\x18\n\x10\x65nrollment_level\x18\x02 \x01(\t\"]\n+OrganizationAccessApprovalSettingsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf5\x03\n\"OrganizationAccessApprovalSettings\x12\x1a\n\x12\x61\x63tive_key_version\x18\x01 \x01(\t\x12\'\n\x1f\x61ncestor_has_active_key_version\x18\x02 \x01(\x08\x12\x19\n\x11\x65nrolled_ancestor\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x1b\n\x13invalid_key_version\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13notification_emails\x18\x07 \x03(\t\x12\x17\n\x0forganization_id\x18\x08 \x01(\t\x12l\n\x11\x65nrolled_services\x18\t \x03(\x0b\x32Q.oak9.tython.gcp.organization.OrganizationAccessApprovalSettingsXEnrolledServices\x12[\n\x08timeouts\x18\n \x01(\x0b\x32I.oak9.tython.gcp.organization.OrganizationAccessApprovalSettingsXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n)OrganizationIamAuditConfigXAuditLogConfig\x12\x18\n\x10\x65xempted_members\x18\x01 \x03(\t\x12\x10\n\x08log_type\x18\x02 \x01(\t\"\xf3\x01\n\x1aOrganizationIamAuditConfig\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12\x61\n\x10\x61udit_log_config\x18\x05 \x03(\x0b\x32G.oak9.tython.gcp.organization.OrganizationIamAuditConfigXAuditLogConfig\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n OrganizationIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xed\x01\n\x16OrganizationIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12Q\n\tcondition\x18\x06 \x01(\x0b\x32>.oak9.tython.gcp.organization.OrganizationIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe8\x01\n\x19OrganizationIamCustomRole\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06org_id\x18\x05 \x01(\t\x12\x13\n\x0bpermissions\x18\x06 \x03(\t\x12\x0f\n\x07role_id\x18\x07 \x01(\t\x12\r\n\x05stage\x18\x08 \x01(\t\x12\r\n\x05title\x18\t \x01(\t\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\x1fOrganizationIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xea\x01\n\x15OrganizationIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12P\n\tcondition\x18\x06 \x01(\x0b\x32=.oak9.tython.gcp.organization.OrganizationIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8f\x01\n\x15OrganizationIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"4\n OrganizationPolicyXBooleanPolicy\x12\x10\n\x08\x65nforced\x18\x01 \x01(\x08\"B\n#OrganizationPolicyXListPolicyXAllow\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x0e\n\x06values\x18\x02 \x03(\t\"A\n\"OrganizationPolicyXListPolicyXDeny\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xf7\x01\n\x1dOrganizationPolicyXListPolicy\x12\x1b\n\x13inherit_from_parent\x18\x01 \x01(\x08\x12\x17\n\x0fsuggested_value\x18\x02 \x01(\t\x12P\n\x05\x61llow\x18\x03 \x01(\x0b\x32\x41.oak9.tython.gcp.organization.OrganizationPolicyXListPolicyXAllow\x12N\n\x04\x64\x65ny\x18\x04 \x01(\x0b\x32@.oak9.tython.gcp.organization.OrganizationPolicyXListPolicyXDeny\"3\n OrganizationPolicyXRestorePolicy\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\"[\n\x1bOrganizationPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\"\x80\x04\n\x12OrganizationPolicy\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x13\n\x0bupdate_time\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\x01\x12V\n\x0e\x62oolean_policy\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.organization.OrganizationPolicyXBooleanPolicy\x12P\n\x0blist_policy\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.organization.OrganizationPolicyXListPolicy\x12V\n\x0erestore_policy\x18\t \x01(\x0b\x32>.oak9.tython.gcp.organization.OrganizationPolicyXRestorePolicy\x12K\n\x08timeouts\x18\n \x01(\x0b\x32\x39.oak9.tython.gcp.organization.OrganizationPolicyXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_organization_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ORGANIZATIONACCESSAPPROVALSETTINGSXENROLLEDSERVICES._serialized_start=81
  _ORGANIZATIONACCESSAPPROVALSETTINGSXENROLLEDSERVICES._serialized_end=183
  _ORGANIZATIONACCESSAPPROVALSETTINGSXTIMEOUTS._serialized_start=185
  _ORGANIZATIONACCESSAPPROVALSETTINGSXTIMEOUTS._serialized_end=278
  _ORGANIZATIONACCESSAPPROVALSETTINGS._serialized_start=281
  _ORGANIZATIONACCESSAPPROVALSETTINGS._serialized_end=782
  _ORGANIZATIONIAMAUDITCONFIGXAUDITLOGCONFIG._serialized_start=784
  _ORGANIZATIONIAMAUDITCONFIGXAUDITLOGCONFIG._serialized_end=871
  _ORGANIZATIONIAMAUDITCONFIG._serialized_start=874
  _ORGANIZATIONIAMAUDITCONFIG._serialized_end=1117
  _ORGANIZATIONIAMBINDINGXCONDITION._serialized_start=1119
  _ORGANIZATIONIAMBINDINGXCONDITION._serialized_end=1209
  _ORGANIZATIONIAMBINDING._serialized_start=1212
  _ORGANIZATIONIAMBINDING._serialized_end=1449
  _ORGANIZATIONIAMCUSTOMROLE._serialized_start=1452
  _ORGANIZATIONIAMCUSTOMROLE._serialized_end=1684
  _ORGANIZATIONIAMMEMBERXCONDITION._serialized_start=1686
  _ORGANIZATIONIAMMEMBERXCONDITION._serialized_end=1775
  _ORGANIZATIONIAMMEMBER._serialized_start=1778
  _ORGANIZATIONIAMMEMBER._serialized_end=2012
  _ORGANIZATIONIAMPOLICY._serialized_start=2015
  _ORGANIZATIONIAMPOLICY._serialized_end=2158
  _ORGANIZATIONPOLICYXBOOLEANPOLICY._serialized_start=2160
  _ORGANIZATIONPOLICYXBOOLEANPOLICY._serialized_end=2212
  _ORGANIZATIONPOLICYXLISTPOLICYXALLOW._serialized_start=2214
  _ORGANIZATIONPOLICYXLISTPOLICYXALLOW._serialized_end=2280
  _ORGANIZATIONPOLICYXLISTPOLICYXDENY._serialized_start=2282
  _ORGANIZATIONPOLICYXLISTPOLICYXDENY._serialized_end=2347
  _ORGANIZATIONPOLICYXLISTPOLICY._serialized_start=2350
  _ORGANIZATIONPOLICYXLISTPOLICY._serialized_end=2597
  _ORGANIZATIONPOLICYXRESTOREPOLICY._serialized_start=2599
  _ORGANIZATIONPOLICYXRESTOREPOLICY._serialized_end=2650
  _ORGANIZATIONPOLICYXTIMEOUTS._serialized_start=2652
  _ORGANIZATIONPOLICYXTIMEOUTS._serialized_end=2743
  _ORGANIZATIONPOLICY._serialized_start=2746
  _ORGANIZATIONPOLICY._serialized_end=3258
# @@protoc_insertion_point(module_scope)
