"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeGlobalAddressXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeGlobalAddressXTimeouts = ComputeGlobalAddressXTimeouts

@typing_extensions.final
class ComputeGlobalAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    ADDRESS_TYPE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PURPOSE_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    address: builtins.str
    address_type: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    ip_version: builtins.str
    name: builtins.str
    network: builtins.str
    prefix_length: builtins.float
    project: builtins.str
    purpose: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeGlobalAddressXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        address_type: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        ip_version: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        prefix_length: builtins.float = ...,
        project: builtins.str = ...,
        purpose: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeGlobalAddressXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "address_type", b"address_type", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "ip_version", b"ip_version", "name", b"name", "network", b"network", "prefix_length", b"prefix_length", "project", b"project", "purpose", b"purpose", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeGlobalAddress = ComputeGlobalAddress

@typing_extensions.final
class ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels = ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels

@typing_extensions.final
class ComputeGlobalForwardingRuleXMetadataFilters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTER_MATCH_CRITERIA_FIELD_NUMBER: builtins.int
    FILTER_LABELS_FIELD_NUMBER: builtins.int
    filter_match_criteria: builtins.str
    @property
    def filter_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels]: ...
    def __init__(
        self,
        *,
        filter_match_criteria: builtins.str = ...,
        filter_labels: collections.abc.Iterable[global___ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter_labels", b"filter_labels", "filter_match_criteria", b"filter_match_criteria"]) -> None: ...

global___ComputeGlobalForwardingRuleXMetadataFilters = ComputeGlobalForwardingRuleXMetadataFilters

@typing_extensions.final
class ComputeGlobalForwardingRuleXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeGlobalForwardingRuleXTimeouts = ComputeGlobalForwardingRuleXTimeouts

@typing_extensions.final
class ComputeGlobalForwardingRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    IP_PROTOCOL_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SCHEME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PORT_RANGE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PSC_CONNECTION_ID_FIELD_NUMBER: builtins.int
    PSC_CONNECTION_STATUS_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    METADATA_FILTERS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    ip_address: builtins.str
    ip_protocol: builtins.str
    ip_version: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    load_balancing_scheme: builtins.str
    name: builtins.str
    network: builtins.str
    port_range: builtins.str
    project: builtins.str
    psc_connection_id: builtins.str
    psc_connection_status: builtins.str
    self_link: builtins.str
    target: builtins.str
    @property
    def metadata_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeGlobalForwardingRuleXMetadataFilters]: ...
    @property
    def timeouts(self) -> global___ComputeGlobalForwardingRuleXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        ip_address: builtins.str = ...,
        ip_protocol: builtins.str = ...,
        ip_version: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        load_balancing_scheme: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        port_range: builtins.str = ...,
        project: builtins.str = ...,
        psc_connection_id: builtins.str = ...,
        psc_connection_status: builtins.str = ...,
        self_link: builtins.str = ...,
        target: builtins.str = ...,
        metadata_filters: collections.abc.Iterable[global___ComputeGlobalForwardingRuleXMetadataFilters] | None = ...,
        timeouts: global___ComputeGlobalForwardingRuleXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "ip_address", b"ip_address", "ip_protocol", b"ip_protocol", "ip_version", b"ip_version", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "load_balancing_scheme", b"load_balancing_scheme", "metadata_filters", b"metadata_filters", "name", b"name", "network", b"network", "port_range", b"port_range", "project", b"project", "psc_connection_id", b"psc_connection_id", "psc_connection_status", b"psc_connection_status", "resource_info", b"resource_info", "self_link", b"self_link", "target", b"target", "timeouts", b"timeouts"]) -> None: ...

global___ComputeGlobalForwardingRule = ComputeGlobalForwardingRule

@typing_extensions.final
class ComputeGlobalNetworkEndpointXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeGlobalNetworkEndpointXTimeouts = ComputeGlobalNetworkEndpointXTimeouts

@typing_extensions.final
class ComputeGlobalNetworkEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_ENDPOINT_GROUP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    global_network_endpoint_group: builtins.str
    id: builtins.str
    ip_address: builtins.str
    port: builtins.float
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeGlobalNetworkEndpointXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        global_network_endpoint_group: builtins.str = ...,
        id: builtins.str = ...,
        ip_address: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeGlobalNetworkEndpointXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fqdn", b"fqdn", "global_network_endpoint_group", b"global_network_endpoint_group", "id", b"id", "ip_address", b"ip_address", "port", b"port", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeGlobalNetworkEndpoint = ComputeGlobalNetworkEndpoint

@typing_extensions.final
class ComputeGlobalNetworkEndpointGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeGlobalNetworkEndpointGroupXTimeouts = ComputeGlobalNetworkEndpointGroupXTimeouts

@typing_extensions.final
class ComputeGlobalNetworkEndpointGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_PORT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_port: builtins.float
    description: builtins.str
    id: builtins.str
    name: builtins.str
    network_endpoint_type: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeGlobalNetworkEndpointGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_port: builtins.float = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network_endpoint_type: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeGlobalNetworkEndpointGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_port", b"default_port", "description", b"description", "id", b"id", "name", b"name", "network_endpoint_type", b"network_endpoint_type", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeGlobalNetworkEndpointGroup = ComputeGlobalNetworkEndpointGroup
