# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_billing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_billing.proto\x12\x17oak9.tython.gcp.billing\x1a\x13shared/shared.proto\"\\\n\"BillingAccountIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf8\x01\n\x18\x42illingAccountIamBinding\x12\x1a\n\x12\x62illing_account_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12N\n\tcondition\x18\x06 \x01(\x0b\x32;.oak9.tython.gcp.billing.BillingAccountIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n!BillingAccountIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf5\x01\n\x17\x42illingAccountIamMember\x12\x1a\n\x12\x62illing_account_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12M\n\tcondition\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.billing.BillingAccountIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\x17\x42illingAccountIamPolicy\x12\x1a\n\x12\x62illing_account_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9e\x01\n\x1c\x42illingBudgetXAllUpdatesRule\x12&\n\x1e\x64isable_default_iam_recipients\x18\x01 \x01(\x08\x12(\n monitoring_notification_channels\x18\x02 \x03(\t\x12\x14\n\x0cpubsub_topic\x18\x03 \x01(\t\x12\x16\n\x0eschema_version\x18\x04 \x01(\t\"[\n$BillingBudgetXAmountXSpecifiedAmount\x12\x15\n\rcurrency_code\x18\x01 \x01(\t\x12\r\n\x05nanos\x18\x02 \x01(\x01\x12\r\n\x05units\x18\x03 \x01(\t\"\x8b\x01\n\x14\x42illingBudgetXAmount\x12\x1a\n\x12last_period_amount\x18\x01 \x01(\x08\x12W\n\x10specified_amount\x18\x02 \x01(\x0b\x32=.oak9.tython.gcp.billing.BillingBudgetXAmountXSpecifiedAmount\"[\n/BillingBudgetXBudgetFilterXCustomPeriodXEndDate\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"]\n1BillingBudgetXBudgetFilterXCustomPeriodXStartDate\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"\xe5\x01\n\'BillingBudgetXBudgetFilterXCustomPeriod\x12Z\n\x08\x65nd_date\x18\x01 \x01(\x0b\x32H.oak9.tython.gcp.billing.BillingBudgetXBudgetFilterXCustomPeriodXEndDate\x12^\n\nstart_date\x18\x02 \x01(\x0b\x32J.oak9.tython.gcp.billing.BillingBudgetXBudgetFilterXCustomPeriodXStartDate\"\xfd\x02\n\x1a\x42illingBudgetXBudgetFilter\x12\x17\n\x0f\x63\x61lendar_period\x18\x01 \x01(\t\x12\x14\n\x0c\x63redit_types\x18\x02 \x03(\t\x12\x1e\n\x16\x63redit_types_treatment\x18\x03 \x01(\t\x12O\n\x06labels\x18\x04 \x03(\x0b\x32?.oak9.tython.gcp.billing.BillingBudgetXBudgetFilter.LabelsEntry\x12\x10\n\x08projects\x18\x05 \x03(\t\x12\x10\n\x08services\x18\x06 \x03(\t\x12\x13\n\x0bsubaccounts\x18\x07 \x03(\t\x12W\n\rcustom_period\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.billing.BillingBudgetXBudgetFilterXCustomPeriod\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"N\n\x1c\x42illingBudgetXThresholdRules\x12\x13\n\x0bspend_basis\x18\x01 \x01(\t\x12\x19\n\x11threshold_percent\x18\x02 \x01(\x01\"H\n\x16\x42illingBudgetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x80\x04\n\rBillingBudget\x12\x17\n\x0f\x62illing_account\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12O\n\x10\x61ll_updates_rule\x18\x05 \x01(\x0b\x32\x35.oak9.tython.gcp.billing.BillingBudgetXAllUpdatesRule\x12=\n\x06\x61mount\x18\x06 \x01(\x0b\x32-.oak9.tython.gcp.billing.BillingBudgetXAmount\x12J\n\rbudget_filter\x18\x07 \x01(\x0b\x32\x33.oak9.tython.gcp.billing.BillingBudgetXBudgetFilter\x12N\n\x0fthreshold_rules\x18\x08 \x03(\x0b\x32\x35.oak9.tython.gcp.billing.BillingBudgetXThresholdRules\x12\x41\n\x08timeouts\x18\t \x01(\x0b\x32/.oak9.tython.gcp.billing.BillingBudgetXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdf\x01\n\x11\x42illingSubaccount\x12\x1a\n\x12\x62illing_account_id\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65letion_policy\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x1e\n\x16master_billing_account\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04open\x18\x07 \x01(\x08\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_billing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BILLINGBUDGETXBUDGETFILTER_LABELSENTRY._options = None
  _BILLINGBUDGETXBUDGETFILTER_LABELSENTRY._serialized_options = b'8\001'
  _BILLINGACCOUNTIAMBINDINGXCONDITION._serialized_start=71
  _BILLINGACCOUNTIAMBINDINGXCONDITION._serialized_end=163
  _BILLINGACCOUNTIAMBINDING._serialized_start=166
  _BILLINGACCOUNTIAMBINDING._serialized_end=414
  _BILLINGACCOUNTIAMMEMBERXCONDITION._serialized_start=416
  _BILLINGACCOUNTIAMMEMBERXCONDITION._serialized_end=507
  _BILLINGACCOUNTIAMMEMBER._serialized_start=510
  _BILLINGACCOUNTIAMMEMBER._serialized_end=755
  _BILLINGACCOUNTIAMPOLICY._serialized_start=758
  _BILLINGACCOUNTIAMPOLICY._serialized_end=915
  _BILLINGBUDGETXALLUPDATESRULE._serialized_start=918
  _BILLINGBUDGETXALLUPDATESRULE._serialized_end=1076
  _BILLINGBUDGETXAMOUNTXSPECIFIEDAMOUNT._serialized_start=1078
  _BILLINGBUDGETXAMOUNTXSPECIFIEDAMOUNT._serialized_end=1169
  _BILLINGBUDGETXAMOUNT._serialized_start=1172
  _BILLINGBUDGETXAMOUNT._serialized_end=1311
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIODXENDDATE._serialized_start=1313
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIODXENDDATE._serialized_end=1404
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIODXSTARTDATE._serialized_start=1406
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIODXSTARTDATE._serialized_end=1499
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIOD._serialized_start=1502
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIOD._serialized_end=1731
  _BILLINGBUDGETXBUDGETFILTER._serialized_start=1734
  _BILLINGBUDGETXBUDGETFILTER._serialized_end=2115
  _BILLINGBUDGETXBUDGETFILTER_LABELSENTRY._serialized_start=2070
  _BILLINGBUDGETXBUDGETFILTER_LABELSENTRY._serialized_end=2115
  _BILLINGBUDGETXTHRESHOLDRULES._serialized_start=2117
  _BILLINGBUDGETXTHRESHOLDRULES._serialized_end=2195
  _BILLINGBUDGETXTIMEOUTS._serialized_start=2197
  _BILLINGBUDGETXTIMEOUTS._serialized_end=2269
  _BILLINGBUDGET._serialized_start=2272
  _BILLINGBUDGET._serialized_end=2784
  _BILLINGSUBACCOUNT._serialized_start=2787
  _BILLINGSUBACCOUNT._serialized_end=3010
# @@protoc_insertion_point(module_scope)
