"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AcceptedPortfolioShare(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    accept_language: builtins.str
    portfolio_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "portfolio_id", b"portfolio_id", "resource_info", b"resource_info"]) -> None: ...

global___AcceptedPortfolioShare = AcceptedPortfolioShare

@typing_extensions.final
class ServiceCatalog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPTED_PORTFOLIO_SHARE_FIELD_NUMBER: builtins.int
    CLOUD_FORMATION_PRODUCT_FIELD_NUMBER: builtins.int
    CLOUD_FORMATION_PROVISIONED_PRODUCT_FIELD_NUMBER: builtins.int
    LAUNCH_NOTIFICATION_CONSTRAINT_FIELD_NUMBER: builtins.int
    LAUNCH_ROLE_CONSTRAINT_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_CONSTRAINT_FIELD_NUMBER: builtins.int
    PORTFOLIO_FIELD_NUMBER: builtins.int
    PORTFOLIO_PRINCIPAL_ASSOCIATION_FIELD_NUMBER: builtins.int
    PORTFOLIO_PRODUCT_ASSOCIATION_FIELD_NUMBER: builtins.int
    PORTFOLIO_SHARE_FIELD_NUMBER: builtins.int
    RESOURCE_UPDATE_CONSTRAINT_FIELD_NUMBER: builtins.int
    STACK_SET_CONSTRAINT_FIELD_NUMBER: builtins.int
    TAG_OPTION_FIELD_NUMBER: builtins.int
    TAG_OPTION_ASSOCIATION_FIELD_NUMBER: builtins.int
    @property
    def accepted_portfolio_share(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AcceptedPortfolioShare]: ...
    @property
    def cloud_formation_product(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFormationProduct]: ...
    @property
    def cloud_formation_provisioned_product(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFormationProvisionedProduct]: ...
    @property
    def launch_notification_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchNotificationConstraint]: ...
    @property
    def launch_role_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchRoleConstraint]: ...
    @property
    def launch_template_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateConstraint]: ...
    @property
    def portfolio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Portfolio]: ...
    @property
    def portfolio_principal_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortfolioPrincipalAssociation]: ...
    @property
    def portfolio_product_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortfolioProductAssociation]: ...
    @property
    def portfolio_share(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortfolioShare]: ...
    @property
    def resource_update_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceUpdateConstraint]: ...
    @property
    def stack_set_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StackSetConstraint]: ...
    @property
    def tag_option(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TagOption]: ...
    @property
    def tag_option_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TagOptionAssociation]: ...
    def __init__(
        self,
        *,
        accepted_portfolio_share: collections.abc.Iterable[global___AcceptedPortfolioShare] | None = ...,
        cloud_formation_product: collections.abc.Iterable[global___CloudFormationProduct] | None = ...,
        cloud_formation_provisioned_product: collections.abc.Iterable[global___CloudFormationProvisionedProduct] | None = ...,
        launch_notification_constraint: collections.abc.Iterable[global___LaunchNotificationConstraint] | None = ...,
        launch_role_constraint: collections.abc.Iterable[global___LaunchRoleConstraint] | None = ...,
        launch_template_constraint: collections.abc.Iterable[global___LaunchTemplateConstraint] | None = ...,
        portfolio: collections.abc.Iterable[global___Portfolio] | None = ...,
        portfolio_principal_association: collections.abc.Iterable[global___PortfolioPrincipalAssociation] | None = ...,
        portfolio_product_association: collections.abc.Iterable[global___PortfolioProductAssociation] | None = ...,
        portfolio_share: collections.abc.Iterable[global___PortfolioShare] | None = ...,
        resource_update_constraint: collections.abc.Iterable[global___ResourceUpdateConstraint] | None = ...,
        stack_set_constraint: collections.abc.Iterable[global___StackSetConstraint] | None = ...,
        tag_option: collections.abc.Iterable[global___TagOption] | None = ...,
        tag_option_association: collections.abc.Iterable[global___TagOptionAssociation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_portfolio_share", b"accepted_portfolio_share", "cloud_formation_product", b"cloud_formation_product", "cloud_formation_provisioned_product", b"cloud_formation_provisioned_product", "launch_notification_constraint", b"launch_notification_constraint", "launch_role_constraint", b"launch_role_constraint", "launch_template_constraint", b"launch_template_constraint", "portfolio", b"portfolio", "portfolio_principal_association", b"portfolio_principal_association", "portfolio_product_association", b"portfolio_product_association", "portfolio_share", b"portfolio_share", "resource_update_constraint", b"resource_update_constraint", "stack_set_constraint", b"stack_set_constraint", "tag_option", b"tag_option", "tag_option_association", b"tag_option_association"]) -> None: ...

global___ServiceCatalog = ServiceCatalog

@typing_extensions.final
class CloudFormationProductProvisioningArtifactProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class InfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLE_TEMPLATE_VALIDATION_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    disable_template_validation: builtins.bool
    @property
    def info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        disable_template_validation: builtins.bool = ...,
        info: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disable_template_validation", b"disable_template_validation", "info", b"info", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___CloudFormationProductProvisioningArtifactProperties = CloudFormationProductProvisioningArtifactProperties

@typing_extensions.final
class CloudFormationProduct(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPLACE_PROVISIONING_ARTIFACTS_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SUPPORT_DESCRIPTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISTRIBUTOR_FIELD_NUMBER: builtins.int
    SUPPORT_EMAIL_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    SUPPORT_URL_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_ARTIFACT_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    replace_provisioning_artifacts: builtins.bool
    owner: builtins.str
    support_description: builtins.str
    description: builtins.str
    distributor: builtins.str
    support_email: builtins.str
    accept_language: builtins.str
    support_url: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    @property
    def provisioning_artifact_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFormationProductProvisioningArtifactProperties]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        replace_provisioning_artifacts: builtins.bool = ...,
        owner: builtins.str = ...,
        support_description: builtins.str = ...,
        description: builtins.str = ...,
        distributor: builtins.str = ...,
        support_email: builtins.str = ...,
        accept_language: builtins.str = ...,
        support_url: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        provisioning_artifact_parameters: collections.abc.Iterable[global___CloudFormationProductProvisioningArtifactProperties] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "distributor", b"distributor", "name", b"name", "owner", b"owner", "provisioning_artifact_parameters", b"provisioning_artifact_parameters", "replace_provisioning_artifacts", b"replace_provisioning_artifacts", "resource_info", b"resource_info", "support_description", b"support_description", "support_email", b"support_email", "support_url", b"support_url", "tags", b"tags"]) -> None: ...

global___CloudFormationProduct = CloudFormationProduct

@typing_extensions.final
class CloudFormationProvisionedProductProvisioningParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___CloudFormationProvisionedProductProvisioningParameter = CloudFormationProvisionedProductProvisioningParameter

@typing_extensions.final
class CloudFormationProvisionedProductProvisioningPreferences(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STACK_SET_ACCOUNTS_FIELD_NUMBER: builtins.int
    STACK_SET_FAILURE_TOLERANCE_COUNT_FIELD_NUMBER: builtins.int
    STACK_SET_FAILURE_TOLERANCE_PERCENTAGE_FIELD_NUMBER: builtins.int
    STACK_SET_MAX_CONCURRENCY_COUNT_FIELD_NUMBER: builtins.int
    STACK_SET_MAX_CONCURRENCY_PERCENTAGE_FIELD_NUMBER: builtins.int
    STACK_SET_OPERATION_TYPE_FIELD_NUMBER: builtins.int
    STACK_SET_REGIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def stack_set_accounts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    stack_set_failure_tolerance_count: builtins.int
    stack_set_failure_tolerance_percentage: builtins.int
    stack_set_max_concurrency_count: builtins.int
    stack_set_max_concurrency_percentage: builtins.int
    stack_set_operation_type: builtins.str
    @property
    def stack_set_regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        stack_set_accounts: collections.abc.Iterable[builtins.str] | None = ...,
        stack_set_failure_tolerance_count: builtins.int = ...,
        stack_set_failure_tolerance_percentage: builtins.int = ...,
        stack_set_max_concurrency_count: builtins.int = ...,
        stack_set_max_concurrency_percentage: builtins.int = ...,
        stack_set_operation_type: builtins.str = ...,
        stack_set_regions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "stack_set_accounts", b"stack_set_accounts", "stack_set_failure_tolerance_count", b"stack_set_failure_tolerance_count", "stack_set_failure_tolerance_percentage", b"stack_set_failure_tolerance_percentage", "stack_set_max_concurrency_count", b"stack_set_max_concurrency_count", "stack_set_max_concurrency_percentage", b"stack_set_max_concurrency_percentage", "stack_set_operation_type", b"stack_set_operation_type", "stack_set_regions", b"stack_set_regions"]) -> None: ...

global___CloudFormationProvisionedProductProvisioningPreferences = CloudFormationProvisionedProductProvisioningPreferences

@typing_extensions.final
class CloudFormationProvisionedProduct(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    NOTIFICATION_ARNS_FIELD_NUMBER: builtins.int
    PATH_ID_FIELD_NUMBER: builtins.int
    PATH_NAME_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_NAME_FIELD_NUMBER: builtins.int
    PROVISIONED_PRODUCT_NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_ARTIFACT_ID_FIELD_NUMBER: builtins.int
    PROVISIONING_ARTIFACT_NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_PARAMETERS_FIELD_NUMBER: builtins.int
    PROVISIONING_PREFERENCES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    accept_language: builtins.str
    @property
    def notification_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    path_id: builtins.str
    path_name: builtins.str
    product_id: builtins.str
    product_name: builtins.str
    provisioned_product_name: builtins.str
    provisioning_artifact_id: builtins.str
    provisioning_artifact_name: builtins.str
    @property
    def provisioning_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFormationProvisionedProductProvisioningParameter]: ...
    @property
    def provisioning_preferences(self) -> global___CloudFormationProvisionedProductProvisioningPreferences: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        accept_language: builtins.str = ...,
        notification_arns: collections.abc.Iterable[builtins.str] | None = ...,
        path_id: builtins.str = ...,
        path_name: builtins.str = ...,
        product_id: builtins.str = ...,
        product_name: builtins.str = ...,
        provisioned_product_name: builtins.str = ...,
        provisioning_artifact_id: builtins.str = ...,
        provisioning_artifact_name: builtins.str = ...,
        provisioning_parameters: collections.abc.Iterable[global___CloudFormationProvisionedProductProvisioningParameter] | None = ...,
        provisioning_preferences: global___CloudFormationProvisionedProductProvisioningPreferences | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provisioning_preferences", b"provisioning_preferences", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "notification_arns", b"notification_arns", "path_id", b"path_id", "path_name", b"path_name", "product_id", b"product_id", "product_name", b"product_name", "provisioned_product_name", b"provisioned_product_name", "provisioning_artifact_id", b"provisioning_artifact_id", "provisioning_artifact_name", b"provisioning_artifact_name", "provisioning_parameters", b"provisioning_parameters", "provisioning_preferences", b"provisioning_preferences", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___CloudFormationProvisionedProduct = CloudFormationProvisionedProduct

@typing_extensions.final
class LaunchNotificationConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NOTIFICATION_ARNS_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def notification_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        notification_arns: collections.abc.Iterable[builtins.str] | None = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "notification_arns", b"notification_arns", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info"]) -> None: ...

global___LaunchNotificationConstraint = LaunchNotificationConstraint

@typing_extensions.final
class LaunchRoleConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LOCAL_ROLE_NAME_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    local_role_name: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        local_role_name: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "local_role_name", b"local_role_name", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___LaunchRoleConstraint = LaunchRoleConstraint

@typing_extensions.final
class LaunchTemplateConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    rules: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
        rules: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___LaunchTemplateConstraint = LaunchTemplateConstraint

@typing_extensions.final
class Portfolio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PROVIDER_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    provider_name: builtins.str
    description: builtins.str
    display_name: builtins.str
    accept_language: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        provider_name: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        accept_language: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "display_name", b"display_name", "provider_name", b"provider_name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Portfolio = Portfolio

@typing_extensions.final
class PortfolioPrincipalAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PRINCIPAL_ARN_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRINCIPAL_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    principal_arn: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    principal_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        principal_arn: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        principal_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "portfolio_id", b"portfolio_id", "principal_arn", b"principal_arn", "principal_type", b"principal_type", "resource_info", b"resource_info"]) -> None: ...

global___PortfolioPrincipalAssociation = PortfolioPrincipalAssociation

@typing_extensions.final
class PortfolioProductAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source_portfolio_id: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_portfolio_id: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info", "source_portfolio_id", b"source_portfolio_id"]) -> None: ...

global___PortfolioProductAssociation = PortfolioProductAssociation

@typing_extensions.final
class PortfolioShare(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    account_id: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        account_id: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "account_id", b"account_id", "portfolio_id", b"portfolio_id", "resource_info", b"resource_info"]) -> None: ...

global___PortfolioShare = PortfolioShare

@typing_extensions.final
class ResourceUpdateConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    TAG_UPDATE_ON_PROVISIONED_PRODUCT_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    accept_language: builtins.str
    tag_update_on_provisioned_product: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        accept_language: builtins.str = ...,
        tag_update_on_provisioned_product: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info", "tag_update_on_provisioned_product", b"tag_update_on_provisioned_product"]) -> None: ...

global___ResourceUpdateConstraint = ResourceUpdateConstraint

@typing_extensions.final
class StackSetConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STACK_INSTANCE_CONTROL_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    REGION_LIST_FIELD_NUMBER: builtins.int
    ADMIN_ROLE_FIELD_NUMBER: builtins.int
    ACCOUNT_LIST_FIELD_NUMBER: builtins.int
    EXECUTION_ROLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    stack_instance_control: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    @property
    def region_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    admin_role: builtins.str
    @property
    def account_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    execution_role: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        stack_instance_control: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
        region_list: collections.abc.Iterable[builtins.str] | None = ...,
        admin_role: builtins.str = ...,
        account_list: collections.abc.Iterable[builtins.str] | None = ...,
        execution_role: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "account_list", b"account_list", "admin_role", b"admin_role", "description", b"description", "execution_role", b"execution_role", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "region_list", b"region_list", "resource_info", b"resource_info", "stack_instance_control", b"stack_instance_control"]) -> None: ...

global___StackSetConstraint = StackSetConstraint

@typing_extensions.final
class TagOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    active: builtins.bool
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        active: builtins.bool = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___TagOption = TagOption

@typing_extensions.final
class TagOptionAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAG_OPTION_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    tag_option_id: builtins.str
    resource_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tag_option_id: builtins.str = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_id", b"resource_id", "resource_info", b"resource_info", "tag_option_id", b"tag_option_id"]) -> None: ...

global___TagOptionAssociation = TagOptionAssociation
