# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_os.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10gcp/gcp_os.proto\x12\x12oak9.tython.gcp.os\x1a\x13shared/shared.proto\"\xd5\x01\n9OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels\x12i\n\x06labels\x18\x01 \x03(\x0b\x32Y.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd5\x01\n9OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels\x12i\n\x06labels\x18\x01 \x03(\x0b\x32Y.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n5OsConfigOsPolicyAssignmentXInstanceFilterXInventories\x12\x15\n\ros_short_name\x18\x01 \x01(\t\x12\x12\n\nos_version\x18\x02 \x01(\t\"\xea\x02\n)OsConfigOsPolicyAssignmentXInstanceFilter\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12g\n\x10\x65xclusion_labels\x18\x02 \x03(\x0b\x32M.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels\x12g\n\x10inclusion_labels\x18\x03 \x03(\x0b\x32M.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels\x12^\n\x0binventories\x18\x04 \x03(\x0b\x32I.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXInventories\"r\nEOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters\x12\x15\n\ros_short_name\x18\x01 \x01(\t\x12\x12\n\nos_version\x18\x02 \x01(\t\"\x8a\x01\nTOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"\x7f\nWOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xf2\x02\nPOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12u\n\x03gcs\x18\x03 \x01(\x0b\x32h.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs\x12{\n\x06remote\x18\x04 \x01(\x0b\x32k.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote\"\x8e\x02\nKOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x18\n\x10output_file_path\x18\x03 \x01(\t\x12\x0e\n\x06script\x18\x04 \x01(\t\x12r\n\x04\x66ile\x18\x05 \x01(\x0b\x32\x64.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile\"\x8b\x01\nUOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"\x80\x01\nXOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xf5\x02\nQOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12v\n\x03gcs\x18\x03 \x01(\x0b\x32i.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs\x12|\n\x06remote\x18\x04 \x01(\x0b\x32l.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote\"\x90\x02\nLOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x18\n\x10output_file_path\x18\x03 \x01(\t\x12\x0e\n\x06script\x18\x04 \x01(\t\x12s\n\x04\x66ile\x18\x05 \x01(\x0b\x32\x65.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile\"\xab\x02\nCOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec\x12p\n\x07\x65nforce\x18\x01 \x01(\x0b\x32_.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce\x12r\n\x08validate\x18\x02 \x01(\x0b\x32`.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate\"\x82\x01\nLOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"w\nOOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xda\x02\nHOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12m\n\x03gcs\x18\x03 \x01(\x0b\x32`.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs\x12s\n\x06remote\x18\x04 \x01(\x0b\x32\x63.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote\"\xf4\x01\nCOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12j\n\x04\x66ile\x18\x05 \x01(\x0b\x32\\.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile\"V\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x87\x01\nQOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"|\nTOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xe9\x02\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12r\n\x03gcs\x18\x03 \x01(\x0b\x32\x65.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs\x12x\n\x06remote\x18\x04 \x01(\x0b\x32h.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote\"\xce\x01\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb\x12\x11\n\tpull_deps\x18\x01 \x01(\x08\x12q\n\x06source\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource\"Y\nIOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x87\x01\nQOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"|\nTOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xe9\x02\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12r\n\x03gcs\x18\x03 \x01(\x0b\x32\x65.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs\x12x\n\x06remote\x18\x04 \x01(\x0b\x32h.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote\"\xcf\x01\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi\x12\x12\n\nproperties\x18\x01 \x03(\t\x12q\n\x06source\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource\"\x87\x01\nQOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"|\nTOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xe9\x02\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12r\n\x03gcs\x18\x03 \x01(\x0b\x32\x65.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs\x12x\n\x06remote\x18\x04 \x01(\x0b\x32h.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote\"\xce\x01\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm\x12\x11\n\tpull_deps\x18\x01 \x01(\x08\x12q\n\x06source\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource\"V\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum\x12\x0c\n\x04name\x18\x01 \x01(\t\"Y\nIOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc6\x06\nBOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg\x12\x15\n\rdesired_state\x18\x01 \x01(\t\x12g\n\x03\x61pt\x18\x02 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt\x12g\n\x03\x64\x65\x62\x18\x03 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb\x12m\n\x06googet\x18\x04 \x01(\x0b\x32].oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget\x12g\n\x03msi\x18\x05 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi\x12g\n\x03rpm\x18\x06 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm\x12g\n\x03yum\x18\x07 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum\x12m\n\x06zypper\x18\x08 \x01(\x0b\x32].oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper\"\xad\x01\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt\x12\x14\n\x0c\x61rchive_type\x18\x01 \x01(\t\x12\x12\n\ncomponents\x18\x02 \x03(\t\x12\x14\n\x0c\x64istribution\x18\x03 \x01(\t\x12\x0f\n\x07gpg_key\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\"j\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x95\x01\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x10\n\x08gpg_keys\x18\x03 \x03(\t\x12\n\n\x02id\x18\x04 \x01(\t\"\x98\x01\nPOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x10\n\x08gpg_keys\x18\x03 \x03(\t\x12\n\n\x02id\x18\x04 \x01(\t\"\x91\x04\nIOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository\x12n\n\x03\x61pt\x18\x01 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt\x12n\n\x03goo\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo\x12n\n\x03yum\x18\x03 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum\x12t\n\x06zypper\x18\x04 \x01(\x0b\x32\x64.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper\"\xf2\x03\n>OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources\x12\n\n\x02id\x18\x01 \x01(\t\x12\x65\n\x04\x65xec\x18\x02 \x01(\x0b\x32W.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec\x12\x65\n\x04\x66ile\x18\x03 \x01(\x0b\x32W.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile\x12\x63\n\x03pkg\x18\x04 \x01(\x0b\x32V.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg\x12q\n\nrepository\x18\x05 \x01(\x0b\x32].oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository\"\x93\x02\n4OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups\x12t\n\x11inventory_filters\x18\x01 \x03(\x0b\x32Y.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters\x12\x65\n\tresources\x18\x02 \x03(\x0b\x32R.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources\"\xe0\x01\n%OsConfigOsPolicyAssignmentXOsPolicies\x12%\n\x1d\x61llow_no_resource_group_match\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04mode\x18\x04 \x01(\t\x12\x61\n\x0fresource_groups\x18\x05 \x03(\x0b\x32H.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups\"U\n3OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xa3\x01\n\"OsConfigOsPolicyAssignmentXRollout\x12\x19\n\x11min_wait_duration\x18\x01 \x01(\t\x12\x62\n\x11\x64isruption_budget\x18\x02 \x01(\x0b\x32G.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget\"U\n#OsConfigOsPolicyAssignmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x80\x05\n\x1aOsConfigOsPolicyAssignment\x12\x10\n\x08\x62\x61seline\x18\x01 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04\x65tag\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x13\n\x0breconciling\x18\t \x01(\x08\x12\x1c\n\x14revision_create_time\x18\n \x01(\t\x12\x13\n\x0brevision_id\x18\x0b \x01(\t\x12\x15\n\rrollout_state\x18\x0c \x01(\t\x12\x0b\n\x03uid\x18\r \x01(\t\x12V\n\x0finstance_filter\x18\x0e \x01(\x0b\x32=.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilter\x12N\n\x0bos_policies\x18\x0f \x03(\x0b\x32\x39.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPolicies\x12G\n\x07rollout\x18\x10 \x01(\x0b\x32\x36.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXRollout\x12I\n\x08timeouts\x18\x11 \x01(\x0b\x32\x37.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc7\x01\n2OsConfigPatchDeploymentXInstanceFilterXGroupLabels\x12\x62\n\x06labels\x18\x01 \x03(\x0b\x32R.oak9.tython.gcp.os.OsConfigPatchDeploymentXInstanceFilterXGroupLabels.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd5\x01\n&OsConfigPatchDeploymentXInstanceFilter\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x1e\n\x16instance_name_prefixes\x18\x02 \x03(\t\x12\x11\n\tinstances\x18\x03 \x03(\t\x12\r\n\x05zones\x18\x04 \x03(\t\x12\\\n\x0cgroup_labels\x18\x05 \x03(\x0b\x32\x46.oak9.tython.gcp.os.OsConfigPatchDeploymentXInstanceFilterXGroupLabels\"?\n\'OsConfigPatchDeploymentXOneTimeSchedule\x12\x14\n\x0c\x65xecute_time\x18\x01 \x01(\t\"e\n\'OsConfigPatchDeploymentXPatchConfigXApt\x12\x10\n\x08\x65xcludes\x18\x01 \x03(\t\x12\x1a\n\x12\x65xclusive_packages\x18\x02 \x03(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\":\n\'OsConfigPatchDeploymentXPatchConfigXGoo\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\x87\x01\nJOsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x19\n\x11generation_number\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\xfe\x01\n@OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig\x12\x1d\n\x15\x61llowed_success_codes\x18\x01 \x03(\x01\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12r\n\ngcs_object\x18\x04 \x01(\x0b\x32^.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject\"\x89\x01\nLOsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x19\n\x11generation_number\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\x82\x02\nBOsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig\x12\x1d\n\x15\x61llowed_success_codes\x18\x01 \x03(\x01\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12t\n\ngcs_object\x18\x04 \x01(\x0b\x32`.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject\"\x9e\x02\n,OsConfigPatchDeploymentXPatchConfigXPostStep\x12t\n\x16linux_exec_step_config\x18\x01 \x01(\x0b\x32T.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig\x12x\n\x18windows_exec_step_config\x18\x02 \x01(\x0b\x32V.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig\"\x86\x01\nIOsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x19\n\x11generation_number\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\xfc\x01\n?OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig\x12\x1d\n\x15\x61llowed_success_codes\x18\x01 \x03(\x01\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12q\n\ngcs_object\x18\x04 \x01(\x0b\x32].oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject\"\x88\x01\nKOsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x19\n\x11generation_number\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\x80\x02\nAOsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig\x12\x1d\n\x15\x61llowed_success_codes\x18\x01 \x03(\x01\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12s\n\ngcs_object\x18\x04 \x01(\x0b\x32_.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject\"\x9b\x02\n+OsConfigPatchDeploymentXPatchConfigXPreStep\x12s\n\x16linux_exec_step_config\x18\x01 \x01(\x0b\x32S.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig\x12w\n\x18windows_exec_step_config\x18\x02 \x01(\x0b\x32U.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig\"y\n1OsConfigPatchDeploymentXPatchConfigXWindowsUpdate\x12\x17\n\x0f\x63lassifications\x18\x01 \x03(\t\x12\x10\n\x08\x65xcludes\x18\x02 \x03(\t\x12\x19\n\x11\x65xclusive_patches\x18\x03 \x03(\t\"z\n\'OsConfigPatchDeploymentXPatchConfigXYum\x12\x10\n\x08\x65xcludes\x18\x01 \x03(\t\x12\x1a\n\x12\x65xclusive_packages\x18\x02 \x03(\t\x12\x0f\n\x07minimal\x18\x03 \x01(\x08\x12\x10\n\x08security\x18\x04 \x01(\x08\"\xad\x01\n*OsConfigPatchDeploymentXPatchConfigXZypper\x12\x12\n\ncategories\x18\x01 \x03(\t\x12\x10\n\x08\x65xcludes\x18\x02 \x03(\t\x12\x19\n\x11\x65xclusive_patches\x18\x03 \x03(\t\x12\x12\n\nseverities\x18\x04 \x03(\t\x12\x15\n\rwith_optional\x18\x05 \x01(\x08\x12\x13\n\x0bwith_update\x18\x06 \x01(\x08\"\x90\x05\n#OsConfigPatchDeploymentXPatchConfig\x12\x1d\n\x15mig_instances_allowed\x18\x01 \x01(\x08\x12\x15\n\rreboot_config\x18\x02 \x01(\t\x12H\n\x03\x61pt\x18\x03 \x01(\x0b\x32;.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXApt\x12H\n\x03goo\x18\x04 \x01(\x0b\x32;.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXGoo\x12S\n\tpost_step\x18\x05 \x01(\x0b\x32@.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStep\x12Q\n\x08pre_step\x18\x06 \x01(\x0b\x32?.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStep\x12]\n\x0ewindows_update\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXWindowsUpdate\x12H\n\x03yum\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXYum\x12N\n\x06zypper\x18\t \x01(\x0b\x32>.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXZypper\"m\n@OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\t\x12\x14\n\x0cweek_ordinal\x18\x02 \x01(\x01\"\xb7\x01\n1OsConfigPatchDeploymentXRecurringScheduleXMonthly\x12\x11\n\tmonth_day\x18\x01 \x01(\x01\x12o\n\x11week_day_of_month\x18\x02 \x01(\x0b\x32T.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth\"u\n3OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay\x12\r\n\x05hours\x18\x01 \x01(\x01\x12\x0f\n\x07minutes\x18\x02 \x01(\x01\x12\r\n\x05nanos\x18\x03 \x01(\x01\x12\x0f\n\x07seconds\x18\x04 \x01(\x01\"Q\n2OsConfigPatchDeploymentXRecurringScheduleXTimeZone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"G\n0OsConfigPatchDeploymentXRecurringScheduleXWeekly\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\t\"\xee\x03\n)OsConfigPatchDeploymentXRecurringSchedule\x12\x10\n\x08\x65nd_time\x18\x01 \x01(\t\x12\x19\n\x11last_execute_time\x18\x02 \x01(\t\x12\x19\n\x11next_execute_time\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\x12V\n\x07monthly\x18\x05 \x01(\x0b\x32\x45.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXMonthly\x12\\\n\x0btime_of_day\x18\x06 \x01(\x0b\x32G.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay\x12Y\n\ttime_zone\x18\x07 \x01(\x0b\x32\x46.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXTimeZone\x12T\n\x06weekly\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXWeekly\"U\n0OsConfigPatchDeploymentXRolloutXDisruptionBudget\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"\x90\x01\n\x1fOsConfigPatchDeploymentXRollout\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12_\n\x11\x64isruption_budget\x18\x02 \x01(\x0b\x32\x44.oak9.tython.gcp.os.OsConfigPatchDeploymentXRolloutXDisruptionBudget\"B\n OsConfigPatchDeploymentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xeb\x05\n\x17OsConfigPatchDeployment\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x19\n\x11last_execute_time\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13patch_deployment_id\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x13\n\x0bupdate_time\x18\t \x01(\t\x12S\n\x0finstance_filter\x18\n \x01(\x0b\x32:.oak9.tython.gcp.os.OsConfigPatchDeploymentXInstanceFilter\x12V\n\x11one_time_schedule\x18\x0b \x01(\x0b\x32;.oak9.tython.gcp.os.OsConfigPatchDeploymentXOneTimeSchedule\x12M\n\x0cpatch_config\x18\x0c \x01(\x0b\x32\x37.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfig\x12Y\n\x12recurring_schedule\x18\r \x01(\x0b\x32=.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringSchedule\x12\x44\n\x07rollout\x18\x0e \x01(\x0b\x32\x33.oak9.tython.gcp.os.OsConfigPatchDeploymentXRollout\x12\x46\n\x08timeouts\x18\x0f \x01(\x0b\x32\x34.oak9.tython.gcp.os.OsConfigPatchDeploymentXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"N\n\x1cOsLoginSshPublicKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfd\x01\n\x13OsLoginSshPublicKey\x12\x1c\n\x14\x65xpiration_time_usec\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x42\n\x08timeouts\x18\x07 \x01(\x0b\x32\x30.oak9.tython.gcp.os.OsLoginSshPublicKeyXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_os_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS_LABELSENTRY._options = None
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS_LABELSENTRY._serialized_options = b'8\001'
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS_LABELSENTRY._options = None
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS_LABELSENTRY._serialized_options = b'8\001'
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS_LABELSENTRY._options = None
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS_LABELSENTRY._serialized_options = b'8\001'
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS._serialized_start=62
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS._serialized_end=275
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS_LABELSENTRY._serialized_start=230
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS_LABELSENTRY._serialized_end=275
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS._serialized_start=278
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS._serialized_end=491
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS_LABELSENTRY._serialized_start=230
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS_LABELSENTRY._serialized_end=275
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINVENTORIES._serialized_start=493
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINVENTORIES._serialized_end=591
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTER._serialized_start=594
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTER._serialized_end=956
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXINVENTORYFILTERS._serialized_start=958
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXINVENTORYFILTERS._serialized_end=1072
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILEXGCS._serialized_start=1075
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILEXGCS._serialized_end=1213
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILEXREMOTE._serialized_start=1215
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILEXREMOTE._serialized_end=1342
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILE._serialized_start=1345
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILE._serialized_end=1715
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCE._serialized_start=1718
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCE._serialized_end=1988
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILEXGCS._serialized_start=1991
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILEXGCS._serialized_end=2130
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILEXREMOTE._serialized_start=2133
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILEXREMOTE._serialized_end=2261
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILE._serialized_start=2264
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILE._serialized_end=2637
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATE._serialized_start=2640
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATE._serialized_end=2912
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXEC._serialized_start=2915
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXEC._serialized_end=3214
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILEXGCS._serialized_start=3217
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILEXGCS._serialized_end=3347
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILEXREMOTE._serialized_start=3349
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILEXREMOTE._serialized_end=3468
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILE._serialized_start=3471
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILE._serialized_end=3817
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILE._serialized_start=3820
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILE._serialized_end=4064
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXAPT._serialized_start=4066
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXAPT._serialized_end=4152
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCEXGCS._serialized_start=4155
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCEXGCS._serialized_end=4290
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCEXREMOTE._serialized_start=4292
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCEXREMOTE._serialized_end=4416
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCE._serialized_start=4419
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCE._serialized_end=4780
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEB._serialized_start=4783
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEB._serialized_end=4989
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXGOOGET._serialized_start=4991
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXGOOGET._serialized_end=5080
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCEXGCS._serialized_start=5083
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCEXGCS._serialized_end=5218
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCEXREMOTE._serialized_start=5220
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCEXREMOTE._serialized_end=5344
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCE._serialized_start=5347
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCE._serialized_end=5708
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSI._serialized_start=5711
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSI._serialized_end=5918
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCEXGCS._serialized_start=5921
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCEXGCS._serialized_end=6056
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCEXREMOTE._serialized_start=6058
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCEXREMOTE._serialized_end=6182
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCE._serialized_start=6185
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCE._serialized_end=6546
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPM._serialized_start=6549
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPM._serialized_end=6755
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXYUM._serialized_start=6757
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXYUM._serialized_end=6843
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXZYPPER._serialized_start=6845
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXZYPPER._serialized_end=6934
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKG._serialized_start=6937
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKG._serialized_end=7775
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXAPT._serialized_start=7778
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXAPT._serialized_end=7951
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXGOO._serialized_start=7953
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXGOO._serialized_end=8059
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXYUM._serialized_start=8062
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXYUM._serialized_end=8211
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXZYPPER._serialized_start=8214
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXZYPPER._serialized_end=8366
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORY._serialized_start=8369
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORY._serialized_end=8898
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCES._serialized_start=8901
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCES._serialized_end=9399
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPS._serialized_start=9402
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPS._serialized_end=9677
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIES._serialized_start=9680
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIES._serialized_end=9904
  _OSCONFIGOSPOLICYASSIGNMENTXROLLOUTXDISRUPTIONBUDGET._serialized_start=9906
  _OSCONFIGOSPOLICYASSIGNMENTXROLLOUTXDISRUPTIONBUDGET._serialized_end=9991
  _OSCONFIGOSPOLICYASSIGNMENTXROLLOUT._serialized_start=9994
  _OSCONFIGOSPOLICYASSIGNMENTXROLLOUT._serialized_end=10157
  _OSCONFIGOSPOLICYASSIGNMENTXTIMEOUTS._serialized_start=10159
  _OSCONFIGOSPOLICYASSIGNMENTXTIMEOUTS._serialized_end=10244
  _OSCONFIGOSPOLICYASSIGNMENT._serialized_start=10247
  _OSCONFIGOSPOLICYASSIGNMENT._serialized_end=10887
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS._serialized_start=10890
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS._serialized_end=11089
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS_LABELSENTRY._serialized_start=230
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS_LABELSENTRY._serialized_end=275
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTER._serialized_start=11092
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTER._serialized_end=11305
  _OSCONFIGPATCHDEPLOYMENTXONETIMESCHEDULE._serialized_start=11307
  _OSCONFIGPATCHDEPLOYMENTXONETIMESCHEDULE._serialized_end=11370
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXAPT._serialized_start=11372
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXAPT._serialized_end=11473
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXGOO._serialized_start=11475
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXGOO._serialized_end=11533
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXLINUXEXECSTEPCONFIGXGCSOBJECT._serialized_start=11536
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXLINUXEXECSTEPCONFIGXGCSOBJECT._serialized_end=11671
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXLINUXEXECSTEPCONFIG._serialized_start=11674
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXLINUXEXECSTEPCONFIG._serialized_end=11928
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXWINDOWSEXECSTEPCONFIGXGCSOBJECT._serialized_start=11931
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXWINDOWSEXECSTEPCONFIGXGCSOBJECT._serialized_end=12068
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXWINDOWSEXECSTEPCONFIG._serialized_start=12071
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXWINDOWSEXECSTEPCONFIG._serialized_end=12329
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEP._serialized_start=12332
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEP._serialized_end=12618
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXLINUXEXECSTEPCONFIGXGCSOBJECT._serialized_start=12621
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXLINUXEXECSTEPCONFIGXGCSOBJECT._serialized_end=12755
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXLINUXEXECSTEPCONFIG._serialized_start=12758
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXLINUXEXECSTEPCONFIG._serialized_end=13010
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXWINDOWSEXECSTEPCONFIGXGCSOBJECT._serialized_start=13013
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXWINDOWSEXECSTEPCONFIGXGCSOBJECT._serialized_end=13149
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXWINDOWSEXECSTEPCONFIG._serialized_start=13152
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXWINDOWSEXECSTEPCONFIG._serialized_end=13408
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEP._serialized_start=13411
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEP._serialized_end=13694
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXWINDOWSUPDATE._serialized_start=13696
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXWINDOWSUPDATE._serialized_end=13817
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXYUM._serialized_start=13819
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXYUM._serialized_end=13941
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXZYPPER._serialized_start=13944
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXZYPPER._serialized_end=14117
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIG._serialized_start=14120
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIG._serialized_end=14776
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXMONTHLYXWEEKDAYOFMONTH._serialized_start=14778
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXMONTHLYXWEEKDAYOFMONTH._serialized_end=14887
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXMONTHLY._serialized_start=14890
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXMONTHLY._serialized_end=15073
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXTIMEOFDAY._serialized_start=15075
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXTIMEOFDAY._serialized_end=15192
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXTIMEZONE._serialized_start=15194
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXTIMEZONE._serialized_end=15275
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXWEEKLY._serialized_start=15277
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXWEEKLY._serialized_end=15348
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULE._serialized_start=15351
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULE._serialized_end=15845
  _OSCONFIGPATCHDEPLOYMENTXROLLOUTXDISRUPTIONBUDGET._serialized_start=15847
  _OSCONFIGPATCHDEPLOYMENTXROLLOUTXDISRUPTIONBUDGET._serialized_end=15932
  _OSCONFIGPATCHDEPLOYMENTXROLLOUT._serialized_start=15935
  _OSCONFIGPATCHDEPLOYMENTXROLLOUT._serialized_end=16079
  _OSCONFIGPATCHDEPLOYMENTXTIMEOUTS._serialized_start=16081
  _OSCONFIGPATCHDEPLOYMENTXTIMEOUTS._serialized_end=16147
  _OSCONFIGPATCHDEPLOYMENT._serialized_start=16150
  _OSCONFIGPATCHDEPLOYMENT._serialized_end=16897
  _OSLOGINSSHPUBLICKEYXTIMEOUTS._serialized_start=16899
  _OSLOGINSSHPUBLICKEYXTIMEOUTS._serialized_end=16977
  _OSLOGINSSHPUBLICKEY._serialized_start=16980
  _OSLOGINSSHPUBLICKEY._serialized_end=17233
# @@protoc_insertion_point(module_scope)
