# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ecr.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_ecr.proto\x12\x13oak9.tython.aws.ecr\x1a\x13shared/shared.proto\"\x88\x01\n\x19RepositoryLifecyclePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15lifecycle_policy_text\x18\x02 \x01(\t\x12\x13\n\x0bregistry_id\x18\x03 \x01(\t\"\xee\x04\n\nRepository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x10lifecycle_policy\x18\x02 \x01(\x0b\x32..oak9.tython.aws.ecr.RepositoryLifecyclePolicy\x12\x17\n\x0frepository_name\x18\x03 \x01(\t\x12Y\n\x16repository_policy_text\x18\x04 \x03(\x0b\x32\x39.oak9.tython.aws.ecr.Repository.RepositoryPolicyTextEntry\x12\x37\n\x04tags\x18\x05 \x03(\x0b\x32).oak9.tython.aws.ecr.Repository.TagsEntry\x12\x1c\n\x14image_tag_mutability\x18\x06 \x01(\t\x12\x65\n\x1cimage_scanning_configuration\x18\x07 \x03(\x0b\x32?.oak9.tython.aws.ecr.Repository.ImageScanningConfigurationEntry\x1a;\n\x19RepositoryPolicyTextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x41\n\x1fImageScanningConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x03\x45\x43R\x12\x33\n\nrepository\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.ecr.Repositoryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ecr_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPOSITORY_REPOSITORYPOLICYTEXTENTRY._options = None
  _REPOSITORY_REPOSITORYPOLICYTEXTENTRY._serialized_options = b'8\001'
  _REPOSITORY_TAGSENTRY._options = None
  _REPOSITORY_TAGSENTRY._serialized_options = b'8\001'
  _REPOSITORY_IMAGESCANNINGCONFIGURATIONENTRY._options = None
  _REPOSITORY_IMAGESCANNINGCONFIGURATIONENTRY._serialized_options = b'8\001'
  _REPOSITORYLIFECYCLEPOLICY._serialized_start=64
  _REPOSITORYLIFECYCLEPOLICY._serialized_end=200
  _REPOSITORY._serialized_start=203
  _REPOSITORY._serialized_end=825
  _REPOSITORY_REPOSITORYPOLICYTEXTENTRY._serialized_start=654
  _REPOSITORY_REPOSITORYPOLICYTEXTENTRY._serialized_end=713
  _REPOSITORY_TAGSENTRY._serialized_start=715
  _REPOSITORY_TAGSENTRY._serialized_end=758
  _REPOSITORY_IMAGESCANNINGCONFIGURATIONENTRY._serialized_start=760
  _REPOSITORY_IMAGESCANNINGCONFIGURATIONENTRY._serialized_end=825
  _ECR._serialized_start=827
  _ECR._serialized_end=885
# @@protoc_insertion_point(module_scope)
