# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_keyvault.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$azure/azure_microsoft_keyvault.proto\x12$oak9.tython.azure.microsoft_keyvault\x1a\x13shared/shared.proto\"\x99\x03\n\x12Microsoft_KeyVault\x12<\n\x06vaults\x18\x01 \x01(\x0b\x32,.oak9.tython.azure.microsoft_keyvault.Vaults\x12Z\n\x16vaults_access_policies\x18\x02 \x03(\x0b\x32:.oak9.tython.azure.microsoft_keyvault.VaultsAccessPolicies\x12\x45\n\x0bvaults_keys\x18\x03 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_keyvault.VaultsKeys\x12K\n\x0evaults_secrets\x18\x04 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_keyvault.VaultsSecrets\x12U\n\x13vaults_certificates\x18\x05 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_keyvault.VaultsCertificates\"q\n\x12VaultsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0ckey_vault_id\x18\x03 \x01(\t\"\xc1\x02\n\rVaultsSecrets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\nattributes\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_keyvault.SecretAttributes\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12K\n\x04tags\x18\x06 \x03(\x0b\x32=.oak9.tython.azure.microsoft_keyvault.VaultsSecrets.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x10SecretAttributes\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0b\n\x03\x65xp\x18\x02 \x01(\t\x12\x0b\n\x03nbf\x18\x03 \x01(\t\"\xdc\x02\n VaultsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12O\n\x10private_endpoint\x18\x04 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_keyvault.PrivateEndpoint\x12v\n%private_link_service_connection_state\x18\x05 \x01(\x0b\x32G.oak9.tython.azure.microsoft_keyvault.PrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x0fPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf6\x03\n\nVaultsKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12G\n\nattributes\x18\x03 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_keyvault.KeyAttributes\x12\x12\n\ncurve_name\x18\x04 \x01(\t\x12\x0f\n\x07key_ops\x18\x05 \x03(\t\x12\x10\n\x08key_size\x18\x06 \x01(\x05\x12\x0b\n\x03kty\x18\x07 \x01(\t\x12N\n\x0erelease_policy\x18\x08 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_keyvault.KeyReleasePolicy\x12M\n\x0frotation_policy\x18\t \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_keyvault.RotationPolicy\x12H\n\x04tags\x18\n \x03(\x0b\x32:.oak9.tython.azure.microsoft_keyvault.VaultsKeys.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x01\n\x0eRotationPolicy\x12U\n\nattributes\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_keyvault.KeyRotationPolicyAttributes\x12N\n\x10lifetime_actions\x18\x02 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_keyvault.LifetimeAction\"\x8e\x01\n\x0eLifetimeAction\x12<\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32,.oak9.tython.azure.microsoft_keyvault.Action\x12>\n\x07trigger\x18\x02 \x01(\x0b\x32-.oak9.tython.azure.microsoft_keyvault.Trigger\"@\n\x07Trigger\x12\x19\n\x11time_after_create\x18\x01 \x01(\t\x12\x1a\n\x12time_before_expiry\x18\x02 \x01(\t\"\x16\n\x06\x41\x63tion\x12\x0c\n\x04type\x18\x01 \x01(\t\"2\n\x1bKeyRotationPolicyAttributes\x12\x13\n\x0b\x65xpiry_time\x18\x01 \x01(\t\"6\n\x10KeyReleasePolicy\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"N\n\rKeyAttributes\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0b\n\x03\x65xp\x18\x02 \x01(\t\x12\x12\n\nexportable\x18\x03 \x01(\x08\x12\x0b\n\x03nbf\x18\x04 \x01(\t\"\xaf\x01\n\x14VaultsAccessPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12P\n\x0f\x61\x63\x63\x65ss_policies\x18\x03 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_keyvault.AccessPolicyEntry\"\x8a\x07\n\x06Vaults\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12P\n\x0f\x61\x63\x63\x65ss_policies\x18\x04 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_keyvault.AccessPolicyEntry\x12\x13\n\x0b\x63reate_mode\x18\x05 \x01(\t\x12\x1e\n\x16\x65nabled_for_deployment\x18\x06 \x01(\x08\x12#\n\x1b\x65nabled_for_disk_encryption\x18\x07 \x01(\x08\x12\'\n\x1f\x65nabled_for_template_deployment\x18\x08 \x01(\x08\x12\x1f\n\x17\x65nable_purge_protection\x18\t \x01(\x08\x12!\n\x19\x65nable_rbac_authorization\x18\n \x01(\x08\x12\x1a\n\x12\x65nable_soft_delete\x18\x0b \x01(\x08\x12J\n\x0cnetwork_acls\x18\x0c \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_keyvault.NetworkRuleSet\x12\x1a\n\x12provisioning_state\x18\r \x01(\t\x12\x1d\n\x15public_network_access\x18\x0e \x01(\t\x12\x36\n\x03sku\x18\x0f \x01(\x0b\x32).oak9.tython.azure.microsoft_keyvault.Sku\x12%\n\x1dsoft_delete_retention_in_days\x18\x10 \x01(\x05\x12\x11\n\ttenant_id\x18\x11 \x01(\t\x12\x11\n\tvault_uri\x18\x12 \x01(\t\x12\x44\n\x04tags\x18\x13 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_keyvault.Vaults.TagsEntry\x12s\n#vaults_private_endpoint_connections\x18\x14 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_keyvault.VaultsPrivateEndpointConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\x03Sku\x12\x0e\n\x06\x66\x61mily\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd1\x01\n\x0eNetworkRuleSet\x12\x0e\n\x06\x62ypass\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\t\x12>\n\x08ip_rules\x18\x03 \x03(\x0b\x32,.oak9.tython.azure.microsoft_keyvault.IPRule\x12W\n\x15virtual_network_rules\x18\x04 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_keyvault.VirtualNetworkRule\"N\n\x12VirtualNetworkRule\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n$ignore_missing_vnet_service_endpoint\x18\x02 \x01(\x08\"\x17\n\x06IPRule\x12\r\n\x05value\x18\x01 \x01(\t\"\x99\x01\n\x11\x41\x63\x63\x65ssPolicyEntry\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\x12\x11\n\tobject_id\x18\x02 \x01(\t\x12\x46\n\x0bpermissions\x18\x03 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_keyvault.Permissions\x12\x11\n\ttenant_id\x18\x04 \x01(\t\"S\n\x0bPermissions\x12\x14\n\x0c\x63\x65rtificates\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x0f\n\x07secrets\x18\x03 \x03(\t\x12\x0f\n\x07storage\x18\x04 \x03(\t\"\x96\x05\n%ManagedHSMsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12S\n\x10private_endpoint\x18\x05 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_keyvault.MHSMPrivateEndpoint\x12z\n%private_link_service_connection_state\x18\x06 \x01(\x0b\x32K.oak9.tython.azure.microsoft_keyvault.MHSMPrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x07 \x01(\t\x12@\n\x03sku\x18\x08 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_keyvault.ManagedHsmSku\x12\x45\n\x0bsystem_data\x18\t \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_keyvault.SystemData\x12\x63\n\x04tags\x18\n \x03(\x0b\x32U.oak9.tython.azure.microsoft_keyvault.ManagedHSMsPrivateEndpointConnections.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n%MHSMPrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"#\n\x13MHSMPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x87\x06\n\x0bManagedHSMs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x63reate_mode\x18\x04 \x01(\t\x12\x1f\n\x17\x65nable_purge_protection\x18\x05 \x01(\x08\x12\x1a\n\x12\x65nable_soft_delete\x18\x06 \x01(\x08\x12 \n\x18initial_admin_object_ids\x18\x07 \x03(\t\x12N\n\x0cnetwork_acls\x18\x08 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_keyvault.MHSMNetworkRuleSet\x12\x1d\n\x15public_network_access\x18\t \x01(\t\x12%\n\x1dsoft_delete_retention_in_days\x18\n \x01(\x05\x12\x11\n\ttenant_id\x18\x0b \x01(\t\x12@\n\x03sku\x18\x0c \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_keyvault.ManagedHsmSku\x12\x45\n\x0bsystem_data\x18\r \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_keyvault.SystemData\x12I\n\x04tags\x18\x0e \x03(\x0b\x32;.oak9.tython.azure.microsoft_keyvault.ManagedHSMs.TagsEntry\x12\x80\x01\n+managed_h_s_ms_private_endpoint_connections\x18\x0f \x03(\x0b\x32K.oak9.tython.azure.microsoft_keyvault.ManagedHSMsPrivateEndpointConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\nSystemData\x12\x12\n\ncreated_at\x18\x01 \x01(\t\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x17\n\x0f\x63reated_by_type\x18\x03 \x01(\t\x12\x18\n\x10last_modified_at\x18\x04 \x01(\t\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x1d\n\x15last_modified_by_type\x18\x06 \x01(\t\"-\n\rManagedHsmSku\x12\x0e\n\x06\x66\x61mily\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xdd\x01\n\x12MHSMNetworkRuleSet\x12\x0e\n\x06\x62ypass\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\t\x12\x42\n\x08ip_rules\x18\x03 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_keyvault.MHSMIPRule\x12[\n\x15virtual_network_rules\x18\x04 \x03(\x0b\x32<.oak9.tython.azure.microsoft_keyvault.MHSMVirtualNetworkRule\"$\n\x16MHSMVirtualNetworkRule\x12\n\n\x02id\x18\x01 \x01(\t\"\x1b\n\nMHSMIPRule\x12\r\n\x05value\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_keyvault_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VAULTSSECRETS_TAGSENTRY._options = None
  _VAULTSSECRETS_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSKEYS_TAGSENTRY._options = None
  _VAULTSKEYS_TAGSENTRY._serialized_options = b'8\001'
  _VAULTS_TAGSENTRY._options = None
  _VAULTS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._options = None
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDHSMS_TAGSENTRY._options = None
  _MANAGEDHSMS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_KEYVAULT._serialized_start=100
  _MICROSOFT_KEYVAULT._serialized_end=509
  _VAULTSCERTIFICATES._serialized_start=511
  _VAULTSCERTIFICATES._serialized_end=624
  _VAULTSSECRETS._serialized_start=627
  _VAULTSSECRETS._serialized_end=948
  _VAULTSSECRETS_TAGSENTRY._serialized_start=905
  _VAULTSSECRETS_TAGSENTRY._serialized_end=948
  _SECRETATTRIBUTES._serialized_start=950
  _SECRETATTRIBUTES._serialized_end=1011
  _VAULTSPRIVATEENDPOINTCONNECTIONS._serialized_start=1014
  _VAULTSPRIVATEENDPOINTCONNECTIONS._serialized_end=1362
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=1364
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=1462
  _PRIVATEENDPOINT._serialized_start=1464
  _PRIVATEENDPOINT._serialized_end=1495
  _VAULTSKEYS._serialized_start=1498
  _VAULTSKEYS._serialized_end=2000
  _VAULTSKEYS_TAGSENTRY._serialized_start=905
  _VAULTSKEYS_TAGSENTRY._serialized_end=948
  _ROTATIONPOLICY._serialized_start=2003
  _ROTATIONPOLICY._serialized_end=2186
  _LIFETIMEACTION._serialized_start=2189
  _LIFETIMEACTION._serialized_end=2331
  _TRIGGER._serialized_start=2333
  _TRIGGER._serialized_end=2397
  _ACTION._serialized_start=2399
  _ACTION._serialized_end=2421
  _KEYROTATIONPOLICYATTRIBUTES._serialized_start=2423
  _KEYROTATIONPOLICYATTRIBUTES._serialized_end=2473
  _KEYRELEASEPOLICY._serialized_start=2475
  _KEYRELEASEPOLICY._serialized_end=2529
  _KEYATTRIBUTES._serialized_start=2531
  _KEYATTRIBUTES._serialized_end=2609
  _VAULTSACCESSPOLICIES._serialized_start=2612
  _VAULTSACCESSPOLICIES._serialized_end=2787
  _VAULTS._serialized_start=2790
  _VAULTS._serialized_end=3696
  _VAULTS_TAGSENTRY._serialized_start=905
  _VAULTS_TAGSENTRY._serialized_end=948
  _SKU._serialized_start=3698
  _SKU._serialized_end=3733
  _NETWORKRULESET._serialized_start=3736
  _NETWORKRULESET._serialized_end=3945
  _VIRTUALNETWORKRULE._serialized_start=3947
  _VIRTUALNETWORKRULE._serialized_end=4025
  _IPRULE._serialized_start=4027
  _IPRULE._serialized_end=4050
  _ACCESSPOLICYENTRY._serialized_start=4053
  _ACCESSPOLICYENTRY._serialized_end=4206
  _PERMISSIONS._serialized_start=4208
  _PERMISSIONS._serialized_end=4291
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS._serialized_start=4294
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS._serialized_end=4956
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_start=905
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_end=948
  _MHSMPRIVATELINKSERVICECONNECTIONSTATE._serialized_start=4958
  _MHSMPRIVATELINKSERVICECONNECTIONSTATE._serialized_end=5060
  _MHSMPRIVATEENDPOINT._serialized_start=5062
  _MHSMPRIVATEENDPOINT._serialized_end=5097
  _MANAGEDHSMS._serialized_start=5100
  _MANAGEDHSMS._serialized_end=5875
  _MANAGEDHSMS_TAGSENTRY._serialized_start=905
  _MANAGEDHSMS_TAGSENTRY._serialized_end=948
  _SYSTEMDATA._serialized_start=5878
  _SYSTEMDATA._serialized_end=6038
  _MANAGEDHSMSKU._serialized_start=6040
  _MANAGEDHSMSKU._serialized_end=6085
  _MHSMNETWORKRULESET._serialized_start=6088
  _MHSMNETWORKRULESET._serialized_end=6309
  _MHSMVIRTUALNETWORKRULE._serialized_start=6311
  _MHSMVIRTUALNETWORKRULE._serialized_end=6347
  _MHSMIPRULE._serialized_start=6349
  _MHSMIPRULE._serialized_end=6376
# @@protoc_insertion_point(module_scope)
