# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_networkmanager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_networkmanager.proto\x12\x1eoak9.tython.aws.networkmanager\x1a\x13shared/shared.proto\"\xb2\x01\n\x1a\x43ustomerGatewayAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11global_network_id\x18\x02 \x01(\t\x12\x1c\n\x14\x63ustomer_gateway_arn\x18\x03 \x01(\t\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12\x0f\n\x07link_id\x18\x05 \x01(\t\"\x86\x04\n\x0eNetworkManager\x12`\n\x1c\x63ustomer_gateway_association\x18\x01 \x03(\x0b\x32:.oak9.tython.aws.networkmanager.CustomerGatewayAssociation\x12\x36\n\x06\x64\x65vice\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.networkmanager.Device\x12\x45\n\x0eglobal_network\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.networkmanager.GlobalNetwork\x12\x32\n\x04link\x18\x04 \x03(\x0b\x32$.oak9.tython.aws.networkmanager.Link\x12I\n\x10link_association\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.networkmanager.LinkAssociation\x12\x32\n\x04site\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.networkmanager.Site\x12`\n\x1ctransit_gateway_registration\x18\x07 \x03(\x0b\x32:.oak9.tython.aws.networkmanager.TransitGatewayRegistration\"\x7f\n\x0e\x44\x65viceLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x10\n\x08latitude\x18\x03 \x01(\t\x12\x11\n\tlongitude\x18\x04 \x01(\t\"\xf5\x02\n\x06\x44\x65vice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12>\n\x04tags\x18\x03 \x03(\x0b\x32\x30.oak9.tython.aws.networkmanager.Device.TagsEntry\x12\x19\n\x11global_network_id\x18\x04 \x01(\t\x12@\n\x08location\x18\x05 \x01(\x0b\x32..oak9.tython.aws.networkmanager.DeviceLocation\x12\r\n\x05model\x18\x06 \x01(\t\x12\x15\n\rserial_number\x18\x07 \x01(\t\x12\x0f\n\x07site_id\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12\x0e\n\x06vendor\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd1\x01\n\rGlobalNetwork\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x45\n\x04tags\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.networkmanager.GlobalNetwork.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\rLinkBandwidth\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x64ownload_speed\x18\x02 \x01(\x05\x12\x14\n\x0cupload_speed\x18\x03 \x01(\x05\"\xcd\x02\n\x04Link\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11global_network_id\x18\x02 \x01(\t\x12\x0f\n\x07site_id\x18\x03 \x01(\t\x12@\n\tbandwidth\x18\x04 \x01(\x0b\x32-.oak9.tython.aws.networkmanager.LinkBandwidth\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12<\n\x04tags\x18\x07 \x03(\x0b\x32..oak9.tython.aws.networkmanager.Link.TagsEntry\x12\x0c\n\x04type\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x0fLinkAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11global_network_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x0f\n\x07link_id\x18\x04 \x01(\t\"}\n\x0cSiteLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x10\n\x08latitude\x18\x03 \x01(\t\x12\x11\n\tlongitude\x18\x04 \x01(\t\"\x9a\x02\n\x04Site\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12<\n\x04tags\x18\x03 \x03(\x0b\x32..oak9.tython.aws.networkmanager.Site.TagsEntry\x12\x19\n\x11global_network_id\x18\x04 \x01(\t\x12>\n\x08location\x18\x05 \x01(\x0b\x32,.oak9.tython.aws.networkmanager.SiteLocation\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x1aTransitGatewayRegistration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11global_network_id\x18\x02 \x01(\t\x12\x1b\n\x13transit_gateway_arn\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_networkmanager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEVICE_TAGSENTRY._options = None
  _DEVICE_TAGSENTRY._serialized_options = b'8\001'
  _GLOBALNETWORK_TAGSENTRY._options = None
  _GLOBALNETWORK_TAGSENTRY._serialized_options = b'8\001'
  _LINK_TAGSENTRY._options = None
  _LINK_TAGSENTRY._serialized_options = b'8\001'
  _SITE_TAGSENTRY._options = None
  _SITE_TAGSENTRY._serialized_options = b'8\001'
  _CUSTOMERGATEWAYASSOCIATION._serialized_start=86
  _CUSTOMERGATEWAYASSOCIATION._serialized_end=264
  _NETWORKMANAGER._serialized_start=267
  _NETWORKMANAGER._serialized_end=785
  _DEVICELOCATION._serialized_start=787
  _DEVICELOCATION._serialized_end=914
  _DEVICE._serialized_start=917
  _DEVICE._serialized_end=1290
  _DEVICE_TAGSENTRY._serialized_start=1247
  _DEVICE_TAGSENTRY._serialized_end=1290
  _GLOBALNETWORK._serialized_start=1293
  _GLOBALNETWORK._serialized_end=1502
  _GLOBALNETWORK_TAGSENTRY._serialized_start=1247
  _GLOBALNETWORK_TAGSENTRY._serialized_end=1290
  _LINKBANDWIDTH._serialized_start=1504
  _LINKBANDWIDTH._serialized_end=1622
  _LINK._serialized_start=1625
  _LINK._serialized_end=1958
  _LINK_TAGSENTRY._serialized_start=1247
  _LINK_TAGSENTRY._serialized_end=1290
  _LINKASSOCIATION._serialized_start=1961
  _LINKASSOCIATION._serialized_end=2098
  _SITELOCATION._serialized_start=2100
  _SITELOCATION._serialized_end=2225
  _SITE._serialized_start=2228
  _SITE._serialized_end=2510
  _SITE_TAGSENTRY._serialized_start=1247
  _SITE_TAGSENTRY._serialized_end=1290
  _TRANSITGATEWAYREGISTRATION._serialized_start=2513
  _TRANSITGATEWAYREGISTRATION._serialized_end=2654
# @@protoc_insertion_point(module_scope)
