"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    COMPUTE_PLATFORM_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    compute_platform: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        compute_platform: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "compute_platform", b"compute_platform", "resource_info", b"resource_info"]) -> None: ...

global___Application = Application

@typing_extensions.final
class CodeDeploy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_FIELD_NUMBER: builtins.int
    DEPLOYMENT_GROUP_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Application]: ...
    @property
    def deployment_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentConfig]: ...
    @property
    def deployment_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroup]: ...
    def __init__(
        self,
        *,
        application: collections.abc.Iterable[global___Application] | None = ...,
        deployment_config: collections.abc.Iterable[global___DeploymentConfig] | None = ...,
        deployment_group: collections.abc.Iterable[global___DeploymentGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "deployment_config", b"deployment_config", "deployment_group", b"deployment_group"]) -> None: ...

global___CodeDeploy = CodeDeploy

@typing_extensions.final
class DeploymentConfigMinimumHealthyHosts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentConfigMinimumHealthyHosts = DeploymentConfigMinimumHealthyHosts

@typing_extensions.final
class DeploymentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_NAME_FIELD_NUMBER: builtins.int
    MINIMUM_HEALTHY_HOSTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    deployment_config_name: builtins.str
    @property
    def minimum_healthy_hosts(self) -> global___DeploymentConfigMinimumHealthyHosts: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deployment_config_name: builtins.str = ...,
        minimum_healthy_hosts: global___DeploymentConfigMinimumHealthyHosts | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["minimum_healthy_hosts", b"minimum_healthy_hosts", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_config_name", b"deployment_config_name", "minimum_healthy_hosts", b"minimum_healthy_hosts", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentConfig = DeploymentConfig

@typing_extensions.final
class DeploymentGroupAlarm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupAlarm = DeploymentGroupAlarm

@typing_extensions.final
class DeploymentGroupAlarmConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARMS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    IGNORE_POLL_ALARM_FAILURE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alarms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupAlarm]: ...
    enabled: builtins.bool
    ignore_poll_alarm_failure: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarms: collections.abc.Iterable[global___DeploymentGroupAlarm] | None = ...,
        enabled: builtins.bool = ...,
        ignore_poll_alarm_failure: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarms", b"alarms", "enabled", b"enabled", "ignore_poll_alarm_failure", b"ignore_poll_alarm_failure", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupAlarmConfiguration = DeploymentGroupAlarmConfiguration

@typing_extensions.final
class DeploymentGroupAutoRollbackConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        events: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "events", b"events", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupAutoRollbackConfiguration = DeploymentGroupAutoRollbackConfiguration

@typing_extensions.final
class DeploymentGroupGitHubLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMMIT_ID_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    commit_id: builtins.str
    repository: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        commit_id: builtins.str = ...,
        repository: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit_id", b"commit_id", "repository", b"repository", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupGitHubLocation = DeploymentGroupGitHubLocation

@typing_extensions.final
class DeploymentGroupS3Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    BUNDLE_TYPE_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket: builtins.str
    bundle_type: builtins.str
    e_tag: builtins.str
    key: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket: builtins.str = ...,
        bundle_type: builtins.str = ...,
        e_tag: builtins.str = ...,
        key: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "bundle_type", b"bundle_type", "e_tag", b"e_tag", "key", b"key", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___DeploymentGroupS3Location = DeploymentGroupS3Location

@typing_extensions.final
class DeploymentGroupRevisionLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GIT_HUB_LOCATION_FIELD_NUMBER: builtins.int
    REVISION_TYPE_FIELD_NUMBER: builtins.int
    S3_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def git_hub_location(self) -> global___DeploymentGroupGitHubLocation: ...
    revision_type: builtins.str
    @property
    def s3_location(self) -> global___DeploymentGroupS3Location: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        git_hub_location: global___DeploymentGroupGitHubLocation | None = ...,
        revision_type: builtins.str = ...,
        s3_location: global___DeploymentGroupS3Location | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["git_hub_location", b"git_hub_location", "resource_info", b"resource_info", "s3_location", b"s3_location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["git_hub_location", b"git_hub_location", "resource_info", b"resource_info", "revision_type", b"revision_type", "s3_location", b"s3_location"]) -> None: ...

global___DeploymentGroupRevisionLocation = DeploymentGroupRevisionLocation

@typing_extensions.final
class DeploymentGroupDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IGNORE_APPLICATION_STOP_FAILURES_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    ignore_application_stop_failures: builtins.bool
    @property
    def revision(self) -> global___DeploymentGroupRevisionLocation: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        ignore_application_stop_failures: builtins.bool = ...,
        revision: global___DeploymentGroupRevisionLocation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "revision", b"revision"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "ignore_application_stop_failures", b"ignore_application_stop_failures", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___DeploymentGroupDeployment = DeploymentGroupDeployment

@typing_extensions.final
class DeploymentGroupDeploymentStyle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEPLOYMENT_OPTION_FIELD_NUMBER: builtins.int
    DEPLOYMENT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    deployment_option: builtins.str
    deployment_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deployment_option: builtins.str = ...,
        deployment_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_option", b"deployment_option", "deployment_type", b"deployment_type", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupDeploymentStyle = DeploymentGroupDeploymentStyle

@typing_extensions.final
class DeploymentGroupEC2TagFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentGroupEC2TagFilter = DeploymentGroupEC2TagFilter

@typing_extensions.final
class DeploymentGroupEC2TagSetListObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EC2_TAG_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ec2_tag_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupEC2TagFilter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ec2_tag_group: collections.abc.Iterable[global___DeploymentGroupEC2TagFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_tag_group", b"ec2_tag_group", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupEC2TagSetListObject = DeploymentGroupEC2TagSetListObject

@typing_extensions.final
class DeploymentGroupEC2TagSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EC2_TAG_SET_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ec2_tag_set_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupEC2TagSetListObject]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ec2_tag_set_list: collections.abc.Iterable[global___DeploymentGroupEC2TagSetListObject] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_tag_set_list", b"ec2_tag_set_list", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupEC2TagSet = DeploymentGroupEC2TagSet

@typing_extensions.final
class DeploymentGroupELBInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupELBInfo = DeploymentGroupELBInfo

@typing_extensions.final
class DeploymentGroupTargetGroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupTargetGroupInfo = DeploymentGroupTargetGroupInfo

@typing_extensions.final
class DeploymentGroupLoadBalancerInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ELB_INFO_LIST_FIELD_NUMBER: builtins.int
    TARGET_GROUP_INFO_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def elb_info_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupELBInfo]: ...
    @property
    def target_group_info_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupTargetGroupInfo]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        elb_info_list: collections.abc.Iterable[global___DeploymentGroupELBInfo] | None = ...,
        target_group_info_list: collections.abc.Iterable[global___DeploymentGroupTargetGroupInfo] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elb_info_list", b"elb_info_list", "resource_info", b"resource_info", "target_group_info_list", b"target_group_info_list"]) -> None: ...

global___DeploymentGroupLoadBalancerInfo = DeploymentGroupLoadBalancerInfo

@typing_extensions.final
class DeploymentGroupTagFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentGroupTagFilter = DeploymentGroupTagFilter

@typing_extensions.final
class DeploymentGroupOnPremisesTagSetListObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_PREMISES_TAG_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_premises_tag_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupTagFilter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_premises_tag_group: collections.abc.Iterable[global___DeploymentGroupTagFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["on_premises_tag_group", b"on_premises_tag_group", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupOnPremisesTagSetListObject = DeploymentGroupOnPremisesTagSetListObject

@typing_extensions.final
class DeploymentGroupOnPremisesTagSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_PREMISES_TAG_SET_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_premises_tag_set_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupOnPremisesTagSetListObject]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_premises_tag_set_list: collections.abc.Iterable[global___DeploymentGroupOnPremisesTagSetListObject] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["on_premises_tag_set_list", b"on_premises_tag_set_list", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupOnPremisesTagSet = DeploymentGroupOnPremisesTagSet

@typing_extensions.final
class DeploymentGroupTriggerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TRIGGER_EVENTS_FIELD_NUMBER: builtins.int
    TRIGGER_NAME_FIELD_NUMBER: builtins.int
    TRIGGER_TARGET_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def trigger_events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    trigger_name: builtins.str
    trigger_target_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        trigger_events: collections.abc.Iterable[builtins.str] | None = ...,
        trigger_name: builtins.str = ...,
        trigger_target_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "trigger_events", b"trigger_events", "trigger_name", b"trigger_name", "trigger_target_arn", b"trigger_target_arn"]) -> None: ...

global___DeploymentGroupTriggerConfig = DeploymentGroupTriggerConfig

@typing_extensions.final
class DeploymentGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_CONFIGURATION_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    AUTO_ROLLBACK_CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTO_SCALING_GROUPS_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_NAME_FIELD_NUMBER: builtins.int
    DEPLOYMENT_GROUP_NAME_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STYLE_FIELD_NUMBER: builtins.int
    EC2_TAG_FILTERS_FIELD_NUMBER: builtins.int
    EC2_TAG_SET_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_INFO_FIELD_NUMBER: builtins.int
    ON_PREMISES_INSTANCE_TAG_FILTERS_FIELD_NUMBER: builtins.int
    ON_PREMISES_TAG_SET_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    TRIGGER_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alarm_configuration(self) -> global___DeploymentGroupAlarmConfiguration: ...
    application_name: builtins.str
    @property
    def auto_rollback_configuration(self) -> global___DeploymentGroupAutoRollbackConfiguration: ...
    @property
    def auto_scaling_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def deployment(self) -> global___DeploymentGroupDeployment: ...
    deployment_config_name: builtins.str
    deployment_group_name: builtins.str
    @property
    def deployment_style(self) -> global___DeploymentGroupDeploymentStyle: ...
    @property
    def ec2_tag_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupEC2TagFilter]: ...
    @property
    def ec2_tag_set(self) -> global___DeploymentGroupEC2TagSet: ...
    @property
    def load_balancer_info(self) -> global___DeploymentGroupLoadBalancerInfo: ...
    @property
    def on_premises_instance_tag_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupTagFilter]: ...
    @property
    def on_premises_tag_set(self) -> global___DeploymentGroupOnPremisesTagSet: ...
    service_role_arn: builtins.str
    @property
    def trigger_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupTriggerConfig]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_configuration: global___DeploymentGroupAlarmConfiguration | None = ...,
        application_name: builtins.str = ...,
        auto_rollback_configuration: global___DeploymentGroupAutoRollbackConfiguration | None = ...,
        auto_scaling_groups: collections.abc.Iterable[builtins.str] | None = ...,
        deployment: global___DeploymentGroupDeployment | None = ...,
        deployment_config_name: builtins.str = ...,
        deployment_group_name: builtins.str = ...,
        deployment_style: global___DeploymentGroupDeploymentStyle | None = ...,
        ec2_tag_filters: collections.abc.Iterable[global___DeploymentGroupEC2TagFilter] | None = ...,
        ec2_tag_set: global___DeploymentGroupEC2TagSet | None = ...,
        load_balancer_info: global___DeploymentGroupLoadBalancerInfo | None = ...,
        on_premises_instance_tag_filters: collections.abc.Iterable[global___DeploymentGroupTagFilter] | None = ...,
        on_premises_tag_set: global___DeploymentGroupOnPremisesTagSet | None = ...,
        service_role_arn: builtins.str = ...,
        trigger_configurations: collections.abc.Iterable[global___DeploymentGroupTriggerConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alarm_configuration", b"alarm_configuration", "auto_rollback_configuration", b"auto_rollback_configuration", "deployment", b"deployment", "deployment_style", b"deployment_style", "ec2_tag_set", b"ec2_tag_set", "load_balancer_info", b"load_balancer_info", "on_premises_tag_set", b"on_premises_tag_set", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_configuration", b"alarm_configuration", "application_name", b"application_name", "auto_rollback_configuration", b"auto_rollback_configuration", "auto_scaling_groups", b"auto_scaling_groups", "deployment", b"deployment", "deployment_config_name", b"deployment_config_name", "deployment_group_name", b"deployment_group_name", "deployment_style", b"deployment_style", "ec2_tag_filters", b"ec2_tag_filters", "ec2_tag_set", b"ec2_tag_set", "load_balancer_info", b"load_balancer_info", "on_premises_instance_tag_filters", b"on_premises_instance_tag_filters", "on_premises_tag_set", b"on_premises_tag_set", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "trigger_configurations", b"trigger_configurations"]) -> None: ...

global___DeploymentGroup = DeploymentGroup
