# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_wafregional.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61ws/aws_wafregional.proto\x12\x1boak9.tython.aws.wafregional\x1a\x13shared/shared.proto\"a\n\x18\x42yteMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\x95\x02\n\x1a\x42yteMatchSetByteMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rtarget_string\x18\x02 \x01(\t\x12\x1c\n\x14target_string_base64\x18\x03 \x01(\t\x12\x1d\n\x15positional_constraint\x18\x04 \x01(\t\x12\x1b\n\x13text_transformation\x18\x05 \x01(\t\x12M\n\x0e\x66ield_to_match\x18\x06 \x01(\x0b\x32\x35.oak9.tython.aws.wafregional.ByteMatchSetFieldToMatch\"\xa9\x01\n\x0c\x42yteMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x11\x62yte_match_tuples\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.wafregional.ByteMatchSetByteMatchTuple\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xed\x05\n\x0bWAFRegional\x12\x41\n\x0e\x62yte_match_set\x18\x01 \x03(\x0b\x32).oak9.tython.aws.wafregional.ByteMatchSet\x12?\n\rgeo_match_set\x18\x02 \x03(\x0b\x32(.oak9.tython.aws.wafregional.GeoMatchSet\x12\x32\n\x06ip_set\x18\x03 \x03(\x0b\x32\".oak9.tython.aws.wafregional.IPSet\x12\x43\n\x0frate_based_rule\x18\x04 \x03(\x0b\x32*.oak9.tython.aws.wafregional.RateBasedRule\x12G\n\x11regex_pattern_set\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.wafregional.RegexPatternSet\x12/\n\x04rule\x18\x06 \x03(\x0b\x32!.oak9.tython.aws.wafregional.Rule\x12K\n\x13size_constraint_set\x18\x07 \x03(\x0b\x32..oak9.tython.aws.wafregional.SizeConstraintSet\x12R\n\x17sql_injection_match_set\x18\x08 \x03(\x0b\x32\x31.oak9.tython.aws.wafregional.SqlInjectionMatchSet\x12\x36\n\tweb_a_c_l\x18\t \x03(\x0b\x32#.oak9.tython.aws.wafregional.WebACL\x12M\n\x15web_a_c_l_association\x18\n \x03(\x0b\x32..oak9.tython.aws.wafregional.WebACLAssociation\x12?\n\rxss_match_set\x18\x0b \x03(\x0b\x32(.oak9.tython.aws.wafregional.XssMatchSet\"g\n\x1dGeoMatchSetGeoMatchConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"\xaf\x01\n\x0bGeoMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x15geo_match_constraints\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.wafregional.GeoMatchSetGeoMatchConstraint\x12\x0c\n\x04name\x18\x03 \x01(\t\"^\n\x14IPSetIPSetDescriptor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"\x9d\x01\n\x05IPSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x12ip_set_descriptors\x18\x02 \x03(\x0b\x32\x31.oak9.tython.aws.wafregional.IPSetIPSetDescriptor\x12\x0c\n\x04name\x18\x03 \x01(\t\"s\n\x16RateBasedRulePredicate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x64\x61ta_id\x18\x02 \x01(\t\x12\x0f\n\x07negated\x18\x03 \x01(\x08\"\xe0\x01\n\rRateBasedRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x12\n\nrate_limit\x18\x03 \x01(\x05\x12M\n\x10match_predicates\x18\x04 \x03(\x0b\x32\x33.oak9.tython.aws.wafregional.RateBasedRulePredicate\x12\x10\n\x08rate_key\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"w\n\x0fRegexPatternSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15regex_pattern_strings\x18\x02 \x03(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"j\n\rRulePredicate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x64\x61ta_id\x18\x02 \x01(\t\x12\x0f\n\x07negated\x18\x03 \x01(\x08\"\xa2\x01\n\x04Rule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12>\n\npredicates\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.wafregional.RulePredicate\x12\x0c\n\x04name\x18\x04 \x01(\t\"f\n\x1dSizeConstraintSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xf6\x01\n\x1fSizeConstraintSetSizeConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12\x1b\n\x13text_transformation\x18\x04 \x01(\t\x12R\n\x0e\x66ield_to_match\x18\x05 \x01(\x0b\x32:.oak9.tython.aws.wafregional.SizeConstraintSetFieldToMatch\"\xb2\x01\n\x11SizeConstraintSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x10size_constraints\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.wafregional.SizeConstraintSetSizeConstraint\x12\x0c\n\x04name\x18\x03 \x01(\t\"i\n SqlInjectionMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xd9\x01\n*SqlInjectionMatchSetSqlInjectionMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13text_transformation\x18\x02 \x01(\t\x12U\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.wafregional.SqlInjectionMatchSetFieldToMatch\"\xca\x01\n\x14SqlInjectionMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12k\n\x1asql_injection_match_tuples\x18\x02 \x03(\x0b\x32G.oak9.tython.aws.wafregional.SqlInjectionMatchSetSqlInjectionMatchTuple\x12\x0c\n\x04name\x18\x03 \x01(\t\"G\n\x0cWebACLAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x01\n\nWebACLRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x39\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafregional.WebACLAction\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12\x0f\n\x07rule_id\x18\x04 \x01(\t\"\xdf\x01\n\x06WebACL\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x41\n\x0e\x64\x65\x66\x61ult_action\x18\x03 \x01(\x0b\x32).oak9.tython.aws.wafregional.WebACLAction\x12\x36\n\x05rules\x18\x04 \x03(\x0b\x32\'.oak9.tython.aws.wafregional.WebACLRule\x12\x0c\n\x04name\x18\x05 \x01(\t\"x\n\x11WebACLAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x14\n\x0cweb_a_c_l_id\x18\x03 \x01(\t\"`\n\x17XssMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xbe\x01\n\x18XssMatchSetXssMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13text_transformation\x18\x02 \x01(\t\x12L\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.wafregional.XssMatchSetFieldToMatch\"\xa5\x01\n\x0bXssMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x10xss_match_tuples\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.wafregional.XssMatchSetXssMatchTuple\x12\x0c\n\x04name\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_wafregional_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BYTEMATCHSETFIELDTOMATCH._serialized_start=79
  _BYTEMATCHSETFIELDTOMATCH._serialized_end=176
  _BYTEMATCHSETBYTEMATCHTUPLE._serialized_start=179
  _BYTEMATCHSETBYTEMATCHTUPLE._serialized_end=456
  _BYTEMATCHSET._serialized_start=459
  _BYTEMATCHSET._serialized_end=628
  _WAFREGIONAL._serialized_start=631
  _WAFREGIONAL._serialized_end=1380
  _GEOMATCHSETGEOMATCHCONSTRAINT._serialized_start=1382
  _GEOMATCHSETGEOMATCHCONSTRAINT._serialized_end=1485
  _GEOMATCHSET._serialized_start=1488
  _GEOMATCHSET._serialized_end=1663
  _IPSETIPSETDESCRIPTOR._serialized_start=1665
  _IPSETIPSETDESCRIPTOR._serialized_end=1759
  _IPSET._serialized_start=1762
  _IPSET._serialized_end=1919
  _RATEBASEDRULEPREDICATE._serialized_start=1921
  _RATEBASEDRULEPREDICATE._serialized_end=2036
  _RATEBASEDRULE._serialized_start=2039
  _RATEBASEDRULE._serialized_end=2263
  _REGEXPATTERNSET._serialized_start=2265
  _REGEXPATTERNSET._serialized_end=2384
  _RULEPREDICATE._serialized_start=2386
  _RULEPREDICATE._serialized_end=2492
  _RULE._serialized_start=2495
  _RULE._serialized_end=2657
  _SIZECONSTRAINTSETFIELDTOMATCH._serialized_start=2659
  _SIZECONSTRAINTSETFIELDTOMATCH._serialized_end=2761
  _SIZECONSTRAINTSETSIZECONSTRAINT._serialized_start=2764
  _SIZECONSTRAINTSETSIZECONSTRAINT._serialized_end=3010
  _SIZECONSTRAINTSET._serialized_start=3013
  _SIZECONSTRAINTSET._serialized_end=3191
  _SQLINJECTIONMATCHSETFIELDTOMATCH._serialized_start=3193
  _SQLINJECTIONMATCHSETFIELDTOMATCH._serialized_end=3298
  _SQLINJECTIONMATCHSETSQLINJECTIONMATCHTUPLE._serialized_start=3301
  _SQLINJECTIONMATCHSETSQLINJECTIONMATCHTUPLE._serialized_end=3518
  _SQLINJECTIONMATCHSET._serialized_start=3521
  _SQLINJECTIONMATCHSET._serialized_end=3723
  _WEBACLACTION._serialized_start=3725
  _WEBACLACTION._serialized_end=3796
  _WEBACLRULE._serialized_start=3799
  _WEBACLRULE._serialized_end=3962
  _WEBACL._serialized_start=3965
  _WEBACL._serialized_end=4188
  _WEBACLASSOCIATION._serialized_start=4190
  _WEBACLASSOCIATION._serialized_end=4310
  _XSSMATCHSETFIELDTOMATCH._serialized_start=4312
  _XSSMATCHSETFIELDTOMATCH._serialized_end=4408
  _XSSMATCHSETXSSMATCHTUPLE._serialized_start=4411
  _XSSMATCHSETXSSMATCHTUPLE._serialized_end=4601
  _XSSMATCHSET._serialized_start=4604
  _XSSMATCHSET._serialized_end=4769
# @@protoc_insertion_point(module_scope)
