# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_budgets.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_budgets.proto\x12\x17oak9.tython.aws.budgets\x1a\x13shared/shared.proto\"w\n\x10\x42udgetSubscriber\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11subscription_type\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"\xb0\x01\n\x12\x42udgetNotification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12\x19\n\x11notification_type\x18\x03 \x01(\t\x12\x11\n\tthreshold\x18\x04 \x01(\x01\x12\x16\n\x0ethreshold_type\x18\x05 \x01(\t\"\xdf\x01\n!BudgetNotificationWithSubscribers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12>\n\x0bsubscribers\x18\x02 \x03(\x0b\x32).oak9.tython.aws.budgets.BudgetSubscriber\x12\x41\n\x0cnotification\x18\x03 \x01(\x0b\x32+.oak9.tython.aws.budgets.BudgetNotification\"d\n\x0b\x42udgetSpend\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0c\n\x04unit\x18\x03 \x01(\t\"g\n\x10\x42udgetTimePeriod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\"\xe4\x02\n\x0f\x42udgetCostTypes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0finclude_support\x18\x02 \x01(\x08\x12\"\n\x1ainclude_other_subscription\x18\x03 \x01(\x08\x12\x13\n\x0binclude_tax\x18\x04 \x01(\x08\x12\x1c\n\x14include_subscription\x18\x05 \x01(\x08\x12\x13\n\x0buse_blended\x18\x06 \x01(\x08\x12\x17\n\x0finclude_upfront\x18\x07 \x01(\x08\x12\x18\n\x10include_discount\x18\x08 \x01(\x08\x12\x16\n\x0einclude_credit\x18\t \x01(\x08\x12\x19\n\x11include_recurring\x18\n \x01(\x08\x12\x15\n\ruse_amortized\x18\x0b \x01(\x08\x12\x16\n\x0einclude_refund\x18\x0c \x01(\x08\"\xe7\x04\n\x10\x42udgetBudgetData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12:\n\x0c\x62udget_limit\x18\x02 \x01(\x0b\x32$.oak9.tython.aws.budgets.BudgetSpend\x12>\n\x0btime_period\x18\x03 \x01(\x0b\x32).oak9.tython.aws.budgets.BudgetTimePeriod\x12\x11\n\ttime_unit\x18\x04 \x01(\t\x12\x61\n\x15planned_budget_limits\x18\x05 \x03(\x0b\x32\x42.oak9.tython.aws.budgets.BudgetBudgetData.PlannedBudgetLimitsEntry\x12P\n\x0c\x63ost_filters\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.budgets.BudgetBudgetData.CostFiltersEntry\x12\x13\n\x0b\x62udget_name\x18\x07 \x01(\t\x12<\n\ncost_types\x18\x08 \x01(\x0b\x32(.oak9.tython.aws.budgets.BudgetCostTypes\x12\x13\n\x0b\x62udget_type\x18\t \x01(\t\x1a:\n\x18PlannedBudgetLimitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x43ostFiltersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe0\x01\n\x06\x42udget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x1enotifications_with_subscribers\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.budgets.BudgetNotificationWithSubscribers\x12\x39\n\x06\x62udget\x18\x03 \x01(\x0b\x32).oak9.tython.aws.budgets.BudgetBudgetData\":\n\x07\x42udgets\x12/\n\x06\x62udget\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.budgets.Budgetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_budgets_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUDGETBUDGETDATA_PLANNEDBUDGETLIMITSENTRY._options = None
  _BUDGETBUDGETDATA_PLANNEDBUDGETLIMITSENTRY._serialized_options = b'8\001'
  _BUDGETBUDGETDATA_COSTFILTERSENTRY._options = None
  _BUDGETBUDGETDATA_COSTFILTERSENTRY._serialized_options = b'8\001'
  _BUDGETSUBSCRIBER._serialized_start=71
  _BUDGETSUBSCRIBER._serialized_end=190
  _BUDGETNOTIFICATION._serialized_start=193
  _BUDGETNOTIFICATION._serialized_end=369
  _BUDGETNOTIFICATIONWITHSUBSCRIBERS._serialized_start=372
  _BUDGETNOTIFICATIONWITHSUBSCRIBERS._serialized_end=595
  _BUDGETSPEND._serialized_start=597
  _BUDGETSPEND._serialized_end=697
  _BUDGETTIMEPERIOD._serialized_start=699
  _BUDGETTIMEPERIOD._serialized_end=802
  _BUDGETCOSTTYPES._serialized_start=805
  _BUDGETCOSTTYPES._serialized_end=1161
  _BUDGETBUDGETDATA._serialized_start=1164
  _BUDGETBUDGETDATA._serialized_end=1779
  _BUDGETBUDGETDATA_PLANNEDBUDGETLIMITSENTRY._serialized_start=1669
  _BUDGETBUDGETDATA_PLANNEDBUDGETLIMITSENTRY._serialized_end=1727
  _BUDGETBUDGETDATA_COSTFILTERSENTRY._serialized_start=1729
  _BUDGETBUDGETDATA_COSTFILTERSENTRY._serialized_end=1779
  _BUDGET._serialized_start=1782
  _BUDGET._serialized_end=2006
  _BUDGETS._serialized_start=2008
  _BUDGETS._serialized_end=2066
# @@protoc_insertion_point(module_scope)
