"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CodeRepositoryGitConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECRET_ARN_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    REPOSITORY_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    secret_arn: builtins.str
    branch: builtins.str
    repository_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        secret_arn: builtins.str = ...,
        branch: builtins.str = ...,
        repository_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "repository_url", b"repository_url", "resource_info", b"resource_info", "secret_arn", b"secret_arn"]) -> None: ...

global___CodeRepositoryGitConfig = CodeRepositoryGitConfig

@typing_extensions.final
class CodeRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CODE_REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    GIT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    code_repository_name: builtins.str
    @property
    def git_config(self) -> global___CodeRepositoryGitConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        code_repository_name: builtins.str = ...,
        git_config: global___CodeRepositoryGitConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["git_config", b"git_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code_repository_name", b"code_repository_name", "git_config", b"git_config", "resource_info", b"resource_info"]) -> None: ...

global___CodeRepository = CodeRepository

@typing_extensions.final
class SageMaker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_REPOSITORY_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIG_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_FIELD_NUMBER: builtins.int
    NOTEBOOK_INSTANCE_FIELD_NUMBER: builtins.int
    NOTEBOOK_INSTANCE_LIFECYCLE_CONFIG_FIELD_NUMBER: builtins.int
    WORKTEAM_FIELD_NUMBER: builtins.int
    @property
    def code_repository(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CodeRepository]: ...
    @property
    def endpoint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Endpoint]: ...
    @property
    def endpoint_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointConfig]: ...
    @property
    def model(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Model]: ...
    @property
    def monitoring_schedule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MonitoringSchedule]: ...
    @property
    def notebook_instance(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebookInstance]: ...
    @property
    def notebook_instance_lifecycle_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebookInstanceLifecycleConfig]: ...
    @property
    def workteam(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Workteam]: ...
    def __init__(
        self,
        *,
        code_repository: collections.abc.Iterable[global___CodeRepository] | None = ...,
        endpoint: collections.abc.Iterable[global___Endpoint] | None = ...,
        endpoint_config: collections.abc.Iterable[global___EndpointConfig] | None = ...,
        model: collections.abc.Iterable[global___Model] | None = ...,
        monitoring_schedule: collections.abc.Iterable[global___MonitoringSchedule] | None = ...,
        notebook_instance: collections.abc.Iterable[global___NotebookInstance] | None = ...,
        notebook_instance_lifecycle_config: collections.abc.Iterable[global___NotebookInstanceLifecycleConfig] | None = ...,
        workteam: collections.abc.Iterable[global___Workteam] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code_repository", b"code_repository", "endpoint", b"endpoint", "endpoint_config", b"endpoint_config", "model", b"model", "monitoring_schedule", b"monitoring_schedule", "notebook_instance", b"notebook_instance", "notebook_instance_lifecycle_config", b"notebook_instance_lifecycle_config", "workteam", b"workteam"]) -> None: ...

global___SageMaker = SageMaker

@typing_extensions.final
class EndpointVariantProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VARIANT_PROPERTY_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    variant_property_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        variant_property_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "variant_property_type", b"variant_property_type"]) -> None: ...

global___EndpointVariantProperty = EndpointVariantProperty

@typing_extensions.final
class Endpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RETAIN_ALL_VARIANT_PROPERTIES_FIELD_NUMBER: builtins.int
    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    EXCLUDE_RETAINED_VARIANT_PROPERTIES_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIG_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    retain_all_variant_properties: builtins.bool
    endpoint_name: builtins.str
    @property
    def exclude_retained_variant_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointVariantProperty]: ...
    endpoint_config_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        retain_all_variant_properties: builtins.bool = ...,
        endpoint_name: builtins.str = ...,
        exclude_retained_variant_properties: collections.abc.Iterable[global___EndpointVariantProperty] | None = ...,
        endpoint_config_name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_config_name", b"endpoint_config_name", "endpoint_name", b"endpoint_name", "exclude_retained_variant_properties", b"exclude_retained_variant_properties", "resource_info", b"resource_info", "retain_all_variant_properties", b"retain_all_variant_properties", "tags", b"tags"]) -> None: ...

global___Endpoint = Endpoint

@typing_extensions.final
class EndpointConfigCaptureOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CAPTURE_MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    capture_mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        capture_mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capture_mode", b"capture_mode", "resource_info", b"resource_info"]) -> None: ...

global___EndpointConfigCaptureOption = EndpointConfigCaptureOption

@typing_extensions.final
class EndpointConfigCaptureContentTypeHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JSON_CONTENT_TYPES_FIELD_NUMBER: builtins.int
    CSV_CONTENT_TYPES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def json_content_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def csv_content_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        json_content_types: collections.abc.Iterable[builtins.str] | None = ...,
        csv_content_types: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["csv_content_types", b"csv_content_types", "json_content_types", b"json_content_types", "resource_info", b"resource_info"]) -> None: ...

global___EndpointConfigCaptureContentTypeHeader = EndpointConfigCaptureContentTypeHeader

@typing_extensions.final
class EndpointConfigDataCaptureConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CAPTURE_OPTIONS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    DESTINATION_S3_URI_FIELD_NUMBER: builtins.int
    INITIAL_SAMPLING_PERCENTAGE_FIELD_NUMBER: builtins.int
    CAPTURE_CONTENT_TYPE_HEADER_FIELD_NUMBER: builtins.int
    ENABLE_CAPTURE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def capture_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointConfigCaptureOption]: ...
    kms_key_id: builtins.str
    destination_s3_uri: builtins.str
    initial_sampling_percentage: builtins.int
    @property
    def capture_content_type_header(self) -> global___EndpointConfigCaptureContentTypeHeader: ...
    enable_capture: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        capture_options: collections.abc.Iterable[global___EndpointConfigCaptureOption] | None = ...,
        kms_key_id: builtins.str = ...,
        destination_s3_uri: builtins.str = ...,
        initial_sampling_percentage: builtins.int = ...,
        capture_content_type_header: global___EndpointConfigCaptureContentTypeHeader | None = ...,
        enable_capture: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capture_content_type_header", b"capture_content_type_header", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capture_content_type_header", b"capture_content_type_header", "capture_options", b"capture_options", "destination_s3_uri", b"destination_s3_uri", "enable_capture", b"enable_capture", "initial_sampling_percentage", b"initial_sampling_percentage", "kms_key_id", b"kms_key_id", "resource_info", b"resource_info"]) -> None: ...

global___EndpointConfigDataCaptureConfig = EndpointConfigDataCaptureConfig

@typing_extensions.final
class EndpointConfigProductionVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    VARIANT_NAME_FIELD_NUMBER: builtins.int
    INITIAL_INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    INITIAL_VARIANT_WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    model_name: builtins.str
    variant_name: builtins.str
    initial_instance_count: builtins.int
    instance_type: builtins.str
    accelerator_type: builtins.str
    initial_variant_weight: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        model_name: builtins.str = ...,
        variant_name: builtins.str = ...,
        initial_instance_count: builtins.int = ...,
        instance_type: builtins.str = ...,
        accelerator_type: builtins.str = ...,
        initial_variant_weight: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_type", b"accelerator_type", "initial_instance_count", b"initial_instance_count", "initial_variant_weight", b"initial_variant_weight", "instance_type", b"instance_type", "model_name", b"model_name", "resource_info", b"resource_info", "variant_name", b"variant_name"]) -> None: ...

global___EndpointConfigProductionVariant = EndpointConfigProductionVariant

@typing_extensions.final
class EndpointConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_CAPTURE_CONFIG_FIELD_NUMBER: builtins.int
    PRODUCTION_VARIANTS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIG_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def data_capture_config(self) -> global___EndpointConfigDataCaptureConfig: ...
    @property
    def production_variants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointConfigProductionVariant]: ...
    kms_key_id: builtins.str
    endpoint_config_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data_capture_config: global___EndpointConfigDataCaptureConfig | None = ...,
        production_variants: collections.abc.Iterable[global___EndpointConfigProductionVariant] | None = ...,
        kms_key_id: builtins.str = ...,
        endpoint_config_name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_capture_config", b"data_capture_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_capture_config", b"data_capture_config", "endpoint_config_name", b"endpoint_config_name", "kms_key_id", b"kms_key_id", "production_variants", b"production_variants", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___EndpointConfig = EndpointConfig

@typing_extensions.final
class ModelContainerDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTAINER_HOSTNAME_FIELD_NUMBER: builtins.int
    MODEL_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MODEL_DATA_URL_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    container_hostname: builtins.str
    model_package_name: builtins.str
    mode: builtins.str
    @property
    def environment(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    model_data_url: builtins.str
    image: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        container_hostname: builtins.str = ...,
        model_package_name: builtins.str = ...,
        mode: builtins.str = ...,
        environment: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        model_data_url: builtins.str = ...,
        image: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_hostname", b"container_hostname", "environment", b"environment", "image", b"image", "mode", b"mode", "model_data_url", b"model_data_url", "model_package_name", b"model_package_name", "resource_info", b"resource_info"]) -> None: ...

global___ModelContainerDefinition = ModelContainerDefinition

@typing_extensions.final
class ModelVpcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnets", b"subnets"]) -> None: ...

global___ModelVpcConfig = ModelVpcConfig

@typing_extensions.final
class Model(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXECUTION_ROLE_ARN_FIELD_NUMBER: builtins.int
    ENABLE_NETWORK_ISOLATION_FIELD_NUMBER: builtins.int
    PRIMARY_CONTAINER_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    VPC_CONFIG_FIELD_NUMBER: builtins.int
    CONTAINERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    execution_role_arn: builtins.str
    enable_network_isolation: builtins.bool
    @property
    def primary_container(self) -> global___ModelContainerDefinition: ...
    model_name: builtins.str
    @property
    def vpc_config(self) -> global___ModelVpcConfig: ...
    @property
    def containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelContainerDefinition]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        execution_role_arn: builtins.str = ...,
        enable_network_isolation: builtins.bool = ...,
        primary_container: global___ModelContainerDefinition | None = ...,
        model_name: builtins.str = ...,
        vpc_config: global___ModelVpcConfig | None = ...,
        containers: collections.abc.Iterable[global___ModelContainerDefinition] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["primary_container", b"primary_container", "resource_info", b"resource_info", "vpc_config", b"vpc_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["containers", b"containers", "enable_network_isolation", b"enable_network_isolation", "execution_role_arn", b"execution_role_arn", "model_name", b"model_name", "primary_container", b"primary_container", "resource_info", b"resource_info", "tags", b"tags", "vpc_config", b"vpc_config"]) -> None: ...

global___Model = Model

@typing_extensions.final
class MonitoringScheduleConstraintsResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_uri", b"s3_uri"]) -> None: ...

global___MonitoringScheduleConstraintsResource = MonitoringScheduleConstraintsResource

@typing_extensions.final
class MonitoringScheduleStatisticsResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_uri", b"s3_uri"]) -> None: ...

global___MonitoringScheduleStatisticsResource = MonitoringScheduleStatisticsResource

@typing_extensions.final
class MonitoringScheduleBaselineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONSTRAINTS_RESOURCE_FIELD_NUMBER: builtins.int
    STATISTICS_RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def constraints_resource(self) -> global___MonitoringScheduleConstraintsResource: ...
    @property
    def statistics_resource(self) -> global___MonitoringScheduleStatisticsResource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        constraints_resource: global___MonitoringScheduleConstraintsResource | None = ...,
        statistics_resource: global___MonitoringScheduleStatisticsResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["constraints_resource", b"constraints_resource", "resource_info", b"resource_info", "statistics_resource", b"statistics_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["constraints_resource", b"constraints_resource", "resource_info", b"resource_info", "statistics_resource", b"statistics_resource"]) -> None: ...

global___MonitoringScheduleBaselineConfig = MonitoringScheduleBaselineConfig

@typing_extensions.final
class MonitoringScheduleEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleEnvironment = MonitoringScheduleEnvironment

@typing_extensions.final
class MonitoringScheduleMonitoringAppSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTAINER_ARGUMENTS_FIELD_NUMBER: builtins.int
    CONTAINER_ENTRYPOINT_FIELD_NUMBER: builtins.int
    IMAGE_URI_FIELD_NUMBER: builtins.int
    POST_ANALYTICS_PROCESSOR_SOURCE_URI_FIELD_NUMBER: builtins.int
    RECORD_PREPROCESSOR_SOURCE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def container_arguments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def container_entrypoint(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    image_uri: builtins.str
    post_analytics_processor_source_uri: builtins.str
    record_preprocessor_source_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        container_arguments: collections.abc.Iterable[builtins.str] | None = ...,
        container_entrypoint: collections.abc.Iterable[builtins.str] | None = ...,
        image_uri: builtins.str = ...,
        post_analytics_processor_source_uri: builtins.str = ...,
        record_preprocessor_source_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_arguments", b"container_arguments", "container_entrypoint", b"container_entrypoint", "image_uri", b"image_uri", "post_analytics_processor_source_uri", b"post_analytics_processor_source_uri", "record_preprocessor_source_uri", b"record_preprocessor_source_uri", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringAppSpecification = MonitoringScheduleMonitoringAppSpecification

@typing_extensions.final
class MonitoringScheduleEndpointInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    S3_DATA_DISTRIBUTION_TYPE_FIELD_NUMBER: builtins.int
    S3_INPUT_MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    endpoint_name: builtins.str
    local_path: builtins.str
    s3_data_distribution_type: builtins.str
    s3_input_mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint_name: builtins.str = ...,
        local_path: builtins.str = ...,
        s3_data_distribution_type: builtins.str = ...,
        s3_input_mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_name", b"endpoint_name", "local_path", b"local_path", "resource_info", b"resource_info", "s3_data_distribution_type", b"s3_data_distribution_type", "s3_input_mode", b"s3_input_mode"]) -> None: ...

global___MonitoringScheduleEndpointInput = MonitoringScheduleEndpointInput

@typing_extensions.final
class MonitoringScheduleMonitoringInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_INPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def endpoint_input(self) -> global___MonitoringScheduleEndpointInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint_input: global___MonitoringScheduleEndpointInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoint_input", b"endpoint_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_input", b"endpoint_input", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringInput = MonitoringScheduleMonitoringInput

@typing_extensions.final
class MonitoringScheduleMonitoringInputs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MONITORING_INPUTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def monitoring_inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MonitoringScheduleMonitoringInput]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        monitoring_inputs: collections.abc.Iterable[global___MonitoringScheduleMonitoringInput] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitoring_inputs", b"monitoring_inputs", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringInputs = MonitoringScheduleMonitoringInputs

@typing_extensions.final
class MonitoringScheduleS3Output(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    S3_UPLOAD_MODE_FIELD_NUMBER: builtins.int
    S3_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    local_path: builtins.str
    s3_upload_mode: builtins.str
    s3_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        local_path: builtins.str = ...,
        s3_upload_mode: builtins.str = ...,
        s3_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_path", b"local_path", "resource_info", b"resource_info", "s3_upload_mode", b"s3_upload_mode", "s3_uri", b"s3_uri"]) -> None: ...

global___MonitoringScheduleS3Output = MonitoringScheduleS3Output

@typing_extensions.final
class MonitoringScheduleMonitoringOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_output(self) -> global___MonitoringScheduleS3Output: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_output: global___MonitoringScheduleS3Output | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_output", b"s3_output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_output", b"s3_output"]) -> None: ...

global___MonitoringScheduleMonitoringOutput = MonitoringScheduleMonitoringOutput

@typing_extensions.final
class MonitoringScheduleMonitoringOutputConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    MONITORING_OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_id: builtins.str
    @property
    def monitoring_outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MonitoringScheduleMonitoringOutput]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_id: builtins.str = ...,
        monitoring_outputs: collections.abc.Iterable[global___MonitoringScheduleMonitoringOutput] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_id", b"kms_key_id", "monitoring_outputs", b"monitoring_outputs", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringOutputConfig = MonitoringScheduleMonitoringOutputConfig

@typing_extensions.final
class MonitoringScheduleClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    VOLUME_KMS_KEY_ID_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_IN_GB_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_count: builtins.int
    instance_type: builtins.str
    volume_kms_key_id: builtins.str
    volume_size_in_gb: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_count: builtins.int = ...,
        instance_type: builtins.str = ...,
        volume_kms_key_id: builtins.str = ...,
        volume_size_in_gb: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_count", b"instance_count", "instance_type", b"instance_type", "resource_info", b"resource_info", "volume_kms_key_id", b"volume_kms_key_id", "volume_size_in_gb", b"volume_size_in_gb"]) -> None: ...

global___MonitoringScheduleClusterConfig = MonitoringScheduleClusterConfig

@typing_extensions.final
class MonitoringScheduleMonitoringResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cluster_config(self) -> global___MonitoringScheduleClusterConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cluster_config: global___MonitoringScheduleClusterConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_config", b"cluster_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_config", b"cluster_config", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringResources = MonitoringScheduleMonitoringResources

@typing_extensions.final
class MonitoringScheduleVpcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnets", b"subnets"]) -> None: ...

global___MonitoringScheduleVpcConfig = MonitoringScheduleVpcConfig

@typing_extensions.final
class MonitoringScheduleNetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLE_INTER_CONTAINER_TRAFFIC_ENCRYPTION_FIELD_NUMBER: builtins.int
    ENABLE_NETWORK_ISOLATION_FIELD_NUMBER: builtins.int
    VPC_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enable_inter_container_traffic_encryption: builtins.bool
    enable_network_isolation: builtins.bool
    @property
    def vpc_config(self) -> global___MonitoringScheduleVpcConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enable_inter_container_traffic_encryption: builtins.bool = ...,
        enable_network_isolation: builtins.bool = ...,
        vpc_config: global___MonitoringScheduleVpcConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "vpc_config", b"vpc_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_inter_container_traffic_encryption", b"enable_inter_container_traffic_encryption", "enable_network_isolation", b"enable_network_isolation", "resource_info", b"resource_info", "vpc_config", b"vpc_config"]) -> None: ...

global___MonitoringScheduleNetworkConfig = MonitoringScheduleNetworkConfig

@typing_extensions.final
class MonitoringScheduleStoppingCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_RUNTIME_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_runtime_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_runtime_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_runtime_in_seconds", b"max_runtime_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleStoppingCondition = MonitoringScheduleStoppingCondition

@typing_extensions.final
class MonitoringScheduleMonitoringJobDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BASELINE_CONFIG_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_APP_SPECIFICATION_FIELD_NUMBER: builtins.int
    MONITORING_INPUTS_FIELD_NUMBER: builtins.int
    MONITORING_OUTPUT_CONFIG_FIELD_NUMBER: builtins.int
    MONITORING_RESOURCES_FIELD_NUMBER: builtins.int
    NETWORK_CONFIG_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    STOPPING_CONDITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def baseline_config(self) -> global___MonitoringScheduleBaselineConfig: ...
    @property
    def environment(self) -> global___MonitoringScheduleEnvironment: ...
    @property
    def monitoring_app_specification(self) -> global___MonitoringScheduleMonitoringAppSpecification: ...
    @property
    def monitoring_inputs(self) -> global___MonitoringScheduleMonitoringInputs: ...
    @property
    def monitoring_output_config(self) -> global___MonitoringScheduleMonitoringOutputConfig: ...
    @property
    def monitoring_resources(self) -> global___MonitoringScheduleMonitoringResources: ...
    @property
    def network_config(self) -> global___MonitoringScheduleNetworkConfig: ...
    role_arn: builtins.str
    @property
    def stopping_condition(self) -> global___MonitoringScheduleStoppingCondition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        baseline_config: global___MonitoringScheduleBaselineConfig | None = ...,
        environment: global___MonitoringScheduleEnvironment | None = ...,
        monitoring_app_specification: global___MonitoringScheduleMonitoringAppSpecification | None = ...,
        monitoring_inputs: global___MonitoringScheduleMonitoringInputs | None = ...,
        monitoring_output_config: global___MonitoringScheduleMonitoringOutputConfig | None = ...,
        monitoring_resources: global___MonitoringScheduleMonitoringResources | None = ...,
        network_config: global___MonitoringScheduleNetworkConfig | None = ...,
        role_arn: builtins.str = ...,
        stopping_condition: global___MonitoringScheduleStoppingCondition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["baseline_config", b"baseline_config", "environment", b"environment", "monitoring_app_specification", b"monitoring_app_specification", "monitoring_inputs", b"monitoring_inputs", "monitoring_output_config", b"monitoring_output_config", "monitoring_resources", b"monitoring_resources", "network_config", b"network_config", "resource_info", b"resource_info", "stopping_condition", b"stopping_condition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["baseline_config", b"baseline_config", "environment", b"environment", "monitoring_app_specification", b"monitoring_app_specification", "monitoring_inputs", b"monitoring_inputs", "monitoring_output_config", b"monitoring_output_config", "monitoring_resources", b"monitoring_resources", "network_config", b"network_config", "resource_info", b"resource_info", "role_arn", b"role_arn", "stopping_condition", b"stopping_condition"]) -> None: ...

global___MonitoringScheduleMonitoringJobDefinition = MonitoringScheduleMonitoringJobDefinition

@typing_extensions.final
class MonitoringScheduleScheduleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SCHEDULE_EXPRESSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    schedule_expression: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        schedule_expression: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schedule_expression", b"schedule_expression"]) -> None: ...

global___MonitoringScheduleScheduleConfig = MonitoringScheduleScheduleConfig

@typing_extensions.final
class MonitoringScheduleMonitoringScheduleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MONITORING_JOB_DEFINITION_FIELD_NUMBER: builtins.int
    SCHEDULE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def monitoring_job_definition(self) -> global___MonitoringScheduleMonitoringJobDefinition: ...
    @property
    def schedule_config(self) -> global___MonitoringScheduleScheduleConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        monitoring_job_definition: global___MonitoringScheduleMonitoringJobDefinition | None = ...,
        schedule_config: global___MonitoringScheduleScheduleConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["monitoring_job_definition", b"monitoring_job_definition", "resource_info", b"resource_info", "schedule_config", b"schedule_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitoring_job_definition", b"monitoring_job_definition", "resource_info", b"resource_info", "schedule_config", b"schedule_config"]) -> None: ...

global___MonitoringScheduleMonitoringScheduleConfig = MonitoringScheduleMonitoringScheduleConfig

@typing_extensions.final
class MonitoringScheduleMonitoringExecutionSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CREATION_TIME_FIELD_NUMBER: builtins.int
    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_TIME_FIELD_NUMBER: builtins.int
    MONITORING_EXECUTION_STATUS_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_NAME_FIELD_NUMBER: builtins.int
    PROCESSING_JOB_ARN_FIELD_NUMBER: builtins.int
    SCHEDULED_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    creation_time: builtins.str
    endpoint_name: builtins.str
    failure_reason: builtins.str
    last_modified_time: builtins.str
    monitoring_execution_status: builtins.str
    monitoring_schedule_name: builtins.str
    processing_job_arn: builtins.str
    scheduled_time: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        creation_time: builtins.str = ...,
        endpoint_name: builtins.str = ...,
        failure_reason: builtins.str = ...,
        last_modified_time: builtins.str = ...,
        monitoring_execution_status: builtins.str = ...,
        monitoring_schedule_name: builtins.str = ...,
        processing_job_arn: builtins.str = ...,
        scheduled_time: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "endpoint_name", b"endpoint_name", "failure_reason", b"failure_reason", "last_modified_time", b"last_modified_time", "monitoring_execution_status", b"monitoring_execution_status", "monitoring_schedule_name", b"monitoring_schedule_name", "processing_job_arn", b"processing_job_arn", "resource_info", b"resource_info", "scheduled_time", b"scheduled_time"]) -> None: ...

global___MonitoringScheduleMonitoringExecutionSummary = MonitoringScheduleMonitoringExecutionSummary

@typing_extensions.final
class MonitoringSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_ARN_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_NAME_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_CONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CREATION_TIME_FIELD_NUMBER: builtins.int
    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_TIME_FIELD_NUMBER: builtins.int
    LAST_MONITORING_EXECUTION_SUMMARY_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    monitoring_schedule_arn: builtins.str
    monitoring_schedule_name: builtins.str
    @property
    def monitoring_schedule_config(self) -> global___MonitoringScheduleMonitoringScheduleConfig: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    creation_time: builtins.str
    endpoint_name: builtins.str
    failure_reason: builtins.str
    last_modified_time: builtins.str
    @property
    def last_monitoring_execution_summary(self) -> global___MonitoringScheduleMonitoringExecutionSummary: ...
    monitoring_schedule_status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        monitoring_schedule_arn: builtins.str = ...,
        monitoring_schedule_name: builtins.str = ...,
        monitoring_schedule_config: global___MonitoringScheduleMonitoringScheduleConfig | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        creation_time: builtins.str = ...,
        endpoint_name: builtins.str = ...,
        failure_reason: builtins.str = ...,
        last_modified_time: builtins.str = ...,
        last_monitoring_execution_summary: global___MonitoringScheduleMonitoringExecutionSummary | None = ...,
        monitoring_schedule_status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_monitoring_execution_summary", b"last_monitoring_execution_summary", "monitoring_schedule_config", b"monitoring_schedule_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "endpoint_name", b"endpoint_name", "failure_reason", b"failure_reason", "last_modified_time", b"last_modified_time", "last_monitoring_execution_summary", b"last_monitoring_execution_summary", "monitoring_schedule_arn", b"monitoring_schedule_arn", "monitoring_schedule_config", b"monitoring_schedule_config", "monitoring_schedule_name", b"monitoring_schedule_name", "monitoring_schedule_status", b"monitoring_schedule_status", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___MonitoringSchedule = MonitoringSchedule

@typing_extensions.final
class NotebookInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_IN_GB_FIELD_NUMBER: builtins.int
    ADDITIONAL_CODE_REPOSITORIES_FIELD_NUMBER: builtins.int
    DEFAULT_CODE_REPOSITORY_FIELD_NUMBER: builtins.int
    DIRECT_INTERNET_ACCESS_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    ROOT_ACCESS_FIELD_NUMBER: builtins.int
    NOTEBOOK_INSTANCE_NAME_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    LIFECYCLE_CONFIG_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_id: builtins.str
    volume_size_in_gb: builtins.int
    @property
    def additional_code_repositories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    default_code_repository: builtins.str
    direct_internet_access: builtins.str
    @property
    def accelerator_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    subnet_id: builtins.str
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role_arn: builtins.str
    root_access: builtins.str
    notebook_instance_name: builtins.str
    instance_type: builtins.str
    lifecycle_config_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_id: builtins.str = ...,
        volume_size_in_gb: builtins.int = ...,
        additional_code_repositories: collections.abc.Iterable[builtins.str] | None = ...,
        default_code_repository: builtins.str = ...,
        direct_internet_access: builtins.str = ...,
        accelerator_types: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        role_arn: builtins.str = ...,
        root_access: builtins.str = ...,
        notebook_instance_name: builtins.str = ...,
        instance_type: builtins.str = ...,
        lifecycle_config_name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_types", b"accelerator_types", "additional_code_repositories", b"additional_code_repositories", "default_code_repository", b"default_code_repository", "direct_internet_access", b"direct_internet_access", "instance_type", b"instance_type", "kms_key_id", b"kms_key_id", "lifecycle_config_name", b"lifecycle_config_name", "notebook_instance_name", b"notebook_instance_name", "resource_info", b"resource_info", "role_arn", b"role_arn", "root_access", b"root_access", "security_group_ids", b"security_group_ids", "subnet_id", b"subnet_id", "tags", b"tags", "volume_size_in_gb", b"volume_size_in_gb"]) -> None: ...

global___NotebookInstance = NotebookInstance

@typing_extensions.final
class NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "resource_info", b"resource_info"]) -> None: ...

global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook = NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook

@typing_extensions.final
class NotebookInstanceLifecycleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_START_FIELD_NUMBER: builtins.int
    NOTEBOOK_INSTANCE_LIFECYCLE_CONFIG_NAME_FIELD_NUMBER: builtins.int
    ON_CREATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_start(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook]: ...
    notebook_instance_lifecycle_config_name: builtins.str
    @property
    def on_create(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_start: collections.abc.Iterable[global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook] | None = ...,
        notebook_instance_lifecycle_config_name: builtins.str = ...,
        on_create: collections.abc.Iterable[global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notebook_instance_lifecycle_config_name", b"notebook_instance_lifecycle_config_name", "on_create", b"on_create", "on_start", b"on_start", "resource_info", b"resource_info"]) -> None: ...

global___NotebookInstanceLifecycleConfig = NotebookInstanceLifecycleConfig

@typing_extensions.final
class WorkteamNotificationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NOTIFICATION_TOPIC_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    notification_topic_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        notification_topic_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_topic_arn", b"notification_topic_arn", "resource_info", b"resource_info"]) -> None: ...

global___WorkteamNotificationConfiguration = WorkteamNotificationConfiguration

@typing_extensions.final
class WorkteamCognitoMemberDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COGNITO_USER_POOL_FIELD_NUMBER: builtins.int
    COGNITO_CLIENT_ID_FIELD_NUMBER: builtins.int
    COGNITO_USER_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cognito_user_pool: builtins.str
    cognito_client_id: builtins.str
    cognito_user_group: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cognito_user_pool: builtins.str = ...,
        cognito_client_id: builtins.str = ...,
        cognito_user_group: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cognito_client_id", b"cognito_client_id", "cognito_user_group", b"cognito_user_group", "cognito_user_pool", b"cognito_user_pool", "resource_info", b"resource_info"]) -> None: ...

global___WorkteamCognitoMemberDefinition = WorkteamCognitoMemberDefinition

@typing_extensions.final
class WorkteamMemberDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COGNITO_MEMBER_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cognito_member_definition(self) -> global___WorkteamCognitoMemberDefinition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cognito_member_definition: global___WorkteamCognitoMemberDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cognito_member_definition", b"cognito_member_definition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cognito_member_definition", b"cognito_member_definition", "resource_info", b"resource_info"]) -> None: ...

global___WorkteamMemberDefinition = WorkteamMemberDefinition

@typing_extensions.final
class Workteam(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    WORKTEAM_NAME_FIELD_NUMBER: builtins.int
    MEMBER_DEFINITIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def notification_configuration(self) -> global___WorkteamNotificationConfiguration: ...
    workteam_name: builtins.str
    @property
    def member_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkteamMemberDefinition]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        notification_configuration: global___WorkteamNotificationConfiguration | None = ...,
        workteam_name: builtins.str = ...,
        member_definitions: collections.abc.Iterable[global___WorkteamMemberDefinition] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_configuration", b"notification_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "member_definitions", b"member_definitions", "notification_configuration", b"notification_configuration", "resource_info", b"resource_info", "tags", b"tags", "workteam_name", b"workteam_name"]) -> None: ...

global___Workteam = Workteam
