# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_notebooks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_notebooks.proto\x12\x19oak9.tython.gcp.notebooks\x1a\x13shared/shared.proto\"F\n#NotebooksEnvironmentXContainerImage\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"O\n\x1dNotebooksEnvironmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"Y\n\x1cNotebooksEnvironmentXVmImage\x12\x14\n\x0cimage_family\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\"\xd9\x03\n\x14NotebooksEnvironment\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13post_startup_script\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12W\n\x0f\x63ontainer_image\x18\t \x01(\x0b\x32>.oak9.tython.gcp.notebooks.NotebooksEnvironmentXContainerImage\x12J\n\x08timeouts\x18\n \x01(\x0b\x32\x38.oak9.tython.gcp.notebooks.NotebooksEnvironmentXTimeouts\x12I\n\x08vm_image\x18\x0b \x01(\x0b\x32\x37.oak9.tython.gcp.notebooks.NotebooksEnvironmentXVmImage\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"G\n#NotebooksInstanceXAcceleratorConfig\x12\x12\n\ncore_count\x18\x01 \x01(\x01\x12\x0c\n\x04type\x18\x02 \x01(\t\"C\n NotebooksInstanceXContainerImage\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"f\n%NotebooksInstanceXReservationAffinity\x12 \n\x18\x63onsume_reservation_type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\x80\x01\n(NotebooksInstanceXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"L\n\x1aNotebooksInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"V\n\x19NotebooksInstanceXVmImage\x12\x14\n\x0cimage_family\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\"\xb5\x0b\n\x11NotebooksInstance\x12\x19\n\x11\x62oot_disk_size_gb\x18\x01 \x01(\x01\x12\x16\n\x0e\x62oot_disk_type\x18\x02 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\t\x12\x1e\n\x16\x63ustom_gpu_driver_path\x18\x04 \x01(\t\x12\x19\n\x11\x64\x61ta_disk_size_gb\x18\x05 \x01(\x01\x12\x16\n\x0e\x64\x61ta_disk_type\x18\x06 \x01(\t\x12\x17\n\x0f\x64isk_encryption\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x1a\n\x12install_gpu_driver\x18\t \x01(\x08\x12\x17\n\x0finstance_owners\x18\n \x03(\t\x12\x0f\n\x07kms_key\x18\x0b \x01(\t\x12H\n\x06labels\x18\x0c \x03(\x0b\x32\x38.oak9.tython.gcp.notebooks.NotebooksInstance.LabelsEntry\x12\x10\n\x08location\x18\r \x01(\t\x12\x14\n\x0cmachine_type\x18\x0e \x01(\t\x12L\n\x08metadata\x18\x0f \x03(\x0b\x32:.oak9.tython.gcp.notebooks.NotebooksInstance.MetadataEntry\x12\x0c\n\x04name\x18\x10 \x01(\t\x12\x0f\n\x07network\x18\x11 \x01(\t\x12\x10\n\x08nic_type\x18\x12 \x01(\t\x12\x17\n\x0fno_proxy_access\x18\x13 \x01(\x08\x12\x14\n\x0cno_public_ip\x18\x14 \x01(\x08\x12\x1b\n\x13no_remove_data_disk\x18\x15 \x01(\x08\x12\x1b\n\x13post_startup_script\x18\x16 \x01(\t\x12\x0f\n\x07project\x18\x17 \x01(\t\x12\x11\n\tproxy_uri\x18\x18 \x01(\t\x12\x17\n\x0fservice_account\x18\x19 \x01(\t\x12\x1e\n\x16service_account_scopes\x18\x1a \x03(\t\x12\r\n\x05state\x18\x1b \x01(\t\x12\x0e\n\x06subnet\x18\x1c \x01(\t\x12\x0c\n\x04tags\x18\x1d \x03(\t\x12\x13\n\x0bupdate_time\x18\x1e \x01(\t\x12Z\n\x12\x61\x63\x63\x65lerator_config\x18\x1f \x01(\x0b\x32>.oak9.tython.gcp.notebooks.NotebooksInstanceXAcceleratorConfig\x12T\n\x0f\x63ontainer_image\x18  \x01(\x0b\x32;.oak9.tython.gcp.notebooks.NotebooksInstanceXContainerImage\x12^\n\x14reservation_affinity\x18! \x01(\x0b\x32@.oak9.tython.gcp.notebooks.NotebooksInstanceXReservationAffinity\x12\x65\n\x18shielded_instance_config\x18\" \x01(\x0b\x32\x43.oak9.tython.gcp.notebooks.NotebooksInstanceXShieldedInstanceConfig\x12G\n\x08timeouts\x18# \x01(\x0b\x32\x35.oak9.tython.gcp.notebooks.NotebooksInstanceXTimeouts\x12\x46\n\x08vm_image\x18$ \x01(\x0b\x32\x34.oak9.tython.gcp.notebooks.NotebooksInstanceXVmImage\x12\x37\n\rresource_info\x18% \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"_\n%NotebooksInstanceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9e\x02\n\x1bNotebooksInstanceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0f\n\x07members\x18\x05 \x03(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12S\n\tcondition\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.notebooks.NotebooksInstanceIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$NotebooksInstanceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9b\x02\n\x1aNotebooksInstanceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0e\n\x06member\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12R\n\tcondition\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.notebooks.NotebooksInstanceIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbe\x01\n\x1aNotebooksInstanceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x1aNotebooksLocationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd3\x01\n\x11NotebooksLocation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x11\n\tself_link\x18\x04 \x01(\t\x12G\n\x08timeouts\x18\x05 \x01(\x0b\x32\x35.oak9.tython.gcp.notebooks.NotebooksLocationXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n\x1dNotebooksRuntimeXAccessConfig\x12\x13\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\t\x12\x11\n\tproxy_uri\x18\x02 \x01(\t\x12\x15\n\rruntime_owner\x18\x03 \x01(\t\"J\n\'NotebooksRuntimeXSoftwareConfigXKernels\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\x85\x03\n\x1fNotebooksRuntimeXSoftwareConfig\x12\x1e\n\x16\x63ustom_gpu_driver_path\x18\x01 \x01(\t\x12 \n\x18\x65nable_health_monitoring\x18\x02 \x01(\x08\x12\x15\n\ridle_shutdown\x18\x03 \x01(\x08\x12\x1d\n\x15idle_shutdown_timeout\x18\x04 \x01(\x01\x12\x1a\n\x12install_gpu_driver\x18\x05 \x01(\x08\x12!\n\x19notebook_upgrade_schedule\x18\x06 \x01(\t\x12\x1b\n\x13post_startup_script\x18\x07 \x01(\t\x12$\n\x1cpost_startup_script_behavior\x18\x08 \x01(\t\x12\x13\n\x0bupgradeable\x18\t \x01(\x08\x12S\n\x07kernels\x18\n \x03(\x0b\x32\x42.oak9.tython.gcp.notebooks.NotebooksRuntimeXSoftwareConfigXKernels\"K\n\x19NotebooksRuntimeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"j\nFNotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig\x12\x12\n\ncore_count\x18\x01 \x01(\x01\x12\x0c\n\x04type\x18\x02 \x01(\t\"g\nDNotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\xd8\x02\nNNotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x11\n\tdisk_name\x18\x02 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x03 \x01(\x01\x12\x11\n\tdisk_type\x18\x04 \x01(\t\x12\x85\x01\n\x06labels\x18\x05 \x03(\x0b\x32u.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x03\n=NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk\x12\x13\n\x0b\x61uto_delete\x18\x01 \x01(\x08\x12\x0c\n\x04\x62oot\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65vice_name\x18\x03 \x01(\t\x12\x19\n\x11guest_os_features\x18\x04 \x03(\t\x12\r\n\x05index\x18\x05 \x01(\x01\x12\x11\n\tinterface\x18\x06 \x01(\t\x12\x0c\n\x04kind\x18\x07 \x01(\t\x12\x10\n\x08licenses\x18\x08 \x03(\t\x12\x0c\n\x04mode\x18\t \x01(\t\x12\x0e\n\x06source\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x84\x01\n\x11initialize_params\x18\x0c \x01(\x0b\x32i.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams\"X\nENotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig\x12\x0f\n\x07kms_key\x18\x01 \x01(\t\"\xa3\x01\nKNotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"\xb5\n\n4NotebooksRuntimeXVirtualMachineXVirtualMachineConfig\x12~\n\x10guest_attributes\x18\x01 \x03(\x0b\x32\x64.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfig.GuestAttributesEntry\x12\x18\n\x10internal_ip_only\x18\x02 \x01(\x08\x12k\n\x06labels\x18\x03 \x03(\x0b\x32[.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfig.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x04 \x01(\t\x12o\n\x08metadata\x18\x05 \x03(\x0b\x32].oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfig.MetadataEntry\x12\x0f\n\x07network\x18\x06 \x01(\t\x12\x10\n\x08nic_type\x18\x07 \x01(\t\x12\x19\n\x11reserved_ip_range\x18\x08 \x01(\t\x12\x0e\n\x06subnet\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x03(\t\x12\x0c\n\x04zone\x18\x0b \x01(\t\x12}\n\x12\x61\x63\x63\x65lerator_config\x18\x0c \x01(\x0b\x32\x61.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig\x12y\n\x10\x63ontainer_images\x18\r \x03(\x0b\x32_.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages\x12k\n\tdata_disk\x18\x0e \x01(\x0b\x32X.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk\x12{\n\x11\x65ncryption_config\x18\x0f \x01(\x0b\x32`.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig\x12\x88\x01\n\x18shielded_instance_config\x18\x10 \x01(\x0b\x32\x66.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig\x1a\x36\n\x14GuestAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x1fNotebooksRuntimeXVirtualMachine\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12o\n\x16virtual_machine_config\x18\x03 \x01(\x0b\x32O.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfig\"\xeb\x04\n\x10NotebooksRuntime\x12\x14\n\x0chealth_state\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12I\n\x07metrics\x18\x04 \x03(\x0b\x32\x38.oak9.tython.gcp.notebooks.NotebooksRuntime.MetricsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\x12O\n\raccess_config\x18\x08 \x01(\x0b\x32\x38.oak9.tython.gcp.notebooks.NotebooksRuntimeXAccessConfig\x12S\n\x0fsoftware_config\x18\t \x01(\x0b\x32:.oak9.tython.gcp.notebooks.NotebooksRuntimeXSoftwareConfig\x12\x46\n\x08timeouts\x18\n \x01(\x0b\x32\x34.oak9.tython.gcp.notebooks.NotebooksRuntimeXTimeouts\x12S\n\x0fvirtual_machine\x18\x0b \x01(\x0b\x32:.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachine\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n$NotebooksRuntimeIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9b\x02\n\x1aNotebooksRuntimeIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x14\n\x0cruntime_name\x18\x07 \x01(\t\x12R\n\tcondition\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.notebooks.NotebooksRuntimeIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#NotebooksRuntimeIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x98\x02\n\x19NotebooksRuntimeIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x14\n\x0cruntime_name\x18\x07 \x01(\t\x12Q\n\tcondition\x18\x08 \x01(\x0b\x32>.oak9.tython.gcp.notebooks.NotebooksRuntimeIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbc\x01\n\x19NotebooksRuntimeIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x14\n\x0cruntime_name\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_notebooks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTEBOOKSINSTANCE_LABELSENTRY._options = None
  _NOTEBOOKSINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSINSTANCE_METADATAENTRY._options = None
  _NOTEBOOKSINSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS_LABELSENTRY._options = None
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_GUESTATTRIBUTESENTRY._options = None
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_GUESTATTRIBUTESENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_LABELSENTRY._options = None
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_METADATAENTRY._options = None
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_METADATAENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIME_METRICSENTRY._options = None
  _NOTEBOOKSRUNTIME_METRICSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSENVIRONMENTXCONTAINERIMAGE._serialized_start=75
  _NOTEBOOKSENVIRONMENTXCONTAINERIMAGE._serialized_end=145
  _NOTEBOOKSENVIRONMENTXTIMEOUTS._serialized_start=147
  _NOTEBOOKSENVIRONMENTXTIMEOUTS._serialized_end=226
  _NOTEBOOKSENVIRONMENTXVMIMAGE._serialized_start=228
  _NOTEBOOKSENVIRONMENTXVMIMAGE._serialized_end=317
  _NOTEBOOKSENVIRONMENT._serialized_start=320
  _NOTEBOOKSENVIRONMENT._serialized_end=793
  _NOTEBOOKSINSTANCEXACCELERATORCONFIG._serialized_start=795
  _NOTEBOOKSINSTANCEXACCELERATORCONFIG._serialized_end=866
  _NOTEBOOKSINSTANCEXCONTAINERIMAGE._serialized_start=868
  _NOTEBOOKSINSTANCEXCONTAINERIMAGE._serialized_end=935
  _NOTEBOOKSINSTANCEXRESERVATIONAFFINITY._serialized_start=937
  _NOTEBOOKSINSTANCEXRESERVATIONAFFINITY._serialized_end=1039
  _NOTEBOOKSINSTANCEXSHIELDEDINSTANCECONFIG._serialized_start=1042
  _NOTEBOOKSINSTANCEXSHIELDEDINSTANCECONFIG._serialized_end=1170
  _NOTEBOOKSINSTANCEXTIMEOUTS._serialized_start=1172
  _NOTEBOOKSINSTANCEXTIMEOUTS._serialized_end=1248
  _NOTEBOOKSINSTANCEXVMIMAGE._serialized_start=1250
  _NOTEBOOKSINSTANCEXVMIMAGE._serialized_end=1336
  _NOTEBOOKSINSTANCE._serialized_start=1339
  _NOTEBOOKSINSTANCE._serialized_end=2800
  _NOTEBOOKSINSTANCE_LABELSENTRY._serialized_start=2706
  _NOTEBOOKSINSTANCE_LABELSENTRY._serialized_end=2751
  _NOTEBOOKSINSTANCE_METADATAENTRY._serialized_start=2753
  _NOTEBOOKSINSTANCE_METADATAENTRY._serialized_end=2800
  _NOTEBOOKSINSTANCEIAMBINDINGXCONDITION._serialized_start=2802
  _NOTEBOOKSINSTANCEIAMBINDINGXCONDITION._serialized_end=2897
  _NOTEBOOKSINSTANCEIAMBINDING._serialized_start=2900
  _NOTEBOOKSINSTANCEIAMBINDING._serialized_end=3186
  _NOTEBOOKSINSTANCEIAMMEMBERXCONDITION._serialized_start=3188
  _NOTEBOOKSINSTANCEIAMMEMBERXCONDITION._serialized_end=3282
  _NOTEBOOKSINSTANCEIAMMEMBER._serialized_start=3285
  _NOTEBOOKSINSTANCEIAMMEMBER._serialized_end=3568
  _NOTEBOOKSINSTANCEIAMPOLICY._serialized_start=3571
  _NOTEBOOKSINSTANCEIAMPOLICY._serialized_end=3761
  _NOTEBOOKSLOCATIONXTIMEOUTS._serialized_start=3763
  _NOTEBOOKSLOCATIONXTIMEOUTS._serialized_end=3839
  _NOTEBOOKSLOCATION._serialized_start=3842
  _NOTEBOOKSLOCATION._serialized_end=4053
  _NOTEBOOKSRUNTIMEXACCESSCONFIG._serialized_start=4055
  _NOTEBOOKSRUNTIMEXACCESSCONFIG._serialized_end=4149
  _NOTEBOOKSRUNTIMEXSOFTWARECONFIGXKERNELS._serialized_start=4151
  _NOTEBOOKSRUNTIMEXSOFTWARECONFIGXKERNELS._serialized_end=4225
  _NOTEBOOKSRUNTIMEXSOFTWARECONFIG._serialized_start=4228
  _NOTEBOOKSRUNTIMEXSOFTWARECONFIG._serialized_end=4617
  _NOTEBOOKSRUNTIMEXTIMEOUTS._serialized_start=4619
  _NOTEBOOKSRUNTIMEXTIMEOUTS._serialized_end=4694
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXACCELERATORCONFIG._serialized_start=4696
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXACCELERATORCONFIG._serialized_end=4802
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXCONTAINERIMAGES._serialized_start=4804
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXCONTAINERIMAGES._serialized_end=4907
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS._serialized_start=4910
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS._serialized_end=5254
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS_LABELSENTRY._serialized_start=2706
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS_LABELSENTRY._serialized_end=2751
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISK._serialized_start=5257
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISK._serialized_end=5648
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXENCRYPTIONCONFIG._serialized_start=5650
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXENCRYPTIONCONFIG._serialized_end=5738
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXSHIELDEDINSTANCECONFIG._serialized_start=5741
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXSHIELDEDINSTANCECONFIG._serialized_end=5904
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG._serialized_start=5907
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG._serialized_end=7240
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_GUESTATTRIBUTESENTRY._serialized_start=7090
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_GUESTATTRIBUTESENTRY._serialized_end=7144
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_LABELSENTRY._serialized_start=2706
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_LABELSENTRY._serialized_end=2751
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_METADATAENTRY._serialized_start=2753
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_METADATAENTRY._serialized_end=2800
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINE._serialized_start=7243
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINE._serialized_end=7433
  _NOTEBOOKSRUNTIME._serialized_start=7436
  _NOTEBOOKSRUNTIME._serialized_end=8055
  _NOTEBOOKSRUNTIME_METRICSENTRY._serialized_start=8009
  _NOTEBOOKSRUNTIME_METRICSENTRY._serialized_end=8055
  _NOTEBOOKSRUNTIMEIAMBINDINGXCONDITION._serialized_start=8057
  _NOTEBOOKSRUNTIMEIAMBINDINGXCONDITION._serialized_end=8151
  _NOTEBOOKSRUNTIMEIAMBINDING._serialized_start=8154
  _NOTEBOOKSRUNTIMEIAMBINDING._serialized_end=8437
  _NOTEBOOKSRUNTIMEIAMMEMBERXCONDITION._serialized_start=8439
  _NOTEBOOKSRUNTIMEIAMMEMBERXCONDITION._serialized_end=8532
  _NOTEBOOKSRUNTIMEIAMMEMBER._serialized_start=8535
  _NOTEBOOKSRUNTIMEIAMMEMBER._serialized_end=8815
  _NOTEBOOKSRUNTIMEIAMPOLICY._serialized_start=8818
  _NOTEBOOKSRUNTIMEIAMPOLICY._serialized_end=9006
# @@protoc_insertion_point(module_scope)
