# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_inspector.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_inspector.proto\x12\x19oak9.tython.aws.inspector\x1a\x13shared/shared.proto\"\x87\x01\n\x10\x41ssessmentTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x61ssessment_target_name\x18\x02 \x01(\t\x12\x1a\n\x12resource_group_arn\x18\x03 \x01(\t\"\xe1\x01\n\tInspector\x12\x46\n\x11\x61ssessment_target\x18\x01 \x03(\x0b\x32+.oak9.tython.aws.inspector.AssessmentTarget\x12J\n\x13\x61ssessment_template\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.inspector.AssessmentTemplate\x12@\n\x0eresource_group\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.inspector.ResourceGroup\"\xfd\x02\n\x12\x41ssessmentTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x61ssessment_target_arn\x18\x02 \x01(\t\x12\x1b\n\x13\x64uration_in_seconds\x18\x03 \x01(\x05\x12 \n\x18\x61ssessment_template_name\x18\x04 \x01(\t\x12\x1a\n\x12rules_package_arns\x18\x05 \x03(\t\x12r\n\x1cuser_attributes_for_findings\x18\x06 \x03(\x0b\x32L.oak9.tython.aws.inspector.AssessmentTemplate.UserAttributesForFindingsEntry\x1a@\n\x1eUserAttributesForFindingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe0\x01\n\rResourceGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x13resource_group_tags\x18\x02 \x03(\x0b\x32?.oak9.tython.aws.inspector.ResourceGroup.ResourceGroupTagsEntry\x1a\x38\n\x16ResourceGroupTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_inspector_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ASSESSMENTTEMPLATE_USERATTRIBUTESFORFINDINGSENTRY._options = None
  _ASSESSMENTTEMPLATE_USERATTRIBUTESFORFINDINGSENTRY._serialized_options = b'8\001'
  _RESOURCEGROUP_RESOURCEGROUPTAGSENTRY._options = None
  _RESOURCEGROUP_RESOURCEGROUPTAGSENTRY._serialized_options = b'8\001'
  _ASSESSMENTTARGET._serialized_start=76
  _ASSESSMENTTARGET._serialized_end=211
  _INSPECTOR._serialized_start=214
  _INSPECTOR._serialized_end=439
  _ASSESSMENTTEMPLATE._serialized_start=442
  _ASSESSMENTTEMPLATE._serialized_end=823
  _ASSESSMENTTEMPLATE_USERATTRIBUTESFORFINDINGSENTRY._serialized_start=759
  _ASSESSMENTTEMPLATE_USERATTRIBUTESFORFINDINGSENTRY._serialized_end=823
  _RESOURCEGROUP._serialized_start=826
  _RESOURCEGROUP._serialized_end=1050
  _RESOURCEGROUP_RESOURCEGROUPTAGSENTRY._serialized_start=994
  _RESOURCEGROUP_RESOURCEGROUPTAGSENTRY._serialized_end=1050
# @@protoc_insertion_point(module_scope)
