# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_app.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_app.proto\x12\x13oak9.tython.gcp.app\x1a\x13shared/shared.proto\"C\n$AppEngineApplicationXFeatureSettings\x12\x1b\n\x13split_health_checks\x18\x01 \x01(\x08\"\x88\x01\n\x18\x41ppEngineApplicationXIap\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x18\n\x10oauth2_client_id\x18\x02 \x01(\t\x12\x1c\n\x14oauth2_client_secret\x18\x03 \x01(\t\x12#\n\x1boauth2_client_secret_sha256\x18\x04 \x01(\t\"?\n\x1d\x41ppEngineApplicationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06update\x18\x02 \x01(\t\"\xa8\x05\n\x14\x41ppEngineApplication\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61uth_domain\x18\x02 \x01(\t\x12\x13\n\x0b\x63ode_bucket\x18\x03 \x01(\t\x12\x15\n\rdatabase_type\x18\x04 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_bucket\x18\x05 \x01(\t\x12\x18\n\x10\x64\x65\x66\x61ult_hostname\x18\x06 \x01(\t\x12\x12\n\ngcr_domain\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x13\n\x0blocation_id\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x16\n\x0eserving_status\x18\x0c \x01(\t\x12Y\n\x11url_dispatch_rule\x18\r \x03(\x0b\x32>.oak9.tython.gcp.app.AppEngineApplication.UrlDispatchRuleEntry\x12S\n\x10\x66\x65\x61ture_settings\x18\x0e \x01(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineApplicationXFeatureSettings\x12:\n\x03iap\x18\x0f \x01(\x0b\x32-.oak9.tython.gcp.app.AppEngineApplicationXIap\x12\x44\n\x08timeouts\x18\x10 \x01(\x0b\x32\x32.oak9.tython.gcp.app.AppEngineApplicationXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x36\n\x14UrlDispatchRuleEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n2AppEngineApplicationUrlDispatchRulesXDispatchRules\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\"_\n-AppEngineApplicationUrlDispatchRulesXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb3\x02\n$AppEngineApplicationUrlDispatchRules\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12_\n\x0e\x64ispatch_rules\x18\x03 \x03(\x0b\x32G.oak9.tython.gcp.app.AppEngineApplicationUrlDispatchRulesXDispatchRules\x12T\n\x08timeouts\x18\x04 \x01(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineApplicationUrlDispatchRulesXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x01\n\"AppEngineDomainMappingXSslSettings\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12&\n\x1epending_managed_certificate_id\x18\x02 \x01(\t\x12\x1b\n\x13ssl_management_type\x18\x03 \x01(\t\"Q\n\x1f\x41ppEngineDomainMappingXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd7\x03\n\x16\x41ppEngineDomainMapping\x12\x13\n\x0b\x64omain_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11override_strategy\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12Z\n\x10resource_records\x18\x06 \x03(\x0b\x32@.oak9.tython.gcp.app.AppEngineDomainMapping.ResourceRecordsEntry\x12M\n\x0cssl_settings\x18\x07 \x01(\x0b\x32\x37.oak9.tython.gcp.app.AppEngineDomainMappingXSslSettings\x12\x46\n\x08timeouts\x18\x08 \x01(\x0b\x32\x34.oak9.tython.gcp.app.AppEngineDomainMappingXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x36\n\x14ResourceRecordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n\x1e\x41ppEngineFirewallRuleXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x81\x02\n\x15\x41ppEngineFirewallRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x01\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x14\n\x0csource_range\x18\x06 \x01(\t\x12\x45\n\x08timeouts\x18\x07 \x01(\x0b\x32\x33.oak9.tython.gcp.app.AppEngineFirewallRuleXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x85\x01\n%AppEngineFlexibleAppVersionXApiConfig\x12\x18\n\x10\x61uth_fail_action\x18\x01 \x01(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12\x0e\n\x06script\x18\x03 \x01(\t\x12\x16\n\x0esecurity_level\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"|\n;AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization\x12!\n\x19\x61ggregation_window_length\x18\x01 \x01(\t\x12\x1a\n\x12target_utilization\x18\x02 \x01(\x01\"\xd4\x01\n<AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization\x12$\n\x1ctarget_read_bytes_per_second\x18\x01 \x01(\x01\x12\"\n\x1atarget_read_ops_per_second\x18\x02 \x01(\x01\x12%\n\x1dtarget_write_bytes_per_second\x18\x03 \x01(\x01\x12#\n\x1btarget_write_ops_per_second\x18\x04 \x01(\x01\"\xe5\x01\n?AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization\x12(\n target_received_bytes_per_second\x18\x01 \x01(\x01\x12*\n\"target_received_packets_per_second\x18\x02 \x01(\x01\x12$\n\x1ctarget_sent_bytes_per_second\x18\x03 \x01(\x01\x12&\n\x1etarget_sent_packets_per_second\x18\x04 \x01(\x01\"\x8e\x01\n?AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization\x12\"\n\x1atarget_concurrent_requests\x18\x01 \x01(\x01\x12\'\n\x1ftarget_request_count_per_second\x18\x02 \x01(\t\"\xd3\x05\n,AppEngineFlexibleAppVersionXAutomaticScaling\x12\x18\n\x10\x63ool_down_period\x18\x01 \x01(\t\x12\x1f\n\x17max_concurrent_requests\x18\x02 \x01(\x01\x12\x1a\n\x12max_idle_instances\x18\x03 \x01(\x01\x12\x1b\n\x13max_pending_latency\x18\x04 \x01(\t\x12\x1b\n\x13max_total_instances\x18\x05 \x01(\x01\x12\x1a\n\x12min_idle_instances\x18\x06 \x01(\x01\x12\x1b\n\x13min_pending_latency\x18\x07 \x01(\t\x12\x1b\n\x13min_total_instances\x18\x08 \x01(\x01\x12i\n\x0f\x63pu_utilization\x18\t \x01(\x0b\x32P.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization\x12k\n\x10\x64isk_utilization\x18\n \x01(\x0b\x32Q.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization\x12q\n\x13network_utilization\x18\x0b \x01(\x0b\x32T.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization\x12q\n\x13request_utilization\x18\x0c \x01(\x0b\x32T.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization\"n\n8AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions\x12\x15\n\rapp_yaml_path\x18\x01 \x01(\t\x12\x1b\n\x13\x63loud_build_timeout\x18\x02 \x01(\t\"A\n0AppEngineFlexibleAppVersionXDeploymentXContainer\x12\r\n\x05image\x18\x01 \x01(\t\"b\n,AppEngineFlexibleAppVersionXDeploymentXFiles\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sha1_sum\x18\x02 \x01(\t\x12\x12\n\nsource_url\x18\x03 \x01(\t\"U\n*AppEngineFlexibleAppVersionXDeploymentXZip\x12\x13\n\x0b\x66iles_count\x18\x01 \x01(\x01\x12\x12\n\nsource_url\x18\x02 \x01(\t\"\x8e\x03\n&AppEngineFlexibleAppVersionXDeployment\x12j\n\x13\x63loud_build_options\x18\x01 \x01(\x0b\x32M.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions\x12X\n\tcontainer\x18\x02 \x01(\x0b\x32\x45.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeploymentXContainer\x12P\n\x05\x66iles\x18\x03 \x03(\x0b\x32\x41.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeploymentXFiles\x12L\n\x03zip\x18\x04 \x01(\x0b\x32?.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeploymentXZip\"\x8c\x01\n/AppEngineFlexibleAppVersionXEndpointsApiService\x12\x11\n\tconfig_id\x18\x01 \x01(\t\x12\x1e\n\x16\x64isable_trace_sampling\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10rollout_strategy\x18\x04 \x01(\t\"7\n&AppEngineFlexibleAppVersionXEntrypoint\x12\r\n\x05shell\x18\x01 \x01(\t\"B\n+AppEngineFlexibleAppVersionXHandlersXScript\x12\x13\n\x0bscript_path\x18\x01 \x01(\t\"\xe1\x02\n0AppEngineFlexibleAppVersionXHandlersXStaticFiles\x12\x1c\n\x14\x61pplication_readable\x18\x01 \x01(\x08\x12\x12\n\nexpiration\x18\x02 \x01(\t\x12l\n\x0chttp_headers\x18\x03 \x03(\x0b\x32V.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXHandlersXStaticFiles.HttpHeadersEntry\x12\x11\n\tmime_type\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x1d\n\x15require_matching_file\x18\x06 \x01(\x08\x12\x19\n\x11upload_path_regex\x18\x07 \x01(\t\x1a\x32\n\x10HttpHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x02\n$AppEngineFlexibleAppVersionXHandlers\x12\x18\n\x10\x61uth_fail_action\x18\x01 \x01(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12#\n\x1bredirect_http_response_code\x18\x03 \x01(\t\x12\x16\n\x0esecurity_level\x18\x04 \x01(\t\x12\x11\n\turl_regex\x18\x05 \x01(\t\x12P\n\x06script\x18\x06 \x01(\x0b\x32@.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXHandlersXScript\x12[\n\x0cstatic_files\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXHandlersXStaticFiles\"\xbd\x01\n)AppEngineFlexibleAppVersionXLivenessCheck\x12\x16\n\x0e\x63heck_interval\x18\x01 \x01(\t\x12\x19\n\x11\x66\x61ilure_threshold\x18\x02 \x01(\x01\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x15\n\rinitial_delay\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x19\n\x11success_threshold\x18\x06 \x01(\x01\x12\x0f\n\x07timeout\x18\x07 \x01(\t\">\n)AppEngineFlexibleAppVersionXManualScaling\x12\x11\n\tinstances\x18\x01 \x01(\x01\"\x90\x01\n#AppEngineFlexibleAppVersionXNetwork\x12\x17\n\x0f\x66orwarded_ports\x18\x01 \x03(\t\x12\x14\n\x0cinstance_tag\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10session_affinity\x18\x04 \x01(\x08\x12\x12\n\nsubnetwork\x18\x05 \x01(\t\"\xc2\x01\n*AppEngineFlexibleAppVersionXReadinessCheck\x12\x19\n\x11\x61pp_start_timeout\x18\x01 \x01(\t\x12\x16\n\x0e\x63heck_interval\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61ilure_threshold\x18\x03 \x01(\x01\x12\x0c\n\x04host\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x19\n\x11success_threshold\x18\x06 \x01(\x01\x12\x0f\n\x07timeout\x18\x07 \x01(\t\"c\n-AppEngineFlexibleAppVersionXResourcesXVolumes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07size_gb\x18\x02 \x01(\x01\x12\x13\n\x0bvolume_type\x18\x03 \x01(\t\"\xad\x01\n%AppEngineFlexibleAppVersionXResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x0f\n\x07\x64isk_gb\x18\x02 \x01(\x01\x12\x11\n\tmemory_gb\x18\x03 \x01(\x01\x12S\n\x07volumes\x18\x04 \x03(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXResourcesXVolumes\"V\n$AppEngineFlexibleAppVersionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\">\n.AppEngineFlexibleAppVersionXVpcAccessConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc8\x0e\n\x1b\x41ppEngineFlexibleAppVersion\x12Y\n\rbeta_settings\x18\x01 \x03(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineFlexibleAppVersion.BetaSettingsEntry\x12\x1a\n\x12\x64\x65\x66\x61ult_expiration\x18\x02 \x01(\t\x12!\n\x19\x64\x65lete_service_on_destroy\x18\x03 \x01(\x08\x12Y\n\renv_variables\x18\x04 \x03(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineFlexibleAppVersion.EnvVariablesEntry\x12\n\n\x02id\x18\x05 \x01(\t\x12\x18\n\x10inbound_services\x18\x06 \x03(\t\x12\x16\n\x0einstance_class\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x1b\n\x13nobuild_files_regex\x18\t \x01(\t\x12\x17\n\x0fnoop_on_destroy\x18\n \x01(\x08\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x0f\n\x07runtime\x18\x0c \x01(\t\x12\x1b\n\x13runtime_api_version\x18\r \x01(\t\x12\x17\n\x0fruntime_channel\x18\x0e \x01(\t\x12$\n\x1cruntime_main_executable_path\x18\x0f \x01(\t\x12\x0f\n\x07service\x18\x10 \x01(\t\x12\x16\n\x0eserving_status\x18\x11 \x01(\t\x12\x12\n\nversion_id\x18\x12 \x01(\t\x12N\n\napi_config\x18\x13 \x01(\x0b\x32:.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXApiConfig\x12\\\n\x11\x61utomatic_scaling\x18\x14 \x01(\x0b\x32\x41.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScaling\x12O\n\ndeployment\x18\x15 \x01(\x0b\x32;.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeployment\x12\x63\n\x15\x65ndpoints_api_service\x18\x16 \x01(\x0b\x32\x44.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXEndpointsApiService\x12O\n\nentrypoint\x18\x17 \x01(\x0b\x32;.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXEntrypoint\x12K\n\x08handlers\x18\x18 \x03(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXHandlers\x12V\n\x0eliveness_check\x18\x19 \x01(\x0b\x32>.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXLivenessCheck\x12V\n\x0emanual_scaling\x18\x1a \x01(\x0b\x32>.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXManualScaling\x12I\n\x07network\x18\x1b \x01(\x0b\x32\x38.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXNetwork\x12X\n\x0freadiness_check\x18\x1c \x01(\x0b\x32?.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXReadinessCheck\x12M\n\tresources\x18\x1d \x01(\x0b\x32:.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXResources\x12K\n\x08timeouts\x18\x1e \x01(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXTimeouts\x12\x61\n\x14vpc_access_connector\x18\x1f \x01(\x0b\x32\x43.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXVpcAccessConnector\x12\x37\n\rresource_info\x18  \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11\x42\x65taSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x45nvVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n/AppEngineServiceNetworkSettingsXNetworkSettings\x12\x1f\n\x17ingress_traffic_allowed\x18\x01 \x01(\t\"Z\n(AppEngineServiceNetworkSettingsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb9\x02\n\x1f\x41ppEngineServiceNetworkSettings\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12^\n\x10network_settings\x18\x04 \x01(\x0b\x32\x44.oak9.tython.gcp.app.AppEngineServiceNetworkSettingsXNetworkSettings\x12O\n\x08timeouts\x18\x05 \x01(\x0b\x32=.oak9.tython.gcp.app.AppEngineServiceNetworkSettingsXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc9\x01\n\"AppEngineServiceSplitTrafficXSplit\x12]\n\x0b\x61llocations\x18\x01 \x03(\x0b\x32H.oak9.tython.gcp.app.AppEngineServiceSplitTrafficXSplit.AllocationsEntry\x12\x10\n\x08shard_by\x18\x02 \x01(\t\x1a\x32\n\x10\x41llocationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n%AppEngineServiceSplitTrafficXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb4\x02\n\x1c\x41ppEngineServiceSplitTraffic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fmigrate_traffic\x18\x02 \x01(\x08\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12\x46\n\x05split\x18\x05 \x01(\x0b\x32\x37.oak9.tython.gcp.app.AppEngineServiceSplitTrafficXSplit\x12L\n\x08timeouts\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.app.AppEngineServiceSplitTrafficXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbd\x01\nFAppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings\x12\x15\n\rmax_instances\x18\x01 \x01(\x01\x12\x15\n\rmin_instances\x18\x02 \x01(\x01\x12\x1e\n\x16target_cpu_utilization\x18\x03 \x01(\x01\x12%\n\x1dtarget_throughput_utilization\x18\x04 \x01(\x01\"\xc4\x02\n,AppEngineStandardAppVersionXAutomaticScaling\x12\x1f\n\x17max_concurrent_requests\x18\x01 \x01(\x01\x12\x1a\n\x12max_idle_instances\x18\x02 \x01(\x01\x12\x1b\n\x13max_pending_latency\x18\x03 \x01(\t\x12\x1a\n\x12min_idle_instances\x18\x04 \x01(\x01\x12\x1b\n\x13min_pending_latency\x18\x05 \x01(\t\x12\x80\x01\n\x1bstandard_scheduler_settings\x18\x06 \x01(\x0b\x32[.oak9.tython.gcp.app.AppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings\"W\n(AppEngineStandardAppVersionXBasicScaling\x12\x14\n\x0cidle_timeout\x18\x01 \x01(\t\x12\x15\n\rmax_instances\x18\x02 \x01(\x01\"b\n,AppEngineStandardAppVersionXDeploymentXFiles\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sha1_sum\x18\x02 \x01(\t\x12\x12\n\nsource_url\x18\x03 \x01(\t\"U\n*AppEngineStandardAppVersionXDeploymentXZip\x12\x13\n\x0b\x66iles_count\x18\x01 \x01(\x01\x12\x12\n\nsource_url\x18\x02 \x01(\t\"\xc8\x01\n&AppEngineStandardAppVersionXDeployment\x12P\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x41.oak9.tython.gcp.app.AppEngineStandardAppVersionXDeploymentXFiles\x12L\n\x03zip\x18\x02 \x01(\x0b\x32?.oak9.tython.gcp.app.AppEngineStandardAppVersionXDeploymentXZip\"7\n&AppEngineStandardAppVersionXEntrypoint\x12\r\n\x05shell\x18\x01 \x01(\t\"B\n+AppEngineStandardAppVersionXHandlersXScript\x12\x13\n\x0bscript_path\x18\x01 \x01(\t\"\xe1\x02\n0AppEngineStandardAppVersionXHandlersXStaticFiles\x12\x1c\n\x14\x61pplication_readable\x18\x01 \x01(\x08\x12\x12\n\nexpiration\x18\x02 \x01(\t\x12l\n\x0chttp_headers\x18\x03 \x03(\x0b\x32V.oak9.tython.gcp.app.AppEngineStandardAppVersionXHandlersXStaticFiles.HttpHeadersEntry\x12\x11\n\tmime_type\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x1d\n\x15require_matching_file\x18\x06 \x01(\x08\x12\x19\n\x11upload_path_regex\x18\x07 \x01(\t\x1a\x32\n\x10HttpHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x02\n$AppEngineStandardAppVersionXHandlers\x12\x18\n\x10\x61uth_fail_action\x18\x01 \x01(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12#\n\x1bredirect_http_response_code\x18\x03 \x01(\t\x12\x16\n\x0esecurity_level\x18\x04 \x01(\t\x12\x11\n\turl_regex\x18\x05 \x01(\t\x12P\n\x06script\x18\x06 \x01(\x0b\x32@.oak9.tython.gcp.app.AppEngineStandardAppVersionXHandlersXScript\x12[\n\x0cstatic_files\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.app.AppEngineStandardAppVersionXHandlersXStaticFiles\"F\n%AppEngineStandardAppVersionXLibraries\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\">\n)AppEngineStandardAppVersionXManualScaling\x12\x11\n\tinstances\x18\x01 \x01(\x01\"V\n$AppEngineStandardAppVersionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\">\n.AppEngineStandardAppVersionXVpcAccessConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe0\t\n\x1b\x41ppEngineStandardAppVersion\x12!\n\x19\x64\x65lete_service_on_destroy\x18\x01 \x01(\x08\x12Y\n\renv_variables\x18\x02 \x03(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineStandardAppVersion.EnvVariablesEntry\x12\n\n\x02id\x18\x03 \x01(\t\x12\x18\n\x10inbound_services\x18\x04 \x03(\t\x12\x16\n\x0einstance_class\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x17\n\x0fnoop_on_destroy\x18\x07 \x01(\x08\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0f\n\x07runtime\x18\t \x01(\t\x12\x1b\n\x13runtime_api_version\x18\n \x01(\t\x12\x0f\n\x07service\x18\x0b \x01(\t\x12\x12\n\nthreadsafe\x18\x0c \x01(\x08\x12\x12\n\nversion_id\x18\r \x01(\t\x12\\\n\x11\x61utomatic_scaling\x18\x0e \x01(\x0b\x32\x41.oak9.tython.gcp.app.AppEngineStandardAppVersionXAutomaticScaling\x12T\n\rbasic_scaling\x18\x0f \x01(\x0b\x32=.oak9.tython.gcp.app.AppEngineStandardAppVersionXBasicScaling\x12O\n\ndeployment\x18\x10 \x01(\x0b\x32;.oak9.tython.gcp.app.AppEngineStandardAppVersionXDeployment\x12O\n\nentrypoint\x18\x11 \x01(\x0b\x32;.oak9.tython.gcp.app.AppEngineStandardAppVersionXEntrypoint\x12K\n\x08handlers\x18\x12 \x03(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineStandardAppVersionXHandlers\x12M\n\tlibraries\x18\x13 \x03(\x0b\x32:.oak9.tython.gcp.app.AppEngineStandardAppVersionXLibraries\x12V\n\x0emanual_scaling\x18\x14 \x01(\x0b\x32>.oak9.tython.gcp.app.AppEngineStandardAppVersionXManualScaling\x12K\n\x08timeouts\x18\x15 \x01(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineStandardAppVersionXTimeouts\x12\x61\n\x14vpc_access_connector\x18\x16 \x01(\x0b\x32\x43.oak9.tython.gcp.app.AppEngineStandardAppVersionXVpcAccessConnector\x12\x37\n\rresource_info\x18\x17 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11\x45nvVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_app_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPENGINEAPPLICATION_URLDISPATCHRULEENTRY._options = None
  _APPENGINEAPPLICATION_URLDISPATCHRULEENTRY._serialized_options = b'8\001'
  _APPENGINEDOMAINMAPPING_RESOURCERECORDSENTRY._options = None
  _APPENGINEDOMAINMAPPING_RESOURCERECORDSENTRY._serialized_options = b'8\001'
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._options = None
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_options = b'8\001'
  _APPENGINEFLEXIBLEAPPVERSION_BETASETTINGSENTRY._options = None
  _APPENGINEFLEXIBLEAPPVERSION_BETASETTINGSENTRY._serialized_options = b'8\001'
  _APPENGINEFLEXIBLEAPPVERSION_ENVVARIABLESENTRY._options = None
  _APPENGINEFLEXIBLEAPPVERSION_ENVVARIABLESENTRY._serialized_options = b'8\001'
  _APPENGINESERVICESPLITTRAFFICXSPLIT_ALLOCATIONSENTRY._options = None
  _APPENGINESERVICESPLITTRAFFICXSPLIT_ALLOCATIONSENTRY._serialized_options = b'8\001'
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._options = None
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_options = b'8\001'
  _APPENGINESTANDARDAPPVERSION_ENVVARIABLESENTRY._options = None
  _APPENGINESTANDARDAPPVERSION_ENVVARIABLESENTRY._serialized_options = b'8\001'
  _APPENGINEAPPLICATIONXFEATURESETTINGS._serialized_start=63
  _APPENGINEAPPLICATIONXFEATURESETTINGS._serialized_end=130
  _APPENGINEAPPLICATIONXIAP._serialized_start=133
  _APPENGINEAPPLICATIONXIAP._serialized_end=269
  _APPENGINEAPPLICATIONXTIMEOUTS._serialized_start=271
  _APPENGINEAPPLICATIONXTIMEOUTS._serialized_end=334
  _APPENGINEAPPLICATION._serialized_start=337
  _APPENGINEAPPLICATION._serialized_end=1017
  _APPENGINEAPPLICATION_URLDISPATCHRULEENTRY._serialized_start=963
  _APPENGINEAPPLICATION_URLDISPATCHRULEENTRY._serialized_end=1017
  _APPENGINEAPPLICATIONURLDISPATCHRULESXDISPATCHRULES._serialized_start=1019
  _APPENGINEAPPLICATIONURLDISPATCHRULESXDISPATCHRULES._serialized_end=1118
  _APPENGINEAPPLICATIONURLDISPATCHRULESXTIMEOUTS._serialized_start=1120
  _APPENGINEAPPLICATIONURLDISPATCHRULESXTIMEOUTS._serialized_end=1215
  _APPENGINEAPPLICATIONURLDISPATCHRULES._serialized_start=1218
  _APPENGINEAPPLICATIONURLDISPATCHRULES._serialized_end=1525
  _APPENGINEDOMAINMAPPINGXSSLSETTINGS._serialized_start=1528
  _APPENGINEDOMAINMAPPINGXSSLSETTINGS._serialized_end=1657
  _APPENGINEDOMAINMAPPINGXTIMEOUTS._serialized_start=1659
  _APPENGINEDOMAINMAPPINGXTIMEOUTS._serialized_end=1740
  _APPENGINEDOMAINMAPPING._serialized_start=1743
  _APPENGINEDOMAINMAPPING._serialized_end=2214
  _APPENGINEDOMAINMAPPING_RESOURCERECORDSENTRY._serialized_start=2160
  _APPENGINEDOMAINMAPPING_RESOURCERECORDSENTRY._serialized_end=2214
  _APPENGINEFIREWALLRULEXTIMEOUTS._serialized_start=2216
  _APPENGINEFIREWALLRULEXTIMEOUTS._serialized_end=2296
  _APPENGINEFIREWALLRULE._serialized_start=2299
  _APPENGINEFIREWALLRULE._serialized_end=2556
  _APPENGINEFLEXIBLEAPPVERSIONXAPICONFIG._serialized_start=2559
  _APPENGINEFLEXIBLEAPPVERSIONXAPICONFIG._serialized_end=2692
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXCPUUTILIZATION._serialized_start=2694
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXCPUUTILIZATION._serialized_end=2818
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXDISKUTILIZATION._serialized_start=2821
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXDISKUTILIZATION._serialized_end=3033
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXNETWORKUTILIZATION._serialized_start=3036
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXNETWORKUTILIZATION._serialized_end=3265
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXREQUESTUTILIZATION._serialized_start=3268
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXREQUESTUTILIZATION._serialized_end=3410
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALING._serialized_start=3413
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALING._serialized_end=4136
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXCLOUDBUILDOPTIONS._serialized_start=4138
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXCLOUDBUILDOPTIONS._serialized_end=4248
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXCONTAINER._serialized_start=4250
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXCONTAINER._serialized_end=4315
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXFILES._serialized_start=4317
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXFILES._serialized_end=4415
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXZIP._serialized_start=4417
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXZIP._serialized_end=4502
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENT._serialized_start=4505
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENT._serialized_end=4903
  _APPENGINEFLEXIBLEAPPVERSIONXENDPOINTSAPISERVICE._serialized_start=4906
  _APPENGINEFLEXIBLEAPPVERSIONXENDPOINTSAPISERVICE._serialized_end=5046
  _APPENGINEFLEXIBLEAPPVERSIONXENTRYPOINT._serialized_start=5048
  _APPENGINEFLEXIBLEAPPVERSIONXENTRYPOINT._serialized_end=5103
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSCRIPT._serialized_start=5105
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSCRIPT._serialized_end=5171
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES._serialized_start=5174
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES._serialized_end=5527
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_start=5477
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_end=5527
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERS._serialized_start=5530
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERS._serialized_end=5864
  _APPENGINEFLEXIBLEAPPVERSIONXLIVENESSCHECK._serialized_start=5867
  _APPENGINEFLEXIBLEAPPVERSIONXLIVENESSCHECK._serialized_end=6056
  _APPENGINEFLEXIBLEAPPVERSIONXMANUALSCALING._serialized_start=6058
  _APPENGINEFLEXIBLEAPPVERSIONXMANUALSCALING._serialized_end=6120
  _APPENGINEFLEXIBLEAPPVERSIONXNETWORK._serialized_start=6123
  _APPENGINEFLEXIBLEAPPVERSIONXNETWORK._serialized_end=6267
  _APPENGINEFLEXIBLEAPPVERSIONXREADINESSCHECK._serialized_start=6270
  _APPENGINEFLEXIBLEAPPVERSIONXREADINESSCHECK._serialized_end=6464
  _APPENGINEFLEXIBLEAPPVERSIONXRESOURCESXVOLUMES._serialized_start=6466
  _APPENGINEFLEXIBLEAPPVERSIONXRESOURCESXVOLUMES._serialized_end=6565
  _APPENGINEFLEXIBLEAPPVERSIONXRESOURCES._serialized_start=6568
  _APPENGINEFLEXIBLEAPPVERSIONXRESOURCES._serialized_end=6741
  _APPENGINEFLEXIBLEAPPVERSIONXTIMEOUTS._serialized_start=6743
  _APPENGINEFLEXIBLEAPPVERSIONXTIMEOUTS._serialized_end=6829
  _APPENGINEFLEXIBLEAPPVERSIONXVPCACCESSCONNECTOR._serialized_start=6831
  _APPENGINEFLEXIBLEAPPVERSIONXVPCACCESSCONNECTOR._serialized_end=6893
  _APPENGINEFLEXIBLEAPPVERSION._serialized_start=6896
  _APPENGINEFLEXIBLEAPPVERSION._serialized_end=8760
  _APPENGINEFLEXIBLEAPPVERSION_BETASETTINGSENTRY._serialized_start=8656
  _APPENGINEFLEXIBLEAPPVERSION_BETASETTINGSENTRY._serialized_end=8707
  _APPENGINEFLEXIBLEAPPVERSION_ENVVARIABLESENTRY._serialized_start=8709
  _APPENGINEFLEXIBLEAPPVERSION_ENVVARIABLESENTRY._serialized_end=8760
  _APPENGINESERVICENETWORKSETTINGSXNETWORKSETTINGS._serialized_start=8762
  _APPENGINESERVICENETWORKSETTINGSXNETWORKSETTINGS._serialized_end=8844
  _APPENGINESERVICENETWORKSETTINGSXTIMEOUTS._serialized_start=8846
  _APPENGINESERVICENETWORKSETTINGSXTIMEOUTS._serialized_end=8936
  _APPENGINESERVICENETWORKSETTINGS._serialized_start=8939
  _APPENGINESERVICENETWORKSETTINGS._serialized_end=9252
  _APPENGINESERVICESPLITTRAFFICXSPLIT._serialized_start=9255
  _APPENGINESERVICESPLITTRAFFICXSPLIT._serialized_end=9456
  _APPENGINESERVICESPLITTRAFFICXSPLIT_ALLOCATIONSENTRY._serialized_start=9406
  _APPENGINESERVICESPLITTRAFFICXSPLIT_ALLOCATIONSENTRY._serialized_end=9456
  _APPENGINESERVICESPLITTRAFFICXTIMEOUTS._serialized_start=9458
  _APPENGINESERVICESPLITTRAFFICXTIMEOUTS._serialized_end=9545
  _APPENGINESERVICESPLITTRAFFIC._serialized_start=9548
  _APPENGINESERVICESPLITTRAFFIC._serialized_end=9856
  _APPENGINESTANDARDAPPVERSIONXAUTOMATICSCALINGXSTANDARDSCHEDULERSETTINGS._serialized_start=9859
  _APPENGINESTANDARDAPPVERSIONXAUTOMATICSCALINGXSTANDARDSCHEDULERSETTINGS._serialized_end=10048
  _APPENGINESTANDARDAPPVERSIONXAUTOMATICSCALING._serialized_start=10051
  _APPENGINESTANDARDAPPVERSIONXAUTOMATICSCALING._serialized_end=10375
  _APPENGINESTANDARDAPPVERSIONXBASICSCALING._serialized_start=10377
  _APPENGINESTANDARDAPPVERSIONXBASICSCALING._serialized_end=10464
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENTXFILES._serialized_start=10466
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENTXFILES._serialized_end=10564
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENTXZIP._serialized_start=10566
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENTXZIP._serialized_end=10651
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENT._serialized_start=10654
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENT._serialized_end=10854
  _APPENGINESTANDARDAPPVERSIONXENTRYPOINT._serialized_start=10856
  _APPENGINESTANDARDAPPVERSIONXENTRYPOINT._serialized_end=10911
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSCRIPT._serialized_start=10913
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSCRIPT._serialized_end=10979
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES._serialized_start=10982
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES._serialized_end=11335
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_start=5477
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_end=5527
  _APPENGINESTANDARDAPPVERSIONXHANDLERS._serialized_start=11338
  _APPENGINESTANDARDAPPVERSIONXHANDLERS._serialized_end=11672
  _APPENGINESTANDARDAPPVERSIONXLIBRARIES._serialized_start=11674
  _APPENGINESTANDARDAPPVERSIONXLIBRARIES._serialized_end=11744
  _APPENGINESTANDARDAPPVERSIONXMANUALSCALING._serialized_start=11746
  _APPENGINESTANDARDAPPVERSIONXMANUALSCALING._serialized_end=11808
  _APPENGINESTANDARDAPPVERSIONXTIMEOUTS._serialized_start=11810
  _APPENGINESTANDARDAPPVERSIONXTIMEOUTS._serialized_end=11896
  _APPENGINESTANDARDAPPVERSIONXVPCACCESSCONNECTOR._serialized_start=11898
  _APPENGINESTANDARDAPPVERSIONXVPCACCESSCONNECTOR._serialized_end=11960
  _APPENGINESTANDARDAPPVERSION._serialized_start=11963
  _APPENGINESTANDARDAPPVERSION._serialized_end=13211
  _APPENGINESTANDARDAPPVERSION_ENVVARIABLESENTRY._serialized_start=8709
  _APPENGINESTANDARDAPPVERSION_ENVVARIABLESENTRY._serialized_end=8760
# @@protoc_insertion_point(module_scope)
