# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_recoveryservices_siterecovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9azure/azure_microsoft_recoveryservices_siterecovery.proto\x12\x39oak9.tython.azure.microsoft_recoveryservices_siterecovery\x1a\x13shared/shared.proto\"\xaf\n\n\'Microsoft_RecoveryServices_SiteRecovery\x12\x84\x01\n!vaults_replication_alert_settings\x18\x01 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationAlertSettings\x12w\n\x1avaults_replication_fabrics\x18\x02 \x03(\x0b\x32S.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabrics\x12\xd7\x01\nLvaults_replication_fabrics_replication_networks_replication_network_mappings\x18\x03 \x03(\x0b\x32\x80\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings\x12\x91\x02\njvaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings\x18\x04 \x03(\x0b\x32\x9c\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings\x12y\n\x1bvaults_replication_policies\x18\x05 \x03(\x0b\x32T.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationPolicies\x12\x8c\x01\n%vaults_replication_protection_intents\x18\x06 \x03(\x0b\x32].oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationProtectionIntents\x12\x84\x01\n!vaults_replication_recovery_plans\x18\x07 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationRecoveryPlans\x12\x84\x01\n!vaults_replication_vault_settings\x18\x08 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationVaultSettings\"\xad\x01\n\x1eVaultsReplicationVaultSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15migration_solution_id\x18\x03 \x01(\t\x12%\n\x1dvmware_to_azure_provider_type\x18\x04 \x01(\t\"\x9e\x03\n\x1eVaultsReplicationRecoveryPlans\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12!\n\x19\x66\x61ilover_deployment_model\x18\x03 \x01(\t\x12\\\n\x06groups\x18\x04 \x03(\x0b\x32L.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanGroup\x12\x19\n\x11primary_fabric_id\x18\x05 \x01(\t\x12}\n\x17provider_specific_input\x18\x06 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanProviderSpecificInput\x12\x1a\n\x12recovery_fabric_id\x18\x07 \x01(\t\"1\n!RecoveryPlanProviderSpecificInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf8\x02\n\x11RecoveryPlanGroup\x12h\n\x11\x65nd_group_actions\x18\x01 \x03(\x0b\x32M.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanAction\x12\x12\n\ngroup_type\x18\x02 \x01(\t\x12y\n\x1breplication_protected_items\x18\x03 \x03(\x0b\x32T.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanProtectedItem\x12j\n\x13start_group_actions\x18\x04 \x03(\x0b\x32M.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanAction\"C\n\x19RecoveryPlanProtectedItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1a\n\x12virtual_machine_id\x18\x02 \x01(\t\"\xcc\x01\n\x12RecoveryPlanAction\x12\x13\n\x0b\x61\x63tion_name\x18\x01 \x01(\t\x12l\n\x0e\x63ustom_details\x18\x02 \x01(\x0b\x32T.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanActionDetails\x12\x1b\n\x13\x66\x61ilover_directions\x18\x03 \x03(\t\x12\x16\n\x0e\x66\x61ilover_types\x18\x04 \x03(\t\")\n\x19RecoveryPlanActionDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf9\x01\n\"VaultsReplicationProtectionIntents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x8b\x01\n\x19provider_specific_details\x18\x03 \x01(\x0b\x32h.oak9.tython.azure.microsoft_recoveryservices_siterecovery.CreateProtectionIntentProviderSpecificDetails\"=\n-CreateProtectionIntentProviderSpecificDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xdb\x01\n\x19VaultsReplicationPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12w\n\x17provider_specific_input\x18\x03 \x01(\x0b\x32V.oak9.tython.azure.microsoft_recoveryservices_siterecovery.PolicyProviderSpecificInput\"+\n\x1bPolicyProviderSpecificInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe3\x01\n+VaultsReplicationFabricsReplicationvCenters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rfriendly_name\x18\x03 \x01(\t\x12\x12\n\nip_address\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\t\x12\x19\n\x11process_server_id\x18\x06 \x01(\t\x12\x19\n\x11run_as_account_id\x18\x07 \x01(\t\"\xd4\x01\naVaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n target_storage_classification_id\x18\x03 \x01(\t\"\xb8\x04\n<VaultsReplicationFabricsReplicationRecoveryServicesProviders\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12w\n\x1d\x61uthentication_identity_input\x18\x03 \x01(\x0b\x32P.oak9.tython.azure.microsoft_recoveryservices_siterecovery.IdentityProviderInput\x12\x0f\n\x07\x62ios_id\x18\x04 \x01(\t\x12\x82\x01\n(data_plane_authentication_identity_input\x18\x05 \x01(\x0b\x32P.oak9.tython.azure.microsoft_recoveryservices_siterecovery.IdentityProviderInput\x12\x12\n\nmachine_id\x18\x06 \x01(\t\x12\x14\n\x0cmachine_name\x18\x07 \x01(\t\x12x\n\x1eresource_access_identity_input\x18\x08 \x01(\x0b\x32P.oak9.tython.azure.microsoft_recoveryservices_siterecovery.IdentityProviderInput\"~\n\x15IdentityProviderInput\x12\x15\n\raad_authority\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x01(\t\x12\x11\n\tobject_id\x18\x04 \x01(\t\x12\x11\n\ttenant_id\x18\x05 \x01(\t\"\xf0\x02\n]VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12\x8c\x01\n\x17provider_specific_input\x18\x04 \x01(\x0b\x32k.oak9.tython.azure.microsoft_recoveryservices_siterecovery.ReplicationProviderSpecificContainerMappingInput\x12&\n\x1etarget_protection_container_id\x18\x05 \x01(\t\"@\n0ReplicationProviderSpecificContainerMappingInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xcf\x02\nPVaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12\x1b\n\x13protectable_item_id\x18\x04 \x01(\t\x12\x83\x01\n\x19provider_specific_details\x18\x05 \x01(\x0b\x32`.oak9.tython.azure.microsoft_recoveryservices_siterecovery.EnableProtectionProviderSpecificInput\"5\n%EnableProtectionProviderSpecificInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb1\x02\nPVaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12\x82\x01\n\x19provider_specific_details\x18\x04 \x01(\x0b\x32_.oak9.tython.azure.microsoft_recoveryservices_siterecovery.EnableMigrationProviderSpecificInput\"4\n$EnableMigrationProviderSpecificInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xfe\x07\n7VaultsReplicationFabricsReplicationProtectionContainers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x8d\x01\n\x17provider_specific_input\x18\x03 \x03(\x0b\x32l.oak9.tython.azure.microsoft_recoveryservices_siterecovery.ReplicationProviderSpecificContainerCreationInput\x12\xee\x01\nXvaults_replication_fabrics_replication_protection_containers_replication_migration_items\x18\x04 \x03(\x0b\x32\x8b\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems\x12\xee\x01\nXvaults_replication_fabrics_replication_protection_containers_replication_protected_items\x18\x05 \x03(\x0b\x32\x8b\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems\x12\x89\x02\nfvaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings\x18\x06 \x03(\x0b\x32\x98\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings\"A\n1ReplicationProviderSpecificContainerCreationInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xcf\x02\nEVaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x83\x01\n\x17\x66\x61\x62ric_specific_details\x18\x03 \x01(\x0b\x32\x62.oak9.tython.azure.microsoft_recoveryservices_siterecovery.FabricSpecificCreateNetworkMappingInput\x12\x1c\n\x14recovery_fabric_name\x18\x04 \x01(\t\x12\x1b\n\x13recovery_network_id\x18\x05 \x01(\t\"7\n\'FabricSpecificCreateNetworkMappingInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf4\x05\n\x18VaultsReplicationFabrics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12n\n\x0e\x63ustom_details\x18\x03 \x01(\x0b\x32V.oak9.tython.azure.microsoft_recoveryservices_siterecovery.FabricSpecificCreationInput\x12\xb8\x01\n<vaults_replication_fabrics_replication_protection_containers\x18\x04 \x03(\x0b\x32r.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationProtectionContainers\x12\xc3\x01\nBvaults_replication_fabrics_replication_recovery_services_providers\x18\x05 \x03(\x0b\x32w.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationRecoveryServicesProviders\x12\x9f\x01\n/vaults_replication_fabrics_replicationv_centers\x18\x06 \x03(\x0b\x32\x66.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationvCenters\"+\n\x1b\x46\x61\x62ricSpecificCreationInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xaf\x01\n\x1eVaultsReplicationAlertSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16\x63ustom_email_addresses\x18\x03 \x03(\t\x12\x0e\n\x06locale\x18\x04 \x01(\t\x12\x16\n\x0esend_to_owners\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_recoveryservices_siterecovery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MICROSOFT_RECOVERYSERVICES_SITERECOVERY._serialized_start=142
  _MICROSOFT_RECOVERYSERVICES_SITERECOVERY._serialized_end=1469
  _VAULTSREPLICATIONVAULTSETTINGS._serialized_start=1472
  _VAULTSREPLICATIONVAULTSETTINGS._serialized_end=1645
  _VAULTSREPLICATIONRECOVERYPLANS._serialized_start=1648
  _VAULTSREPLICATIONRECOVERYPLANS._serialized_end=2062
  _RECOVERYPLANPROVIDERSPECIFICINPUT._serialized_start=2064
  _RECOVERYPLANPROVIDERSPECIFICINPUT._serialized_end=2113
  _RECOVERYPLANGROUP._serialized_start=2116
  _RECOVERYPLANGROUP._serialized_end=2492
  _RECOVERYPLANPROTECTEDITEM._serialized_start=2494
  _RECOVERYPLANPROTECTEDITEM._serialized_end=2561
  _RECOVERYPLANACTION._serialized_start=2564
  _RECOVERYPLANACTION._serialized_end=2768
  _RECOVERYPLANACTIONDETAILS._serialized_start=2770
  _RECOVERYPLANACTIONDETAILS._serialized_end=2811
  _VAULTSREPLICATIONPROTECTIONINTENTS._serialized_start=2814
  _VAULTSREPLICATIONPROTECTIONINTENTS._serialized_end=3063
  _CREATEPROTECTIONINTENTPROVIDERSPECIFICDETAILS._serialized_start=3065
  _CREATEPROTECTIONINTENTPROVIDERSPECIFICDETAILS._serialized_end=3126
  _VAULTSREPLICATIONPOLICIES._serialized_start=3129
  _VAULTSREPLICATIONPOLICIES._serialized_end=3348
  _POLICYPROVIDERSPECIFICINPUT._serialized_start=3350
  _POLICYPROVIDERSPECIFICINPUT._serialized_end=3393
  _VAULTSREPLICATIONFABRICSREPLICATIONVCENTERS._serialized_start=3396
  _VAULTSREPLICATIONFABRICSREPLICATIONVCENTERS._serialized_end=3623
  _VAULTSREPLICATIONFABRICSREPLICATIONSTORAGECLASSIFICATIONSREPLICATIONSTORAGECLASSIFICATIONMAPPINGS._serialized_start=3626
  _VAULTSREPLICATIONFABRICSREPLICATIONSTORAGECLASSIFICATIONSREPLICATIONSTORAGECLASSIFICATIONMAPPINGS._serialized_end=3838
  _VAULTSREPLICATIONFABRICSREPLICATIONRECOVERYSERVICESPROVIDERS._serialized_start=3841
  _VAULTSREPLICATIONFABRICSREPLICATIONRECOVERYSERVICESPROVIDERS._serialized_end=4409
  _IDENTITYPROVIDERINPUT._serialized_start=4411
  _IDENTITYPROVIDERINPUT._serialized_end=4537
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONPROTECTIONCONTAINERMAPPINGS._serialized_start=4540
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONPROTECTIONCONTAINERMAPPINGS._serialized_end=4908
  _REPLICATIONPROVIDERSPECIFICCONTAINERMAPPINGINPUT._serialized_start=4910
  _REPLICATIONPROVIDERSPECIFICCONTAINERMAPPINGINPUT._serialized_end=4974
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONPROTECTEDITEMS._serialized_start=4977
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONPROTECTEDITEMS._serialized_end=5312
  _ENABLEPROTECTIONPROVIDERSPECIFICINPUT._serialized_start=5314
  _ENABLEPROTECTIONPROVIDERSPECIFICINPUT._serialized_end=5367
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONMIGRATIONITEMS._serialized_start=5370
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONMIGRATIONITEMS._serialized_end=5675
  _ENABLEMIGRATIONPROVIDERSPECIFICINPUT._serialized_start=5677
  _ENABLEMIGRATIONPROVIDERSPECIFICINPUT._serialized_end=5729
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERS._serialized_start=5732
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERS._serialized_end=6754
  _REPLICATIONPROVIDERSPECIFICCONTAINERCREATIONINPUT._serialized_start=6756
  _REPLICATIONPROVIDERSPECIFICCONTAINERCREATIONINPUT._serialized_end=6821
  _VAULTSREPLICATIONFABRICSREPLICATIONNETWORKSREPLICATIONNETWORKMAPPINGS._serialized_start=6824
  _VAULTSREPLICATIONFABRICSREPLICATIONNETWORKSREPLICATIONNETWORKMAPPINGS._serialized_end=7159
  _FABRICSPECIFICCREATENETWORKMAPPINGINPUT._serialized_start=7161
  _FABRICSPECIFICCREATENETWORKMAPPINGINPUT._serialized_end=7216
  _VAULTSREPLICATIONFABRICS._serialized_start=7219
  _VAULTSREPLICATIONFABRICS._serialized_end=7975
  _FABRICSPECIFICCREATIONINPUT._serialized_start=7977
  _FABRICSPECIFICCREATIONINPUT._serialized_end=8020
  _VAULTSREPLICATIONALERTSETTINGS._serialized_start=8023
  _VAULTSREPLICATIONALERTSETTINGS._serialized_end=8198
# @@protoc_insertion_point(module_scope)
