# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.certificates.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6kubernetes/kubernetes_io.k8s.api.certificates.v1.proto\x12#oak9.tython.k8s.api.certificates.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xec\x02\n\x19\x43\x65rtificateSigningRequest\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12P\n\x04spec\x18\x04 \x01(\x0b\x32\x42.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequestSpec\x12T\n\x06status\x18\x05 \x01(\x0b\x32\x44.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequestStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbe\x02\n\"CertificateSigningRequestCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12M\n\x10last_update_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x02\n\x1d\x43\x65rtificateSigningRequestList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12M\n\x05items\x18\x02 \x03(\x0b\x32>.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequest\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe5\x02\n\x1d\x43\x65rtificateSigningRequestSpec\x12\x1a\n\x12\x65xpiration_seconds\x18\x01 \x01(\x05\x12\\\n\x05\x65xtra\x18\x02 \x03(\x0b\x32M.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequestSpec.ExtraEntry\x12\x0e\n\x06groups\x18\x03 \x03(\t\x12\x0f\n\x07request\x18\x04 \x01(\t\x12\x13\n\x0bsigner_name\x18\x05 \x01(\t\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x0e\n\x06usages\x18\x07 \x03(\t\x12\x10\n\x08username\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x01\n\x1f\x43\x65rtificateSigningRequestStatus\x12\x13\n\x0b\x63\x65rtificate\x18\x01 \x01(\t\x12[\n\nconditions\x18\x02 \x03(\x0b\x32G.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequestCondition\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.certificates.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CERTIFICATESIGNINGREQUESTSPEC_EXTRAENTRY._options = None
  _CERTIFICATESIGNINGREQUESTSPEC_EXTRAENTRY._serialized_options = b'8\001'
  _CERTIFICATESIGNINGREQUEST._serialized_start=183
  _CERTIFICATESIGNINGREQUEST._serialized_end=547
  _CERTIFICATESIGNINGREQUESTCONDITION._serialized_start=550
  _CERTIFICATESIGNINGREQUESTCONDITION._serialized_end=868
  _CERTIFICATESIGNINGREQUESTLIST._serialized_start=871
  _CERTIFICATESIGNINGREQUESTLIST._serialized_end=1148
  _CERTIFICATESIGNINGREQUESTSPEC._serialized_start=1151
  _CERTIFICATESIGNINGREQUESTSPEC._serialized_end=1508
  _CERTIFICATESIGNINGREQUESTSPEC_EXTRAENTRY._serialized_start=1464
  _CERTIFICATESIGNINGREQUESTSPEC_EXTRAENTRY._serialized_end=1508
  _CERTIFICATESIGNINGREQUESTSTATUS._serialized_start=1511
  _CERTIFICATESIGNINGREQUESTSTATUS._serialized_end=1715
# @@protoc_insertion_point(module_scope)
