"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_applicationGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_GATEWAYS_FIELD_NUMBER: builtins.int
    APPLICATION_GATEWAY_WEB_APPLICATION_FIREWALL_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def application_gateways(self) -> global___ApplicationGateways: ...
    @property
    def application_gateway_web_application_firewall_policies(self) -> global___ApplicationGatewayWebApplicationFirewallPolicies: ...
    def __init__(
        self,
        *,
        application_gateways: global___ApplicationGateways | None = ...,
        application_gateway_web_application_firewall_policies: global___ApplicationGatewayWebApplicationFirewallPolicies | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application_gateway_web_application_firewall_policies", b"application_gateway_web_application_firewall_policies", "application_gateways", b"application_gateways"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_gateway_web_application_firewall_policies", b"application_gateway_web_application_firewall_policies", "application_gateways", b"application_gateways"]) -> None: ...

global___Microsoft_Network_applicationGateways = Microsoft_Network_applicationGateways

@typing_extensions.final
class HttpListener(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___HttpListener = HttpListener

@typing_extensions.final
class BackendHttpSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___BackendHttpSettings = BackendHttpSettings

@typing_extensions.final
class BackendAddressPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___BackendAddressPool = BackendAddressPool

@typing_extensions.final
class FrontendPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___FrontendPort = FrontendPort

@typing_extensions.final
class FrontendIPConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___FrontendIPConfiguration = FrontendIPConfiguration

@typing_extensions.final
class Subnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___Subnet = Subnet

@typing_extensions.final
class PublicIpAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PublicIpAddress = PublicIpAddress

@typing_extensions.final
class ApplicationGatewaysPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationGatewaysPrivateEndpointConnections = ApplicationGatewaysPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    status: builtins.str
    description: builtins.str
    actions_required: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        description: builtins.str = ...,
        actions_required: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class ApplicationGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    SSL_POLICY_FIELD_NUMBER: builtins.int
    GATEWAY_IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CERTIFICATES_FIELD_NUMBER: builtins.int
    TRUSTED_ROOT_CERTIFICATES_FIELD_NUMBER: builtins.int
    TRUSTED_CLIENT_CERTIFICATES_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATES_FIELD_NUMBER: builtins.int
    FRONTEND_IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    FRONTEND_PORTS_FIELD_NUMBER: builtins.int
    PROBES_FIELD_NUMBER: builtins.int
    BACKEND_ADDRESS_POOLS_FIELD_NUMBER: builtins.int
    BACKEND_HTTP_SETTINGS_COLLECTION_FIELD_NUMBER: builtins.int
    HTTP_LISTENERS_FIELD_NUMBER: builtins.int
    SSL_PROFILES_FIELD_NUMBER: builtins.int
    URL_PATH_MAPS_FIELD_NUMBER: builtins.int
    REQUEST_ROUTING_RULES_FIELD_NUMBER: builtins.int
    REWRITE_RULE_SETS_FIELD_NUMBER: builtins.int
    REDIRECT_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    WEB_APPLICATION_FIREWALL_CONFIGURATION_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    ENABLE_HTTP2_FIELD_NUMBER: builtins.int
    ENABLE_FIPS_FIELD_NUMBER: builtins.int
    AUTOSCALE_CONFIGURATION_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    CUSTOM_ERROR_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    FORCE_FIREWALL_POLICY_ASSOCIATION_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    APPLICATION_GATEWAYS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sku(self) -> global___ApplicationGatewaySku: ...
    @property
    def ssl_policy(self) -> global___ApplicationGatewaySslPolicy: ...
    @property
    def gateway_ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayIPConfiguration]: ...
    @property
    def authentication_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayAuthenticationCertificate]: ...
    @property
    def trusted_root_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayTrustedRootCertificate]: ...
    @property
    def trusted_client_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayTrustedClientCertificate]: ...
    @property
    def ssl_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewaySslCertificate]: ...
    @property
    def frontend_ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayFrontendIPConfiguration]: ...
    @property
    def frontend_ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayFrontendPort]: ...
    @property
    def probes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayProbe]: ...
    @property
    def backend_address_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayBackendAddressPool]: ...
    @property
    def backend_http_settings_collection(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayBackendHttpSettings]: ...
    @property
    def http_listeners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayHttpListener]: ...
    @property
    def ssl_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewaySslProfile]: ...
    @property
    def url_path_maps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayUrlPathMap]: ...
    @property
    def request_routing_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRequestRoutingRule]: ...
    @property
    def rewrite_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRewriteRuleSet]: ...
    @property
    def redirect_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRedirectConfiguration]: ...
    @property
    def web_application_firewall_configuration(self) -> global___ApplicationGatewayWebApplicationFirewallConfiguration: ...
    firewall_policy: builtins.str
    enable_http2: builtins.bool
    enable_fips: builtins.bool
    @property
    def autoscale_configuration(self) -> global___ApplicationGatewayAutoscaleConfiguration: ...
    @property
    def private_link_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayPrivateLinkConfiguration]: ...
    @property
    def custom_error_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayCustomError]: ...
    force_firewall_policy_association: builtins.bool
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    @property
    def application_gateways_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewaysPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sku: global___ApplicationGatewaySku | None = ...,
        ssl_policy: global___ApplicationGatewaySslPolicy | None = ...,
        gateway_ip_configurations: collections.abc.Iterable[global___ApplicationGatewayIPConfiguration] | None = ...,
        authentication_certificates: collections.abc.Iterable[global___ApplicationGatewayAuthenticationCertificate] | None = ...,
        trusted_root_certificates: collections.abc.Iterable[global___ApplicationGatewayTrustedRootCertificate] | None = ...,
        trusted_client_certificates: collections.abc.Iterable[global___ApplicationGatewayTrustedClientCertificate] | None = ...,
        ssl_certificates: collections.abc.Iterable[global___ApplicationGatewaySslCertificate] | None = ...,
        frontend_ip_configurations: collections.abc.Iterable[global___ApplicationGatewayFrontendIPConfiguration] | None = ...,
        frontend_ports: collections.abc.Iterable[global___ApplicationGatewayFrontendPort] | None = ...,
        probes: collections.abc.Iterable[global___ApplicationGatewayProbe] | None = ...,
        backend_address_pools: collections.abc.Iterable[global___ApplicationGatewayBackendAddressPool] | None = ...,
        backend_http_settings_collection: collections.abc.Iterable[global___ApplicationGatewayBackendHttpSettings] | None = ...,
        http_listeners: collections.abc.Iterable[global___ApplicationGatewayHttpListener] | None = ...,
        ssl_profiles: collections.abc.Iterable[global___ApplicationGatewaySslProfile] | None = ...,
        url_path_maps: collections.abc.Iterable[global___ApplicationGatewayUrlPathMap] | None = ...,
        request_routing_rules: collections.abc.Iterable[global___ApplicationGatewayRequestRoutingRule] | None = ...,
        rewrite_rule_sets: collections.abc.Iterable[global___ApplicationGatewayRewriteRuleSet] | None = ...,
        redirect_configurations: collections.abc.Iterable[global___ApplicationGatewayRedirectConfiguration] | None = ...,
        web_application_firewall_configuration: global___ApplicationGatewayWebApplicationFirewallConfiguration | None = ...,
        firewall_policy: builtins.str = ...,
        enable_http2: builtins.bool = ...,
        enable_fips: builtins.bool = ...,
        autoscale_configuration: global___ApplicationGatewayAutoscaleConfiguration | None = ...,
        private_link_configurations: collections.abc.Iterable[global___ApplicationGatewayPrivateLinkConfiguration] | None = ...,
        custom_error_configurations: collections.abc.Iterable[global___ApplicationGatewayCustomError] | None = ...,
        force_firewall_policy_association: builtins.bool = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        application_gateways_private_endpoint_connections: collections.abc.Iterable[global___ApplicationGatewaysPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscale_configuration", b"autoscale_configuration", "identity", b"identity", "resource_info", b"resource_info", "sku", b"sku", "ssl_policy", b"ssl_policy", "web_application_firewall_configuration", b"web_application_firewall_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_gateways_private_endpoint_connections", b"application_gateways_private_endpoint_connections", "authentication_certificates", b"authentication_certificates", "autoscale_configuration", b"autoscale_configuration", "backend_address_pools", b"backend_address_pools", "backend_http_settings_collection", b"backend_http_settings_collection", "custom_error_configurations", b"custom_error_configurations", "enable_fips", b"enable_fips", "enable_http2", b"enable_http2", "firewall_policy", b"firewall_policy", "force_firewall_policy_association", b"force_firewall_policy_association", "frontend_ip_configurations", b"frontend_ip_configurations", "frontend_ports", b"frontend_ports", "gateway_ip_configurations", b"gateway_ip_configurations", "http_listeners", b"http_listeners", "identity", b"identity", "location", b"location", "name", b"name", "private_link_configurations", b"private_link_configurations", "probes", b"probes", "redirect_configurations", b"redirect_configurations", "request_routing_rules", b"request_routing_rules", "resource_info", b"resource_info", "rewrite_rule_sets", b"rewrite_rule_sets", "sku", b"sku", "ssl_certificates", b"ssl_certificates", "ssl_policy", b"ssl_policy", "ssl_profiles", b"ssl_profiles", "tags", b"tags", "trusted_client_certificates", b"trusted_client_certificates", "trusted_root_certificates", b"trusted_root_certificates", "url_path_maps", b"url_path_maps", "web_application_firewall_configuration", b"web_application_firewall_configuration", "zones", b"zones"]) -> None: ...

global___ApplicationGateways = ApplicationGateways

@typing_extensions.final
class ManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ManagedServiceIdentity = ManagedServiceIdentity

@typing_extensions.final
class ApplicationGatewayPrivateLinkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayPrivateLinkIpConfiguration]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        ip_configurations: collections.abc.Iterable[global___ApplicationGatewayPrivateLinkIpConfiguration] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_configurations", b"ip_configurations", "name", b"name"]) -> None: ...

global___ApplicationGatewayPrivateLinkConfiguration = ApplicationGatewayPrivateLinkConfiguration

@typing_extensions.final
class ApplicationGatewayPrivateLinkIpConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ALLOCATION_METHOD_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    private_ip_address: builtins.str
    private_ip_allocation_method: builtins.str
    @property
    def subnet(self) -> global___Subnet: ...
    primary: builtins.bool
    name: builtins.str
    def __init__(
        self,
        *,
        private_ip_address: builtins.str = ...,
        private_ip_allocation_method: builtins.str = ...,
        subnet: global___Subnet | None = ...,
        primary: builtins.bool = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "primary", b"primary", "private_ip_address", b"private_ip_address", "private_ip_allocation_method", b"private_ip_allocation_method", "subnet", b"subnet"]) -> None: ...

global___ApplicationGatewayPrivateLinkIpConfiguration = ApplicationGatewayPrivateLinkIpConfiguration

@typing_extensions.final
class ApplicationGatewayAutoscaleConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    min_capacity: builtins.int
    max_capacity: builtins.int
    def __init__(
        self,
        *,
        min_capacity: builtins.int = ...,
        max_capacity: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_capacity", b"max_capacity", "min_capacity", b"min_capacity"]) -> None: ...

global___ApplicationGatewayAutoscaleConfiguration = ApplicationGatewayAutoscaleConfiguration

@typing_extensions.final
class ApplicationGatewayWebApplicationFirewallConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    FIREWALL_MODE_FIELD_NUMBER: builtins.int
    RULE_SET_TYPE_FIELD_NUMBER: builtins.int
    RULE_SET_VERSION_FIELD_NUMBER: builtins.int
    DISABLED_RULE_GROUPS_FIELD_NUMBER: builtins.int
    REQUEST_BODY_CHECK_FIELD_NUMBER: builtins.int
    MAX_REQUEST_BODY_SIZE_FIELD_NUMBER: builtins.int
    MAX_REQUEST_BODY_SIZE_IN_KB_FIELD_NUMBER: builtins.int
    FILE_UPLOAD_LIMIT_IN_MB_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    firewall_mode: builtins.str
    rule_set_type: builtins.str
    rule_set_version: builtins.str
    @property
    def disabled_rule_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayFirewallDisabledRuleGroup]: ...
    request_body_check: builtins.bool
    max_request_body_size: builtins.int
    max_request_body_size_in_kb: builtins.int
    file_upload_limit_in_mb: builtins.int
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayFirewallExclusion]: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        firewall_mode: builtins.str = ...,
        rule_set_type: builtins.str = ...,
        rule_set_version: builtins.str = ...,
        disabled_rule_groups: collections.abc.Iterable[global___ApplicationGatewayFirewallDisabledRuleGroup] | None = ...,
        request_body_check: builtins.bool = ...,
        max_request_body_size: builtins.int = ...,
        max_request_body_size_in_kb: builtins.int = ...,
        file_upload_limit_in_mb: builtins.int = ...,
        exclusions: collections.abc.Iterable[global___ApplicationGatewayFirewallExclusion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_rule_groups", b"disabled_rule_groups", "enabled", b"enabled", "exclusions", b"exclusions", "file_upload_limit_in_mb", b"file_upload_limit_in_mb", "firewall_mode", b"firewall_mode", "max_request_body_size", b"max_request_body_size", "max_request_body_size_in_kb", b"max_request_body_size_in_kb", "request_body_check", b"request_body_check", "rule_set_type", b"rule_set_type", "rule_set_version", b"rule_set_version"]) -> None: ...

global___ApplicationGatewayWebApplicationFirewallConfiguration = ApplicationGatewayWebApplicationFirewallConfiguration

@typing_extensions.final
class ApplicationGatewayFirewallExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VARIABLE_FIELD_NUMBER: builtins.int
    SELECTOR_MATCH_OPERATOR_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    match_variable: builtins.str
    selector_match_operator: builtins.str
    selector: builtins.str
    def __init__(
        self,
        *,
        match_variable: builtins.str = ...,
        selector_match_operator: builtins.str = ...,
        selector: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_variable", b"match_variable", "selector", b"selector", "selector_match_operator", b"selector_match_operator"]) -> None: ...

global___ApplicationGatewayFirewallExclusion = ApplicationGatewayFirewallExclusion

@typing_extensions.final
class ApplicationGatewayFirewallDisabledRuleGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_GROUP_NAME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    rule_group_name: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        rule_group_name: builtins.str = ...,
        rules: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_group_name", b"rule_group_name", "rules", b"rules"]) -> None: ...

global___ApplicationGatewayFirewallDisabledRuleGroup = ApplicationGatewayFirewallDisabledRuleGroup

@typing_extensions.final
class ApplicationGatewayRedirectConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDIRECT_TYPE_FIELD_NUMBER: builtins.int
    TARGET_LISTENER_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    INCLUDE_PATH_FIELD_NUMBER: builtins.int
    INCLUDE_QUERY_STRING_FIELD_NUMBER: builtins.int
    REQUEST_ROUTING_RULES_FIELD_NUMBER: builtins.int
    URL_PATH_MAPS_FIELD_NUMBER: builtins.int
    PATH_RULES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    redirect_type: builtins.str
    target_listener: builtins.str
    target_url: builtins.str
    include_path: builtins.bool
    include_query_string: builtins.bool
    @property
    def request_routing_rules(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def url_path_maps(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def path_rules(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        redirect_type: builtins.str = ...,
        target_listener: builtins.str = ...,
        target_url: builtins.str = ...,
        include_path: builtins.bool = ...,
        include_query_string: builtins.bool = ...,
        request_routing_rules: collections.abc.Iterable[builtins.str] | None = ...,
        url_path_maps: collections.abc.Iterable[builtins.str] | None = ...,
        path_rules: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_path", b"include_path", "include_query_string", b"include_query_string", "name", b"name", "path_rules", b"path_rules", "redirect_type", b"redirect_type", "request_routing_rules", b"request_routing_rules", "target_listener", b"target_listener", "target_url", b"target_url", "url_path_maps", b"url_path_maps"]) -> None: ...

global___ApplicationGatewayRedirectConfiguration = ApplicationGatewayRedirectConfiguration

@typing_extensions.final
class ApplicationGatewayRewriteRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REWRITE_RULES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def rewrite_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRewriteRule]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        rewrite_rules: collections.abc.Iterable[global___ApplicationGatewayRewriteRule] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "rewrite_rules", b"rewrite_rules"]) -> None: ...

global___ApplicationGatewayRewriteRuleSet = ApplicationGatewayRewriteRuleSet

@typing_extensions.final
class ApplicationGatewayRewriteRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RULE_SEQUENCE_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    ACTION_SET_FIELD_NUMBER: builtins.int
    name: builtins.str
    rule_sequence: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRewriteRuleCondition]: ...
    @property
    def action_set(self) -> global___ApplicationGatewayRewriteRuleActionSet: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        rule_sequence: builtins.int = ...,
        conditions: collections.abc.Iterable[global___ApplicationGatewayRewriteRuleCondition] | None = ...,
        action_set: global___ApplicationGatewayRewriteRuleActionSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action_set", b"action_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_set", b"action_set", "conditions", b"conditions", "name", b"name", "rule_sequence", b"rule_sequence"]) -> None: ...

global___ApplicationGatewayRewriteRule = ApplicationGatewayRewriteRule

@typing_extensions.final
class ApplicationGatewayRewriteRuleActionSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADER_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    RESPONSE_HEADER_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    URL_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def request_header_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayHeaderConfiguration]: ...
    @property
    def response_header_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayHeaderConfiguration]: ...
    @property
    def url_configuration(self) -> global___ApplicationGatewayUrlConfiguration: ...
    def __init__(
        self,
        *,
        request_header_configurations: collections.abc.Iterable[global___ApplicationGatewayHeaderConfiguration] | None = ...,
        response_header_configurations: collections.abc.Iterable[global___ApplicationGatewayHeaderConfiguration] | None = ...,
        url_configuration: global___ApplicationGatewayUrlConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["url_configuration", b"url_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_header_configurations", b"request_header_configurations", "response_header_configurations", b"response_header_configurations", "url_configuration", b"url_configuration"]) -> None: ...

global___ApplicationGatewayRewriteRuleActionSet = ApplicationGatewayRewriteRuleActionSet

@typing_extensions.final
class ApplicationGatewayUrlConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODIFIED_PATH_FIELD_NUMBER: builtins.int
    MODIFIED_QUERY_STRING_FIELD_NUMBER: builtins.int
    REROUTE_FIELD_NUMBER: builtins.int
    modified_path: builtins.str
    modified_query_string: builtins.str
    reroute: builtins.bool
    def __init__(
        self,
        *,
        modified_path: builtins.str = ...,
        modified_query_string: builtins.str = ...,
        reroute: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["modified_path", b"modified_path", "modified_query_string", b"modified_query_string", "reroute", b"reroute"]) -> None: ...

global___ApplicationGatewayUrlConfiguration = ApplicationGatewayUrlConfiguration

@typing_extensions.final
class ApplicationGatewayHeaderConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value"]) -> None: ...

global___ApplicationGatewayHeaderConfiguration = ApplicationGatewayHeaderConfiguration

@typing_extensions.final
class ApplicationGatewayRewriteRuleCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIABLE_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    IGNORE_CASE_FIELD_NUMBER: builtins.int
    NEGATE_FIELD_NUMBER: builtins.int
    variable: builtins.str
    pattern: builtins.str
    ignore_case: builtins.bool
    negate: builtins.bool
    def __init__(
        self,
        *,
        variable: builtins.str = ...,
        pattern: builtins.str = ...,
        ignore_case: builtins.bool = ...,
        negate: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_case", b"ignore_case", "negate", b"negate", "pattern", b"pattern", "variable", b"variable"]) -> None: ...

global___ApplicationGatewayRewriteRuleCondition = ApplicationGatewayRewriteRuleCondition

@typing_extensions.final
class ApplicationGatewayRequestRoutingRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_TYPE_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    BACKEND_ADDRESS_POOL_FIELD_NUMBER: builtins.int
    BACKEND_HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    HTTP_LISTENER_FIELD_NUMBER: builtins.int
    URL_PATH_MAP_FIELD_NUMBER: builtins.int
    REWRITE_RULE_SET_FIELD_NUMBER: builtins.int
    REDIRECT_CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    rule_type: builtins.str
    priority: builtins.int
    @property
    def backend_address_pool(self) -> global___BackendAddressPool: ...
    @property
    def backend_http_settings(self) -> global___BackendHttpSettings: ...
    @property
    def http_listener(self) -> global___HttpListener: ...
    url_path_map: builtins.str
    rewrite_rule_set: builtins.str
    redirect_configuration: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        rule_type: builtins.str = ...,
        priority: builtins.int = ...,
        backend_address_pool: global___BackendAddressPool | None = ...,
        backend_http_settings: global___BackendHttpSettings | None = ...,
        http_listener: global___HttpListener | None = ...,
        url_path_map: builtins.str = ...,
        rewrite_rule_set: builtins.str = ...,
        redirect_configuration: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend_address_pool", b"backend_address_pool", "backend_http_settings", b"backend_http_settings", "http_listener", b"http_listener"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_address_pool", b"backend_address_pool", "backend_http_settings", b"backend_http_settings", "http_listener", b"http_listener", "name", b"name", "priority", b"priority", "redirect_configuration", b"redirect_configuration", "rewrite_rule_set", b"rewrite_rule_set", "rule_type", b"rule_type", "url_path_map", b"url_path_map"]) -> None: ...

global___ApplicationGatewayRequestRoutingRule = ApplicationGatewayRequestRoutingRule

@typing_extensions.final
class ApplicationGatewayUrlPathMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_BACKEND_ADDRESS_POOL_FIELD_NUMBER: builtins.int
    DEFAULT_BACKEND_HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    DEFAULT_REWRITE_RULE_SET_FIELD_NUMBER: builtins.int
    DEFAULT_REDIRECT_CONFIGURATION_FIELD_NUMBER: builtins.int
    PATH_RULES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    default_backend_address_pool: builtins.str
    default_backend_http_settings: builtins.str
    default_rewrite_rule_set: builtins.str
    default_redirect_configuration: builtins.str
    @property
    def path_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayPathRule]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        default_backend_address_pool: builtins.str = ...,
        default_backend_http_settings: builtins.str = ...,
        default_rewrite_rule_set: builtins.str = ...,
        default_redirect_configuration: builtins.str = ...,
        path_rules: collections.abc.Iterable[global___ApplicationGatewayPathRule] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_backend_address_pool", b"default_backend_address_pool", "default_backend_http_settings", b"default_backend_http_settings", "default_redirect_configuration", b"default_redirect_configuration", "default_rewrite_rule_set", b"default_rewrite_rule_set", "name", b"name", "path_rules", b"path_rules"]) -> None: ...

global___ApplicationGatewayUrlPathMap = ApplicationGatewayUrlPathMap

@typing_extensions.final
class ApplicationGatewayPathRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATHS_FIELD_NUMBER: builtins.int
    BACKEND_ADDRESS_POOL_FIELD_NUMBER: builtins.int
    BACKEND_HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    REDIRECT_CONFIGURATION_FIELD_NUMBER: builtins.int
    REWRITE_RULE_SET_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def backend_address_pool(self) -> global___BackendAddressPool: ...
    @property
    def backend_http_settings(self) -> global___BackendHttpSettings: ...
    redirect_configuration: builtins.str
    rewrite_rule_set: builtins.str
    firewall_policy: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        backend_address_pool: global___BackendAddressPool | None = ...,
        backend_http_settings: global___BackendHttpSettings | None = ...,
        redirect_configuration: builtins.str = ...,
        rewrite_rule_set: builtins.str = ...,
        firewall_policy: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend_address_pool", b"backend_address_pool", "backend_http_settings", b"backend_http_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_address_pool", b"backend_address_pool", "backend_http_settings", b"backend_http_settings", "firewall_policy", b"firewall_policy", "name", b"name", "paths", b"paths", "redirect_configuration", b"redirect_configuration", "rewrite_rule_set", b"rewrite_rule_set"]) -> None: ...

global___ApplicationGatewayPathRule = ApplicationGatewayPathRule

@typing_extensions.final
class ApplicationGatewaySslProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUSTED_CLIENT_CERTIFICATES_FIELD_NUMBER: builtins.int
    SSL_POLICY_FIELD_NUMBER: builtins.int
    CLIENT_AUTH_CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def trusted_client_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ssl_policy(self) -> global___ApplicationGatewaySslPolicy: ...
    @property
    def client_auth_configuration(self) -> global___ApplicationGatewayClientAuthConfiguration: ...
    name: builtins.str
    def __init__(
        self,
        *,
        trusted_client_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        ssl_policy: global___ApplicationGatewaySslPolicy | None = ...,
        client_auth_configuration: global___ApplicationGatewayClientAuthConfiguration | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_auth_configuration", b"client_auth_configuration", "ssl_policy", b"ssl_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_auth_configuration", b"client_auth_configuration", "name", b"name", "ssl_policy", b"ssl_policy", "trusted_client_certificates", b"trusted_client_certificates"]) -> None: ...

global___ApplicationGatewaySslProfile = ApplicationGatewaySslProfile

@typing_extensions.final
class ApplicationGatewayClientAuthConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERIFY_CLIENT_CERT_ISSUER_D_N_FIELD_NUMBER: builtins.int
    verify_client_cert_issuer_d_n: builtins.bool
    def __init__(
        self,
        *,
        verify_client_cert_issuer_d_n: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["verify_client_cert_issuer_d_n", b"verify_client_cert_issuer_d_n"]) -> None: ...

global___ApplicationGatewayClientAuthConfiguration = ApplicationGatewayClientAuthConfiguration

@typing_extensions.final
class ApplicationGatewayHttpListener(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FRONTEND_IP_CONFIGURATION_FIELD_NUMBER: builtins.int
    FRONTEND_PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATE_FIELD_NUMBER: builtins.int
    SSL_PROFILE_FIELD_NUMBER: builtins.int
    REQUIRE_SERVER_NAME_INDICATION_FIELD_NUMBER: builtins.int
    CUSTOM_ERROR_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    HOST_NAMES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def frontend_ip_configuration(self) -> global___FrontendIPConfiguration: ...
    @property
    def frontend_port(self) -> global___FrontendPort: ...
    protocol: builtins.str
    host_name: builtins.str
    ssl_certificate: builtins.str
    ssl_profile: builtins.str
    require_server_name_indication: builtins.bool
    @property
    def custom_error_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayCustomError]: ...
    firewall_policy: builtins.str
    @property
    def host_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        frontend_ip_configuration: global___FrontendIPConfiguration | None = ...,
        frontend_port: global___FrontendPort | None = ...,
        protocol: builtins.str = ...,
        host_name: builtins.str = ...,
        ssl_certificate: builtins.str = ...,
        ssl_profile: builtins.str = ...,
        require_server_name_indication: builtins.bool = ...,
        custom_error_configurations: collections.abc.Iterable[global___ApplicationGatewayCustomError] | None = ...,
        firewall_policy: builtins.str = ...,
        host_names: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["frontend_ip_configuration", b"frontend_ip_configuration", "frontend_port", b"frontend_port"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_error_configurations", b"custom_error_configurations", "firewall_policy", b"firewall_policy", "frontend_ip_configuration", b"frontend_ip_configuration", "frontend_port", b"frontend_port", "host_name", b"host_name", "host_names", b"host_names", "name", b"name", "protocol", b"protocol", "require_server_name_indication", b"require_server_name_indication", "ssl_certificate", b"ssl_certificate", "ssl_profile", b"ssl_profile"]) -> None: ...

global___ApplicationGatewayHttpListener = ApplicationGatewayHttpListener

@typing_extensions.final
class ApplicationGatewayCustomError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_CODE_FIELD_NUMBER: builtins.int
    CUSTOM_ERROR_PAGE_URL_FIELD_NUMBER: builtins.int
    status_code: builtins.str
    custom_error_page_url: builtins.str
    def __init__(
        self,
        *,
        status_code: builtins.str = ...,
        custom_error_page_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_error_page_url", b"custom_error_page_url", "status_code", b"status_code"]) -> None: ...

global___ApplicationGatewayCustomError = ApplicationGatewayCustomError

@typing_extensions.final
class ApplicationGatewayBackendHttpSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    COOKIE_BASED_AFFINITY_FIELD_NUMBER: builtins.int
    REQUEST_TIMEOUT_FIELD_NUMBER: builtins.int
    PROBE_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CERTIFICATES_FIELD_NUMBER: builtins.int
    TRUSTED_ROOT_CERTIFICATES_FIELD_NUMBER: builtins.int
    CONNECTION_DRAINING_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    PICK_HOST_NAME_FROM_BACKEND_ADDRESS_FIELD_NUMBER: builtins.int
    AFFINITY_COOKIE_NAME_FIELD_NUMBER: builtins.int
    PROBE_ENABLED_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    port: builtins.int
    protocol: builtins.str
    cookie_based_affinity: builtins.str
    request_timeout: builtins.int
    probe: builtins.str
    @property
    def authentication_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def trusted_root_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def connection_draining(self) -> global___ApplicationGatewayConnectionDraining: ...
    host_name: builtins.str
    pick_host_name_from_backend_address: builtins.bool
    affinity_cookie_name: builtins.str
    probe_enabled: builtins.bool
    path: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        cookie_based_affinity: builtins.str = ...,
        request_timeout: builtins.int = ...,
        probe: builtins.str = ...,
        authentication_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        trusted_root_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        connection_draining: global___ApplicationGatewayConnectionDraining | None = ...,
        host_name: builtins.str = ...,
        pick_host_name_from_backend_address: builtins.bool = ...,
        affinity_cookie_name: builtins.str = ...,
        probe_enabled: builtins.bool = ...,
        path: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection_draining", b"connection_draining"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["affinity_cookie_name", b"affinity_cookie_name", "authentication_certificates", b"authentication_certificates", "connection_draining", b"connection_draining", "cookie_based_affinity", b"cookie_based_affinity", "host_name", b"host_name", "name", b"name", "path", b"path", "pick_host_name_from_backend_address", b"pick_host_name_from_backend_address", "port", b"port", "probe", b"probe", "probe_enabled", b"probe_enabled", "protocol", b"protocol", "request_timeout", b"request_timeout", "trusted_root_certificates", b"trusted_root_certificates"]) -> None: ...

global___ApplicationGatewayBackendHttpSettings = ApplicationGatewayBackendHttpSettings

@typing_extensions.final
class ApplicationGatewayConnectionDraining(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    DRAIN_TIMEOUT_IN_SEC_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    drain_timeout_in_sec: builtins.int
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        drain_timeout_in_sec: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["drain_timeout_in_sec", b"drain_timeout_in_sec", "enabled", b"enabled"]) -> None: ...

global___ApplicationGatewayConnectionDraining = ApplicationGatewayConnectionDraining

@typing_extensions.final
class ApplicationGatewayBackendAddressPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_ADDRESSES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def backend_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayBackendAddress]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        backend_addresses: collections.abc.Iterable[global___ApplicationGatewayBackendAddress] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_addresses", b"backend_addresses", "name", b"name"]) -> None: ...

global___ApplicationGatewayBackendAddressPool = ApplicationGatewayBackendAddressPool

@typing_extensions.final
class ApplicationGatewayBackendAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    ip_address: builtins.str
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        ip_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fqdn", b"fqdn", "ip_address", b"ip_address"]) -> None: ...

global___ApplicationGatewayBackendAddress = ApplicationGatewayBackendAddress

@typing_extensions.final
class ApplicationGatewayProbe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTOCOL_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    PICK_HOST_NAME_FROM_BACKEND_HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    MIN_SERVERS_FIELD_NUMBER: builtins.int
    MATCH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    protocol: builtins.str
    host: builtins.str
    path: builtins.str
    interval: builtins.int
    timeout: builtins.int
    unhealthy_threshold: builtins.int
    pick_host_name_from_backend_http_settings: builtins.bool
    min_servers: builtins.int
    @property
    def match(self) -> global___ApplicationGatewayProbeHealthResponseMatch: ...
    port: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        protocol: builtins.str = ...,
        host: builtins.str = ...,
        path: builtins.str = ...,
        interval: builtins.int = ...,
        timeout: builtins.int = ...,
        unhealthy_threshold: builtins.int = ...,
        pick_host_name_from_backend_http_settings: builtins.bool = ...,
        min_servers: builtins.int = ...,
        match: global___ApplicationGatewayProbeHealthResponseMatch | None = ...,
        port: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match", b"match"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "interval", b"interval", "match", b"match", "min_servers", b"min_servers", "name", b"name", "path", b"path", "pick_host_name_from_backend_http_settings", b"pick_host_name_from_backend_http_settings", "port", b"port", "protocol", b"protocol", "timeout", b"timeout", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...

global___ApplicationGatewayProbe = ApplicationGatewayProbe

@typing_extensions.final
class ApplicationGatewayProbeHealthResponseMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    STATUS_CODES_FIELD_NUMBER: builtins.int
    body: builtins.str
    @property
    def status_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        body: builtins.str = ...,
        status_codes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "status_codes", b"status_codes"]) -> None: ...

global___ApplicationGatewayProbeHealthResponseMatch = ApplicationGatewayProbeHealthResponseMatch

@typing_extensions.final
class ApplicationGatewayFrontendPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    port: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "port", b"port"]) -> None: ...

global___ApplicationGatewayFrontendPort = ApplicationGatewayFrontendPort

@typing_extensions.final
class ApplicationGatewayFrontendIPConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ALLOCATION_METHOD_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_FIELD_NUMBER: builtins.int
    private_ip_address: builtins.str
    private_ip_allocation_method: builtins.str
    @property
    def subnet(self) -> global___Subnet: ...
    private_link_configuration: builtins.str
    name: builtins.str
    @property
    def public_ip_address(self) -> global___PublicIpAddress: ...
    def __init__(
        self,
        *,
        private_ip_address: builtins.str = ...,
        private_ip_allocation_method: builtins.str = ...,
        subnet: global___Subnet | None = ...,
        private_link_configuration: builtins.str = ...,
        name: builtins.str = ...,
        public_ip_address: global___PublicIpAddress | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["public_ip_address", b"public_ip_address", "subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_ip_address", b"private_ip_address", "private_ip_allocation_method", b"private_ip_allocation_method", "private_link_configuration", b"private_link_configuration", "public_ip_address", b"public_ip_address", "subnet", b"subnet"]) -> None: ...

global___ApplicationGatewayFrontendIPConfiguration = ApplicationGatewayFrontendIPConfiguration

@typing_extensions.final
class ApplicationGatewaySslCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    KEY_VAULT_SECRET_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    data: builtins.str
    password: builtins.str
    key_vault_secret_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
        password: builtins.str = ...,
        key_vault_secret_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "key_vault_secret_id", b"key_vault_secret_id", "name", b"name", "password", b"password"]) -> None: ...

global___ApplicationGatewaySslCertificate = ApplicationGatewaySslCertificate

@typing_extensions.final
class ApplicationGatewayTrustedClientCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    data: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "name", b"name"]) -> None: ...

global___ApplicationGatewayTrustedClientCertificate = ApplicationGatewayTrustedClientCertificate

@typing_extensions.final
class ApplicationGatewayTrustedRootCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    KEY_VAULT_SECRET_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    data: builtins.str
    key_vault_secret_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
        key_vault_secret_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "key_vault_secret_id", b"key_vault_secret_id", "name", b"name"]) -> None: ...

global___ApplicationGatewayTrustedRootCertificate = ApplicationGatewayTrustedRootCertificate

@typing_extensions.final
class ApplicationGatewayAuthenticationCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    data: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "name", b"name"]) -> None: ...

global___ApplicationGatewayAuthenticationCertificate = ApplicationGatewayAuthenticationCertificate

@typing_extensions.final
class ApplicationGatewayIPConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def subnet(self) -> global___Subnet: ...
    name: builtins.str
    def __init__(
        self,
        *,
        subnet: global___Subnet | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "subnet", b"subnet"]) -> None: ...

global___ApplicationGatewayIPConfiguration = ApplicationGatewayIPConfiguration

@typing_extensions.final
class ApplicationGatewaySslPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_SSL_PROTOCOLS_FIELD_NUMBER: builtins.int
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    CIPHER_SUITES_FIELD_NUMBER: builtins.int
    MIN_PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    @property
    def disabled_ssl_protocols(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    policy_type: builtins.str
    policy_name: builtins.str
    @property
    def cipher_suites(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    min_protocol_version: builtins.str
    def __init__(
        self,
        *,
        disabled_ssl_protocols: collections.abc.Iterable[builtins.str] | None = ...,
        policy_type: builtins.str = ...,
        policy_name: builtins.str = ...,
        cipher_suites: collections.abc.Iterable[builtins.str] | None = ...,
        min_protocol_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cipher_suites", b"cipher_suites", "disabled_ssl_protocols", b"disabled_ssl_protocols", "min_protocol_version", b"min_protocol_version", "policy_name", b"policy_name", "policy_type", b"policy_type"]) -> None: ...

global___ApplicationGatewaySslPolicy = ApplicationGatewaySslPolicy

@typing_extensions.final
class ApplicationGatewaySku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    name: builtins.str
    tier: builtins.str
    capacity: builtins.int
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tier: builtins.str = ...,
        capacity: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "name", b"name", "tier", b"tier"]) -> None: ...

global___ApplicationGatewaySku = ApplicationGatewaySku

@typing_extensions.final
class ApplicationGatewayWebApplicationFirewallPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    POLICY_SETTINGS_FIELD_NUMBER: builtins.int
    CUSTOM_RULES_FIELD_NUMBER: builtins.int
    MANAGED_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def policy_settings(self) -> global___PolicySettings: ...
    @property
    def custom_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WebApplicationFirewallCustomRule]: ...
    @property
    def managed_rules(self) -> global___ManagedRulesDefinition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        policy_settings: global___PolicySettings | None = ...,
        custom_rules: collections.abc.Iterable[global___WebApplicationFirewallCustomRule] | None = ...,
        managed_rules: global___ManagedRulesDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed_rules", b"managed_rules", "policy_settings", b"policy_settings", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_rules", b"custom_rules", "location", b"location", "managed_rules", b"managed_rules", "name", b"name", "policy_settings", b"policy_settings", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ApplicationGatewayWebApplicationFirewallPolicies = ApplicationGatewayWebApplicationFirewallPolicies

@typing_extensions.final
class ManagedRulesDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUSIONS_FIELD_NUMBER: builtins.int
    MANAGED_RULE_SETS_FIELD_NUMBER: builtins.int
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OwaspCrsExclusionEntry]: ...
    @property
    def managed_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleSet]: ...
    def __init__(
        self,
        *,
        exclusions: collections.abc.Iterable[global___OwaspCrsExclusionEntry] | None = ...,
        managed_rule_sets: collections.abc.Iterable[global___ManagedRuleSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclusions", b"exclusions", "managed_rule_sets", b"managed_rule_sets"]) -> None: ...

global___ManagedRulesDefinition = ManagedRulesDefinition

@typing_extensions.final
class ManagedRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_SET_TYPE_FIELD_NUMBER: builtins.int
    RULE_SET_VERSION_FIELD_NUMBER: builtins.int
    RULE_GROUP_OVERRIDES_FIELD_NUMBER: builtins.int
    rule_set_type: builtins.str
    rule_set_version: builtins.str
    @property
    def rule_group_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleGroupOverride]: ...
    def __init__(
        self,
        *,
        rule_set_type: builtins.str = ...,
        rule_set_version: builtins.str = ...,
        rule_group_overrides: collections.abc.Iterable[global___ManagedRuleGroupOverride] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_group_overrides", b"rule_group_overrides", "rule_set_type", b"rule_set_type", "rule_set_version", b"rule_set_version"]) -> None: ...

global___ManagedRuleSet = ManagedRuleSet

@typing_extensions.final
class ManagedRuleGroupOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_GROUP_NAME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    rule_group_name: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleOverride]: ...
    def __init__(
        self,
        *,
        rule_group_name: builtins.str = ...,
        rules: collections.abc.Iterable[global___ManagedRuleOverride] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_group_name", b"rule_group_name", "rules", b"rules"]) -> None: ...

global___ManagedRuleGroupOverride = ManagedRuleGroupOverride

@typing_extensions.final
class ManagedRuleOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_id", b"rule_id", "state", b"state"]) -> None: ...

global___ManagedRuleOverride = ManagedRuleOverride

@typing_extensions.final
class OwaspCrsExclusionEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VARIABLE_FIELD_NUMBER: builtins.int
    SELECTOR_MATCH_OPERATOR_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    match_variable: builtins.str
    selector_match_operator: builtins.str
    selector: builtins.str
    def __init__(
        self,
        *,
        match_variable: builtins.str = ...,
        selector_match_operator: builtins.str = ...,
        selector: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_variable", b"match_variable", "selector", b"selector", "selector_match_operator", b"selector_match_operator"]) -> None: ...

global___OwaspCrsExclusionEntry = OwaspCrsExclusionEntry

@typing_extensions.final
class WebApplicationFirewallCustomRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    RULE_TYPE_FIELD_NUMBER: builtins.int
    MATCH_CONDITIONS_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    priority: builtins.int
    rule_type: builtins.str
    @property
    def match_conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchCondition]: ...
    action: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        rule_type: builtins.str = ...,
        match_conditions: collections.abc.Iterable[global___MatchCondition] | None = ...,
        action: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "match_conditions", b"match_conditions", "name", b"name", "priority", b"priority", "rule_type", b"rule_type"]) -> None: ...

global___WebApplicationFirewallCustomRule = WebApplicationFirewallCustomRule

@typing_extensions.final
class MatchCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VARIABLES_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    NEGATION_CONDITON_FIELD_NUMBER: builtins.int
    MATCH_VALUES_FIELD_NUMBER: builtins.int
    TRANSFORMS_FIELD_NUMBER: builtins.int
    @property
    def match_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchVariable]: ...
    operator: builtins.str
    negation_conditon: builtins.bool
    @property
    def match_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def transforms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        match_variables: collections.abc.Iterable[global___MatchVariable] | None = ...,
        operator: builtins.str = ...,
        negation_conditon: builtins.bool = ...,
        match_values: collections.abc.Iterable[builtins.str] | None = ...,
        transforms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_values", b"match_values", "match_variables", b"match_variables", "negation_conditon", b"negation_conditon", "operator", b"operator", "transforms", b"transforms"]) -> None: ...

global___MatchCondition = MatchCondition

@typing_extensions.final
class MatchVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIABLE_NAME_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    variable_name: builtins.str
    selector: builtins.str
    def __init__(
        self,
        *,
        variable_name: builtins.str = ...,
        selector: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["selector", b"selector", "variable_name", b"variable_name"]) -> None: ...

global___MatchVariable = MatchVariable

@typing_extensions.final
class PolicySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    REQUEST_BODY_CHECK_FIELD_NUMBER: builtins.int
    MAX_REQUEST_BODY_SIZE_IN_KB_FIELD_NUMBER: builtins.int
    FILE_UPLOAD_LIMIT_IN_MB_FIELD_NUMBER: builtins.int
    state: builtins.str
    mode: builtins.str
    request_body_check: builtins.bool
    max_request_body_size_in_kb: builtins.int
    file_upload_limit_in_mb: builtins.int
    def __init__(
        self,
        *,
        state: builtins.str = ...,
        mode: builtins.str = ...,
        request_body_check: builtins.bool = ...,
        max_request_body_size_in_kb: builtins.int = ...,
        file_upload_limit_in_mb: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_upload_limit_in_mb", b"file_upload_limit_in_mb", "max_request_body_size_in_kb", b"max_request_body_size_in_kb", "mode", b"mode", "request_body_check", b"request_body_check", "state", b"state"]) -> None: ...

global___PolicySettings = PolicySettings
