# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_vpcendpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ws/aws_ec2_vpcendpoint.proto\x12\x1foak9.tython.aws.ec2_vpcendpoint\x1a\x13shared/shared.proto\"\xff\x02\n\x0bVPCEndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x0fpolicy_document\x18\x02 \x03(\x0b\x32@.oak9.tython.aws.ec2_vpcendpoint.VPCEndpoint.PolicyDocumentEntry\x12\x1b\n\x13private_dns_enabled\x18\x03 \x01(\x08\x12\x17\n\x0froute_table_ids\x18\x04 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\t\x12\x14\n\x0cservice_name\x18\x06 \x01(\t\x12\x12\n\nsubnet_ids\x18\x07 \x03(\t\x12\x19\n\x11vpc_endpoint_type\x18\x08 \x01(\t\x12\x0e\n\x06vpc_id\x18\t \x01(\t\x1a\x35\n\x13PolicyDocumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x02\n\x0f\x45\x43\x32_VPCEndpoint\x12\x42\n\x0cvpc_endpoint\x18\x01 \x01(\x0b\x32,.oak9.tython.aws.ec2_vpcendpoint.VPCEndpoint\x12Q\n\x14vpc_endpoint_service\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.ec2_vpcendpoint.VPCEndpointService\x12h\n vpc_endpoint_service_permissions\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.ec2_vpcendpoint.VPCEndpointServicePermissions\"\xb4\x01\n\x12VPCEndpointService\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1anetwork_load_balancer_arns\x18\x02 \x03(\t\x12\x1b\n\x13\x61\x63\x63\x65ptance_required\x18\x03 \x01(\x08\x12$\n\x1c\x61ppliance_load_balancer_arns\x18\x04 \x03(\t\"\x88\x01\n\x1dVPCEndpointServicePermissions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x61llowed_principals\x18\x02 \x03(\t\x12\x12\n\nservice_id\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_vpcendpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VPCENDPOINT_POLICYDOCUMENTENTRY._options = None
  _VPCENDPOINT_POLICYDOCUMENTENTRY._serialized_options = b'8\001'
  _VPCENDPOINT._serialized_start=88
  _VPCENDPOINT._serialized_end=471
  _VPCENDPOINT_POLICYDOCUMENTENTRY._serialized_start=418
  _VPCENDPOINT_POLICYDOCUMENTENTRY._serialized_end=471
  _EC2_VPCENDPOINT._serialized_start=474
  _EC2_VPCENDPOINT._serialized_end=748
  _VPCENDPOINTSERVICE._serialized_start=751
  _VPCENDPOINTSERVICE._serialized_end=931
  _VPCENDPOINTSERVICEPERMISSIONS._serialized_start=934
  _VPCENDPOINTSERVICEPERMISSIONS._serialized_end=1070
# @@protoc_insertion_point(module_scope)
