# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_instance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_ec2_instance.proto\x12\x1coak9.tython.aws.ec2_instance\x1a\x13shared/shared.proto\"\xd9\x01\n\x0bInstanceEbs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x02 \x01(\x08\x12\x11\n\tencrypted\x18\x03 \x01(\x08\x12\x0c\n\x04iops\x18\x04 \x01(\x05\x12\x12\n\nkms_key_id\x18\x05 \x01(\t\x12\x13\n\x0bsnapshot_id\x18\x06 \x01(\t\x12\x13\n\x0bvolume_size\x18\x07 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x08 \x01(\t\"K\n\x10InstanceNoDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfb\x01\n\x1aInstanceBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x36\n\x03\x65\x62s\x18\x03 \x01(\x0b\x32).oak9.tython.aws.ec2_instance.InstanceEbs\x12\x41\n\tno_device\x18\x04 \x01(\x0b\x32..oak9.tython.aws.ec2_instance.InstanceNoDevice\x12\x14\n\x0cvirtual_name\x18\x05 \x01(\t\"{\n\x12InstanceCpuOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncore_count\x18\x02 \x01(\x05\x12\x18\n\x10threads_per_core\x18\x03 \x01(\x05\"k\n\x1bInstanceCreditSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63pu_credits\x18\x02 \x01(\t\"Z\n\x1fInstanceElasticGpuSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"m\n#InstanceElasticInferenceAccelerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"i\n\x1aInstanceHibernationOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nconfigured\x18\x02 \x01(\x08\"l\n\x1bInstanceInstanceIpv6Address\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\"\xa9\x01\n#InstanceLaunchTemplateSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12launch_template_id\x18\x02 \x01(\t\x12\x1c\n\x14launch_template_name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"z\n\x1cInstanceLicenseSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19license_configuration_arn\x18\x02 \x01(\t\"\x8d\x01\n%InstancePrivateIpAddressSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07primary\x18\x02 \x01(\x08\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\"\xa0\x04\n\x18InstanceNetworkInterface\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x61ssociate_public_ip_address\x18\x02 \x01(\x08\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65vice_index\x18\x05 \x01(\t\x12\x11\n\tgroup_set\x18\x06 \x03(\t\x12\x1a\n\x12ipv6_address_count\x18\x07 \x01(\x05\x12Q\n\x0eipv6_addresses\x18\x08 \x03(\x0b\x32\x39.oak9.tython.aws.ec2_instance.InstanceInstanceIpv6Address\x12\x1c\n\x14network_interface_id\x18\t \x01(\t\x12\x1a\n\x12private_ip_address\x18\n \x01(\t\x12\x61\n\x14private_ip_addresses\x18\x0b \x03(\x0b\x32\x43.oak9.tython.aws.ec2_instance.InstancePrivateIpAddressSpecification\x12*\n\"secondary_private_ip_address_count\x18\x0c \x01(\x05\x12\x11\n\tsubnet_id\x18\r \x01(\t\"s\n\x1cInstanceAssociationParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x03(\t\"\xc4\x01\n\x16InstanceSsmAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x16\x61ssociation_parameters\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.ec2_instance.InstanceAssociationParameter\x12\x15\n\rdocument_name\x18\x03 \x01(\t\"l\n\x0eInstanceVolume\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x11\n\tvolume_id\x18\x03 \x01(\t\"\xc7\x0e\n\x08Instance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\x12\x10\n\x08\x61\x66\x66inity\x18\x03 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x04 \x01(\t\x12W\n\x15\x62lock_device_mappings\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.ec2_instance.InstanceBlockDeviceMapping\x12\x45\n\x0b\x63pu_options\x18\x06 \x01(\x0b\x32\x30.oak9.tython.aws.ec2_instance.InstanceCpuOptions\x12W\n\x14\x63redit_specification\x18\x07 \x01(\x0b\x32\x39.oak9.tython.aws.ec2_instance.InstanceCreditSpecification\x12\x1f\n\x17\x64isable_api_termination\x18\x08 \x01(\x08\x12\x15\n\rebs_optimized\x18\t \x01(\x08\x12\x61\n\x1a\x65lastic_gpu_specifications\x18\n \x03(\x0b\x32=.oak9.tython.aws.ec2_instance.InstanceElasticGpuSpecification\x12i\n\x1e\x65lastic_inference_accelerators\x18\x0b \x03(\x0b\x32\x41.oak9.tython.aws.ec2_instance.InstanceElasticInferenceAccelerator\x12U\n\x13hibernation_options\x18\x0c \x01(\x0b\x32\x38.oak9.tython.aws.ec2_instance.InstanceHibernationOptions\x12\x0f\n\x07host_id\x18\r \x01(\t\x12\x1f\n\x17host_resource_group_arn\x18\x0e \x01(\t\x12\x1c\n\x14iam_instance_profile\x18\x0f \x01(\t\x12\x10\n\x08image_id\x18\x10 \x01(\t\x12,\n$instance_initiated_shutdown_behavior\x18\x11 \x01(\t\x12\x15\n\rinstance_type\x18\x12 \x01(\t\x12\x1a\n\x12ipv6_address_count\x18\x13 \x01(\x05\x12Q\n\x0eipv6_addresses\x18\x14 \x03(\x0b\x32\x39.oak9.tython.aws.ec2_instance.InstanceInstanceIpv6Address\x12\x11\n\tkernel_id\x18\x15 \x01(\t\x12\x10\n\x08key_name\x18\x16 \x01(\t\x12Z\n\x0flaunch_template\x18\x17 \x01(\x0b\x32\x41.oak9.tython.aws.ec2_instance.InstanceLaunchTemplateSpecification\x12Z\n\x16license_specifications\x18\x18 \x03(\x0b\x32:.oak9.tython.aws.ec2_instance.InstanceLicenseSpecification\x12\x12\n\nmonitoring\x18\x19 \x01(\x08\x12R\n\x12network_interfaces\x18\x1a \x03(\x0b\x32\x36.oak9.tython.aws.ec2_instance.InstanceNetworkInterface\x12\x1c\n\x14placement_group_name\x18\x1b \x01(\t\x12\x1a\n\x12private_ip_address\x18\x1c \x01(\t\x12\x12\n\nramdisk_id\x18\x1d \x01(\t\x12\x1a\n\x12security_group_ids\x18\x1e \x03(\t\x12\x17\n\x0fsecurity_groups\x18\x1f \x03(\t\x12\x19\n\x11source_dest_check\x18  \x01(\x08\x12N\n\x10ssm_associations\x18! \x03(\x0b\x32\x34.oak9.tython.aws.ec2_instance.InstanceSsmAssociation\x12\x11\n\tsubnet_id\x18\" \x01(\t\x12>\n\x04tags\x18# \x03(\x0b\x32\x30.oak9.tython.aws.ec2_instance.Instance.TagsEntry\x12\x0f\n\x07tenancy\x18$ \x01(\t\x12\x11\n\tuser_data\x18% \x01(\t\x12=\n\x07volumes\x18& \x03(\x0b\x32,.oak9.tython.aws.ec2_instance.InstanceVolume\x12:\n\tplacement\x18\' \x01(\x0b\x32\'.oak9.tython.aws.ec2_instance.Placement\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\x0c\x45\x43\x32_Instance\x12\x38\n\x08instance\x18\x01 \x01(\x0b\x32&.oak9.tython.aws.ec2_instance.Instance\x12\x45\n\x0flaunch_template\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.ec2_instance.LaunchTemplate\"\xf3\x01\n\x1eLaunchTemplateTagSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12T\n\x04tags\x18\x03 \x03(\x0b\x32\x46.oak9.tython.aws.ec2_instance.LaunchTemplateTagSpecification.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x01\n\x11LaunchTemplateEbs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsnapshot_id\x18\x02 \x01(\t\x12\x13\n\x0bvolume_type\x18\x03 \x01(\t\x12\x12\n\nkms_key_id\x18\x04 \x01(\t\x12\x11\n\tencrypted\x18\x05 \x01(\x08\x12\x0c\n\x04iops\x18\x06 \x01(\x05\x12\x13\n\x0bvolume_size\x18\x07 \x01(\x05\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x08 \x01(\x08\"\xd7\x01\n LaunchTemplateBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x03\x65\x62s\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.ec2_instance.LaunchTemplateEbs\x12\x11\n\tno_device\x18\x03 \x01(\t\x12\x14\n\x0cvirtual_name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x05 \x01(\t\"v\n LaunchTemplateIamInstanceProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"`\n%LaunchTemplateElasticGpuSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x01\n7LaunchTemplateLaunchTemplateElasticInferenceAccelerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x87\x02\n\x17LaunchTemplatePlacement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x0f\n\x07tenancy\x18\x03 \x01(\t\x12\x15\n\rspread_domain\x18\x04 \x01(\t\x12\x18\n\x10partition_number\x18\x05 \x01(\x05\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12\x10\n\x08\x61\x66\x66inity\x18\x07 \x01(\t\x12\x0f\n\x07host_id\x18\x08 \x01(\t\x12\x1f\n\x17host_resource_group_arn\x18\t \x01(\t\"\x82\x01\n\x1aLaunchTemplatePrivateIpAdd\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12private_ip_address\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\x08\"f\n\x15LaunchTemplateIpv6Add\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\"\xaa\x04\n\x1eLaunchTemplateNetworkInterface\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\x12V\n\x14private_ip_addresses\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.ec2_instance.LaunchTemplatePrivateIpAdd\x12*\n\"secondary_private_ip_address_count\x18\x05 \x01(\x05\x12\x14\n\x0c\x64\x65vice_index\x18\x06 \x01(\x05\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12K\n\x0eipv6_addresses\x18\x08 \x03(\x0b\x32\x33.oak9.tython.aws.ec2_instance.LaunchTemplateIpv6Add\x12#\n\x1b\x61ssociate_public_ip_address\x18\t \x01(\x08\x12\x1c\n\x14network_interface_id\x18\n \x01(\t\x12\x16\n\x0einterface_type\x18\x0b \x01(\t\x12\x1a\n\x12ipv6_address_count\x18\x0c \x01(\x05\x12\x0e\n\x06groups\x18\r \x03(\t\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x0e \x01(\x08\"d\n\x18LaunchTemplateMonitoring\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"o\n LaunchTemplateHibernationOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nconfigured\x18\x02 \x01(\x08\"\xa9\x01\n\x1dLaunchTemplateMetadataOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1bhttp_put_response_hop_limit\x18\x02 \x01(\x05\x12\x13\n\x0bhttp_tokens\x18\x03 \x01(\t\x12\x15\n\rhttp_endpoint\x18\x04 \x01(\t\"\x80\x01\n\"LaunchTemplateLicenseSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19license_configuration_arn\x18\x02 \x01(\t\"\x81\x01\n\x18LaunchTemplateCpuOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x05\x12\x12\n\ncore_count\x18\x03 \x01(\x05\"\xe0\x01\n\x19LaunchTemplateSpotOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12spot_instance_type\x18\x02 \x01(\t\x12&\n\x1einstance_interruption_behavior\x18\x03 \x01(\t\x12\x11\n\tmax_price\x18\x04 \x01(\t\x12\x1e\n\x16\x62lock_duration_minutes\x18\x05 \x01(\x05\x12\x13\n\x0bvalid_until\x18\x06 \x01(\t\"\xc2\x01\n#LaunchTemplateInstanceMarketOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x0cspot_options\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.ec2_instance.LaunchTemplateSpotOptions\x12\x13\n\x0bmarket_type\x18\x03 \x01(\t\"\x83\x01\n\'LaunchTemplateCapacityReservationTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x63\x61pacity_reservation_id\x18\x02 \x01(\t\"\xfe\x01\n.LaunchTemplateCapacityReservationSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1f\x63\x61pacity_reservation_preference\x18\x02 \x01(\t\x12j\n\x1b\x63\x61pacity_reservation_target\x18\x03 \x01(\x0b\x32\x45.oak9.tython.aws.ec2_instance.LaunchTemplateCapacityReservationTarget\"q\n!LaunchTemplateCreditSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63pu_credits\x18\x02 \x01(\t\"\xfb\r\n LaunchTemplateLaunchTemplateData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fsecurity_groups\x18\x02 \x03(\t\x12X\n\x12tag_specifications\x18\x03 \x03(\x0b\x32<.oak9.tython.aws.ec2_instance.LaunchTemplateTagSpecification\x12\x11\n\tuser_data\x18\x04 \x01(\t\x12]\n\x15\x62lock_device_mappings\x18\x05 \x03(\x0b\x32>.oak9.tython.aws.ec2_instance.LaunchTemplateBlockDeviceMapping\x12\\\n\x14iam_instance_profile\x18\x06 \x01(\x0b\x32>.oak9.tython.aws.ec2_instance.LaunchTemplateIamInstanceProfile\x12\x11\n\tkernel_id\x18\x07 \x01(\t\x12\x15\n\rebs_optimized\x18\x08 \x01(\x08\x12g\n\x1a\x65lastic_gpu_specifications\x18\t \x03(\x0b\x32\x43.oak9.tython.aws.ec2_instance.LaunchTemplateElasticGpuSpecification\x12}\n\x1e\x65lastic_inference_accelerators\x18\n \x03(\x0b\x32U.oak9.tython.aws.ec2_instance.LaunchTemplateLaunchTemplateElasticInferenceAccelerator\x12H\n\tplacement\x18\x0b \x01(\x0b\x32\x35.oak9.tython.aws.ec2_instance.LaunchTemplatePlacement\x12X\n\x12network_interfaces\x18\x0c \x03(\x0b\x32<.oak9.tython.aws.ec2_instance.LaunchTemplateNetworkInterface\x12\x10\n\x08image_id\x18\r \x01(\t\x12\x15\n\rinstance_type\x18\x0e \x01(\t\x12J\n\nmonitoring\x18\x0f \x01(\x0b\x32\x36.oak9.tython.aws.ec2_instance.LaunchTemplateMonitoring\x12[\n\x13hibernation_options\x18\x10 \x01(\x0b\x32>.oak9.tython.aws.ec2_instance.LaunchTemplateHibernationOptions\x12U\n\x10metadata_options\x18\x11 \x01(\x0b\x32;.oak9.tython.aws.ec2_instance.LaunchTemplateMetadataOptions\x12`\n\x16license_specifications\x18\x12 \x03(\x0b\x32@.oak9.tython.aws.ec2_instance.LaunchTemplateLicenseSpecification\x12,\n$instance_initiated_shutdown_behavior\x18\x13 \x01(\t\x12K\n\x0b\x63pu_options\x18\x14 \x01(\x0b\x32\x36.oak9.tython.aws.ec2_instance.LaunchTemplateCpuOptions\x12\x1a\n\x12security_group_ids\x18\x15 \x03(\t\x12\x10\n\x08key_name\x18\x16 \x01(\t\x12\x1f\n\x17\x64isable_api_termination\x18\x17 \x01(\x08\x12\x62\n\x17instance_market_options\x18\x18 \x01(\x0b\x32\x41.oak9.tython.aws.ec2_instance.LaunchTemplateInstanceMarketOptions\x12\x13\n\x0bram_disk_id\x18\x19 \x01(\t\x12x\n\"capacity_reservation_specification\x18\x1a \x01(\x0b\x32L.oak9.tython.aws.ec2_instance.LaunchTemplateCapacityReservationSpecification\x12]\n\x14\x63redit_specification\x18\x1b \x01(\x0b\x32?.oak9.tython.aws.ec2_instance.LaunchTemplateCreditSpecification\"&\n\tPlacement\x12\x19\n\x11\x61vailability_zone\x18\x01 \x01(\t\"\xc5\x01\n\x0eLaunchTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14launch_template_name\x18\x02 \x01(\t\x12\\\n\x14launch_template_data\x18\x03 \x01(\x0b\x32>.oak9.tython.aws.ec2_instance.LaunchTemplateLaunchTemplateDatab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_instance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INSTANCE_TAGSENTRY._options = None
  _INSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._options = None
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_options = b'8\001'
  _INSTANCEEBS._serialized_start=82
  _INSTANCEEBS._serialized_end=299
  _INSTANCENODEVICE._serialized_start=301
  _INSTANCENODEVICE._serialized_end=376
  _INSTANCEBLOCKDEVICEMAPPING._serialized_start=379
  _INSTANCEBLOCKDEVICEMAPPING._serialized_end=630
  _INSTANCECPUOPTIONS._serialized_start=632
  _INSTANCECPUOPTIONS._serialized_end=755
  _INSTANCECREDITSPECIFICATION._serialized_start=757
  _INSTANCECREDITSPECIFICATION._serialized_end=864
  _INSTANCEELASTICGPUSPECIFICATION._serialized_start=866
  _INSTANCEELASTICGPUSPECIFICATION._serialized_end=956
  _INSTANCEELASTICINFERENCEACCELERATOR._serialized_start=958
  _INSTANCEELASTICINFERENCEACCELERATOR._serialized_end=1067
  _INSTANCEHIBERNATIONOPTIONS._serialized_start=1069
  _INSTANCEHIBERNATIONOPTIONS._serialized_end=1174
  _INSTANCEINSTANCEIPV6ADDRESS._serialized_start=1176
  _INSTANCEINSTANCEIPV6ADDRESS._serialized_end=1284
  _INSTANCELAUNCHTEMPLATESPECIFICATION._serialized_start=1287
  _INSTANCELAUNCHTEMPLATESPECIFICATION._serialized_end=1456
  _INSTANCELICENSESPECIFICATION._serialized_start=1458
  _INSTANCELICENSESPECIFICATION._serialized_end=1580
  _INSTANCEPRIVATEIPADDRESSSPECIFICATION._serialized_start=1583
  _INSTANCEPRIVATEIPADDRESSSPECIFICATION._serialized_end=1724
  _INSTANCENETWORKINTERFACE._serialized_start=1727
  _INSTANCENETWORKINTERFACE._serialized_end=2271
  _INSTANCEASSOCIATIONPARAMETER._serialized_start=2273
  _INSTANCEASSOCIATIONPARAMETER._serialized_end=2388
  _INSTANCESSMASSOCIATION._serialized_start=2391
  _INSTANCESSMASSOCIATION._serialized_end=2587
  _INSTANCEVOLUME._serialized_start=2589
  _INSTANCEVOLUME._serialized_end=2697
  _INSTANCE._serialized_start=2700
  _INSTANCE._serialized_end=4563
  _INSTANCE_TAGSENTRY._serialized_start=4520
  _INSTANCE_TAGSENTRY._serialized_end=4563
  _EC2_INSTANCE._serialized_start=4566
  _EC2_INSTANCE._serialized_end=4709
  _LAUNCHTEMPLATETAGSPECIFICATION._serialized_start=4712
  _LAUNCHTEMPLATETAGSPECIFICATION._serialized_end=4955
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_start=4520
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_end=4563
  _LAUNCHTEMPLATEEBS._serialized_start=4958
  _LAUNCHTEMPLATEEBS._serialized_end=5181
  _LAUNCHTEMPLATEBLOCKDEVICEMAPPING._serialized_start=5184
  _LAUNCHTEMPLATEBLOCKDEVICEMAPPING._serialized_end=5399
  _LAUNCHTEMPLATEIAMINSTANCEPROFILE._serialized_start=5401
  _LAUNCHTEMPLATEIAMINSTANCEPROFILE._serialized_end=5519
  _LAUNCHTEMPLATEELASTICGPUSPECIFICATION._serialized_start=5521
  _LAUNCHTEMPLATEELASTICGPUSPECIFICATION._serialized_end=5617
  _LAUNCHTEMPLATELAUNCHTEMPLATEELASTICINFERENCEACCELERATOR._serialized_start=5620
  _LAUNCHTEMPLATELAUNCHTEMPLATEELASTICINFERENCEACCELERATOR._serialized_end=5749
  _LAUNCHTEMPLATEPLACEMENT._serialized_start=5752
  _LAUNCHTEMPLATEPLACEMENT._serialized_end=6015
  _LAUNCHTEMPLATEPRIVATEIPADD._serialized_start=6018
  _LAUNCHTEMPLATEPRIVATEIPADD._serialized_end=6148
  _LAUNCHTEMPLATEIPV6ADD._serialized_start=6150
  _LAUNCHTEMPLATEIPV6ADD._serialized_end=6252
  _LAUNCHTEMPLATENETWORKINTERFACE._serialized_start=6255
  _LAUNCHTEMPLATENETWORKINTERFACE._serialized_end=6809
  _LAUNCHTEMPLATEMONITORING._serialized_start=6811
  _LAUNCHTEMPLATEMONITORING._serialized_end=6911
  _LAUNCHTEMPLATEHIBERNATIONOPTIONS._serialized_start=6913
  _LAUNCHTEMPLATEHIBERNATIONOPTIONS._serialized_end=7024
  _LAUNCHTEMPLATEMETADATAOPTIONS._serialized_start=7027
  _LAUNCHTEMPLATEMETADATAOPTIONS._serialized_end=7196
  _LAUNCHTEMPLATELICENSESPECIFICATION._serialized_start=7199
  _LAUNCHTEMPLATELICENSESPECIFICATION._serialized_end=7327
  _LAUNCHTEMPLATECPUOPTIONS._serialized_start=7330
  _LAUNCHTEMPLATECPUOPTIONS._serialized_end=7459
  _LAUNCHTEMPLATESPOTOPTIONS._serialized_start=7462
  _LAUNCHTEMPLATESPOTOPTIONS._serialized_end=7686
  _LAUNCHTEMPLATEINSTANCEMARKETOPTIONS._serialized_start=7689
  _LAUNCHTEMPLATEINSTANCEMARKETOPTIONS._serialized_end=7883
  _LAUNCHTEMPLATECAPACITYRESERVATIONTARGET._serialized_start=7886
  _LAUNCHTEMPLATECAPACITYRESERVATIONTARGET._serialized_end=8017
  _LAUNCHTEMPLATECAPACITYRESERVATIONSPECIFICATION._serialized_start=8020
  _LAUNCHTEMPLATECAPACITYRESERVATIONSPECIFICATION._serialized_end=8274
  _LAUNCHTEMPLATECREDITSPECIFICATION._serialized_start=8276
  _LAUNCHTEMPLATECREDITSPECIFICATION._serialized_end=8389
  _LAUNCHTEMPLATELAUNCHTEMPLATEDATA._serialized_start=8392
  _LAUNCHTEMPLATELAUNCHTEMPLATEDATA._serialized_end=10179
  _PLACEMENT._serialized_start=10181
  _PLACEMENT._serialized_end=10219
  _LAUNCHTEMPLATE._serialized_start=10222
  _LAUNCHTEMPLATE._serialized_end=10419
# @@protoc_insertion_point(module_scope)
