# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codestarnotifications.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#aws/aws_codestarnotifications.proto\x12%oak9.tython.aws.codestarnotifications\x1a\x13shared/shared.proto\"~\n\x16NotificationRuleTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0btarget_type\x18\x02 \x01(\t\x12\x16\n\x0etarget_address\x18\x03 \x01(\t\"\xf6\x02\n\x10NotificationRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65vent_type_ids\x18\x02 \x03(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65tail_type\x18\x04 \x01(\t\x12\x10\n\x08resource\x18\x05 \x01(\t\x12N\n\x07targets\x18\x06 \x03(\x0b\x32=.oak9.tython.aws.codestarnotifications.NotificationRuleTarget\x12O\n\x04tags\x18\x07 \x03(\x0b\x32\x41.oak9.tython.aws.codestarnotifications.NotificationRule.TagsEntry\x12\x0c\n\x04name\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x15\x43odeStarNotifications\x12R\n\x11notification_rule\x18\x01 \x03(\x0b\x32\x37.oak9.tython.aws.codestarnotifications.NotificationRuleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codestarnotifications_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFICATIONRULE_TAGSENTRY._options = None
  _NOTIFICATIONRULE_TAGSENTRY._serialized_options = b'8\001'
  _NOTIFICATIONRULETARGET._serialized_start=99
  _NOTIFICATIONRULETARGET._serialized_end=225
  _NOTIFICATIONRULE._serialized_start=228
  _NOTIFICATIONRULE._serialized_end=602
  _NOTIFICATIONRULE_TAGSENTRY._serialized_start=559
  _NOTIFICATIONRULE_TAGSENTRY._serialized_end=602
  _CODESTARNOTIFICATIONS._serialized_start=604
  _CODESTARNOTIFICATIONS._serialized_end=711
# @@protoc_insertion_point(module_scope)
