# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_iap.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_iap.proto\x12\x13oak9.tython.gcp.iap\x1a\x13shared/shared.proto\"a\n\'IapAppEngineServiceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x94\x02\n\x1dIapAppEngineServiceIamBinding\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\x12O\n\tcondition\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.iap.IapAppEngineServiceIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n&IapAppEngineServiceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x91\x02\n\x1cIapAppEngineServiceIamMember\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\x12N\n\tcondition\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.iap.IapAppEngineServiceIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x01\n\x1cIapAppEngineServiceIamPolicy\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0f\n\x07service\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"a\n\'IapAppEngineVersionIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa8\x02\n\x1dIapAppEngineVersionIamBinding\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\x12\x12\n\nversion_id\x18\x08 \x01(\t\x12O\n\tcondition\x18\t \x01(\x0b\x32<.oak9.tython.gcp.iap.IapAppEngineVersionIamBindingXCondition\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n&IapAppEngineVersionIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa5\x02\n\x1cIapAppEngineVersionIamMember\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\x12\x12\n\nversion_id\x18\x08 \x01(\t\x12N\n\tcondition\x18\t \x01(\x0b\x32;.oak9.tython.gcp.iap.IapAppEngineVersionIamMemberXCondition\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x01\n\x1cIapAppEngineVersionIamPolicy\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0f\n\x07service\x18\x06 \x01(\t\x12\x12\n\nversion_id\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"3\n\x11IapBrandXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xf5\x01\n\x08IapBrand\x12\x19\n\x11\x61pplication_title\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11org_internal_only\x18\x04 \x01(\x08\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x15\n\rsupport_email\x18\x06 \x01(\t\x12\x38\n\x08timeouts\x18\x07 \x01(\x0b\x32&.oak9.tython.gcp.iap.IapBrandXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"4\n\x12IapClientXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xd3\x01\n\tIapClient\x12\r\n\x05\x62rand\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0e\n\x06secret\x18\x05 \x01(\t\x12\x39\n\x08timeouts\x18\x06 \x01(\x0b\x32\'.oak9.tython.gcp.iap.IapClientXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n\x1dIapTunnelIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xdf\x01\n\x13IapTunnelIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x45\n\tcondition\x18\x06 \x01(\x0b\x32\x32.oak9.tython.gcp.iap.IapTunnelIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"V\n\x1cIapTunnelIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xdc\x01\n\x12IapTunnelIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x44\n\tcondition\x18\x06 \x01(\x0b\x32\x31.oak9.tython.gcp.iap.IapTunnelIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8d\x01\n\x12IapTunnelIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n%IapTunnelInstanceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8f\x02\n\x1bIapTunnelInstanceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12M\n\tcondition\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.iap.IapTunnelInstanceIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$IapTunnelInstanceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8c\x02\n\x1aIapTunnelInstanceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12L\n\tcondition\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.iap.IapTunnelInstanceIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb5\x01\n\x1aIapTunnelInstanceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04zone\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"b\n(IapWebBackendServiceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x92\x02\n\x1eIapWebBackendServiceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x1b\n\x13web_backend_service\x18\x06 \x01(\t\x12P\n\tcondition\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.iap.IapWebBackendServiceIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"a\n\'IapWebBackendServiceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8f\x02\n\x1dIapWebBackendServiceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x1b\n\x13web_backend_service\x18\x06 \x01(\t\x12O\n\tcondition\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.iap.IapWebBackendServiceIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb5\x01\n\x1dIapWebBackendServiceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x1b\n\x13web_backend_service\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"T\n\x1aIapWebIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xd9\x01\n\x10IapWebIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x42\n\tcondition\x18\x06 \x01(\x0b\x32/.oak9.tython.gcp.iap.IapWebIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"S\n\x19IapWebIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xd6\x01\n\x0fIapWebIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x41\n\tcondition\x18\x06 \x01(\x0b\x32..oak9.tython.gcp.iap.IapWebIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x01\n\x0fIapWebIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"a\n\'IapWebTypeAppEngineIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x83\x02\n\x1dIapWebTypeAppEngineIamBinding\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12O\n\tcondition\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.iap.IapWebTypeAppEngineIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n&IapWebTypeAppEngineIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x80\x02\n\x1cIapWebTypeAppEngineIamMember\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12N\n\tcondition\x18\x07 \x01(\x0b\x32;.oak9.tython.gcp.iap.IapWebTypeAppEngineIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa7\x01\n\x1cIapWebTypeAppEngineIamPolicy\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n%IapWebTypeComputeIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xef\x01\n\x1bIapWebTypeComputeIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12M\n\tcondition\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.iap.IapWebTypeComputeIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$IapWebTypeComputeIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xec\x01\n\x1aIapWebTypeComputeIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12L\n\tcondition\x18\x06 \x01(\x0b\x32\x39.oak9.tython.gcp.iap.IapWebTypeComputeIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x01\n\x1aIapWebTypeComputeIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_iap_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IAPAPPENGINESERVICEIAMBINDINGXCONDITION._serialized_start=63
  _IAPAPPENGINESERVICEIAMBINDINGXCONDITION._serialized_end=160
  _IAPAPPENGINESERVICEIAMBINDING._serialized_start=163
  _IAPAPPENGINESERVICEIAMBINDING._serialized_end=439
  _IAPAPPENGINESERVICEIAMMEMBERXCONDITION._serialized_start=441
  _IAPAPPENGINESERVICEIAMMEMBERXCONDITION._serialized_end=537
  _IAPAPPENGINESERVICEIAMMEMBER._serialized_start=540
  _IAPAPPENGINESERVICEIAMMEMBER._serialized_end=813
  _IAPAPPENGINESERVICEIAMPOLICY._serialized_start=816
  _IAPAPPENGINESERVICEIAMPOLICY._serialized_end=1000
  _IAPAPPENGINEVERSIONIAMBINDINGXCONDITION._serialized_start=1002
  _IAPAPPENGINEVERSIONIAMBINDINGXCONDITION._serialized_end=1099
  _IAPAPPENGINEVERSIONIAMBINDING._serialized_start=1102
  _IAPAPPENGINEVERSIONIAMBINDING._serialized_end=1398
  _IAPAPPENGINEVERSIONIAMMEMBERXCONDITION._serialized_start=1400
  _IAPAPPENGINEVERSIONIAMMEMBERXCONDITION._serialized_end=1496
  _IAPAPPENGINEVERSIONIAMMEMBER._serialized_start=1499
  _IAPAPPENGINEVERSIONIAMMEMBER._serialized_end=1792
  _IAPAPPENGINEVERSIONIAMPOLICY._serialized_start=1795
  _IAPAPPENGINEVERSIONIAMPOLICY._serialized_end=1999
  _IAPBRANDXTIMEOUTS._serialized_start=2001
  _IAPBRANDXTIMEOUTS._serialized_end=2052
  _IAPBRAND._serialized_start=2055
  _IAPBRAND._serialized_end=2300
  _IAPCLIENTXTIMEOUTS._serialized_start=2302
  _IAPCLIENTXTIMEOUTS._serialized_end=2354
  _IAPCLIENT._serialized_start=2357
  _IAPCLIENT._serialized_end=2568
  _IAPTUNNELIAMBINDINGXCONDITION._serialized_start=2570
  _IAPTUNNELIAMBINDINGXCONDITION._serialized_end=2657
  _IAPTUNNELIAMBINDING._serialized_start=2660
  _IAPTUNNELIAMBINDING._serialized_end=2883
  _IAPTUNNELIAMMEMBERXCONDITION._serialized_start=2885
  _IAPTUNNELIAMMEMBERXCONDITION._serialized_end=2971
  _IAPTUNNELIAMMEMBER._serialized_start=2974
  _IAPTUNNELIAMMEMBER._serialized_end=3194
  _IAPTUNNELIAMPOLICY._serialized_start=3197
  _IAPTUNNELIAMPOLICY._serialized_end=3338
  _IAPTUNNELINSTANCEIAMBINDINGXCONDITION._serialized_start=3340
  _IAPTUNNELINSTANCEIAMBINDINGXCONDITION._serialized_end=3435
  _IAPTUNNELINSTANCEIAMBINDING._serialized_start=3438
  _IAPTUNNELINSTANCEIAMBINDING._serialized_end=3709
  _IAPTUNNELINSTANCEIAMMEMBERXCONDITION._serialized_start=3711
  _IAPTUNNELINSTANCEIAMMEMBERXCONDITION._serialized_end=3805
  _IAPTUNNELINSTANCEIAMMEMBER._serialized_start=3808
  _IAPTUNNELINSTANCEIAMMEMBER._serialized_end=4076
  _IAPTUNNELINSTANCEIAMPOLICY._serialized_start=4079
  _IAPTUNNELINSTANCEIAMPOLICY._serialized_end=4260
  _IAPWEBBACKENDSERVICEIAMBINDINGXCONDITION._serialized_start=4262
  _IAPWEBBACKENDSERVICEIAMBINDINGXCONDITION._serialized_end=4360
  _IAPWEBBACKENDSERVICEIAMBINDING._serialized_start=4363
  _IAPWEBBACKENDSERVICEIAMBINDING._serialized_end=4637
  _IAPWEBBACKENDSERVICEIAMMEMBERXCONDITION._serialized_start=4639
  _IAPWEBBACKENDSERVICEIAMMEMBERXCONDITION._serialized_end=4736
  _IAPWEBBACKENDSERVICEIAMMEMBER._serialized_start=4739
  _IAPWEBBACKENDSERVICEIAMMEMBER._serialized_end=5010
  _IAPWEBBACKENDSERVICEIAMPOLICY._serialized_start=5013
  _IAPWEBBACKENDSERVICEIAMPOLICY._serialized_end=5194
  _IAPWEBIAMBINDINGXCONDITION._serialized_start=5196
  _IAPWEBIAMBINDINGXCONDITION._serialized_end=5280
  _IAPWEBIAMBINDING._serialized_start=5283
  _IAPWEBIAMBINDING._serialized_end=5500
  _IAPWEBIAMMEMBERXCONDITION._serialized_start=5502
  _IAPWEBIAMMEMBERXCONDITION._serialized_end=5585
  _IAPWEBIAMMEMBER._serialized_start=5588
  _IAPWEBIAMMEMBER._serialized_end=5802
  _IAPWEBIAMPOLICY._serialized_start=5805
  _IAPWEBIAMPOLICY._serialized_end=5943
  _IAPWEBTYPEAPPENGINEIAMBINDINGXCONDITION._serialized_start=5945
  _IAPWEBTYPEAPPENGINEIAMBINDINGXCONDITION._serialized_end=6042
  _IAPWEBTYPEAPPENGINEIAMBINDING._serialized_start=6045
  _IAPWEBTYPEAPPENGINEIAMBINDING._serialized_end=6304
  _IAPWEBTYPEAPPENGINEIAMMEMBERXCONDITION._serialized_start=6306
  _IAPWEBTYPEAPPENGINEIAMMEMBERXCONDITION._serialized_end=6402
  _IAPWEBTYPEAPPENGINEIAMMEMBER._serialized_start=6405
  _IAPWEBTYPEAPPENGINEIAMMEMBER._serialized_end=6661
  _IAPWEBTYPEAPPENGINEIAMPOLICY._serialized_start=6664
  _IAPWEBTYPEAPPENGINEIAMPOLICY._serialized_end=6831
  _IAPWEBTYPECOMPUTEIAMBINDINGXCONDITION._serialized_start=6833
  _IAPWEBTYPECOMPUTEIAMBINDINGXCONDITION._serialized_end=6928
  _IAPWEBTYPECOMPUTEIAMBINDING._serialized_start=6931
  _IAPWEBTYPECOMPUTEIAMBINDING._serialized_end=7170
  _IAPWEBTYPECOMPUTEIAMMEMBERXCONDITION._serialized_start=7172
  _IAPWEBTYPECOMPUTEIAMMEMBERXCONDITION._serialized_end=7266
  _IAPWEBTYPECOMPUTEIAMMEMBER._serialized_start=7269
  _IAPWEBTYPECOMPUTEIAMMEMBER._serialized_end=7505
  _IAPWEBTYPECOMPUTEIAMPOLICY._serialized_start=7508
  _IAPWEBTYPECOMPUTEIAMPOLICY._serialized_end=7657
# @@protoc_insertion_point(module_scope)
