"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApplicationTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ApplicationTags = ApplicationTags

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationTags]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[global___ApplicationTags] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Application = Application

@typing_extensions.final
class AppConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROFILE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STRATEGY_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    HOSTED_CONFIGURATION_VERSION_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Application]: ...
    @property
    def configuration_profile(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationProfile]: ...
    @property
    def deployment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Deployment]: ...
    @property
    def deployment_strategy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentStrategy]: ...
    @property
    def environment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Environment]: ...
    @property
    def hosted_configuration_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostedConfigurationVersion]: ...
    def __init__(
        self,
        *,
        application: collections.abc.Iterable[global___Application] | None = ...,
        configuration_profile: collections.abc.Iterable[global___ConfigurationProfile] | None = ...,
        deployment: collections.abc.Iterable[global___Deployment] | None = ...,
        deployment_strategy: collections.abc.Iterable[global___DeploymentStrategy] | None = ...,
        environment: collections.abc.Iterable[global___Environment] | None = ...,
        hosted_configuration_version: collections.abc.Iterable[global___HostedConfigurationVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "configuration_profile", b"configuration_profile", "deployment", b"deployment", "deployment_strategy", b"deployment_strategy", "environment", b"environment", "hosted_configuration_version", b"hosted_configuration_version"]) -> None: ...

global___AppConfig = AppConfig

@typing_extensions.final
class ConfigurationProfileValidators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "resource_info", b"resource_info"]) -> None: ...

global___ConfigurationProfileValidators = ConfigurationProfileValidators

@typing_extensions.final
class ConfigurationProfileTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ConfigurationProfileTags = ConfigurationProfileTags

@typing_extensions.final
class ConfigurationProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_URI_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    RETRIEVAL_ROLE_ARN_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location_uri: builtins.str
    description: builtins.str
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationProfileValidators]: ...
    retrieval_role_arn: builtins.str
    application_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationProfileTags]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location_uri: builtins.str = ...,
        description: builtins.str = ...,
        validators: collections.abc.Iterable[global___ConfigurationProfileValidators] | None = ...,
        retrieval_role_arn: builtins.str = ...,
        application_id: builtins.str = ...,
        tags: collections.abc.Iterable[global___ConfigurationProfileTags] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "description", b"description", "location_uri", b"location_uri", "name", b"name", "resource_info", b"resource_info", "retrieval_role_arn", b"retrieval_role_arn", "tags", b"tags", "validators", b"validators"]) -> None: ...

global___ConfigurationProfile = ConfigurationProfile

@typing_extensions.final
class DeploymentTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentTags = DeploymentTags

@typing_extensions.final
class Deployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STRATEGY_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROFILE_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONFIGURATION_VERSION_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    deployment_strategy_id: builtins.str
    configuration_profile_id: builtins.str
    environment_id: builtins.str
    description: builtins.str
    configuration_version: builtins.str
    application_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentTags]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deployment_strategy_id: builtins.str = ...,
        configuration_profile_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        description: builtins.str = ...,
        configuration_version: builtins.str = ...,
        application_id: builtins.str = ...,
        tags: collections.abc.Iterable[global___DeploymentTags] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "configuration_profile_id", b"configuration_profile_id", "configuration_version", b"configuration_version", "deployment_strategy_id", b"deployment_strategy_id", "description", b"description", "environment_id", b"environment_id", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Deployment = Deployment

@typing_extensions.final
class DeploymentStrategyTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentStrategyTags = DeploymentStrategyTags

@typing_extensions.final
class DeploymentStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPLICATE_TO_FIELD_NUMBER: builtins.int
    GROWTH_TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEPLOYMENT_DURATION_IN_MINUTES_FIELD_NUMBER: builtins.int
    GROWTH_FACTOR_FIELD_NUMBER: builtins.int
    FINAL_BAKE_TIME_IN_MINUTES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    replicate_to: builtins.str
    growth_type: builtins.str
    description: builtins.str
    deployment_duration_in_minutes: builtins.float
    growth_factor: builtins.float
    final_bake_time_in_minutes: builtins.float
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentStrategyTags]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        replicate_to: builtins.str = ...,
        growth_type: builtins.str = ...,
        description: builtins.str = ...,
        deployment_duration_in_minutes: builtins.float = ...,
        growth_factor: builtins.float = ...,
        final_bake_time_in_minutes: builtins.float = ...,
        tags: collections.abc.Iterable[global___DeploymentStrategyTags] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_duration_in_minutes", b"deployment_duration_in_minutes", "description", b"description", "final_bake_time_in_minutes", b"final_bake_time_in_minutes", "growth_factor", b"growth_factor", "growth_type", b"growth_type", "name", b"name", "replicate_to", b"replicate_to", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DeploymentStrategy = DeploymentStrategy

@typing_extensions.final
class EnvironmentMonitors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_ARN_FIELD_NUMBER: builtins.int
    ALARM_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alarm_arn: builtins.str
    alarm_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_arn: builtins.str = ...,
        alarm_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_arn", b"alarm_arn", "alarm_role_arn", b"alarm_role_arn", "resource_info", b"resource_info"]) -> None: ...

global___EnvironmentMonitors = EnvironmentMonitors

@typing_extensions.final
class EnvironmentTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___EnvironmentTags = EnvironmentTags

@typing_extensions.final
class Environment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MONITORS_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def monitors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentMonitors]: ...
    application_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentTags]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        monitors: collections.abc.Iterable[global___EnvironmentMonitors] | None = ...,
        application_id: builtins.str = ...,
        tags: collections.abc.Iterable[global___EnvironmentTags] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "description", b"description", "monitors", b"monitors", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Environment = Environment

@typing_extensions.final
class HostedConfigurationVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROFILE_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    LATEST_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    configuration_profile_id: builtins.str
    description: builtins.str
    content_type: builtins.str
    latest_version_number: builtins.float
    content: builtins.str
    application_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        configuration_profile_id: builtins.str = ...,
        description: builtins.str = ...,
        content_type: builtins.str = ...,
        latest_version_number: builtins.float = ...,
        content: builtins.str = ...,
        application_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "configuration_profile_id", b"configuration_profile_id", "content", b"content", "content_type", b"content_type", "description", b"description", "latest_version_number", b"latest_version_number", "resource_info", b"resource_info"]) -> None: ...

global___HostedConfigurationVersion = HostedConfigurationVersion
