# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticsearch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_elasticsearch.proto\x12\x1doak9.tython.aws.elasticsearch\x1a\x13shared/shared.proto\"\xa3\x01\n\x17\x44omainMasterUserOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fmaster_user_arn\x18\x02 \x01(\t\x12\x18\n\x10master_user_name\x18\x03 \x01(\t\x12\x1c\n\x14master_user_password\x18\x04 \x01(\t\"\xeb\x01\n\"DomainAdvancedSecurityOptionsInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12&\n\x1einternal_user_database_enabled\x18\x03 \x01(\x08\x12S\n\x13master_user_options\x18\x04 \x01(\x0b\x32\x36.oak9.tython.aws.elasticsearch.DomainMasterUserOptions\"\xa2\x01\n\x14\x44omainCognitoOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x18\n\x10identity_pool_id\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x05 \x01(\t\"\x8b\x01\n\x1b\x44omainDomainEndpointOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65nforce_http_s\x18\x02 \x01(\x08\x12\x1b\n\x13tls_security_policy\x18\x03 \x01(\t\"\x98\x01\n\x10\x44omainEBSOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65\x62s_enabled\x18\x02 \x01(\x08\x12\x0c\n\x04iops\x18\x03 \x01(\x05\x12\x13\n\x0bvolume_size\x18\x04 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x05 \x01(\t\"u\n\x19\x44omainZoneAwarenessConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x61vailability_zone_count\x18\x02 \x01(\x05\"\xe4\x02\n DomainElasticsearchClusterConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65\x64icated_master_count\x18\x02 \x01(\x05\x12 \n\x18\x64\x65\x64icated_master_enabled\x18\x03 \x01(\x08\x12\x1d\n\x15\x64\x65\x64icated_master_type\x18\x04 \x01(\t\x12\x16\n\x0einstance_count\x18\x05 \x01(\x05\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12W\n\x15zone_awareness_config\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.elasticsearch.DomainZoneAwarenessConfig\x12\x1e\n\x16zone_awareness_enabled\x18\x08 \x01(\x08\"}\n\x1d\x44omainEncryptionAtRestOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x12\n\nkms_key_id\x18\x03 \x01(\t\"m\n!DomainNodeToNodeEncryptionOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"w\n\x15\x44omainSnapshotOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1d\x61utomated_snapshot_start_hour\x18\x02 \x01(\x05\"{\n\x10\x44omainVPCOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\"\xf0\n\n\x06\x44omain\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0f\x61\x63\x63\x65ss_policies\x18\x02 \x03(\x0b\x32\x39.oak9.tython.aws.elasticsearch.Domain.AccessPoliciesEntry\x12T\n\x10\x61\x64vanced_options\x18\x03 \x03(\x0b\x32:.oak9.tython.aws.elasticsearch.Domain.AdvancedOptionsEntry\x12\x64\n\x19\x61\x64vanced_security_options\x18\x04 \x01(\x0b\x32\x41.oak9.tython.aws.elasticsearch.DomainAdvancedSecurityOptionsInput\x12L\n\x0f\x63ognito_options\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.elasticsearch.DomainCognitoOptions\x12[\n\x17\x64omain_endpoint_options\x18\x06 \x01(\x0b\x32:.oak9.tython.aws.elasticsearch.DomainDomainEndpointOptions\x12\x13\n\x0b\x64omain_name\x18\x07 \x01(\t\x12\x44\n\x0b\x65\x62s_options\x18\x08 \x01(\x0b\x32/.oak9.tython.aws.elasticsearch.DomainEBSOptions\x12\x65\n\x1c\x65lasticsearch_cluster_config\x18\t \x01(\x0b\x32?.oak9.tython.aws.elasticsearch.DomainElasticsearchClusterConfig\x12\x1d\n\x15\x65lasticsearch_version\x18\n \x01(\t\x12`\n\x1a\x65ncryption_at_rest_options\x18\x0b \x01(\x0b\x32<.oak9.tython.aws.elasticsearch.DomainEncryptionAtRestOptions\x12i\n\x1fnode_to_node_encryption_options\x18\x0c \x01(\x0b\x32@.oak9.tython.aws.elasticsearch.DomainNodeToNodeEncryptionOptions\x12N\n\x10snapshot_options\x18\r \x01(\x0b\x32\x34.oak9.tython.aws.elasticsearch.DomainSnapshotOptions\x12=\n\x04tags\x18\x0e \x03(\x0b\x32/.oak9.tython.aws.elasticsearch.Domain.TagsEntry\x12\x44\n\x0bvpc_options\x18\x0f \x01(\x0b\x32/.oak9.tython.aws.elasticsearch.DomainVPCOptions\x12S\n\x16log_publishing_options\x18\x10 \x01(\x0b\x32\x33.oak9.tython.aws.elasticsearch.LogPublishingOptions\x1a\x35\n\x13\x41\x63\x63\x65ssPoliciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14\x41\x64vancedOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\rElasticsearch\x12\x35\n\x06\x64omain\x18\x01 \x01(\x0b\x32%.oak9.tython.aws.elasticsearch.Domain\"_\n\x14LogPublishingOptions\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12$\n\x1c\x63loudwatchlogs_log_group_arn\x18\x02 \x01(\t\x12\x10\n\x08log_type\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticsearch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAIN_ACCESSPOLICIESENTRY._options = None
  _DOMAIN_ACCESSPOLICIESENTRY._serialized_options = b'8\001'
  _DOMAIN_ADVANCEDOPTIONSENTRY._options = None
  _DOMAIN_ADVANCEDOPTIONSENTRY._serialized_options = b'8\001'
  _DOMAIN_TAGSENTRY._options = None
  _DOMAIN_TAGSENTRY._serialized_options = b'8\001'
  _DOMAINMASTERUSEROPTIONS._serialized_start=84
  _DOMAINMASTERUSEROPTIONS._serialized_end=247
  _DOMAINADVANCEDSECURITYOPTIONSINPUT._serialized_start=250
  _DOMAINADVANCEDSECURITYOPTIONSINPUT._serialized_end=485
  _DOMAINCOGNITOOPTIONS._serialized_start=488
  _DOMAINCOGNITOOPTIONS._serialized_end=650
  _DOMAINDOMAINENDPOINTOPTIONS._serialized_start=653
  _DOMAINDOMAINENDPOINTOPTIONS._serialized_end=792
  _DOMAINEBSOPTIONS._serialized_start=795
  _DOMAINEBSOPTIONS._serialized_end=947
  _DOMAINZONEAWARENESSCONFIG._serialized_start=949
  _DOMAINZONEAWARENESSCONFIG._serialized_end=1066
  _DOMAINELASTICSEARCHCLUSTERCONFIG._serialized_start=1069
  _DOMAINELASTICSEARCHCLUSTERCONFIG._serialized_end=1425
  _DOMAINENCRYPTIONATRESTOPTIONS._serialized_start=1427
  _DOMAINENCRYPTIONATRESTOPTIONS._serialized_end=1552
  _DOMAINNODETONODEENCRYPTIONOPTIONS._serialized_start=1554
  _DOMAINNODETONODEENCRYPTIONOPTIONS._serialized_end=1663
  _DOMAINSNAPSHOTOPTIONS._serialized_start=1665
  _DOMAINSNAPSHOTOPTIONS._serialized_end=1784
  _DOMAINVPCOPTIONS._serialized_start=1786
  _DOMAINVPCOPTIONS._serialized_end=1909
  _DOMAIN._serialized_start=1912
  _DOMAIN._serialized_end=3304
  _DOMAIN_ACCESSPOLICIESENTRY._serialized_start=3150
  _DOMAIN_ACCESSPOLICIESENTRY._serialized_end=3203
  _DOMAIN_ADVANCEDOPTIONSENTRY._serialized_start=3205
  _DOMAIN_ADVANCEDOPTIONSENTRY._serialized_end=3259
  _DOMAIN_TAGSENTRY._serialized_start=3261
  _DOMAIN_TAGSENTRY._serialized_end=3304
  _ELASTICSEARCH._serialized_start=3306
  _ELASTICSEARCH._serialized_end=3376
  _LOGPUBLISHINGOPTIONS._serialized_start=3378
  _LOGPUBLISHINGOPTIONS._serialized_end=3473
# @@protoc_insertion_point(module_scope)
