"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApiCache(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TRANSIT_ENCRYPTION_ENABLED_FIELD_NUMBER: builtins.int
    AT_REST_ENCRYPTION_ENABLED_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    API_CACHING_BEHAVIOR_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    transit_encryption_enabled: builtins.bool
    at_rest_encryption_enabled: builtins.bool
    api_id: builtins.str
    api_caching_behavior: builtins.str
    ttl: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        transit_encryption_enabled: builtins.bool = ...,
        at_rest_encryption_enabled: builtins.bool = ...,
        api_id: builtins.str = ...,
        api_caching_behavior: builtins.str = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_caching_behavior", b"api_caching_behavior", "api_id", b"api_id", "at_rest_encryption_enabled", b"at_rest_encryption_enabled", "resource_info", b"resource_info", "transit_encryption_enabled", b"transit_encryption_enabled", "ttl", b"ttl", "type", b"type"]) -> None: ...

global___ApiCache = ApiCache

@typing_extensions.final
class AppSync(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_CACHE_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    DATA_SOURCE_FIELD_NUMBER: builtins.int
    FUNCTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    GRAPH_Q_L_API_FIELD_NUMBER: builtins.int
    GRAPH_Q_L_SCHEMA_FIELD_NUMBER: builtins.int
    RESOLVER_FIELD_NUMBER: builtins.int
    GRAPH_Q_L_API_ADDITIONAL_AUTHENTICATION_PROVIDER_FIELD_NUMBER: builtins.int
    @property
    def api_cache(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiCache]: ...
    @property
    def api_key(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiKey]: ...
    @property
    def data_source(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataSource]: ...
    @property
    def function_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FunctionConfiguration]: ...
    @property
    def graph_q_l_api(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GraphQLApi]: ...
    @property
    def graph_q_l_schema(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GraphQLSchema]: ...
    @property
    def resolver(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Resolver]: ...
    @property
    def graph_q_l_api_additional_authentication_provider(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GraphQLApiAdditionalAuthenticationProvider]: ...
    def __init__(
        self,
        *,
        api_cache: collections.abc.Iterable[global___ApiCache] | None = ...,
        api_key: collections.abc.Iterable[global___ApiKey] | None = ...,
        data_source: collections.abc.Iterable[global___DataSource] | None = ...,
        function_configuration: collections.abc.Iterable[global___FunctionConfiguration] | None = ...,
        graph_q_l_api: collections.abc.Iterable[global___GraphQLApi] | None = ...,
        graph_q_l_schema: collections.abc.Iterable[global___GraphQLSchema] | None = ...,
        resolver: collections.abc.Iterable[global___Resolver] | None = ...,
        graph_q_l_api_additional_authentication_provider: collections.abc.Iterable[global___GraphQLApiAdditionalAuthenticationProvider] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_cache", b"api_cache", "api_key", b"api_key", "data_source", b"data_source", "function_configuration", b"function_configuration", "graph_q_l_api", b"graph_q_l_api", "graph_q_l_api_additional_authentication_provider", b"graph_q_l_api_additional_authentication_provider", "graph_q_l_schema", b"graph_q_l_schema", "resolver", b"resolver"]) -> None: ...

global___AppSync = AppSync

@typing_extensions.final
class ApiKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRES_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    expires: builtins.float
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        expires: builtins.float = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "description", b"description", "expires", b"expires", "resource_info", b"resource_info"]) -> None: ...

global___ApiKey = ApiKey

@typing_extensions.final
class DataSourceAwsIamConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SIGNING_REGION_FIELD_NUMBER: builtins.int
    SIGNING_SERVICE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    signing_region: builtins.str
    signing_service_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        signing_region: builtins.str = ...,
        signing_service_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "signing_region", b"signing_region", "signing_service_name", b"signing_service_name"]) -> None: ...

global___DataSourceAwsIamConfig = DataSourceAwsIamConfig

@typing_extensions.final
class DataSourceAuthorizationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_IAM_CONFIG_FIELD_NUMBER: builtins.int
    AUTHORIZATION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def aws_iam_config(self) -> global___DataSourceAwsIamConfig: ...
    authorization_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_iam_config: global___DataSourceAwsIamConfig | None = ...,
        authorization_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_iam_config", b"aws_iam_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization_type", b"authorization_type", "aws_iam_config", b"aws_iam_config", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceAuthorizationConfig = DataSourceAuthorizationConfig

@typing_extensions.final
class DataSourceHttpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    AUTHORIZATION_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    endpoint: builtins.str
    @property
    def authorization_config(self) -> global___DataSourceAuthorizationConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint: builtins.str = ...,
        authorization_config: global___DataSourceAuthorizationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization_config", b"authorization_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization_config", b"authorization_config", "endpoint", b"endpoint", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceHttpConfig = DataSourceHttpConfig

@typing_extensions.final
class DataSourceRdsHttpEndpointConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    DB_CLUSTER_IDENTIFIER_FIELD_NUMBER: builtins.int
    AWS_SECRET_STORE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    aws_region: builtins.str
    schema: builtins.str
    database_name: builtins.str
    db_cluster_identifier: builtins.str
    aws_secret_store_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_region: builtins.str = ...,
        schema: builtins.str = ...,
        database_name: builtins.str = ...,
        db_cluster_identifier: builtins.str = ...,
        aws_secret_store_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_region", b"aws_region", "aws_secret_store_arn", b"aws_secret_store_arn", "database_name", b"database_name", "db_cluster_identifier", b"db_cluster_identifier", "resource_info", b"resource_info", "schema", b"schema"]) -> None: ...

global___DataSourceRdsHttpEndpointConfig = DataSourceRdsHttpEndpointConfig

@typing_extensions.final
class DataSourceRelationalDatabaseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RDS_HTTP_ENDPOINT_CONFIG_FIELD_NUMBER: builtins.int
    RELATIONAL_DATABASE_SOURCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def rds_http_endpoint_config(self) -> global___DataSourceRdsHttpEndpointConfig: ...
    relational_database_source_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rds_http_endpoint_config: global___DataSourceRdsHttpEndpointConfig | None = ...,
        relational_database_source_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rds_http_endpoint_config", b"rds_http_endpoint_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["rds_http_endpoint_config", b"rds_http_endpoint_config", "relational_database_source_type", b"relational_database_source_type", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceRelationalDatabaseConfig = DataSourceRelationalDatabaseConfig

@typing_extensions.final
class DataSourceLambdaConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LAMBDA_FUNCTION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    lambda_function_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        lambda_function_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lambda_function_arn", b"lambda_function_arn", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceLambdaConfig = DataSourceLambdaConfig

@typing_extensions.final
class DataSourceDeltaSyncConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BASE_TABLE_TTL_FIELD_NUMBER: builtins.int
    DELTA_SYNC_TABLE_TTL_FIELD_NUMBER: builtins.int
    DELTA_SYNC_TABLE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    base_table_ttl: builtins.str
    delta_sync_table_ttl: builtins.str
    delta_sync_table_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        base_table_ttl: builtins.str = ...,
        delta_sync_table_ttl: builtins.str = ...,
        delta_sync_table_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_table_ttl", b"base_table_ttl", "delta_sync_table_name", b"delta_sync_table_name", "delta_sync_table_ttl", b"delta_sync_table_ttl", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceDeltaSyncConfig = DataSourceDeltaSyncConfig

@typing_extensions.final
class DataSourceDynamoDBConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    VERSIONED_FIELD_NUMBER: builtins.int
    DELTA_SYNC_CONFIG_FIELD_NUMBER: builtins.int
    USE_CALLER_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    table_name: builtins.str
    aws_region: builtins.str
    versioned: builtins.bool
    @property
    def delta_sync_config(self) -> global___DataSourceDeltaSyncConfig: ...
    use_caller_credentials: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        table_name: builtins.str = ...,
        aws_region: builtins.str = ...,
        versioned: builtins.bool = ...,
        delta_sync_config: global___DataSourceDeltaSyncConfig | None = ...,
        use_caller_credentials: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delta_sync_config", b"delta_sync_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_region", b"aws_region", "delta_sync_config", b"delta_sync_config", "resource_info", b"resource_info", "table_name", b"table_name", "use_caller_credentials", b"use_caller_credentials", "versioned", b"versioned"]) -> None: ...

global___DataSourceDynamoDBConfig = DataSourceDynamoDBConfig

@typing_extensions.final
class DataSourceElasticsearchConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    aws_region: builtins.str
    endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_region: builtins.str = ...,
        endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_region", b"aws_region", "endpoint", b"endpoint", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceElasticsearchConfig = DataSourceElasticsearchConfig

@typing_extensions.final
class DataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    HTTP_CONFIG_FIELD_NUMBER: builtins.int
    RELATIONAL_DATABASE_CONFIG_FIELD_NUMBER: builtins.int
    LAMBDA_CONFIG_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DYNAMO_DB_CONFIG_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    description: builtins.str
    service_role_arn: builtins.str
    @property
    def http_config(self) -> global___DataSourceHttpConfig: ...
    @property
    def relational_database_config(self) -> global___DataSourceRelationalDatabaseConfig: ...
    @property
    def lambda_config(self) -> global___DataSourceLambdaConfig: ...
    api_id: builtins.str
    name: builtins.str
    @property
    def dynamo_db_config(self) -> global___DataSourceDynamoDBConfig: ...
    @property
    def elasticsearch_config(self) -> global___DataSourceElasticsearchConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        description: builtins.str = ...,
        service_role_arn: builtins.str = ...,
        http_config: global___DataSourceHttpConfig | None = ...,
        relational_database_config: global___DataSourceRelationalDatabaseConfig | None = ...,
        lambda_config: global___DataSourceLambdaConfig | None = ...,
        api_id: builtins.str = ...,
        name: builtins.str = ...,
        dynamo_db_config: global___DataSourceDynamoDBConfig | None = ...,
        elasticsearch_config: global___DataSourceElasticsearchConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamo_db_config", b"dynamo_db_config", "elasticsearch_config", b"elasticsearch_config", "http_config", b"http_config", "lambda_config", b"lambda_config", "relational_database_config", b"relational_database_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "description", b"description", "dynamo_db_config", b"dynamo_db_config", "elasticsearch_config", b"elasticsearch_config", "http_config", b"http_config", "lambda_config", b"lambda_config", "name", b"name", "relational_database_config", b"relational_database_config", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "type", b"type"]) -> None: ...

global___DataSource = DataSource

@typing_extensions.final
class FunctionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESPONSE_MAPPING_TEMPLATE_S3_LOCATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DATA_SOURCE_NAME_FIELD_NUMBER: builtins.int
    REQUEST_MAPPING_TEMPLATE_FIELD_NUMBER: builtins.int
    RESPONSE_MAPPING_TEMPLATE_FIELD_NUMBER: builtins.int
    FUNCTION_VERSION_FIELD_NUMBER: builtins.int
    REQUEST_MAPPING_TEMPLATE_S3_LOCATION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    response_mapping_template_s3_location: builtins.str
    description: builtins.str
    data_source_name: builtins.str
    request_mapping_template: builtins.str
    response_mapping_template: builtins.str
    function_version: builtins.str
    request_mapping_template_s3_location: builtins.str
    api_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        response_mapping_template_s3_location: builtins.str = ...,
        description: builtins.str = ...,
        data_source_name: builtins.str = ...,
        request_mapping_template: builtins.str = ...,
        response_mapping_template: builtins.str = ...,
        function_version: builtins.str = ...,
        request_mapping_template_s3_location: builtins.str = ...,
        api_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "data_source_name", b"data_source_name", "description", b"description", "function_version", b"function_version", "name", b"name", "request_mapping_template", b"request_mapping_template", "request_mapping_template_s3_location", b"request_mapping_template_s3_location", "resource_info", b"resource_info", "response_mapping_template", b"response_mapping_template", "response_mapping_template_s3_location", b"response_mapping_template_s3_location"]) -> None: ...

global___FunctionConfiguration = FunctionConfiguration

@typing_extensions.final
class GraphQLApiOpenIDConnectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    AUTH_TTL_FIELD_NUMBER: builtins.int
    IAT_TTL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    issuer: builtins.str
    client_id: builtins.str
    auth_ttl: builtins.float
    iat_ttl: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        issuer: builtins.str = ...,
        client_id: builtins.str = ...,
        auth_ttl: builtins.float = ...,
        iat_ttl: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_ttl", b"auth_ttl", "client_id", b"client_id", "iat_ttl", b"iat_ttl", "issuer", b"issuer", "resource_info", b"resource_info"]) -> None: ...

global___GraphQLApiOpenIDConnectConfig = GraphQLApiOpenIDConnectConfig

@typing_extensions.final
class GraphQLApiUserPoolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APP_ID_CLIENT_REGEX_FIELD_NUMBER: builtins.int
    USER_POOL_ID_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    app_id_client_regex: builtins.str
    user_pool_id: builtins.str
    aws_region: builtins.str
    default_action: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        app_id_client_regex: builtins.str = ...,
        user_pool_id: builtins.str = ...,
        aws_region: builtins.str = ...,
        default_action: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id_client_regex", b"app_id_client_regex", "aws_region", b"aws_region", "default_action", b"default_action", "resource_info", b"resource_info", "user_pool_id", b"user_pool_id"]) -> None: ...

global___GraphQLApiUserPoolConfig = GraphQLApiUserPoolConfig

@typing_extensions.final
class GraphQLApiTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___GraphQLApiTags = GraphQLApiTags

@typing_extensions.final
class GraphQLApiLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGS_ROLE_ARN_FIELD_NUMBER: builtins.int
    EXCLUDE_VERBOSE_CONTENT_FIELD_NUMBER: builtins.int
    FIELD_LOG_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cloud_watch_logs_role_arn: builtins.str
    exclude_verbose_content: builtins.bool
    field_log_level: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logs_role_arn: builtins.str = ...,
        exclude_verbose_content: builtins.bool = ...,
        field_log_level: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logs_role_arn", b"cloud_watch_logs_role_arn", "exclude_verbose_content", b"exclude_verbose_content", "field_log_level", b"field_log_level", "resource_info", b"resource_info"]) -> None: ...

global___GraphQLApiLogConfig = GraphQLApiLogConfig

@typing_extensions.final
class GraphQLApiAdditionalAuthenticationProviders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___GraphQLApiAdditionalAuthenticationProviders = GraphQLApiAdditionalAuthenticationProviders

@typing_extensions.final
class GraphQLApi(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OPEN_ID_CONNECT_CONFIG_FIELD_NUMBER: builtins.int
    XRAY_ENABLED_FIELD_NUMBER: builtins.int
    USER_POOL_CONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    ADDITIONAL_AUTHENTICATION_PROVIDERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def open_id_connect_config(self) -> global___GraphQLApiOpenIDConnectConfig: ...
    xray_enabled: builtins.bool
    @property
    def user_pool_config(self) -> global___GraphQLApiUserPoolConfig: ...
    @property
    def tags(self) -> global___GraphQLApiTags: ...
    name: builtins.str
    authentication_type: builtins.str
    @property
    def log_config(self) -> global___GraphQLApiLogConfig: ...
    @property
    def additional_authentication_providers(self) -> global___GraphQLApiAdditionalAuthenticationProviders: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        open_id_connect_config: global___GraphQLApiOpenIDConnectConfig | None = ...,
        xray_enabled: builtins.bool = ...,
        user_pool_config: global___GraphQLApiUserPoolConfig | None = ...,
        tags: global___GraphQLApiTags | None = ...,
        name: builtins.str = ...,
        authentication_type: builtins.str = ...,
        log_config: global___GraphQLApiLogConfig | None = ...,
        additional_authentication_providers: global___GraphQLApiAdditionalAuthenticationProviders | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["additional_authentication_providers", b"additional_authentication_providers", "log_config", b"log_config", "open_id_connect_config", b"open_id_connect_config", "resource_info", b"resource_info", "tags", b"tags", "user_pool_config", b"user_pool_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_authentication_providers", b"additional_authentication_providers", "authentication_type", b"authentication_type", "log_config", b"log_config", "name", b"name", "open_id_connect_config", b"open_id_connect_config", "resource_info", b"resource_info", "tags", b"tags", "user_pool_config", b"user_pool_config", "xray_enabled", b"xray_enabled"]) -> None: ...

global___GraphQLApi = GraphQLApi

@typing_extensions.final
class GraphQLSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEFINITION_FIELD_NUMBER: builtins.int
    DEFINITION_S3_LOCATION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    definition: builtins.str
    definition_s3_location: builtins.str
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        definition: builtins.str = ...,
        definition_s3_location: builtins.str = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "definition", b"definition", "definition_s3_location", b"definition_s3_location", "resource_info", b"resource_info"]) -> None: ...

global___GraphQLSchema = GraphQLSchema

@typing_extensions.final
class ResolverPipelineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FUNCTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def functions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        functions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["functions", b"functions", "resource_info", b"resource_info"]) -> None: ...

global___ResolverPipelineConfig = ResolverPipelineConfig

@typing_extensions.final
class ResolverCachingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHING_KEYS_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def caching_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ttl: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        caching_keys: collections.abc.Iterable[builtins.str] | None = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caching_keys", b"caching_keys", "resource_info", b"resource_info", "ttl", b"ttl"]) -> None: ...

global___ResolverCachingConfig = ResolverCachingConfig

@typing_extensions.final
class ResolverLambdaConflictHandlerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LAMBDA_CONFLICT_HANDLER_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    lambda_conflict_handler_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        lambda_conflict_handler_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lambda_conflict_handler_arn", b"lambda_conflict_handler_arn", "resource_info", b"resource_info"]) -> None: ...

global___ResolverLambdaConflictHandlerConfig = ResolverLambdaConflictHandlerConfig

@typing_extensions.final
class ResolverSyncConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFLICT_HANDLER_FIELD_NUMBER: builtins.int
    CONFLICT_DETECTION_FIELD_NUMBER: builtins.int
    LAMBDA_CONFLICT_HANDLER_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    conflict_handler: builtins.str
    conflict_detection: builtins.str
    @property
    def lambda_conflict_handler_config(self) -> global___ResolverLambdaConflictHandlerConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        conflict_handler: builtins.str = ...,
        conflict_detection: builtins.str = ...,
        lambda_conflict_handler_config: global___ResolverLambdaConflictHandlerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lambda_conflict_handler_config", b"lambda_conflict_handler_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conflict_detection", b"conflict_detection", "conflict_handler", b"conflict_handler", "lambda_conflict_handler_config", b"lambda_conflict_handler_config", "resource_info", b"resource_info"]) -> None: ...

global___ResolverSyncConfig = ResolverSyncConfig

@typing_extensions.final
class Resolver(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESPONSE_MAPPING_TEMPLATE_S3_LOCATION_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    PIPELINE_CONFIG_FIELD_NUMBER: builtins.int
    DATA_SOURCE_NAME_FIELD_NUMBER: builtins.int
    REQUEST_MAPPING_TEMPLATE_FIELD_NUMBER: builtins.int
    RESPONSE_MAPPING_TEMPLATE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    CACHING_CONFIG_FIELD_NUMBER: builtins.int
    SYNC_CONFIG_FIELD_NUMBER: builtins.int
    REQUEST_MAPPING_TEMPLATE_S3_LOCATION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    FIELD_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    response_mapping_template_s3_location: builtins.str
    type_name: builtins.str
    @property
    def pipeline_config(self) -> global___ResolverPipelineConfig: ...
    data_source_name: builtins.str
    request_mapping_template: builtins.str
    response_mapping_template: builtins.str
    kind: builtins.str
    @property
    def caching_config(self) -> global___ResolverCachingConfig: ...
    @property
    def sync_config(self) -> global___ResolverSyncConfig: ...
    request_mapping_template_s3_location: builtins.str
    api_id: builtins.str
    field_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        response_mapping_template_s3_location: builtins.str = ...,
        type_name: builtins.str = ...,
        pipeline_config: global___ResolverPipelineConfig | None = ...,
        data_source_name: builtins.str = ...,
        request_mapping_template: builtins.str = ...,
        response_mapping_template: builtins.str = ...,
        kind: builtins.str = ...,
        caching_config: global___ResolverCachingConfig | None = ...,
        sync_config: global___ResolverSyncConfig | None = ...,
        request_mapping_template_s3_location: builtins.str = ...,
        api_id: builtins.str = ...,
        field_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["caching_config", b"caching_config", "pipeline_config", b"pipeline_config", "resource_info", b"resource_info", "sync_config", b"sync_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "caching_config", b"caching_config", "data_source_name", b"data_source_name", "field_name", b"field_name", "kind", b"kind", "pipeline_config", b"pipeline_config", "request_mapping_template", b"request_mapping_template", "request_mapping_template_s3_location", b"request_mapping_template_s3_location", "resource_info", b"resource_info", "response_mapping_template", b"response_mapping_template", "response_mapping_template_s3_location", b"response_mapping_template_s3_location", "sync_config", b"sync_config", "type_name", b"type_name"]) -> None: ...

global___Resolver = Resolver

@typing_extensions.final
class GraphQLApiCognitoUserPoolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APP_ID_CLIENT_REGEX_FIELD_NUMBER: builtins.int
    USER_POOL_ID_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    app_id_client_regex: builtins.str
    user_pool_id: builtins.str
    aws_region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        app_id_client_regex: builtins.str = ...,
        user_pool_id: builtins.str = ...,
        aws_region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id_client_regex", b"app_id_client_regex", "aws_region", b"aws_region", "resource_info", b"resource_info", "user_pool_id", b"user_pool_id"]) -> None: ...

global___GraphQLApiCognitoUserPoolConfig = GraphQLApiCognitoUserPoolConfig

@typing_extensions.final
class GraphQLApiAdditionalAuthenticationProvider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OPEN_ID_CONNECT_CONFIG_FIELD_NUMBER: builtins.int
    USER_POOL_CONFIG_FIELD_NUMBER: builtins.int
    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def open_id_connect_config(self) -> global___GraphQLApiOpenIDConnectConfig: ...
    @property
    def user_pool_config(self) -> global___GraphQLApiCognitoUserPoolConfig: ...
    authentication_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        open_id_connect_config: global___GraphQLApiOpenIDConnectConfig | None = ...,
        user_pool_config: global___GraphQLApiCognitoUserPoolConfig | None = ...,
        authentication_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["open_id_connect_config", b"open_id_connect_config", "resource_info", b"resource_info", "user_pool_config", b"user_pool_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "open_id_connect_config", b"open_id_connect_config", "resource_info", b"resource_info", "user_pool_config", b"user_pool_config"]) -> None: ...

global___GraphQLApiAdditionalAuthenticationProvider = GraphQLApiAdditionalAuthenticationProvider
