# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_cloudbuild.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_cloudbuild.proto\x12\x1aoak9.tython.gcp.cloudbuild\x1a\x13shared/shared.proto\"=\n CloudbuildTriggerXApprovalConfig\x12\x19\n\x11\x61pproval_required\x18\x01 \x01(\x08\"\xde\x01\n)CloudbuildTriggerXBuildXArtifactsXObjects\x12\x10\n\x08location\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\x12\x61\n\x06timing\x18\x03 \x03(\x0b\x32Q.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXArtifactsXObjects.TimingEntry\x1a-\n\x0bTimingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n!CloudbuildTriggerXBuildXArtifacts\x12\x0e\n\x06images\x18\x01 \x03(\t\x12V\n\x07objects\x18\x02 \x01(\x0b\x32\x45.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXArtifactsXObjects\"[\n6CloudbuildTriggerXBuildXAvailableSecretsXSecretManager\x12\x0b\n\x03\x65nv\x18\x01 \x01(\t\x12\x14\n\x0cversion_name\x18\x02 \x01(\t\"\x96\x01\n(CloudbuildTriggerXBuildXAvailableSecrets\x12j\n\x0esecret_manager\x18\x01 \x03(\x0b\x32R.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXAvailableSecretsXSecretManager\"E\n\'CloudbuildTriggerXBuildXOptionsXVolumes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x85\x03\n\x1f\x43loudbuildTriggerXBuildXOptions\x12\x14\n\x0c\x64isk_size_gb\x18\x01 \x01(\x01\x12\x1d\n\x15\x64ynamic_substitutions\x18\x02 \x01(\x08\x12\x0b\n\x03\x65nv\x18\x03 \x03(\t\x12\x1c\n\x14log_streaming_option\x18\x04 \x01(\t\x12\x0f\n\x07logging\x18\x05 \x01(\t\x12\x14\n\x0cmachine_type\x18\x06 \x01(\t\x12\x1f\n\x17requested_verify_option\x18\x07 \x01(\t\x12\x12\n\nsecret_env\x18\x08 \x03(\t\x12\x1e\n\x16source_provenance_hash\x18\t \x03(\t\x12\x1b\n\x13substitution_option\x18\n \x01(\t\x12\x13\n\x0bworker_pool\x18\x0b \x01(\t\x12T\n\x07volumes\x18\x0c \x03(\x0b\x32\x43.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXOptionsXVolumes\"\xc7\x01\n\x1e\x43loudbuildTriggerXBuildXSecret\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\x12]\n\nsecret_env\x18\x02 \x03(\x0b\x32I.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSecret.SecretEnvEntry\x1a\x30\n\x0eSecretEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd7\x02\n)CloudbuildTriggerXBuildXSourceXRepoSource\x12\x13\n\x0b\x62ranch_name\x18\x01 \x01(\t\x12\x12\n\ncommit_sha\x18\x02 \x01(\t\x12\x0b\n\x03\x64ir\x18\x03 \x01(\t\x12\x14\n\x0cinvert_regex\x18\x04 \x01(\x08\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\trepo_name\x18\x06 \x01(\t\x12o\n\rsubstitutions\x18\x07 \x03(\x0b\x32X.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSourceXRepoSource.SubstitutionsEntry\x12\x10\n\x08tag_name\x18\x08 \x01(\t\x1a\x34\n\x12SubstitutionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n,CloudbuildTriggerXBuildXSourceXStorageSource\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\xde\x01\n\x1e\x43loudbuildTriggerXBuildXSource\x12Z\n\x0brepo_source\x18\x01 \x01(\x0b\x32\x45.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSourceXRepoSource\x12`\n\x0estorage_source\x18\x02 \x01(\x0b\x32H.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSourceXStorageSource\"B\n$CloudbuildTriggerXBuildXStepXVolumes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x8e\x02\n\x1c\x43loudbuildTriggerXBuildXStep\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0b\n\x03\x64ir\x18\x02 \x01(\t\x12\x12\n\nentrypoint\x18\x03 \x01(\t\x12\x0b\n\x03\x65nv\x18\x04 \x03(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x12\n\nsecret_env\x18\x07 \x03(\t\x12\x0f\n\x07timeout\x18\x08 \x01(\t\x12\x0e\n\x06timing\x18\t \x01(\t\x12\x10\n\x08wait_for\x18\n \x03(\t\x12Q\n\x07volumes\x18\x0b \x03(\x0b\x32@.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXStepXVolumes\"\xe6\x05\n\x17\x43loudbuildTriggerXBuild\x12\x0e\n\x06images\x18\x01 \x03(\t\x12\x13\n\x0blogs_bucket\x18\x02 \x01(\t\x12\x11\n\tqueue_ttl\x18\x03 \x01(\t\x12]\n\rsubstitutions\x18\x04 \x03(\x0b\x32\x46.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuild.SubstitutionsEntry\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\x0f\n\x07timeout\x18\x06 \x01(\t\x12P\n\tartifacts\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXArtifacts\x12_\n\x11\x61vailable_secrets\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXAvailableSecrets\x12L\n\x07options\x18\t \x01(\x0b\x32;.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXOptions\x12J\n\x06secret\x18\n \x03(\x0b\x32:.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSecret\x12J\n\x06source\x18\x0b \x01(\x0b\x32:.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSource\x12\x46\n\x04step\x18\x0c \x03(\x0b\x32\x38.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXStep\x1a\x34\n\x12SubstitutionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x1f\x43loudbuildTriggerXGitFileSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\trepo_type\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"e\n$CloudbuildTriggerXGithubXPullRequest\x12\x0e\n\x06\x62ranch\x18\x01 \x01(\t\x12\x17\n\x0f\x63omment_control\x18\x02 \x01(\t\x12\x14\n\x0cinvert_regex\x18\x03 \x01(\x08\"R\n\x1d\x43loudbuildTriggerXGithubXPush\x12\x0e\n\x06\x62ranch\x18\x01 \x01(\t\x12\x14\n\x0cinvert_regex\x18\x02 \x01(\x08\x12\x0b\n\x03tag\x18\x03 \x01(\t\"\xd8\x01\n\x18\x43loudbuildTriggerXGithub\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12V\n\x0cpull_request\x18\x03 \x01(\x0b\x32@.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXGithubXPullRequest\x12G\n\x04push\x18\x04 \x01(\x0b\x32\x39.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXGithubXPush\"s\n\x1e\x43loudbuildTriggerXPubsubConfig\x12\x1d\n\x15service_account_email\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x14\n\x0csubscription\x18\x03 \x01(\t\x12\r\n\x05topic\x18\x04 \x01(\t\"N\n\x1f\x43loudbuildTriggerXSourceToBuild\x12\x0b\n\x03ref\x18\x01 \x01(\t\x12\x11\n\trepo_type\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"L\n\x1a\x43loudbuildTriggerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa8\x01\n!CloudbuildTriggerXTriggerTemplate\x12\x13\n\x0b\x62ranch_name\x18\x01 \x01(\t\x12\x12\n\ncommit_sha\x18\x02 \x01(\t\x12\x0b\n\x03\x64ir\x18\x03 \x01(\t\x12\x14\n\x0cinvert_regex\x18\x04 \x01(\x08\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\trepo_name\x18\x06 \x01(\t\x12\x10\n\x08tag_name\x18\x07 \x01(\t\"@\n\x1f\x43loudbuildTriggerXWebhookConfig\x12\x0e\n\x06secret\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"\xc2\t\n\x11\x43loudbuildTrigger\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x15\n\rignored_files\x18\x07 \x03(\t\x12\x1a\n\x12include_build_logs\x18\x08 \x01(\t\x12\x16\n\x0eincluded_files\x18\t \x03(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x17\n\x0fservice_account\x18\x0c \x01(\t\x12W\n\rsubstitutions\x18\r \x03(\x0b\x32@.oak9.tython.gcp.cloudbuild.CloudbuildTrigger.SubstitutionsEntry\x12\x0c\n\x04tags\x18\x0e \x03(\t\x12\x12\n\ntrigger_id\x18\x0f \x01(\t\x12U\n\x0f\x61pproval_config\x18\x10 \x01(\x0b\x32<.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXApprovalConfig\x12\x42\n\x05\x62uild\x18\x11 \x01(\x0b\x32\x33.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuild\x12T\n\x0fgit_file_source\x18\x12 \x01(\x0b\x32;.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXGitFileSource\x12\x44\n\x06github\x18\x13 \x01(\x0b\x32\x34.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXGithub\x12Q\n\rpubsub_config\x18\x14 \x01(\x0b\x32:.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXPubsubConfig\x12T\n\x0fsource_to_build\x18\x15 \x01(\x0b\x32;.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXSourceToBuild\x12H\n\x08timeouts\x18\x16 \x01(\x0b\x32\x36.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXTimeouts\x12W\n\x10trigger_template\x18\x17 \x01(\x0b\x32=.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXTriggerTemplate\x12S\n\x0ewebhook_config\x18\x18 \x01(\x0b\x32;.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXWebhookConfig\x12\x37\n\rresource_info\x18\x19 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x34\n\x12SubstitutionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\"CloudbuildWorkerPoolXNetworkConfig\x12\x16\n\x0epeered_network\x18\x01 \x01(\t\"O\n\x1d\x43loudbuildWorkerPoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"g\n!CloudbuildWorkerPoolXWorkerConfig\x12\x14\n\x0c\x64isk_size_gb\x18\x01 \x01(\x01\x12\x14\n\x0cmachine_type\x18\x02 \x01(\t\x12\x16\n\x0eno_external_ip\x18\x03 \x01(\x08\"\x84\x05\n\x14\x43loudbuildWorkerPool\x12V\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x41.oak9.tython.gcp.cloudbuild.CloudbuildWorkerPool.AnnotationsEntry\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65lete_time\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12\x0b\n\x03uid\x18\n \x01(\t\x12\x13\n\x0bupdate_time\x18\x0b \x01(\t\x12V\n\x0enetwork_config\x18\x0c \x01(\x0b\x32>.oak9.tython.gcp.cloudbuild.CloudbuildWorkerPoolXNetworkConfig\x12K\n\x08timeouts\x18\r \x01(\x0b\x32\x39.oak9.tython.gcp.cloudbuild.CloudbuildWorkerPoolXTimeouts\x12T\n\rworker_config\x18\x0e \x01(\x0b\x32=.oak9.tython.gcp.cloudbuild.CloudbuildWorkerPoolXWorkerConfig\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_cloudbuild_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS_TIMINGENTRY._options = None
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS_TIMINGENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGERXBUILDXSECRET_SECRETENVENTRY._options = None
  _CLOUDBUILDTRIGGERXBUILDXSECRET_SECRETENVENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE_SUBSTITUTIONSENTRY._options = None
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE_SUBSTITUTIONSENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGERXBUILD_SUBSTITUTIONSENTRY._options = None
  _CLOUDBUILDTRIGGERXBUILD_SUBSTITUTIONSENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGER_SUBSTITUTIONSENTRY._options = None
  _CLOUDBUILDTRIGGER_SUBSTITUTIONSENTRY._serialized_options = b'8\001'
  _CLOUDBUILDWORKERPOOL_ANNOTATIONSENTRY._options = None
  _CLOUDBUILDWORKERPOOL_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGERXAPPROVALCONFIG._serialized_start=77
  _CLOUDBUILDTRIGGERXAPPROVALCONFIG._serialized_end=138
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS._serialized_start=141
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS._serialized_end=363
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS_TIMINGENTRY._serialized_start=318
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS_TIMINGENTRY._serialized_end=363
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTS._serialized_start=366
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTS._serialized_end=505
  _CLOUDBUILDTRIGGERXBUILDXAVAILABLESECRETSXSECRETMANAGER._serialized_start=507
  _CLOUDBUILDTRIGGERXBUILDXAVAILABLESECRETSXSECRETMANAGER._serialized_end=598
  _CLOUDBUILDTRIGGERXBUILDXAVAILABLESECRETS._serialized_start=601
  _CLOUDBUILDTRIGGERXBUILDXAVAILABLESECRETS._serialized_end=751
  _CLOUDBUILDTRIGGERXBUILDXOPTIONSXVOLUMES._serialized_start=753
  _CLOUDBUILDTRIGGERXBUILDXOPTIONSXVOLUMES._serialized_end=822
  _CLOUDBUILDTRIGGERXBUILDXOPTIONS._serialized_start=825
  _CLOUDBUILDTRIGGERXBUILDXOPTIONS._serialized_end=1214
  _CLOUDBUILDTRIGGERXBUILDXSECRET._serialized_start=1217
  _CLOUDBUILDTRIGGERXBUILDXSECRET._serialized_end=1416
  _CLOUDBUILDTRIGGERXBUILDXSECRET_SECRETENVENTRY._serialized_start=1368
  _CLOUDBUILDTRIGGERXBUILDXSECRET_SECRETENVENTRY._serialized_end=1416
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE._serialized_start=1419
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE._serialized_end=1762
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE_SUBSTITUTIONSENTRY._serialized_start=1710
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE_SUBSTITUTIONSENTRY._serialized_end=1762
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXSTORAGESOURCE._serialized_start=1764
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXSTORAGESOURCE._serialized_end=1862
  _CLOUDBUILDTRIGGERXBUILDXSOURCE._serialized_start=1865
  _CLOUDBUILDTRIGGERXBUILDXSOURCE._serialized_end=2087
  _CLOUDBUILDTRIGGERXBUILDXSTEPXVOLUMES._serialized_start=2089
  _CLOUDBUILDTRIGGERXBUILDXSTEPXVOLUMES._serialized_end=2155
  _CLOUDBUILDTRIGGERXBUILDXSTEP._serialized_start=2158
  _CLOUDBUILDTRIGGERXBUILDXSTEP._serialized_end=2428
  _CLOUDBUILDTRIGGERXBUILD._serialized_start=2431
  _CLOUDBUILDTRIGGERXBUILD._serialized_end=3173
  _CLOUDBUILDTRIGGERXBUILD_SUBSTITUTIONSENTRY._serialized_start=1710
  _CLOUDBUILDTRIGGERXBUILD_SUBSTITUTIONSENTRY._serialized_end=1762
  _CLOUDBUILDTRIGGERXGITFILESOURCE._serialized_start=3175
  _CLOUDBUILDTRIGGERXGITFILESOURCE._serialized_end=3272
  _CLOUDBUILDTRIGGERXGITHUBXPULLREQUEST._serialized_start=3274
  _CLOUDBUILDTRIGGERXGITHUBXPULLREQUEST._serialized_end=3375
  _CLOUDBUILDTRIGGERXGITHUBXPUSH._serialized_start=3377
  _CLOUDBUILDTRIGGERXGITHUBXPUSH._serialized_end=3459
  _CLOUDBUILDTRIGGERXGITHUB._serialized_start=3462
  _CLOUDBUILDTRIGGERXGITHUB._serialized_end=3678
  _CLOUDBUILDTRIGGERXPUBSUBCONFIG._serialized_start=3680
  _CLOUDBUILDTRIGGERXPUBSUBCONFIG._serialized_end=3795
  _CLOUDBUILDTRIGGERXSOURCETOBUILD._serialized_start=3797
  _CLOUDBUILDTRIGGERXSOURCETOBUILD._serialized_end=3875
  _CLOUDBUILDTRIGGERXTIMEOUTS._serialized_start=3877
  _CLOUDBUILDTRIGGERXTIMEOUTS._serialized_end=3953
  _CLOUDBUILDTRIGGERXTRIGGERTEMPLATE._serialized_start=3956
  _CLOUDBUILDTRIGGERXTRIGGERTEMPLATE._serialized_end=4124
  _CLOUDBUILDTRIGGERXWEBHOOKCONFIG._serialized_start=4126
  _CLOUDBUILDTRIGGERXWEBHOOKCONFIG._serialized_end=4190
  _CLOUDBUILDTRIGGER._serialized_start=4193
  _CLOUDBUILDTRIGGER._serialized_end=5411
  _CLOUDBUILDTRIGGER_SUBSTITUTIONSENTRY._serialized_start=1710
  _CLOUDBUILDTRIGGER_SUBSTITUTIONSENTRY._serialized_end=1762
  _CLOUDBUILDWORKERPOOLXNETWORKCONFIG._serialized_start=5413
  _CLOUDBUILDWORKERPOOLXNETWORKCONFIG._serialized_end=5473
  _CLOUDBUILDWORKERPOOLXTIMEOUTS._serialized_start=5475
  _CLOUDBUILDWORKERPOOLXTIMEOUTS._serialized_end=5554
  _CLOUDBUILDWORKERPOOLXWORKERCONFIG._serialized_start=5556
  _CLOUDBUILDWORKERPOOLXWORKERCONFIG._serialized_end=5659
  _CLOUDBUILDWORKERPOOL._serialized_start=5662
  _CLOUDBUILDWORKERPOOL._serialized_end=6306
  _CLOUDBUILDWORKERPOOL_ANNOTATIONSENTRY._serialized_start=6256
  _CLOUDBUILDWORKERPOOL_ANNOTATIONSENTRY._serialized_end=6306
# @@protoc_insertion_point(module_scope)
