"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ConnectorProfileDatadogConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileDatadogConnectorProfileProperties = ConnectorProfileDatadogConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileDynatraceConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileDynatraceConnectorProfileProperties = ConnectorProfileDynatraceConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileInforNexusConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileInforNexusConnectorProfileProperties = ConnectorProfileInforNexusConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileMarketoConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileMarketoConnectorProfileProperties = ConnectorProfileMarketoConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileRedshiftConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATABASE_URL_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    database_url: builtins.str
    bucket_name: builtins.str
    bucket_prefix: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        database_url: builtins.str = ...,
        bucket_name: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "database_url", b"database_url", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ConnectorProfileRedshiftConnectorProfileProperties = ConnectorProfileRedshiftConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileSalesforceConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    IS_SANDBOX_ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    is_sandbox_environment: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
        is_sandbox_environment: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "is_sandbox_environment", b"is_sandbox_environment", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileSalesforceConnectorProfileProperties = ConnectorProfileSalesforceConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileServiceNowConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileServiceNowConnectorProfileProperties = ConnectorProfileServiceNowConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileSlackConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileSlackConnectorProfileProperties = ConnectorProfileSlackConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileSnowflakeConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    WAREHOUSE_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_NAME_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    warehouse: builtins.str
    stage: builtins.str
    bucket_name: builtins.str
    bucket_prefix: builtins.str
    private_link_service_name: builtins.str
    account_name: builtins.str
    region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        warehouse: builtins.str = ...,
        stage: builtins.str = ...,
        bucket_name: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
        private_link_service_name: builtins.str = ...,
        account_name: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_name", b"account_name", "bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "private_link_service_name", b"private_link_service_name", "region", b"region", "resource_info", b"resource_info", "stage", b"stage", "warehouse", b"warehouse"]) -> None: ...

global___ConnectorProfileSnowflakeConnectorProfileProperties = ConnectorProfileSnowflakeConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileVeevaConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileVeevaConnectorProfileProperties = ConnectorProfileVeevaConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileZendeskConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_url", b"instance_url", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileZendeskConnectorProfileProperties = ConnectorProfileZendeskConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileConnectorProfileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATADOG_FIELD_NUMBER: builtins.int
    DYNATRACE_FIELD_NUMBER: builtins.int
    INFOR_NEXUS_FIELD_NUMBER: builtins.int
    MARKETO_FIELD_NUMBER: builtins.int
    REDSHIFT_FIELD_NUMBER: builtins.int
    SALESFORCE_FIELD_NUMBER: builtins.int
    SERVICE_NOW_FIELD_NUMBER: builtins.int
    SLACK_FIELD_NUMBER: builtins.int
    SNOWFLAKE_FIELD_NUMBER: builtins.int
    VEEVA_FIELD_NUMBER: builtins.int
    ZENDESK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def datadog(self) -> global___ConnectorProfileDatadogConnectorProfileProperties: ...
    @property
    def dynatrace(self) -> global___ConnectorProfileDynatraceConnectorProfileProperties: ...
    @property
    def infor_nexus(self) -> global___ConnectorProfileInforNexusConnectorProfileProperties: ...
    @property
    def marketo(self) -> global___ConnectorProfileMarketoConnectorProfileProperties: ...
    @property
    def redshift(self) -> global___ConnectorProfileRedshiftConnectorProfileProperties: ...
    @property
    def salesforce(self) -> global___ConnectorProfileSalesforceConnectorProfileProperties: ...
    @property
    def service_now(self) -> global___ConnectorProfileServiceNowConnectorProfileProperties: ...
    @property
    def slack(self) -> global___ConnectorProfileSlackConnectorProfileProperties: ...
    @property
    def snowflake(self) -> global___ConnectorProfileSnowflakeConnectorProfileProperties: ...
    @property
    def veeva(self) -> global___ConnectorProfileVeevaConnectorProfileProperties: ...
    @property
    def zendesk(self) -> global___ConnectorProfileZendeskConnectorProfileProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        datadog: global___ConnectorProfileDatadogConnectorProfileProperties | None = ...,
        dynatrace: global___ConnectorProfileDynatraceConnectorProfileProperties | None = ...,
        infor_nexus: global___ConnectorProfileInforNexusConnectorProfileProperties | None = ...,
        marketo: global___ConnectorProfileMarketoConnectorProfileProperties | None = ...,
        redshift: global___ConnectorProfileRedshiftConnectorProfileProperties | None = ...,
        salesforce: global___ConnectorProfileSalesforceConnectorProfileProperties | None = ...,
        service_now: global___ConnectorProfileServiceNowConnectorProfileProperties | None = ...,
        slack: global___ConnectorProfileSlackConnectorProfileProperties | None = ...,
        snowflake: global___ConnectorProfileSnowflakeConnectorProfileProperties | None = ...,
        veeva: global___ConnectorProfileVeevaConnectorProfileProperties | None = ...,
        zendesk: global___ConnectorProfileZendeskConnectorProfileProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["datadog", b"datadog", "dynatrace", b"dynatrace", "infor_nexus", b"infor_nexus", "marketo", b"marketo", "redshift", b"redshift", "resource_info", b"resource_info", "salesforce", b"salesforce", "service_now", b"service_now", "slack", b"slack", "snowflake", b"snowflake", "veeva", b"veeva", "zendesk", b"zendesk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["datadog", b"datadog", "dynatrace", b"dynatrace", "infor_nexus", b"infor_nexus", "marketo", b"marketo", "redshift", b"redshift", "resource_info", b"resource_info", "salesforce", b"salesforce", "service_now", b"service_now", "slack", b"slack", "snowflake", b"snowflake", "veeva", b"veeva", "zendesk", b"zendesk"]) -> None: ...

global___ConnectorProfileConnectorProfileProperties = ConnectorProfileConnectorProfileProperties

@typing_extensions.final
class ConnectorProfileAmplitudeConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    SECRET_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    api_key: builtins.str
    secret_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_key: builtins.str = ...,
        secret_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "resource_info", b"resource_info", "secret_key", b"secret_key"]) -> None: ...

global___ConnectorProfileAmplitudeConnectorProfileCredentials = ConnectorProfileAmplitudeConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileDatadogConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    APPLICATION_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    api_key: builtins.str
    application_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_key: builtins.str = ...,
        application_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "application_key", b"application_key", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileDatadogConnectorProfileCredentials = ConnectorProfileDatadogConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileDynatraceConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    api_token: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_token", b"api_token", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileDynatraceConnectorProfileCredentials = ConnectorProfileDynatraceConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileConnectorOAuthRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTH_CODE_FIELD_NUMBER: builtins.int
    REDIRECT_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    auth_code: builtins.str
    redirect_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auth_code: builtins.str = ...,
        redirect_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_code", b"auth_code", "redirect_uri", b"redirect_uri", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileConnectorOAuthRequest = ConnectorProfileConnectorOAuthRequest

@typing_extensions.final
class ConnectorProfileGoogleAnalyticsConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    CONNECTOR_O_AUTH_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_id: builtins.str
    client_secret: builtins.str
    access_token: builtins.str
    refresh_token: builtins.str
    @property
    def connector_o_auth_request(self) -> global___ConnectorProfileConnectorOAuthRequest: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        access_token: builtins.str = ...,
        refresh_token: builtins.str = ...,
        connector_o_auth_request: global___ConnectorProfileConnectorOAuthRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_o_auth_request", b"connector_o_auth_request", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "client_id", b"client_id", "client_secret", b"client_secret", "connector_o_auth_request", b"connector_o_auth_request", "refresh_token", b"refresh_token", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileGoogleAnalyticsConnectorProfileCredentials = ConnectorProfileGoogleAnalyticsConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileInforNexusConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    SECRET_ACCESS_KEY_FIELD_NUMBER: builtins.int
    DATAKEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    access_key_id: builtins.str
    user_id: builtins.str
    secret_access_key: builtins.str
    datakey: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        access_key_id: builtins.str = ...,
        user_id: builtins.str = ...,
        secret_access_key: builtins.str = ...,
        datakey: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key_id", b"access_key_id", "datakey", b"datakey", "resource_info", b"resource_info", "secret_access_key", b"secret_access_key", "user_id", b"user_id"]) -> None: ...

global___ConnectorProfileInforNexusConnectorProfileCredentials = ConnectorProfileInforNexusConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileMarketoConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    CONNECTOR_O_AUTH_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_id: builtins.str
    client_secret: builtins.str
    access_token: builtins.str
    @property
    def connector_o_auth_request(self) -> global___ConnectorProfileConnectorOAuthRequest: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        access_token: builtins.str = ...,
        connector_o_auth_request: global___ConnectorProfileConnectorOAuthRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_o_auth_request", b"connector_o_auth_request", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "client_id", b"client_id", "client_secret", b"client_secret", "connector_o_auth_request", b"connector_o_auth_request", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileMarketoConnectorProfileCredentials = ConnectorProfileMarketoConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileRedshiftConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___ConnectorProfileRedshiftConnectorProfileCredentials = ConnectorProfileRedshiftConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileSalesforceConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    CONNECTOR_O_AUTH_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    access_token: builtins.str
    refresh_token: builtins.str
    @property
    def connector_o_auth_request(self) -> global___ConnectorProfileConnectorOAuthRequest: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        access_token: builtins.str = ...,
        refresh_token: builtins.str = ...,
        connector_o_auth_request: global___ConnectorProfileConnectorOAuthRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_o_auth_request", b"connector_o_auth_request", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "connector_o_auth_request", b"connector_o_auth_request", "refresh_token", b"refresh_token", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileSalesforceConnectorProfileCredentials = ConnectorProfileSalesforceConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileServiceNowConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___ConnectorProfileServiceNowConnectorProfileCredentials = ConnectorProfileServiceNowConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileSingularConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    api_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileSingularConnectorProfileCredentials = ConnectorProfileSingularConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileSlackConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    CONNECTOR_O_AUTH_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_id: builtins.str
    client_secret: builtins.str
    access_token: builtins.str
    @property
    def connector_o_auth_request(self) -> global___ConnectorProfileConnectorOAuthRequest: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        access_token: builtins.str = ...,
        connector_o_auth_request: global___ConnectorProfileConnectorOAuthRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_o_auth_request", b"connector_o_auth_request", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "client_id", b"client_id", "client_secret", b"client_secret", "connector_o_auth_request", b"connector_o_auth_request", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileSlackConnectorProfileCredentials = ConnectorProfileSlackConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileSnowflakeConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___ConnectorProfileSnowflakeConnectorProfileCredentials = ConnectorProfileSnowflakeConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileTrendmicroConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_SECRET_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    api_secret_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_secret_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_secret_key", b"api_secret_key", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileTrendmicroConnectorProfileCredentials = ConnectorProfileTrendmicroConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileVeevaConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___ConnectorProfileVeevaConnectorProfileCredentials = ConnectorProfileVeevaConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileZendeskConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    CONNECTOR_O_AUTH_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_id: builtins.str
    client_secret: builtins.str
    access_token: builtins.str
    @property
    def connector_o_auth_request(self) -> global___ConnectorProfileConnectorOAuthRequest: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        access_token: builtins.str = ...,
        connector_o_auth_request: global___ConnectorProfileConnectorOAuthRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_o_auth_request", b"connector_o_auth_request", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "client_id", b"client_id", "client_secret", b"client_secret", "connector_o_auth_request", b"connector_o_auth_request", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileZendeskConnectorProfileCredentials = ConnectorProfileZendeskConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileConnectorProfileCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AMPLITUDE_FIELD_NUMBER: builtins.int
    DATADOG_FIELD_NUMBER: builtins.int
    DYNATRACE_FIELD_NUMBER: builtins.int
    GOOGLE_ANALYTICS_FIELD_NUMBER: builtins.int
    INFOR_NEXUS_FIELD_NUMBER: builtins.int
    MARKETO_FIELD_NUMBER: builtins.int
    REDSHIFT_FIELD_NUMBER: builtins.int
    SALESFORCE_FIELD_NUMBER: builtins.int
    SERVICE_NOW_FIELD_NUMBER: builtins.int
    SINGULAR_FIELD_NUMBER: builtins.int
    SLACK_FIELD_NUMBER: builtins.int
    SNOWFLAKE_FIELD_NUMBER: builtins.int
    TRENDMICRO_FIELD_NUMBER: builtins.int
    VEEVA_FIELD_NUMBER: builtins.int
    ZENDESK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def amplitude(self) -> global___ConnectorProfileAmplitudeConnectorProfileCredentials: ...
    @property
    def datadog(self) -> global___ConnectorProfileDatadogConnectorProfileCredentials: ...
    @property
    def dynatrace(self) -> global___ConnectorProfileDynatraceConnectorProfileCredentials: ...
    @property
    def google_analytics(self) -> global___ConnectorProfileGoogleAnalyticsConnectorProfileCredentials: ...
    @property
    def infor_nexus(self) -> global___ConnectorProfileInforNexusConnectorProfileCredentials: ...
    @property
    def marketo(self) -> global___ConnectorProfileMarketoConnectorProfileCredentials: ...
    @property
    def redshift(self) -> global___ConnectorProfileRedshiftConnectorProfileCredentials: ...
    @property
    def salesforce(self) -> global___ConnectorProfileSalesforceConnectorProfileCredentials: ...
    @property
    def service_now(self) -> global___ConnectorProfileServiceNowConnectorProfileCredentials: ...
    @property
    def singular(self) -> global___ConnectorProfileSingularConnectorProfileCredentials: ...
    @property
    def slack(self) -> global___ConnectorProfileSlackConnectorProfileCredentials: ...
    @property
    def snowflake(self) -> global___ConnectorProfileSnowflakeConnectorProfileCredentials: ...
    @property
    def trendmicro(self) -> global___ConnectorProfileTrendmicroConnectorProfileCredentials: ...
    @property
    def veeva(self) -> global___ConnectorProfileVeevaConnectorProfileCredentials: ...
    @property
    def zendesk(self) -> global___ConnectorProfileZendeskConnectorProfileCredentials: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        amplitude: global___ConnectorProfileAmplitudeConnectorProfileCredentials | None = ...,
        datadog: global___ConnectorProfileDatadogConnectorProfileCredentials | None = ...,
        dynatrace: global___ConnectorProfileDynatraceConnectorProfileCredentials | None = ...,
        google_analytics: global___ConnectorProfileGoogleAnalyticsConnectorProfileCredentials | None = ...,
        infor_nexus: global___ConnectorProfileInforNexusConnectorProfileCredentials | None = ...,
        marketo: global___ConnectorProfileMarketoConnectorProfileCredentials | None = ...,
        redshift: global___ConnectorProfileRedshiftConnectorProfileCredentials | None = ...,
        salesforce: global___ConnectorProfileSalesforceConnectorProfileCredentials | None = ...,
        service_now: global___ConnectorProfileServiceNowConnectorProfileCredentials | None = ...,
        singular: global___ConnectorProfileSingularConnectorProfileCredentials | None = ...,
        slack: global___ConnectorProfileSlackConnectorProfileCredentials | None = ...,
        snowflake: global___ConnectorProfileSnowflakeConnectorProfileCredentials | None = ...,
        trendmicro: global___ConnectorProfileTrendmicroConnectorProfileCredentials | None = ...,
        veeva: global___ConnectorProfileVeevaConnectorProfileCredentials | None = ...,
        zendesk: global___ConnectorProfileZendeskConnectorProfileCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["amplitude", b"amplitude", "datadog", b"datadog", "dynatrace", b"dynatrace", "google_analytics", b"google_analytics", "infor_nexus", b"infor_nexus", "marketo", b"marketo", "redshift", b"redshift", "resource_info", b"resource_info", "salesforce", b"salesforce", "service_now", b"service_now", "singular", b"singular", "slack", b"slack", "snowflake", b"snowflake", "trendmicro", b"trendmicro", "veeva", b"veeva", "zendesk", b"zendesk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amplitude", b"amplitude", "datadog", b"datadog", "dynatrace", b"dynatrace", "google_analytics", b"google_analytics", "infor_nexus", b"infor_nexus", "marketo", b"marketo", "redshift", b"redshift", "resource_info", b"resource_info", "salesforce", b"salesforce", "service_now", b"service_now", "singular", b"singular", "slack", b"slack", "snowflake", b"snowflake", "trendmicro", b"trendmicro", "veeva", b"veeva", "zendesk", b"zendesk"]) -> None: ...

global___ConnectorProfileConnectorProfileCredentials = ConnectorProfileConnectorProfileCredentials

@typing_extensions.final
class ConnectorProfileConnectorProfileConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONNECTOR_PROFILE_PROPERTIES_FIELD_NUMBER: builtins.int
    CONNECTOR_PROFILE_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def connector_profile_properties(self) -> global___ConnectorProfileConnectorProfileProperties: ...
    @property
    def connector_profile_credentials(self) -> global___ConnectorProfileConnectorProfileCredentials: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        connector_profile_properties: global___ConnectorProfileConnectorProfileProperties | None = ...,
        connector_profile_credentials: global___ConnectorProfileConnectorProfileCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_profile_credentials", b"connector_profile_credentials", "connector_profile_properties", b"connector_profile_properties", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_profile_credentials", b"connector_profile_credentials", "connector_profile_properties", b"connector_profile_properties", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfileConnectorProfileConfig = ConnectorProfileConnectorProfileConfig

@typing_extensions.final
class ConnectorProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONNECTOR_PROFILE_NAME_FIELD_NUMBER: builtins.int
    KMS_ARN_FIELD_NUMBER: builtins.int
    CONNECTOR_TYPE_FIELD_NUMBER: builtins.int
    CONNECTION_MODE_FIELD_NUMBER: builtins.int
    CONNECTOR_PROFILE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    connector_profile_name: builtins.str
    kms_arn: builtins.str
    connector_type: builtins.str
    connection_mode: builtins.str
    @property
    def connector_profile_config(self) -> global___ConnectorProfileConnectorProfileConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        connector_profile_name: builtins.str = ...,
        kms_arn: builtins.str = ...,
        connector_type: builtins.str = ...,
        connection_mode: builtins.str = ...,
        connector_profile_config: global___ConnectorProfileConnectorProfileConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_profile_config", b"connector_profile_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_mode", b"connection_mode", "connector_profile_config", b"connector_profile_config", "connector_profile_name", b"connector_profile_name", "connector_type", b"connector_type", "kms_arn", b"kms_arn", "resource_info", b"resource_info"]) -> None: ...

global___ConnectorProfile = ConnectorProfile

@typing_extensions.final
class AppFlow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_PROFILE_FIELD_NUMBER: builtins.int
    FLOW_FIELD_NUMBER: builtins.int
    @property
    def connector_profile(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectorProfile]: ...
    @property
    def flow(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Flow]: ...
    def __init__(
        self,
        *,
        connector_profile: collections.abc.Iterable[global___ConnectorProfile] | None = ...,
        flow: collections.abc.Iterable[global___Flow] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_profile", b"connector_profile", "flow", b"flow"]) -> None: ...

global___AppFlow = AppFlow

@typing_extensions.final
class FlowScheduledTriggerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SCHEDULE_EXPRESSION_FIELD_NUMBER: builtins.int
    DATA_PULL_MODE_FIELD_NUMBER: builtins.int
    SCHEDULE_START_TIME_FIELD_NUMBER: builtins.int
    SCHEDULE_END_TIME_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    schedule_expression: builtins.str
    data_pull_mode: builtins.str
    schedule_start_time: builtins.float
    schedule_end_time: builtins.float
    time_zone: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        schedule_expression: builtins.str = ...,
        data_pull_mode: builtins.str = ...,
        schedule_start_time: builtins.float = ...,
        schedule_end_time: builtins.float = ...,
        time_zone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_pull_mode", b"data_pull_mode", "resource_info", b"resource_info", "schedule_end_time", b"schedule_end_time", "schedule_expression", b"schedule_expression", "schedule_start_time", b"schedule_start_time", "time_zone", b"time_zone"]) -> None: ...

global___FlowScheduledTriggerProperties = FlowScheduledTriggerProperties

@typing_extensions.final
class FlowTriggerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TRIGGER_TYPE_FIELD_NUMBER: builtins.int
    TRIGGER_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    trigger_type: builtins.str
    @property
    def trigger_properties(self) -> global___FlowScheduledTriggerProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        trigger_type: builtins.str = ...,
        trigger_properties: global___FlowScheduledTriggerProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "trigger_properties", b"trigger_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "trigger_properties", b"trigger_properties", "trigger_type", b"trigger_type"]) -> None: ...

global___FlowTriggerConfig = FlowTriggerConfig

@typing_extensions.final
class FlowAmplitudeSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowAmplitudeSourceProperties = FlowAmplitudeSourceProperties

@typing_extensions.final
class FlowDatadogSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowDatadogSourceProperties = FlowDatadogSourceProperties

@typing_extensions.final
class FlowDynatraceSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowDynatraceSourceProperties = FlowDynatraceSourceProperties

@typing_extensions.final
class FlowGoogleAnalyticsSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowGoogleAnalyticsSourceProperties = FlowGoogleAnalyticsSourceProperties

@typing_extensions.final
class FlowInforNexusSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowInforNexusSourceProperties = FlowInforNexusSourceProperties

@typing_extensions.final
class FlowMarketoSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowMarketoSourceProperties = FlowMarketoSourceProperties

@typing_extensions.final
class FlowS3SourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_name: builtins.str
    bucket_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_name: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "resource_info", b"resource_info"]) -> None: ...

global___FlowS3SourceProperties = FlowS3SourceProperties

@typing_extensions.final
class FlowSalesforceSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    ENABLE_DYNAMIC_FIELD_UPDATE_FIELD_NUMBER: builtins.int
    INCLUDE_DELETED_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    enable_dynamic_field_update: builtins.bool
    include_deleted_records: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
        enable_dynamic_field_update: builtins.bool = ...,
        include_deleted_records: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_dynamic_field_update", b"enable_dynamic_field_update", "include_deleted_records", b"include_deleted_records", "object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowSalesforceSourceProperties = FlowSalesforceSourceProperties

@typing_extensions.final
class FlowServiceNowSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowServiceNowSourceProperties = FlowServiceNowSourceProperties

@typing_extensions.final
class FlowSingularSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowSingularSourceProperties = FlowSingularSourceProperties

@typing_extensions.final
class FlowSlackSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowSlackSourceProperties = FlowSlackSourceProperties

@typing_extensions.final
class FlowTrendmicroSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowTrendmicroSourceProperties = FlowTrendmicroSourceProperties

@typing_extensions.final
class FlowVeevaSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowVeevaSourceProperties = FlowVeevaSourceProperties

@typing_extensions.final
class FlowZendeskSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowZendeskSourceProperties = FlowZendeskSourceProperties

@typing_extensions.final
class FlowSourceConnectorProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AMPLITUDE_FIELD_NUMBER: builtins.int
    DATADOG_FIELD_NUMBER: builtins.int
    DYNATRACE_FIELD_NUMBER: builtins.int
    GOOGLE_ANALYTICS_FIELD_NUMBER: builtins.int
    INFOR_NEXUS_FIELD_NUMBER: builtins.int
    MARKETO_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    SALESFORCE_FIELD_NUMBER: builtins.int
    SERVICE_NOW_FIELD_NUMBER: builtins.int
    SINGULAR_FIELD_NUMBER: builtins.int
    SLACK_FIELD_NUMBER: builtins.int
    TRENDMICRO_FIELD_NUMBER: builtins.int
    VEEVA_FIELD_NUMBER: builtins.int
    ZENDESK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def amplitude(self) -> global___FlowAmplitudeSourceProperties: ...
    @property
    def datadog(self) -> global___FlowDatadogSourceProperties: ...
    @property
    def dynatrace(self) -> global___FlowDynatraceSourceProperties: ...
    @property
    def google_analytics(self) -> global___FlowGoogleAnalyticsSourceProperties: ...
    @property
    def infor_nexus(self) -> global___FlowInforNexusSourceProperties: ...
    @property
    def marketo(self) -> global___FlowMarketoSourceProperties: ...
    @property
    def s3(self) -> global___FlowS3SourceProperties: ...
    @property
    def salesforce(self) -> global___FlowSalesforceSourceProperties: ...
    @property
    def service_now(self) -> global___FlowServiceNowSourceProperties: ...
    @property
    def singular(self) -> global___FlowSingularSourceProperties: ...
    @property
    def slack(self) -> global___FlowSlackSourceProperties: ...
    @property
    def trendmicro(self) -> global___FlowTrendmicroSourceProperties: ...
    @property
    def veeva(self) -> global___FlowVeevaSourceProperties: ...
    @property
    def zendesk(self) -> global___FlowZendeskSourceProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        amplitude: global___FlowAmplitudeSourceProperties | None = ...,
        datadog: global___FlowDatadogSourceProperties | None = ...,
        dynatrace: global___FlowDynatraceSourceProperties | None = ...,
        google_analytics: global___FlowGoogleAnalyticsSourceProperties | None = ...,
        infor_nexus: global___FlowInforNexusSourceProperties | None = ...,
        marketo: global___FlowMarketoSourceProperties | None = ...,
        s3: global___FlowS3SourceProperties | None = ...,
        salesforce: global___FlowSalesforceSourceProperties | None = ...,
        service_now: global___FlowServiceNowSourceProperties | None = ...,
        singular: global___FlowSingularSourceProperties | None = ...,
        slack: global___FlowSlackSourceProperties | None = ...,
        trendmicro: global___FlowTrendmicroSourceProperties | None = ...,
        veeva: global___FlowVeevaSourceProperties | None = ...,
        zendesk: global___FlowZendeskSourceProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["amplitude", b"amplitude", "datadog", b"datadog", "dynatrace", b"dynatrace", "google_analytics", b"google_analytics", "infor_nexus", b"infor_nexus", "marketo", b"marketo", "resource_info", b"resource_info", "s3", b"s3", "salesforce", b"salesforce", "service_now", b"service_now", "singular", b"singular", "slack", b"slack", "trendmicro", b"trendmicro", "veeva", b"veeva", "zendesk", b"zendesk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amplitude", b"amplitude", "datadog", b"datadog", "dynatrace", b"dynatrace", "google_analytics", b"google_analytics", "infor_nexus", b"infor_nexus", "marketo", b"marketo", "resource_info", b"resource_info", "s3", b"s3", "salesforce", b"salesforce", "service_now", b"service_now", "singular", b"singular", "slack", b"slack", "trendmicro", b"trendmicro", "veeva", b"veeva", "zendesk", b"zendesk"]) -> None: ...

global___FlowSourceConnectorProperties = FlowSourceConnectorProperties

@typing_extensions.final
class FlowSourceFlowConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONNECTOR_TYPE_FIELD_NUMBER: builtins.int
    CONNECTOR_PROFILE_NAME_FIELD_NUMBER: builtins.int
    SOURCE_CONNECTOR_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    connector_type: builtins.str
    connector_profile_name: builtins.str
    @property
    def source_connector_properties(self) -> global___FlowSourceConnectorProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        connector_type: builtins.str = ...,
        connector_profile_name: builtins.str = ...,
        source_connector_properties: global___FlowSourceConnectorProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source_connector_properties", b"source_connector_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_profile_name", b"connector_profile_name", "connector_type", b"connector_type", "resource_info", b"resource_info", "source_connector_properties", b"source_connector_properties"]) -> None: ...

global___FlowSourceFlowConfig = FlowSourceFlowConfig

@typing_extensions.final
class FlowErrorHandlingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FAIL_ON_FIRST_ERROR_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    fail_on_first_error: builtins.bool
    bucket_prefix: builtins.str
    bucket_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        fail_on_first_error: builtins.bool = ...,
        bucket_prefix: builtins.str = ...,
        bucket_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "fail_on_first_error", b"fail_on_first_error", "resource_info", b"resource_info"]) -> None: ...

global___FlowErrorHandlingConfig = FlowErrorHandlingConfig

@typing_extensions.final
class FlowRedshiftDestinationProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    INTERMEDIATE_BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    ERROR_HANDLING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    intermediate_bucket_name: builtins.str
    bucket_prefix: builtins.str
    @property
    def error_handling_config(self) -> global___FlowErrorHandlingConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
        intermediate_bucket_name: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
        error_handling_config: global___FlowErrorHandlingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["error_handling_config", b"error_handling_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_prefix", b"bucket_prefix", "error_handling_config", b"error_handling_config", "intermediate_bucket_name", b"intermediate_bucket_name", "object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowRedshiftDestinationProperties = FlowRedshiftDestinationProperties

@typing_extensions.final
class FlowPrefixConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PREFIX_TYPE_FIELD_NUMBER: builtins.int
    PREFIX_FORMAT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    prefix_type: builtins.str
    prefix_format: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        prefix_type: builtins.str = ...,
        prefix_format: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prefix_format", b"prefix_format", "prefix_type", b"prefix_type", "resource_info", b"resource_info"]) -> None: ...

global___FlowPrefixConfig = FlowPrefixConfig

@typing_extensions.final
class FlowAggregationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AGGREGATION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    aggregation_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aggregation_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregation_type", b"aggregation_type", "resource_info", b"resource_info"]) -> None: ...

global___FlowAggregationConfig = FlowAggregationConfig

@typing_extensions.final
class FlowS3OutputFormatConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FILE_TYPE_FIELD_NUMBER: builtins.int
    PREFIX_CONFIG_FIELD_NUMBER: builtins.int
    AGGREGATION_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    file_type: builtins.str
    @property
    def prefix_config(self) -> global___FlowPrefixConfig: ...
    @property
    def aggregation_config(self) -> global___FlowAggregationConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        file_type: builtins.str = ...,
        prefix_config: global___FlowPrefixConfig | None = ...,
        aggregation_config: global___FlowAggregationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aggregation_config", b"aggregation_config", "prefix_config", b"prefix_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregation_config", b"aggregation_config", "file_type", b"file_type", "prefix_config", b"prefix_config", "resource_info", b"resource_info"]) -> None: ...

global___FlowS3OutputFormatConfig = FlowS3OutputFormatConfig

@typing_extensions.final
class FlowS3DestinationProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    S3_OUTPUT_FORMAT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_name: builtins.str
    bucket_prefix: builtins.str
    @property
    def s3_output_format_config(self) -> global___FlowS3OutputFormatConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_name: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
        s3_output_format_config: global___FlowS3OutputFormatConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_output_format_config", b"s3_output_format_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "resource_info", b"resource_info", "s3_output_format_config", b"s3_output_format_config"]) -> None: ...

global___FlowS3DestinationProperties = FlowS3DestinationProperties

@typing_extensions.final
class FlowSalesforceDestinationProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    ERROR_HANDLING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    @property
    def error_handling_config(self) -> global___FlowErrorHandlingConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
        error_handling_config: global___FlowErrorHandlingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["error_handling_config", b"error_handling_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_handling_config", b"error_handling_config", "object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowSalesforceDestinationProperties = FlowSalesforceDestinationProperties

@typing_extensions.final
class FlowSnowflakeDestinationProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    INTERMEDIATE_BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    ERROR_HANDLING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    intermediate_bucket_name: builtins.str
    bucket_prefix: builtins.str
    @property
    def error_handling_config(self) -> global___FlowErrorHandlingConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
        intermediate_bucket_name: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
        error_handling_config: global___FlowErrorHandlingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["error_handling_config", b"error_handling_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_prefix", b"bucket_prefix", "error_handling_config", b"error_handling_config", "intermediate_bucket_name", b"intermediate_bucket_name", "object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowSnowflakeDestinationProperties = FlowSnowflakeDestinationProperties

@typing_extensions.final
class FlowEventBridgeDestinationProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    ERROR_HANDLING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object: builtins.str
    @property
    def error_handling_config(self) -> global___FlowErrorHandlingConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object: builtins.str = ...,
        error_handling_config: global___FlowErrorHandlingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["error_handling_config", b"error_handling_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_handling_config", b"error_handling_config", "object", b"object", "resource_info", b"resource_info"]) -> None: ...

global___FlowEventBridgeDestinationProperties = FlowEventBridgeDestinationProperties

@typing_extensions.final
class FlowDestinationConnectorProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REDSHIFT_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    SALESFORCE_FIELD_NUMBER: builtins.int
    SNOWFLAKE_FIELD_NUMBER: builtins.int
    EVENT_BRIDGE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def redshift(self) -> global___FlowRedshiftDestinationProperties: ...
    @property
    def s3(self) -> global___FlowS3DestinationProperties: ...
    @property
    def salesforce(self) -> global___FlowSalesforceDestinationProperties: ...
    @property
    def snowflake(self) -> global___FlowSnowflakeDestinationProperties: ...
    @property
    def event_bridge(self) -> global___FlowEventBridgeDestinationProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        redshift: global___FlowRedshiftDestinationProperties | None = ...,
        s3: global___FlowS3DestinationProperties | None = ...,
        salesforce: global___FlowSalesforceDestinationProperties | None = ...,
        snowflake: global___FlowSnowflakeDestinationProperties | None = ...,
        event_bridge: global___FlowEventBridgeDestinationProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event_bridge", b"event_bridge", "redshift", b"redshift", "resource_info", b"resource_info", "s3", b"s3", "salesforce", b"salesforce", "snowflake", b"snowflake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_bridge", b"event_bridge", "redshift", b"redshift", "resource_info", b"resource_info", "s3", b"s3", "salesforce", b"salesforce", "snowflake", b"snowflake"]) -> None: ...

global___FlowDestinationConnectorProperties = FlowDestinationConnectorProperties

@typing_extensions.final
class FlowDestinationFlowConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONNECTOR_TYPE_FIELD_NUMBER: builtins.int
    CONNECTOR_PROFILE_NAME_FIELD_NUMBER: builtins.int
    DESTINATION_CONNECTOR_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    connector_type: builtins.str
    connector_profile_name: builtins.str
    @property
    def destination_connector_properties(self) -> global___FlowDestinationConnectorProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        connector_type: builtins.str = ...,
        connector_profile_name: builtins.str = ...,
        destination_connector_properties: global___FlowDestinationConnectorProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination_connector_properties", b"destination_connector_properties", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_profile_name", b"connector_profile_name", "connector_type", b"connector_type", "destination_connector_properties", b"destination_connector_properties", "resource_info", b"resource_info"]) -> None: ...

global___FlowDestinationFlowConfig = FlowDestinationFlowConfig

@typing_extensions.final
class FlowConnectorOperator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AMPLITUDE_FIELD_NUMBER: builtins.int
    DATADOG_FIELD_NUMBER: builtins.int
    DYNATRACE_FIELD_NUMBER: builtins.int
    GOOGLE_ANALYTICS_FIELD_NUMBER: builtins.int
    INFOR_NEXUS_FIELD_NUMBER: builtins.int
    MARKETO_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    SALESFORCE_FIELD_NUMBER: builtins.int
    SERVICE_NOW_FIELD_NUMBER: builtins.int
    SINGULAR_FIELD_NUMBER: builtins.int
    SLACK_FIELD_NUMBER: builtins.int
    TRENDMICRO_FIELD_NUMBER: builtins.int
    VEEVA_FIELD_NUMBER: builtins.int
    ZENDESK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    amplitude: builtins.str
    datadog: builtins.str
    dynatrace: builtins.str
    google_analytics: builtins.str
    infor_nexus: builtins.str
    marketo: builtins.str
    s3: builtins.str
    salesforce: builtins.str
    service_now: builtins.str
    singular: builtins.str
    slack: builtins.str
    trendmicro: builtins.str
    veeva: builtins.str
    zendesk: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        amplitude: builtins.str = ...,
        datadog: builtins.str = ...,
        dynatrace: builtins.str = ...,
        google_analytics: builtins.str = ...,
        infor_nexus: builtins.str = ...,
        marketo: builtins.str = ...,
        s3: builtins.str = ...,
        salesforce: builtins.str = ...,
        service_now: builtins.str = ...,
        singular: builtins.str = ...,
        slack: builtins.str = ...,
        trendmicro: builtins.str = ...,
        veeva: builtins.str = ...,
        zendesk: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amplitude", b"amplitude", "datadog", b"datadog", "dynatrace", b"dynatrace", "google_analytics", b"google_analytics", "infor_nexus", b"infor_nexus", "marketo", b"marketo", "resource_info", b"resource_info", "s3", b"s3", "salesforce", b"salesforce", "service_now", b"service_now", "singular", b"singular", "slack", b"slack", "trendmicro", b"trendmicro", "veeva", b"veeva", "zendesk", b"zendesk"]) -> None: ...

global___FlowConnectorOperator = FlowConnectorOperator

@typing_extensions.final
class FlowTaskPropertiesObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___FlowTaskPropertiesObject = FlowTaskPropertiesObject

@typing_extensions.final
class FlowTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_FIELDS_FIELD_NUMBER: builtins.int
    CONNECTOR_OPERATOR_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_FIELD_NUMBER: builtins.int
    TASK_TYPE_FIELD_NUMBER: builtins.int
    TASK_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def source_fields(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def connector_operator(self) -> global___FlowConnectorOperator: ...
    destination_field: builtins.str
    task_type: builtins.str
    @property
    def task_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FlowTaskPropertiesObject]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_fields: collections.abc.Iterable[builtins.str] | None = ...,
        connector_operator: global___FlowConnectorOperator | None = ...,
        destination_field: builtins.str = ...,
        task_type: builtins.str = ...,
        task_properties: collections.abc.Iterable[global___FlowTaskPropertiesObject] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_operator", b"connector_operator", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_operator", b"connector_operator", "destination_field", b"destination_field", "resource_info", b"resource_info", "source_fields", b"source_fields", "task_properties", b"task_properties", "task_type", b"task_type"]) -> None: ...

global___FlowTask = FlowTask

@typing_extensions.final
class Flow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FLOW_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    KMS_ARN_FIELD_NUMBER: builtins.int
    TRIGGER_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FLOW_CONFIG_FIELD_NUMBER: builtins.int
    DESTINATION_FLOW_CONFIG_LIST_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    flow_name: builtins.str
    description: builtins.str
    kms_arn: builtins.str
    @property
    def trigger_config(self) -> global___FlowTriggerConfig: ...
    @property
    def source_flow_config(self) -> global___FlowSourceFlowConfig: ...
    @property
    def destination_flow_config_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FlowDestinationFlowConfig]: ...
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FlowTask]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        flow_name: builtins.str = ...,
        description: builtins.str = ...,
        kms_arn: builtins.str = ...,
        trigger_config: global___FlowTriggerConfig | None = ...,
        source_flow_config: global___FlowSourceFlowConfig | None = ...,
        destination_flow_config_list: collections.abc.Iterable[global___FlowDestinationFlowConfig] | None = ...,
        tasks: collections.abc.Iterable[global___FlowTask] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source_flow_config", b"source_flow_config", "trigger_config", b"trigger_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "destination_flow_config_list", b"destination_flow_config_list", "flow_name", b"flow_name", "kms_arn", b"kms_arn", "resource_info", b"resource_info", "source_flow_config", b"source_flow_config", "tags", b"tags", "tasks", b"tasks", "trigger_config", b"trigger_config"]) -> None: ...

global___Flow = Flow
