"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeDiskXDiskEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    KMS_KEY_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    RAW_KEY_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    kms_key_self_link: builtins.str
    kms_key_service_account: builtins.str
    raw_key: builtins.str
    sha256: builtins.str
    def __init__(
        self,
        *,
        kms_key_self_link: builtins.str = ...,
        kms_key_service_account: builtins.str = ...,
        raw_key: builtins.str = ...,
        sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_self_link", b"kms_key_self_link", "kms_key_service_account", b"kms_key_service_account", "raw_key", b"raw_key", "sha256", b"sha256"]) -> None: ...

global___ComputeDiskXDiskEncryptionKey = ComputeDiskXDiskEncryptionKey

@typing_extensions.final
class ComputeDiskXSourceImageEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    KMS_KEY_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    RAW_KEY_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    kms_key_self_link: builtins.str
    kms_key_service_account: builtins.str
    raw_key: builtins.str
    sha256: builtins.str
    def __init__(
        self,
        *,
        kms_key_self_link: builtins.str = ...,
        kms_key_service_account: builtins.str = ...,
        raw_key: builtins.str = ...,
        sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_self_link", b"kms_key_self_link", "kms_key_service_account", b"kms_key_service_account", "raw_key", b"raw_key", "sha256", b"sha256"]) -> None: ...

global___ComputeDiskXSourceImageEncryptionKey = ComputeDiskXSourceImageEncryptionKey

@typing_extensions.final
class ComputeDiskXSourceSnapshotEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    KMS_KEY_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    RAW_KEY_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    kms_key_self_link: builtins.str
    kms_key_service_account: builtins.str
    raw_key: builtins.str
    sha256: builtins.str
    def __init__(
        self,
        *,
        kms_key_self_link: builtins.str = ...,
        kms_key_service_account: builtins.str = ...,
        raw_key: builtins.str = ...,
        sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_self_link", b"kms_key_self_link", "kms_key_service_account", b"kms_key_service_account", "raw_key", b"raw_key", "sha256", b"sha256"]) -> None: ...

global___ComputeDiskXSourceSnapshotEncryptionKey = ComputeDiskXSourceSnapshotEncryptionKey

@typing_extensions.final
class ComputeDiskXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeDiskXTimeouts = ComputeDiskXTimeouts

@typing_extensions.final
class ComputeDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LAST_ATTACH_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_DETACH_TIMESTAMP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PHYSICAL_BLOCK_SIZE_BYTES_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROVISIONED_IOPS_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SNAPSHOT_FIELD_NUMBER: builtins.int
    SOURCE_IMAGE_ID_FIELD_NUMBER: builtins.int
    SOURCE_SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    SOURCE_IMAGE_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    SOURCE_SNAPSHOT_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    image: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    last_attach_timestamp: builtins.str
    last_detach_timestamp: builtins.str
    name: builtins.str
    physical_block_size_bytes: builtins.float
    project: builtins.str
    provisioned_iops: builtins.float
    self_link: builtins.str
    size: builtins.float
    snapshot: builtins.str
    source_image_id: builtins.str
    source_snapshot_id: builtins.str
    type: builtins.str
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    zone: builtins.str
    @property
    def disk_encryption_key(self) -> global___ComputeDiskXDiskEncryptionKey: ...
    @property
    def source_image_encryption_key(self) -> global___ComputeDiskXSourceImageEncryptionKey: ...
    @property
    def source_snapshot_encryption_key(self) -> global___ComputeDiskXSourceSnapshotEncryptionKey: ...
    @property
    def timeouts(self) -> global___ComputeDiskXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        image: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        last_attach_timestamp: builtins.str = ...,
        last_detach_timestamp: builtins.str = ...,
        name: builtins.str = ...,
        physical_block_size_bytes: builtins.float = ...,
        project: builtins.str = ...,
        provisioned_iops: builtins.float = ...,
        self_link: builtins.str = ...,
        size: builtins.float = ...,
        snapshot: builtins.str = ...,
        source_image_id: builtins.str = ...,
        source_snapshot_id: builtins.str = ...,
        type: builtins.str = ...,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        zone: builtins.str = ...,
        disk_encryption_key: global___ComputeDiskXDiskEncryptionKey | None = ...,
        source_image_encryption_key: global___ComputeDiskXSourceImageEncryptionKey | None = ...,
        source_snapshot_encryption_key: global___ComputeDiskXSourceSnapshotEncryptionKey | None = ...,
        timeouts: global___ComputeDiskXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_key", b"disk_encryption_key", "resource_info", b"resource_info", "source_image_encryption_key", b"source_image_encryption_key", "source_snapshot_encryption_key", b"source_snapshot_encryption_key", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "disk_encryption_key", b"disk_encryption_key", "id", b"id", "image", b"image", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "last_attach_timestamp", b"last_attach_timestamp", "last_detach_timestamp", b"last_detach_timestamp", "name", b"name", "physical_block_size_bytes", b"physical_block_size_bytes", "project", b"project", "provisioned_iops", b"provisioned_iops", "resource_info", b"resource_info", "self_link", b"self_link", "size", b"size", "snapshot", b"snapshot", "source_image_encryption_key", b"source_image_encryption_key", "source_image_id", b"source_image_id", "source_snapshot_encryption_key", b"source_snapshot_encryption_key", "source_snapshot_id", b"source_snapshot_id", "timeouts", b"timeouts", "type", b"type", "users", b"users", "zone", b"zone"]) -> None: ...

global___ComputeDisk = ComputeDisk

@typing_extensions.final
class ComputeDiskIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeDiskIamBindingXCondition = ComputeDiskIamBindingXCondition

@typing_extensions.final
class ComputeDiskIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    role: builtins.str
    zone: builtins.str
    @property
    def condition(self) -> global___ComputeDiskIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        zone: builtins.str = ...,
        condition: global___ComputeDiskIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "name", b"name", "project", b"project", "resource_info", b"resource_info", "role", b"role", "zone", b"zone"]) -> None: ...

global___ComputeDiskIamBinding = ComputeDiskIamBinding

@typing_extensions.final
class ComputeDiskIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeDiskIamMemberXCondition = ComputeDiskIamMemberXCondition

@typing_extensions.final
class ComputeDiskIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    name: builtins.str
    project: builtins.str
    role: builtins.str
    zone: builtins.str
    @property
    def condition(self) -> global___ComputeDiskIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        zone: builtins.str = ...,
        condition: global___ComputeDiskIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "name", b"name", "project", b"project", "resource_info", b"resource_info", "role", b"role", "zone", b"zone"]) -> None: ...

global___ComputeDiskIamMember = ComputeDiskIamMember

@typing_extensions.final
class ComputeDiskIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    name: builtins.str
    policy_data: builtins.str
    project: builtins.str
    zone: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        zone: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "name", b"name", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "zone", b"zone"]) -> None: ...

global___ComputeDiskIamPolicy = ComputeDiskIamPolicy

@typing_extensions.final
class ComputeDiskResourcePolicyAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeDiskResourcePolicyAttachmentXTimeouts = ComputeDiskResourcePolicyAttachmentXTimeouts

@typing_extensions.final
class ComputeDiskResourcePolicyAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    disk: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___ComputeDiskResourcePolicyAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        disk: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___ComputeDiskResourcePolicyAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk", b"disk", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeDiskResourcePolicyAttachment = ComputeDiskResourcePolicyAttachment
