# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_iot.proto\x12\x13oak9.tython.aws.iot\x1a\x13shared/shared.proto\"[\n AuthorizerTokenSigningPublicKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x01\n\x0e\x41uthorizerTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\x04tags\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iot.AuthorizerTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x02\n\nAuthorizer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x61uthorizer_function_arn\x18\x02 \x01(\t\x12\x17\n\x0f\x61uthorizer_name\x18\x03 \x01(\t\x12\x18\n\x10signing_disabled\x18\x04 \x01(\x08\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x16\n\x0etoken_key_name\x18\x06 \x01(\t\x12X\n\x19token_signing_public_keys\x18\x07 \x01(\x0b\x32\x35.oak9.tython.aws.iot.AuthorizerTokenSigningPublicKeys\x12\x31\n\x04tags\x18\x08 \x01(\x0b\x32#.oak9.tython.aws.iot.AuthorizerTags\"\xef\x03\n\x03IoT\x12\x33\n\nauthorizer\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.iot.Authorizer\x12\x35\n\x0b\x63\x65rtificate\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.iot.Certificate\x12+\n\x06policy\x18\x03 \x03(\x0b\x32\x1b.oak9.tython.aws.iot.Policy\x12S\n\x1bpolicy_principal_attachment\x18\x04 \x03(\x0b\x32..oak9.tython.aws.iot.PolicyPrincipalAttachment\x12H\n\x15provisioning_template\x18\x05 \x03(\x0b\x32).oak9.tython.aws.iot.ProvisioningTemplate\x12)\n\x05thing\x18\x06 \x03(\x0b\x32\x1a.oak9.tython.aws.iot.Thing\x12Q\n\x1athing_principal_attachment\x18\x07 \x03(\x0b\x32-.oak9.tython.aws.iot.ThingPrincipalAttachment\x12\x32\n\ntopic_rule\x18\x08 \x03(\x0b\x32\x1e.oak9.tython.aws.iot.TopicRule\"\xca\x01\n\x0b\x43\x65rtificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63\x61_certificate_pem\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_pem\x18\x03 \x01(\t\x12#\n\x1b\x63\x65rtificate_signing_request\x18\x04 \x01(\t\x12\x18\n\x10\x63\x65rtificate_mode\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\"\xd7\x01\n\x06Policy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x0fpolicy_document\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.iot.Policy.PolicyDocumentEntry\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\x1a\x35\n\x13PolicyDocumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x19PolicyPrincipalAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bpolicy_name\x18\x02 \x01(\t\x12\x11\n\tprincipal\x18\x03 \x01(\t\"\x8c\x01\n$ProvisioningTemplateProvisioningHook\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntarget_arn\x18\x02 \x01(\t\x12\x17\n\x0fpayload_version\x18\x03 \x01(\t\"\xc7\x01\n\x18ProvisioningTemplateTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x04tags\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.iot.ProvisioningTemplateTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x02\n\x14ProvisioningTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rtemplate_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x1d\n\x15provisioning_role_arn\x18\x05 \x01(\t\x12\x15\n\rtemplate_body\x18\x06 \x01(\t\x12X\n\x15pre_provisioning_hook\x18\x07 \x01(\x0b\x32\x39.oak9.tython.aws.iot.ProvisioningTemplateProvisioningHook\x12;\n\x04tags\x18\x08 \x01(\x0b\x32-.oak9.tython.aws.iot.ProvisioningTemplateTags\"\xd3\x01\n\x15ThingAttributePayload\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\nattributes\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.iot.ThingAttributePayload.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9b\x01\n\x05Thing\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x11\x61ttribute_payload\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.iot.ThingAttributePayload\x12\x12\n\nthing_name\x18\x03 \x01(\t\"z\n\x18ThingPrincipalAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tprincipal\x18\x02 \x01(\t\x12\x12\n\nthing_name\x18\x03 \x01(\t\"\xaa\x01\n\x1eTopicRuleCloudwatchAlarmAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nalarm_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x14\n\x0cstate_reason\x18\x04 \x01(\t\x12\x13\n\x0bstate_value\x18\x05 \x01(\t\"\xe0\x01\n\x1fTopicRuleCloudwatchMetricAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x18\n\x10metric_namespace\x18\x03 \x01(\t\x12\x18\n\x10metric_timestamp\x18\x04 \x01(\t\x12\x13\n\x0bmetric_unit\x18\x05 \x01(\t\x12\x14\n\x0cmetric_value\x18\x06 \x01(\t\x12\x10\n\x08role_arn\x18\x07 \x01(\t\"\xa0\x02\n\x17TopicRuleDynamoDBAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0ehash_key_field\x18\x02 \x01(\t\x12\x15\n\rhash_key_type\x18\x03 \x01(\t\x12\x16\n\x0ehash_key_value\x18\x04 \x01(\t\x12\x15\n\rpayload_field\x18\x05 \x01(\t\x12\x17\n\x0frange_key_field\x18\x06 \x01(\t\x12\x16\n\x0erange_key_type\x18\x07 \x01(\t\x12\x17\n\x0frange_key_value\x18\x08 \x01(\t\x12\x10\n\x08role_arn\x18\t \x01(\t\x12\x12\n\ntable_name\x18\n \x01(\t\"d\n\x15TopicRulePutItemInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\"\xa4\x01\n\x19TopicRuleDynamoDBv2Action\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x08put_item\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.iot.TopicRulePutItemInput\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x96\x01\n\x1cTopicRuleElasticsearchAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\x95\x01\n\x17TopicRuleFirehoseAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x65livery_stream_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x11\n\tseparator\x18\x04 \x01(\t\"\x96\x01\n\x1bTopicRuleSigV4Authorization\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12\x14\n\x0cservice_name\x18\x03 \x01(\t\x12\x16\n\x0esigning_region\x18\x04 \x01(\t\"\x96\x01\n\x1aTopicRuleHttpAuthorization\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\x05sigv4\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.iot.TopicRuleSigV4Authorization\"p\n\x19TopicRuleHttpActionHeader\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xf5\x01\n\x13TopicRuleHttpAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x04\x61uth\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.iot.TopicRuleHttpAuthorization\x12\x18\n\x10\x63onfirmation_url\x18\x03 \x01(\t\x12?\n\x07headers\x18\x04 \x03(\x0b\x32..oak9.tython.aws.iot.TopicRuleHttpActionHeader\x12\x0b\n\x03url\x18\x05 \x01(\t\"~\n\x1bTopicRuleIotAnalyticsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x8d\x01\n\x18TopicRuleIotEventsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ninput_name\x18\x02 \x01(\t\x12\x12\n\nmessage_id\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\x8c\x01\n\x1fTopicRuleAssetPropertyTimestamp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0foffset_in_nanos\x18\x02 \x01(\t\x12\x17\n\x0ftime_in_seconds\x18\x03 \x01(\t\"\xb2\x01\n\x1dTopicRuleAssetPropertyVariant\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rboolean_value\x18\x02 \x01(\t\x12\x14\n\x0c\x64ouble_value\x18\x03 \x01(\t\x12\x15\n\rinteger_value\x18\x04 \x01(\t\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\"\xf3\x01\n\x1bTopicRuleAssetPropertyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07quality\x18\x02 \x01(\t\x12G\n\ttimestamp\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.iot.TopicRuleAssetPropertyTimestamp\x12\x41\n\x05value\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.iot.TopicRuleAssetPropertyVariant\"\xfa\x01\n#TopicRulePutAssetPropertyValueEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x61sset_id\x18\x02 \x01(\t\x12\x10\n\x08\x65ntry_id\x18\x03 \x01(\t\x12\x16\n\x0eproperty_alias\x18\x04 \x01(\t\x12\x13\n\x0bproperty_id\x18\x05 \x01(\t\x12I\n\x0fproperty_values\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.iot.TopicRuleAssetPropertyValue\"\xcb\x01\n\x1aTopicRuleIotSiteWiseAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n put_asset_property_value_entries\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.iot.TopicRulePutAssetPropertyValueEntry\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x8f\x01\n\x16TopicRuleKinesisAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rpartition_key\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"f\n\x15TopicRuleLambdaAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66unction_arn\x18\x02 \x01(\t\"\x81\x01\n\x18TopicRuleRepublishAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03qos\x18\x02 \x01(\x05\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\r\n\x05topic\x18\x04 \x01(\t\"\x80\x01\n\x11TopicRuleS3Action\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x62ucket_name\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\x8b\x01\n\x12TopicRuleSnsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0emessage_format\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x12\n\ntarget_arn\x18\x04 \x01(\t\"\x86\x01\n\x12TopicRuleSqsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tqueue_url\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x12\n\nuse_base64\x18\x04 \x01(\x08\"\xa4\x01\n\x1cTopicRuleStepFunctionsAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x65xecution_name_prefix\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x1a\n\x12state_machine_name\x18\x04 \x01(\t\"\xad\t\n\x0fTopicRuleAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x10\x63loudwatch_alarm\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.iot.TopicRuleCloudwatchAlarmAction\x12O\n\x11\x63loudwatch_metric\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.iot.TopicRuleCloudwatchMetricAction\x12?\n\tdynamo_db\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.iot.TopicRuleDynamoDBAction\x12\x43\n\x0b\x64ynamo_dbv2\x18\x05 \x01(\x0b\x32..oak9.tython.aws.iot.TopicRuleDynamoDBv2Action\x12H\n\relasticsearch\x18\x06 \x01(\x0b\x32\x31.oak9.tython.aws.iot.TopicRuleElasticsearchAction\x12>\n\x08\x66irehose\x18\x07 \x01(\x0b\x32,.oak9.tython.aws.iot.TopicRuleFirehoseAction\x12\x36\n\x04http\x18\x08 \x01(\x0b\x32(.oak9.tython.aws.iot.TopicRuleHttpAction\x12G\n\riot_analytics\x18\t \x01(\x0b\x32\x30.oak9.tython.aws.iot.TopicRuleIotAnalyticsAction\x12\x41\n\niot_events\x18\n \x01(\x0b\x32-.oak9.tython.aws.iot.TopicRuleIotEventsAction\x12\x46\n\riot_site_wise\x18\x0b \x01(\x0b\x32/.oak9.tython.aws.iot.TopicRuleIotSiteWiseAction\x12<\n\x07kinesis\x18\x0c \x01(\x0b\x32+.oak9.tython.aws.iot.TopicRuleKinesisAction\x12:\n\x06lambda\x18\r \x01(\x0b\x32*.oak9.tython.aws.iot.TopicRuleLambdaAction\x12@\n\trepublish\x18\x0e \x01(\x0b\x32-.oak9.tython.aws.iot.TopicRuleRepublishAction\x12\x32\n\x02s3\x18\x0f \x01(\x0b\x32&.oak9.tython.aws.iot.TopicRuleS3Action\x12\x34\n\x03sns\x18\x10 \x01(\x0b\x32\'.oak9.tython.aws.iot.TopicRuleSnsAction\x12\x34\n\x03sqs\x18\x11 \x01(\x0b\x32\'.oak9.tython.aws.iot.TopicRuleSqsAction\x12I\n\x0estep_functions\x18\x12 \x01(\x0b\x32\x31.oak9.tython.aws.iot.TopicRuleStepFunctionsAction\"\x9d\x02\n\x19TopicRuleTopicRulePayload\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x35\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32$.oak9.tython.aws.iot.TopicRuleAction\x12\x1b\n\x13\x61ws_iot_sql_version\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12:\n\x0c\x65rror_action\x18\x05 \x01(\x0b\x32$.oak9.tython.aws.iot.TopicRuleAction\x12\x15\n\rrule_disabled\x18\x06 \x01(\x08\x12\x0b\n\x03sql\x18\x07 \x01(\t\"\xa3\x01\n\tTopicRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\trule_name\x18\x02 \x01(\t\x12J\n\x12topic_rule_payload\x18\x03 \x01(\x0b\x32..oak9.tython.aws.iot.TopicRuleTopicRulePayloadb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUTHORIZERTAGS_TAGSENTRY._options = None
  _AUTHORIZERTAGS_TAGSENTRY._serialized_options = b'8\001'
  _POLICY_POLICYDOCUMENTENTRY._options = None
  _POLICY_POLICYDOCUMENTENTRY._serialized_options = b'8\001'
  _PROVISIONINGTEMPLATETAGS_TAGSENTRY._options = None
  _PROVISIONINGTEMPLATETAGS_TAGSENTRY._serialized_options = b'8\001'
  _THINGATTRIBUTEPAYLOAD_ATTRIBUTESENTRY._options = None
  _THINGATTRIBUTEPAYLOAD_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _AUTHORIZERTOKENSIGNINGPUBLICKEYS._serialized_start=63
  _AUTHORIZERTOKENSIGNINGPUBLICKEYS._serialized_end=154
  _AUTHORIZERTAGS._serialized_start=157
  _AUTHORIZERTAGS._serialized_end=336
  _AUTHORIZERTAGS_TAGSENTRY._serialized_start=293
  _AUTHORIZERTAGS_TAGSENTRY._serialized_end=336
  _AUTHORIZER._serialized_start=339
  _AUTHORIZER._serialized_end=673
  _IOT._serialized_start=676
  _IOT._serialized_end=1171
  _CERTIFICATE._serialized_start=1174
  _CERTIFICATE._serialized_end=1376
  _POLICY._serialized_start=1379
  _POLICY._serialized_end=1594
  _POLICY_POLICYDOCUMENTENTRY._serialized_start=1541
  _POLICY_POLICYDOCUMENTENTRY._serialized_end=1594
  _POLICYPRINCIPALATTACHMENT._serialized_start=1596
  _POLICYPRINCIPALATTACHMENT._serialized_end=1720
  _PROVISIONINGTEMPLATEPROVISIONINGHOOK._serialized_start=1723
  _PROVISIONINGTEMPLATEPROVISIONINGHOOK._serialized_end=1863
  _PROVISIONINGTEMPLATETAGS._serialized_start=1866
  _PROVISIONINGTEMPLATETAGS._serialized_end=2065
  _PROVISIONINGTEMPLATETAGS_TAGSENTRY._serialized_start=293
  _PROVISIONINGTEMPLATETAGS_TAGSENTRY._serialized_end=336
  _PROVISIONINGTEMPLATE._serialized_start=2068
  _PROVISIONINGTEMPLATE._serialized_end=2413
  _THINGATTRIBUTEPAYLOAD._serialized_start=2416
  _THINGATTRIBUTEPAYLOAD._serialized_end=2627
  _THINGATTRIBUTEPAYLOAD_ATTRIBUTESENTRY._serialized_start=2578
  _THINGATTRIBUTEPAYLOAD_ATTRIBUTESENTRY._serialized_end=2627
  _THING._serialized_start=2630
  _THING._serialized_end=2785
  _THINGPRINCIPALATTACHMENT._serialized_start=2787
  _THINGPRINCIPALATTACHMENT._serialized_end=2909
  _TOPICRULECLOUDWATCHALARMACTION._serialized_start=2912
  _TOPICRULECLOUDWATCHALARMACTION._serialized_end=3082
  _TOPICRULECLOUDWATCHMETRICACTION._serialized_start=3085
  _TOPICRULECLOUDWATCHMETRICACTION._serialized_end=3309
  _TOPICRULEDYNAMODBACTION._serialized_start=3312
  _TOPICRULEDYNAMODBACTION._serialized_end=3600
  _TOPICRULEPUTITEMINPUT._serialized_start=3602
  _TOPICRULEPUTITEMINPUT._serialized_end=3702
  _TOPICRULEDYNAMODBV2ACTION._serialized_start=3705
  _TOPICRULEDYNAMODBV2ACTION._serialized_end=3869
  _TOPICRULEELASTICSEARCHACTION._serialized_start=3872
  _TOPICRULEELASTICSEARCHACTION._serialized_end=4022
  _TOPICRULEFIREHOSEACTION._serialized_start=4025
  _TOPICRULEFIREHOSEACTION._serialized_end=4174
  _TOPICRULESIGV4AUTHORIZATION._serialized_start=4177
  _TOPICRULESIGV4AUTHORIZATION._serialized_end=4327
  _TOPICRULEHTTPAUTHORIZATION._serialized_start=4330
  _TOPICRULEHTTPAUTHORIZATION._serialized_end=4480
  _TOPICRULEHTTPACTIONHEADER._serialized_start=4482
  _TOPICRULEHTTPACTIONHEADER._serialized_end=4594
  _TOPICRULEHTTPACTION._serialized_start=4597
  _TOPICRULEHTTPACTION._serialized_end=4842
  _TOPICRULEIOTANALYTICSACTION._serialized_start=4844
  _TOPICRULEIOTANALYTICSACTION._serialized_end=4970
  _TOPICRULEIOTEVENTSACTION._serialized_start=4973
  _TOPICRULEIOTEVENTSACTION._serialized_end=5114
  _TOPICRULEASSETPROPERTYTIMESTAMP._serialized_start=5117
  _TOPICRULEASSETPROPERTYTIMESTAMP._serialized_end=5257
  _TOPICRULEASSETPROPERTYVARIANT._serialized_start=5260
  _TOPICRULEASSETPROPERTYVARIANT._serialized_end=5438
  _TOPICRULEASSETPROPERTYVALUE._serialized_start=5441
  _TOPICRULEASSETPROPERTYVALUE._serialized_end=5684
  _TOPICRULEPUTASSETPROPERTYVALUEENTRY._serialized_start=5687
  _TOPICRULEPUTASSETPROPERTYVALUEENTRY._serialized_end=5937
  _TOPICRULEIOTSITEWISEACTION._serialized_start=5940
  _TOPICRULEIOTSITEWISEACTION._serialized_end=6143
  _TOPICRULEKINESISACTION._serialized_start=6146
  _TOPICRULEKINESISACTION._serialized_end=6289
  _TOPICRULELAMBDAACTION._serialized_start=6291
  _TOPICRULELAMBDAACTION._serialized_end=6393
  _TOPICRULEREPUBLISHACTION._serialized_start=6396
  _TOPICRULEREPUBLISHACTION._serialized_end=6525
  _TOPICRULES3ACTION._serialized_start=6528
  _TOPICRULES3ACTION._serialized_end=6656
  _TOPICRULESNSACTION._serialized_start=6659
  _TOPICRULESNSACTION._serialized_end=6798
  _TOPICRULESQSACTION._serialized_start=6801
  _TOPICRULESQSACTION._serialized_end=6935
  _TOPICRULESTEPFUNCTIONSACTION._serialized_start=6938
  _TOPICRULESTEPFUNCTIONSACTION._serialized_end=7102
  _TOPICRULEACTION._serialized_start=7105
  _TOPICRULEACTION._serialized_end=8302
  _TOPICRULETOPICRULEPAYLOAD._serialized_start=8305
  _TOPICRULETOPICRULEPAYLOAD._serialized_end=8590
  _TOPICRULE._serialized_start=8593
  _TOPICRULE._serialized_end=8756
# @@protoc_insertion_point(module_scope)
