"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FilestoreInstanceXFileSharesXNfsExportOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_MODE_FIELD_NUMBER: builtins.int
    ANON_GID_FIELD_NUMBER: builtins.int
    ANON_UID_FIELD_NUMBER: builtins.int
    IP_RANGES_FIELD_NUMBER: builtins.int
    SQUASH_MODE_FIELD_NUMBER: builtins.int
    access_mode: builtins.str
    anon_gid: builtins.float
    anon_uid: builtins.float
    @property
    def ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    squash_mode: builtins.str
    def __init__(
        self,
        *,
        access_mode: builtins.str = ...,
        anon_gid: builtins.float = ...,
        anon_uid: builtins.float = ...,
        ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        squash_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_mode", b"access_mode", "anon_gid", b"anon_gid", "anon_uid", b"anon_uid", "ip_ranges", b"ip_ranges", "squash_mode", b"squash_mode"]) -> None: ...

global___FilestoreInstanceXFileSharesXNfsExportOptions = FilestoreInstanceXFileSharesXNfsExportOptions

@typing_extensions.final
class FilestoreInstanceXFileShares(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_GB_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NFS_EXPORT_OPTIONS_FIELD_NUMBER: builtins.int
    capacity_gb: builtins.float
    name: builtins.str
    @property
    def nfs_export_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FilestoreInstanceXFileSharesXNfsExportOptions]: ...
    def __init__(
        self,
        *,
        capacity_gb: builtins.float = ...,
        name: builtins.str = ...,
        nfs_export_options: collections.abc.Iterable[global___FilestoreInstanceXFileSharesXNfsExportOptions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity_gb", b"capacity_gb", "name", b"name", "nfs_export_options", b"nfs_export_options"]) -> None: ...

global___FilestoreInstanceXFileShares = FilestoreInstanceXFileShares

@typing_extensions.final
class FilestoreInstanceXNetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECT_MODE_FIELD_NUMBER: builtins.int
    IP_ADDRESSES_FIELD_NUMBER: builtins.int
    MODES_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    RESERVED_IP_RANGE_FIELD_NUMBER: builtins.int
    connect_mode: builtins.str
    @property
    def ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def modes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    network: builtins.str
    reserved_ip_range: builtins.str
    def __init__(
        self,
        *,
        connect_mode: builtins.str = ...,
        ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        modes: collections.abc.Iterable[builtins.str] | None = ...,
        network: builtins.str = ...,
        reserved_ip_range: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connect_mode", b"connect_mode", "ip_addresses", b"ip_addresses", "modes", b"modes", "network", b"network", "reserved_ip_range", b"reserved_ip_range"]) -> None: ...

global___FilestoreInstanceXNetworks = FilestoreInstanceXNetworks

@typing_extensions.final
class FilestoreInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___FilestoreInstanceXTimeouts = FilestoreInstanceXTimeouts

@typing_extensions.final
class FilestoreInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    FILE_SHARES_FIELD_NUMBER: builtins.int
    NETWORKS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    etag: builtins.str
    id: builtins.str
    kms_key_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    tier: builtins.str
    zone: builtins.str
    @property
    def file_shares(self) -> global___FilestoreInstanceXFileShares: ...
    @property
    def networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FilestoreInstanceXNetworks]: ...
    @property
    def timeouts(self) -> global___FilestoreInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tier: builtins.str = ...,
        zone: builtins.str = ...,
        file_shares: global___FilestoreInstanceXFileShares | None = ...,
        networks: collections.abc.Iterable[global___FilestoreInstanceXNetworks] | None = ...,
        timeouts: global___FilestoreInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file_shares", b"file_shares", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "etag", b"etag", "file_shares", b"file_shares", "id", b"id", "kms_key_name", b"kms_key_name", "labels", b"labels", "location", b"location", "name", b"name", "networks", b"networks", "project", b"project", "resource_info", b"resource_info", "tier", b"tier", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___FilestoreInstance = FilestoreInstance
