# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_firewallpolicies.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4azure/azure_microsoft_network_firewallpolicies.proto\x12\x34oak9.tython.azure.microsoft_network_firewallpolicies\x1a\x13shared/shared.proto\"\x87\x01\n\"Microsoft_Network_firewallPolicies\x12\x61\n\x11\x66irewall_policies\x18\x01 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicies\"\xed\x01\n$FirewallPoliciesRuleCollectionGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12l\n\x10rule_collections\x18\x04 \x03(\x0b\x32R.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyRuleCollection\"\\\n\x1c\x46irewallPolicyRuleCollection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12\x1c\n\x14rule_collection_type\x18\x03 \x01(\t\"\xa8\x08\n\x10\x46irewallPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12^\n\x04tags\x18\x04 \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicies.TagsEntry\x12\x13\n\x0b\x62\x61se_policy\x18\x05 \x01(\t\x12\x19\n\x11threat_intel_mode\x18\x06 \x01(\t\x12x\n\x16threat_intel_whitelist\x18\x07 \x01(\x0b\x32X.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyThreatIntelWhitelist\x12W\n\x0c\x64ns_settings\x18\x08 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_firewallpolicies.DnsSettings\x12s\n\x13intrusion_detection\x18\t \x01(\x0b\x32V.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyIntrusionDetection\x12q\n\x12transport_security\x18\n \x01(\x0b\x32U.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyTransportSecurity\x12T\n\x03sku\x18\x0b \x01(\x0b\x32G.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicySku\x12^\n\x08identity\x18\x0c \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_firewallpolicies.ManagedServiceIdentity\x12\x8c\x01\n(firewall_policies_rule_collection_groups\x18\r \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPoliciesRuleCollectionGroups\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf2\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x8a\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32h.oak9.tython.azure.microsoft_network_firewallpolicies.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"!\n\x11\x46irewallPolicySku\x12\x0c\n\x04tier\x18\x01 \x01(\t\"\x9a\x01\n\x1f\x46irewallPolicyTransportSecurity\x12w\n\x15\x63\x65rtificate_authority\x18\x01 \x01(\x0b\x32X.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyCertificateAuthority\"O\n\"FirewallPolicyCertificateAuthority\x12\x1b\n\x13key_vault_secret_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xac\x01\n FirewallPolicyIntrusionDetection\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12z\n\rconfiguration\x18\x02 \x01(\x0b\x32\x63.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyIntrusionDetectionConfiguration\"\xd0\x02\n-FirewallPolicyIntrusionDetectionConfiguration\x12\x89\x01\n\x13signature_overrides\x18\x01 \x03(\x0b\x32l.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyIntrusionDetectionSignatureSpecification\x12\x92\x01\n\x17\x62ypass_traffic_settings\x18\x02 \x03(\x0b\x32q.oak9.tython.azure.microsoft_network_firewallpolicies.FirewallPolicyIntrusionDetectionBypassTrafficSpecifications\"\xff\x01\n;FirewallPolicyIntrusionDetectionBypassTrafficSpecifications\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x18\n\x10source_addresses\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x65stination_addresses\x18\x05 \x03(\t\x12\x19\n\x11\x64\x65stination_ports\x18\x06 \x03(\t\x12\x18\n\x10source_ip_groups\x18\x07 \x03(\t\x12\x1d\n\x15\x64\x65stination_ip_groups\x18\x08 \x03(\t\"R\n6FirewallPolicyIntrusionDetectionSignatureSpecification\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\t\"]\n\x0b\x44nsSettings\x12\x0f\n\x07servers\x18\x01 \x03(\t\x12\x14\n\x0c\x65nable_proxy\x18\x02 \x01(\x08\x12\'\n\x1frequire_proxy_for_network_rules\x18\x03 \x01(\x08\"I\n\"FirewallPolicyThreatIntelWhitelist\x12\x14\n\x0cip_addresses\x18\x01 \x03(\t\x12\r\n\x05\x66qdns\x18\x02 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_firewallpolicies_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FIREWALLPOLICIES_TAGSENTRY._options = None
  _FIREWALLPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_FIREWALLPOLICIES._serialized_start=132
  _MICROSOFT_NETWORK_FIREWALLPOLICIES._serialized_end=267
  _FIREWALLPOLICIESRULECOLLECTIONGROUPS._serialized_start=270
  _FIREWALLPOLICIESRULECOLLECTIONGROUPS._serialized_end=507
  _FIREWALLPOLICYRULECOLLECTION._serialized_start=509
  _FIREWALLPOLICYRULECOLLECTION._serialized_end=601
  _FIREWALLPOLICIES._serialized_start=604
  _FIREWALLPOLICIES._serialized_end=1668
  _FIREWALLPOLICIES_TAGSENTRY._serialized_start=1625
  _FIREWALLPOLICIES_TAGSENTRY._serialized_end=1668
  _MANAGEDSERVICEIDENTITY._serialized_start=1671
  _MANAGEDSERVICEIDENTITY._serialized_end=1913
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=1852
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=1913
  _FIREWALLPOLICYSKU._serialized_start=1915
  _FIREWALLPOLICYSKU._serialized_end=1948
  _FIREWALLPOLICYTRANSPORTSECURITY._serialized_start=1951
  _FIREWALLPOLICYTRANSPORTSECURITY._serialized_end=2105
  _FIREWALLPOLICYCERTIFICATEAUTHORITY._serialized_start=2107
  _FIREWALLPOLICYCERTIFICATEAUTHORITY._serialized_end=2186
  _FIREWALLPOLICYINTRUSIONDETECTION._serialized_start=2189
  _FIREWALLPOLICYINTRUSIONDETECTION._serialized_end=2361
  _FIREWALLPOLICYINTRUSIONDETECTIONCONFIGURATION._serialized_start=2364
  _FIREWALLPOLICYINTRUSIONDETECTIONCONFIGURATION._serialized_end=2700
  _FIREWALLPOLICYINTRUSIONDETECTIONBYPASSTRAFFICSPECIFICATIONS._serialized_start=2703
  _FIREWALLPOLICYINTRUSIONDETECTIONBYPASSTRAFFICSPECIFICATIONS._serialized_end=2958
  _FIREWALLPOLICYINTRUSIONDETECTIONSIGNATURESPECIFICATION._serialized_start=2960
  _FIREWALLPOLICYINTRUSIONDETECTIONSIGNATURESPECIFICATION._serialized_end=3042
  _DNSSETTINGS._serialized_start=3044
  _DNSSETTINGS._serialized_end=3137
  _FIREWALLPOLICYTHREATINTELWHITELIST._serialized_start=3139
  _FIREWALLPOLICYTHREATINTELWHITELIST._serialized_end=3212
# @@protoc_insertion_point(module_scope)
