"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServiceAccountXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create"]) -> None: ...

global___ServiceAccountXTimeouts = ServiceAccountXTimeouts

@typing_extensions.final
class ServiceAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    description: builtins.str
    disabled: builtins.bool
    display_name: builtins.str
    email: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    unique_id: builtins.str
    @property
    def timeouts(self) -> global___ServiceAccountXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        display_name: builtins.str = ...,
        email: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        unique_id: builtins.str = ...,
        timeouts: global___ServiceAccountXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "description", b"description", "disabled", b"disabled", "display_name", b"display_name", "email", b"email", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "unique_id", b"unique_id"]) -> None: ...

global___ServiceAccount = ServiceAccount

@typing_extensions.final
class ServiceAccountIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ServiceAccountIamBindingXCondition = ServiceAccountIamBindingXCondition

@typing_extensions.final
class ServiceAccountIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    service_account_id: builtins.str
    @property
    def condition(self) -> global___ServiceAccountIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        service_account_id: builtins.str = ...,
        condition: global___ServiceAccountIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role", "service_account_id", b"service_account_id"]) -> None: ...

global___ServiceAccountIamBinding = ServiceAccountIamBinding

@typing_extensions.final
class ServiceAccountIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ServiceAccountIamMemberXCondition = ServiceAccountIamMemberXCondition

@typing_extensions.final
class ServiceAccountIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    service_account_id: builtins.str
    @property
    def condition(self) -> global___ServiceAccountIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        service_account_id: builtins.str = ...,
        condition: global___ServiceAccountIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role", "service_account_id", b"service_account_id"]) -> None: ...

global___ServiceAccountIamMember = ServiceAccountIamMember

@typing_extensions.final
class ServiceAccountIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    service_account_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        service_account_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info", "service_account_id", b"service_account_id"]) -> None: ...

global___ServiceAccountIamPolicy = ServiceAccountIamPolicy

@typing_extensions.final
class ServiceAccountKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class KeepersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    KEEPERS_FIELD_NUMBER: builtins.int
    KEY_ALGORITHM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_TYPE_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_DATA_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_TYPE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    VALID_AFTER_FIELD_NUMBER: builtins.int
    VALID_BEFORE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def keepers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    key_algorithm: builtins.str
    name: builtins.str
    private_key: builtins.str
    private_key_type: builtins.str
    public_key: builtins.str
    public_key_data: builtins.str
    public_key_type: builtins.str
    service_account_id: builtins.str
    valid_after: builtins.str
    valid_before: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        keepers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        key_algorithm: builtins.str = ...,
        name: builtins.str = ...,
        private_key: builtins.str = ...,
        private_key_type: builtins.str = ...,
        public_key: builtins.str = ...,
        public_key_data: builtins.str = ...,
        public_key_type: builtins.str = ...,
        service_account_id: builtins.str = ...,
        valid_after: builtins.str = ...,
        valid_before: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "keepers", b"keepers", "key_algorithm", b"key_algorithm", "name", b"name", "private_key", b"private_key", "private_key_type", b"private_key_type", "public_key", b"public_key", "public_key_data", b"public_key_data", "public_key_type", b"public_key_type", "resource_info", b"resource_info", "service_account_id", b"service_account_id", "valid_after", b"valid_after", "valid_before", b"valid_before"]) -> None: ...

global___ServiceAccountKey = ServiceAccountKey

@typing_extensions.final
class ServiceNetworkingConnectionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ServiceNetworkingConnectionXTimeouts = ServiceNetworkingConnectionXTimeouts

@typing_extensions.final
class ServiceNetworkingConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PEERING_FIELD_NUMBER: builtins.int
    RESERVED_PEERING_RANGES_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    network: builtins.str
    peering: builtins.str
    @property
    def reserved_peering_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service: builtins.str
    @property
    def timeouts(self) -> global___ServiceNetworkingConnectionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        network: builtins.str = ...,
        peering: builtins.str = ...,
        reserved_peering_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        service: builtins.str = ...,
        timeouts: global___ServiceNetworkingConnectionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "network", b"network", "peering", b"peering", "reserved_peering_ranges", b"reserved_peering_ranges", "resource_info", b"resource_info", "service", b"service", "timeouts", b"timeouts"]) -> None: ...

global___ServiceNetworkingConnection = ServiceNetworkingConnection

@typing_extensions.final
class ServiceNetworkingPeeredDnsDomainXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read"]) -> None: ...

global___ServiceNetworkingPeeredDnsDomainXTimeouts = ServiceNetworkingPeeredDnsDomainXTimeouts

@typing_extensions.final
class ServiceNetworkingPeeredDnsDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_SUFFIX_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dns_suffix: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    parent: builtins.str
    project: builtins.str
    service: builtins.str
    @property
    def timeouts(self) -> global___ServiceNetworkingPeeredDnsDomainXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dns_suffix: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        parent: builtins.str = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        timeouts: global___ServiceNetworkingPeeredDnsDomainXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_suffix", b"dns_suffix", "id", b"id", "name", b"name", "network", b"network", "parent", b"parent", "project", b"project", "resource_info", b"resource_info", "service", b"service", "timeouts", b"timeouts"]) -> None: ...

global___ServiceNetworkingPeeredDnsDomain = ServiceNetworkingPeeredDnsDomain
