"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_FrontDoor_NetworkExperimentProfiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_EXPERIMENT_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def network_experiment_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkExperimentProfiles]: ...
    def __init__(
        self,
        *,
        network_experiment_profiles: collections.abc.Iterable[global___NetworkExperimentProfiles] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_experiment_profiles", b"network_experiment_profiles"]) -> None: ...

global___Microsoft_Network_FrontDoor_NetworkExperimentProfiles = Microsoft_Network_FrontDoor_NetworkExperimentProfiles

@typing_extensions.final
class NetworkExperimentProfilesExperiments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    ENDPOINT_A_FIELD_NUMBER: builtins.int
    ENDPOINT_B_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    description: builtins.str
    enabled_state: builtins.str
    @property
    def endpoint_a(self) -> global___Endpoint: ...
    @property
    def endpoint_b(self) -> global___Endpoint: ...
    resource_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        enabled_state: builtins.str = ...,
        endpoint_a: global___Endpoint | None = ...,
        endpoint_b: global___Endpoint | None = ...,
        resource_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoint_a", b"endpoint_a", "endpoint_b", b"endpoint_b", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "enabled_state", b"enabled_state", "endpoint_a", b"endpoint_a", "endpoint_b", b"endpoint_b", "location", b"location", "name", b"name", "resource_info", b"resource_info", "resource_state", b"resource_state", "tags", b"tags"]) -> None: ...

global___NetworkExperimentProfilesExperiments = NetworkExperimentProfilesExperiments

@typing_extensions.final
class Endpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    endpoint: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        endpoint: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "name", b"name"]) -> None: ...

global___Endpoint = Endpoint

@typing_extensions.final
class NetworkExperimentProfiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NETWORK_EXPERIMENT_PROFILES__EXPERIMENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    location: builtins.str
    name: builtins.str
    enabled_state: builtins.str
    resource_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def network_experiment_profiles__experiments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkExperimentProfilesExperiments]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        enabled_state: builtins.str = ...,
        resource_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_experiment_profiles__experiments: collections.abc.Iterable[global___NetworkExperimentProfilesExperiments] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled_state", b"enabled_state", "etag", b"etag", "location", b"location", "name", b"name", "network_experiment_profiles__experiments", b"network_experiment_profiles__experiments", "resource_info", b"resource_info", "resource_state", b"resource_state", "tags", b"tags"]) -> None: ...

global___NetworkExperimentProfiles = NetworkExperimentProfiles
