# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_certificate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_certificate.proto\x12\x1boak9.tython.gcp.certificate\x1a\x13shared/shared.proto\"c\n%CertificateManagerCertificateXManaged\x12\x1a\n\x12\x64ns_authorizations\x18\x01 \x03(\t\x12\x0f\n\x07\x64omains\x18\x02 \x03(\t\x12\r\n\x05state\x18\x03 \x01(\t\"]\n)CertificateManagerCertificateXSelfManaged\x12\x17\n\x0f\x63\x65rtificate_pem\x18\x01 \x01(\t\x12\x17\n\x0fprivate_key_pem\x18\x02 \x01(\t\"X\n&CertificateManagerCertificateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb8\x04\n\x1d\x43\x65rtificateManagerCertificate\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12V\n\x06labels\x18\x03 \x03(\x0b\x32\x46.oak9.tython.gcp.certificate.CertificateManagerCertificate.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12S\n\x07managed\x18\x07 \x01(\x0b\x32\x42.oak9.tython.gcp.certificate.CertificateManagerCertificateXManaged\x12\\\n\x0cself_managed\x18\x08 \x01(\x0b\x32\x46.oak9.tython.gcp.certificate.CertificateManagerCertificateXSelfManaged\x12U\n\x08timeouts\x18\t \x01(\x0b\x32\x43.oak9.tython.gcp.certificate.CertificateManagerCertificateXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n)CertificateManagerCertificateMapXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc3\x04\n CertificateManagerCertificateMap\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x64\n\x0cgclb_targets\x18\x03 \x03(\x0b\x32N.oak9.tython.gcp.certificate.CertificateManagerCertificateMap.GclbTargetsEntry\x12\n\n\x02id\x18\x04 \x01(\t\x12Y\n\x06labels\x18\x05 \x03(\x0b\x32I.oak9.tython.gcp.certificate.CertificateManagerCertificateMap.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12X\n\x08timeouts\x18\t \x01(\x0b\x32\x46.oak9.tython.gcp.certificate.CertificateManagerCertificateMapXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10GclbTargetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n.CertificateManagerCertificateMapEntryXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8d\x04\n%CertificateManagerCertificateMapEntry\x12\x14\n\x0c\x63\x65rtificates\x18\x01 \x03(\t\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08hostname\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12^\n\x06labels\x18\x06 \x03(\x0b\x32N.oak9.tython.gcp.certificate.CertificateManagerCertificateMapEntry.LabelsEntry\x12\x0b\n\x03map\x18\x07 \x01(\t\x12\x0f\n\x07matcher\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x13\n\x0bupdate_time\x18\x0c \x01(\t\x12]\n\x08timeouts\x18\r \x01(\x0b\x32K.oak9.tython.gcp.certificate.CertificateManagerCertificateMapEntryXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n+CertificateManagerDnsAuthorizationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc4\x04\n\"CertificateManagerDnsAuthorization\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12s\n\x13\x64ns_resource_record\x18\x02 \x03(\x0b\x32V.oak9.tython.gcp.certificate.CertificateManagerDnsAuthorization.DnsResourceRecordEntry\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12[\n\x06labels\x18\x05 \x03(\x0b\x32K.oak9.tython.gcp.certificate.CertificateManagerDnsAuthorization.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12Z\n\x08timeouts\x18\x08 \x01(\x0b\x32H.oak9.tython.gcp.certificate.CertificateManagerDnsAuthorizationXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x38\n\x16\x44nsResourceRecordEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_certificate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CERTIFICATEMANAGERCERTIFICATE_LABELSENTRY._options = None
  _CERTIFICATEMANAGERCERTIFICATE_LABELSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERCERTIFICATEMAP_GCLBTARGETSENTRY._options = None
  _CERTIFICATEMANAGERCERTIFICATEMAP_GCLBTARGETSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERCERTIFICATEMAP_LABELSENTRY._options = None
  _CERTIFICATEMANAGERCERTIFICATEMAP_LABELSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY_LABELSENTRY._options = None
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY_LABELSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERDNSAUTHORIZATION_DNSRESOURCERECORDENTRY._options = None
  _CERTIFICATEMANAGERDNSAUTHORIZATION_DNSRESOURCERECORDENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERDNSAUTHORIZATION_LABELSENTRY._options = None
  _CERTIFICATEMANAGERDNSAUTHORIZATION_LABELSENTRY._serialized_options = b'8\001'
  _CERTIFICATEMANAGERCERTIFICATEXMANAGED._serialized_start=79
  _CERTIFICATEMANAGERCERTIFICATEXMANAGED._serialized_end=178
  _CERTIFICATEMANAGERCERTIFICATEXSELFMANAGED._serialized_start=180
  _CERTIFICATEMANAGERCERTIFICATEXSELFMANAGED._serialized_end=273
  _CERTIFICATEMANAGERCERTIFICATEXTIMEOUTS._serialized_start=275
  _CERTIFICATEMANAGERCERTIFICATEXTIMEOUTS._serialized_end=363
  _CERTIFICATEMANAGERCERTIFICATE._serialized_start=366
  _CERTIFICATEMANAGERCERTIFICATE._serialized_end=934
  _CERTIFICATEMANAGERCERTIFICATE_LABELSENTRY._serialized_start=889
  _CERTIFICATEMANAGERCERTIFICATE_LABELSENTRY._serialized_end=934
  _CERTIFICATEMANAGERCERTIFICATEMAPXTIMEOUTS._serialized_start=936
  _CERTIFICATEMANAGERCERTIFICATEMAPXTIMEOUTS._serialized_end=1027
  _CERTIFICATEMANAGERCERTIFICATEMAP._serialized_start=1030
  _CERTIFICATEMANAGERCERTIFICATEMAP._serialized_end=1609
  _CERTIFICATEMANAGERCERTIFICATEMAP_GCLBTARGETSENTRY._serialized_start=1512
  _CERTIFICATEMANAGERCERTIFICATEMAP_GCLBTARGETSENTRY._serialized_end=1562
  _CERTIFICATEMANAGERCERTIFICATEMAP_LABELSENTRY._serialized_start=889
  _CERTIFICATEMANAGERCERTIFICATEMAP_LABELSENTRY._serialized_end=934
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRYXTIMEOUTS._serialized_start=1611
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRYXTIMEOUTS._serialized_end=1707
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY._serialized_start=1710
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY._serialized_end=2235
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY_LABELSENTRY._serialized_start=889
  _CERTIFICATEMANAGERCERTIFICATEMAPENTRY_LABELSENTRY._serialized_end=934
  _CERTIFICATEMANAGERDNSAUTHORIZATIONXTIMEOUTS._serialized_start=2237
  _CERTIFICATEMANAGERDNSAUTHORIZATIONXTIMEOUTS._serialized_end=2330
  _CERTIFICATEMANAGERDNSAUTHORIZATION._serialized_start=2333
  _CERTIFICATEMANAGERDNSAUTHORIZATION._serialized_end=2913
  _CERTIFICATEMANAGERDNSAUTHORIZATION_DNSRESOURCERECORDENTRY._serialized_start=2810
  _CERTIFICATEMANAGERDNSAUTHORIZATION_DNSRESOURCERECORDENTRY._serialized_end=2866
  _CERTIFICATEMANAGERDNSAUTHORIZATION_LABELSENTRY._serialized_start=889
  _CERTIFICATEMANAGERDNSAUTHORIZATION_LABELSENTRY._serialized_end=934
# @@protoc_insertion_point(module_scope)
