# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_detective.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_detective.proto\x12\x19oak9.tython.aws.detective\x1a\x13shared/shared.proto\"@\n\x05Graph\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x84\x01\n\tDetective\x12/\n\x05graph\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.detective.Graph\x12\x46\n\x11member_invitation\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.detective.MemberInvitation\"\xa0\x01\n\x10MemberInvitation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tgraph_arn\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\x1c\n\x14member_email_address\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_detective_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GRAPH._serialized_start=75
  _GRAPH._serialized_end=139
  _DETECTIVE._serialized_start=142
  _DETECTIVE._serialized_end=274
  _MEMBERINVITATION._serialized_start=277
  _MEMBERINVITATION._serialized_end=437
# @@protoc_insertion_point(module_scope)
