# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_robomaker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_robomaker.proto\x12\x19oak9.tython.aws.robomaker\x1a\x13shared/shared.proto\"\xb5\x01\n\x05\x46leet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x38\n\x04tags\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.robomaker.Fleet.TagsEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x03\n\tRoboMaker\x12/\n\x05\x66leet\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.robomaker.Fleet\x12/\n\x05robot\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.robomaker.Robot\x12\x46\n\x11robot_application\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.robomaker.RobotApplication\x12U\n\x19robot_application_version\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.robomaker.RobotApplicationVersion\x12P\n\x16simulation_application\x18\x05 \x03(\x0b\x32\x30.oak9.tython.aws.robomaker.SimulationApplication\x12_\n\x1esimulation_application_version\x18\x06 \x03(\x0b\x32\x37.oak9.tython.aws.robomaker.SimulationApplicationVersion\"\xf7\x01\n\x05Robot\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x66leet\x18\x02 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x03 \x01(\t\x12\x1b\n\x13greengrass_group_id\x18\x04 \x01(\t\x12\x38\n\x04tags\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.robomaker.Robot.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\"RobotApplicationRobotSoftwareSuite\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x90\x01\n\x1cRobotApplicationSourceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x03 \x01(\t\x12\x0e\n\x06s3_key\x18\x04 \x01(\t\"\x8f\x03\n\x10RobotApplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63urrent_revision_id\x18\x02 \x01(\t\x12[\n\x14robot_software_suite\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.robomaker.RobotApplicationRobotSoftwareSuite\x12H\n\x07sources\x18\x04 \x03(\x0b\x32\x37.oak9.tython.aws.robomaker.RobotApplicationSourceConfig\x12\x43\n\x04tags\x18\x05 \x03(\x0b\x32\x35.oak9.tython.aws.robomaker.RobotApplication.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x01\n\x17RobotApplicationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63urrent_revision_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"~\n$SimulationApplicationRenderingEngine\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x86\x01\n,SimulationApplicationSimulationSoftwareSuite\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x81\x01\n\'SimulationApplicationRobotSoftwareSuite\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x95\x01\n!SimulationApplicationSourceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x03 \x01(\t\x12\x0e\n\x06s3_key\x18\x04 \x01(\t\"\xea\x04\n\x15SimulationApplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x10rendering_engine\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.robomaker.SimulationApplicationRenderingEngine\x12j\n\x19simulation_software_suite\x18\x03 \x01(\x0b\x32G.oak9.tython.aws.robomaker.SimulationApplicationSimulationSoftwareSuite\x12\x1b\n\x13\x63urrent_revision_id\x18\x04 \x01(\t\x12`\n\x14robot_software_suite\x18\x05 \x01(\x0b\x32\x42.oak9.tython.aws.robomaker.SimulationApplicationRobotSoftwareSuite\x12M\n\x07sources\x18\x06 \x03(\x0b\x32<.oak9.tython.aws.robomaker.SimulationApplicationSourceConfig\x12H\n\x04tags\x18\x07 \x03(\x0b\x32:.oak9.tython.aws.robomaker.SimulationApplication.TagsEntry\x12\x0c\n\x04name\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x1cSimulationApplicationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63urrent_revision_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_robomaker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FLEET_TAGSENTRY._options = None
  _FLEET_TAGSENTRY._serialized_options = b'8\001'
  _ROBOT_TAGSENTRY._options = None
  _ROBOT_TAGSENTRY._serialized_options = b'8\001'
  _ROBOTAPPLICATION_TAGSENTRY._options = None
  _ROBOTAPPLICATION_TAGSENTRY._serialized_options = b'8\001'
  _SIMULATIONAPPLICATION_TAGSENTRY._options = None
  _SIMULATIONAPPLICATION_TAGSENTRY._serialized_options = b'8\001'
  _FLEET._serialized_start=76
  _FLEET._serialized_end=257
  _FLEET_TAGSENTRY._serialized_start=214
  _FLEET_TAGSENTRY._serialized_end=257
  _ROBOMAKER._serialized_start=260
  _ROBOMAKER._serialized_end=707
  _ROBOT._serialized_start=710
  _ROBOT._serialized_end=957
  _ROBOT_TAGSENTRY._serialized_start=214
  _ROBOT_TAGSENTRY._serialized_end=257
  _ROBOTAPPLICATIONROBOTSOFTWARESUITE._serialized_start=959
  _ROBOTAPPLICATIONROBOTSOFTWARESUITE._serialized_end=1083
  _ROBOTAPPLICATIONSOURCECONFIG._serialized_start=1086
  _ROBOTAPPLICATIONSOURCECONFIG._serialized_end=1230
  _ROBOTAPPLICATION._serialized_start=1233
  _ROBOTAPPLICATION._serialized_end=1632
  _ROBOTAPPLICATION_TAGSENTRY._serialized_start=214
  _ROBOTAPPLICATION_TAGSENTRY._serialized_end=257
  _ROBOTAPPLICATIONVERSION._serialized_start=1635
  _ROBOTAPPLICATIONVERSION._serialized_end=1767
  _SIMULATIONAPPLICATIONRENDERINGENGINE._serialized_start=1769
  _SIMULATIONAPPLICATIONRENDERINGENGINE._serialized_end=1895
  _SIMULATIONAPPLICATIONSIMULATIONSOFTWARESUITE._serialized_start=1898
  _SIMULATIONAPPLICATIONSIMULATIONSOFTWARESUITE._serialized_end=2032
  _SIMULATIONAPPLICATIONROBOTSOFTWARESUITE._serialized_start=2035
  _SIMULATIONAPPLICATIONROBOTSOFTWARESUITE._serialized_end=2164
  _SIMULATIONAPPLICATIONSOURCECONFIG._serialized_start=2167
  _SIMULATIONAPPLICATIONSOURCECONFIG._serialized_end=2316
  _SIMULATIONAPPLICATION._serialized_start=2319
  _SIMULATIONAPPLICATION._serialized_end=2937
  _SIMULATIONAPPLICATION_TAGSENTRY._serialized_start=214
  _SIMULATIONAPPLICATION_TAGSENTRY._serialized_end=257
  _SIMULATIONAPPLICATIONVERSION._serialized_start=2940
  _SIMULATIONAPPLICATIONVERSION._serialized_end=3077
# @@protoc_insertion_point(module_scope)
