"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EssentialContactsContactXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___EssentialContactsContactXTimeouts = EssentialContactsContactXTimeouts

@typing_extensions.final
class EssentialContactsContact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LANGUAGE_TAG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NOTIFICATION_CATEGORY_SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    email: builtins.str
    id: builtins.str
    language_tag: builtins.str
    name: builtins.str
    @property
    def notification_category_subscriptions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    parent: builtins.str
    @property
    def timeouts(self) -> global___EssentialContactsContactXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        id: builtins.str = ...,
        language_tag: builtins.str = ...,
        name: builtins.str = ...,
        notification_category_subscriptions: collections.abc.Iterable[builtins.str] | None = ...,
        parent: builtins.str = ...,
        timeouts: global___EssentialContactsContactXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "id", b"id", "language_tag", b"language_tag", "name", b"name", "notification_category_subscriptions", b"notification_category_subscriptions", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___EssentialContactsContact = EssentialContactsContact
