# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_security.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_security.proto\x12 oak9.tython.gcp.compute_security\x1a\x13shared/shared.proto\"q\nFComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x17\n\x0frule_visibility\x18\x02 \x01(\t\"\xc0\x01\n.ComputeSecurityPolicyXAdaptiveProtectionConfig\x12\x8d\x01\n\x1blayer_7_ddos_defense_config\x18\x01 \x01(\x0b\x32h.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig\"V\n+ComputeSecurityPolicyXAdvancedOptionsConfig\x12\x14\n\x0cjson_parsing\x18\x01 \x01(\t\x12\x11\n\tlog_level\x18\x02 \x01(\t\"@\n\'ComputeSecurityPolicyXRuleXMatchXConfig\x12\x15\n\rsrc_ip_ranges\x18\x01 \x03(\t\";\n%ComputeSecurityPolicyXRuleXMatchXExpr\x12\x12\n\nexpression\x18\x01 \x01(\t\"\xec\x01\n ComputeSecurityPolicyXRuleXMatch\x12\x16\n\x0eversioned_expr\x18\x01 \x01(\t\x12Y\n\x06\x63onfig\x18\x02 \x01(\x0b\x32I.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXMatchXConfig\x12U\n\x04\x65xpr\x18\x03 \x01(\x0b\x32G.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXMatchXExpr\"_\n8ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x14\n\x0cinterval_sec\x18\x02 \x01(\x01\"a\nAComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"e\n>ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x14\n\x0cinterval_sec\x18\x02 \x01(\x01\"\xa5\x04\n+ComputeSecurityPolicyXRuleXRateLimitOptions\x12\x18\n\x10\x62\x61n_duration_sec\x18\x01 \x01(\x01\x12\x16\n\x0e\x63onform_action\x18\x02 \x01(\t\x12\x16\n\x0e\x65nforce_on_key\x18\x03 \x01(\t\x12\x1b\n\x13\x65nforce_on_key_name\x18\x04 \x01(\t\x12\x15\n\rexceed_action\x18\x05 \x01(\t\x12q\n\rban_threshold\x18\x06 \x01(\x0b\x32Z.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold\x12\x84\x01\n\x17\x65xceed_redirect_options\x18\x07 \x01(\x0b\x32\x63.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions\x12~\n\x14rate_limit_threshold\x18\x08 \x01(\x0b\x32`.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold\"J\n*ComputeSecurityPolicyXRuleXRedirectOptions\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x8a\x03\n\x1a\x43omputeSecurityPolicyXRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07preview\x18\x03 \x01(\x08\x12\x10\n\x08priority\x18\x04 \x01(\x01\x12Q\n\x05match\x18\x05 \x01(\x0b\x32\x42.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXMatch\x12i\n\x12rate_limit_options\x18\x06 \x01(\x0b\x32M.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRateLimitOptions\x12\x66\n\x10redirect_options\x18\x07 \x01(\x0b\x32L.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRedirectOptions\"P\n\x1e\x43omputeSecurityPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcc\x04\n\x15\x43omputeSecurityPolicy\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x11\n\tself_link\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\x12t\n\x1a\x61\x64\x61ptive_protection_config\x18\x08 \x01(\x0b\x32P.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXAdaptiveProtectionConfig\x12n\n\x17\x61\x64vanced_options_config\x18\t \x01(\x0b\x32M.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXAdvancedOptionsConfig\x12J\n\x04rule\x18\n \x03(\x0b\x32<.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRule\x12R\n\x08timeouts\x18\x0b \x01(\x0b\x32@.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_security_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESECURITYPOLICYXADAPTIVEPROTECTIONCONFIGXLAYER7DDOSDEFENSECONFIG._serialized_start=89
  _COMPUTESECURITYPOLICYXADAPTIVEPROTECTIONCONFIGXLAYER7DDOSDEFENSECONFIG._serialized_end=202
  _COMPUTESECURITYPOLICYXADAPTIVEPROTECTIONCONFIG._serialized_start=205
  _COMPUTESECURITYPOLICYXADAPTIVEPROTECTIONCONFIG._serialized_end=397
  _COMPUTESECURITYPOLICYXADVANCEDOPTIONSCONFIG._serialized_start=399
  _COMPUTESECURITYPOLICYXADVANCEDOPTIONSCONFIG._serialized_end=485
  _COMPUTESECURITYPOLICYXRULEXMATCHXCONFIG._serialized_start=487
  _COMPUTESECURITYPOLICYXRULEXMATCHXCONFIG._serialized_end=551
  _COMPUTESECURITYPOLICYXRULEXMATCHXEXPR._serialized_start=553
  _COMPUTESECURITYPOLICYXRULEXMATCHXEXPR._serialized_end=612
  _COMPUTESECURITYPOLICYXRULEXMATCH._serialized_start=615
  _COMPUTESECURITYPOLICYXRULEXMATCH._serialized_end=851
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXBANTHRESHOLD._serialized_start=853
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXBANTHRESHOLD._serialized_end=948
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXEXCEEDREDIRECTOPTIONS._serialized_start=950
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXEXCEEDREDIRECTOPTIONS._serialized_end=1047
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXRATELIMITTHRESHOLD._serialized_start=1049
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXRATELIMITTHRESHOLD._serialized_end=1150
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONS._serialized_start=1153
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONS._serialized_end=1702
  _COMPUTESECURITYPOLICYXRULEXREDIRECTOPTIONS._serialized_start=1704
  _COMPUTESECURITYPOLICYXRULEXREDIRECTOPTIONS._serialized_end=1778
  _COMPUTESECURITYPOLICYXRULE._serialized_start=1781
  _COMPUTESECURITYPOLICYXRULE._serialized_end=2175
  _COMPUTESECURITYPOLICYXTIMEOUTS._serialized_start=2177
  _COMPUTESECURITYPOLICYXTIMEOUTS._serialized_end=2257
  _COMPUTESECURITYPOLICY._serialized_start=2260
  _COMPUTESECURITYPOLICY._serialized_end=2848
# @@protoc_insertion_point(module_scope)
