# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_storage_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_storage_pb2 as gcp_dot_gcp__storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#gcp/gcp_google_storage_bundle.proto\x12%oak9.tython.gcp.google_storage_bundle\x1a\x13shared/shared.proto\x1a\x15gcp/gcp_storage.proto\"\xfb\x08\n\rGoogleStorage\x12>\n\x0estorage_bucket\x18\x01 \x01(\x0b\x32&.oak9.tython.gcp.storage.StorageBucket\x12Z\n\x1dstorage_bucket_access_control\x18\x02 \x03(\x0b\x32\x33.oak9.tython.gcp.storage.StorageBucketAccessControl\x12\x45\n\x12storage_bucket_acl\x18\x03 \x03(\x0b\x32).oak9.tython.gcp.storage.StorageBucketAcl\x12T\n\x1astorage_bucket_iam_binding\x18\x04 \x03(\x0b\x32\x30.oak9.tython.gcp.storage.StorageBucketIamBinding\x12R\n\x19storage_bucket_iam_member\x18\x05 \x03(\x0b\x32/.oak9.tython.gcp.storage.StorageBucketIamMember\x12R\n\x19storage_bucket_iam_policy\x18\x06 \x03(\x0b\x32/.oak9.tython.gcp.storage.StorageBucketIamPolicy\x12K\n\x15storage_bucket_object\x18\x07 \x03(\x0b\x32,.oak9.tython.gcp.storage.StorageBucketObject\x12i\n%storage_default_object_access_control\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.storage.StorageDefaultObjectAccessControl\x12T\n\x1astorage_default_object_acl\x18\t \x01(\x0b\x32\x30.oak9.tython.gcp.storage.StorageDefaultObjectAcl\x12\x41\n\x10storage_hmac_key\x18\n \x01(\x0b\x32\'.oak9.tython.gcp.storage.StorageHmacKey\x12J\n\x14storage_notification\x18\x0b \x01(\x0b\x32,.oak9.tython.gcp.storage.StorageNotification\x12Z\n\x1dstorage_object_access_control\x18\x0c \x03(\x0b\x32\x33.oak9.tython.gcp.storage.StorageObjectAccessControl\x12\x45\n\x12storage_object_acl\x18\r \x03(\x0b\x32).oak9.tython.gcp.storage.StorageObjectAcl\x12I\n\x14storage_transfer_job\x18\x0e \x01(\x0b\x32+.oak9.tython.gcp.storage.StorageTransferJobb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_storage_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLESTORAGE._serialized_start=123
  _GOOGLESTORAGE._serialized_end=1270
# @@protoc_insertion_point(module_scope)
