# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_essential.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_essential.proto\x12\x19oak9.tython.gcp.essential\x1a\x13shared/shared.proto\"S\n!EssentialContactsContactXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9f\x02\n\x18\x45ssentialContactsContact\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x14\n\x0clanguage_tag\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12+\n#notification_category_subscriptions\x18\x05 \x03(\t\x12\x0e\n\x06parent\x18\x06 \x01(\t\x12N\n\x08timeouts\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.essential.EssentialContactsContactXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_essential_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ESSENTIALCONTACTSCONTACTXTIMEOUTS._serialized_start=75
  _ESSENTIALCONTACTSCONTACTXTIMEOUTS._serialized_end=158
  _ESSENTIALCONTACTSCONTACT._serialized_start=161
  _ESSENTIALCONTACTSCONTACT._serialized_end=448
# @@protoc_insertion_point(module_scope)
