# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.authorization.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7kubernetes/kubernetes_io.k8s.api.authorization.v1.proto\x12$oak9.tython.k8s.api.authorization.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xe1\x02\n\x18LocalSubjectAccessReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12K\n\x04spec\x18\x04 \x01(\x0b\x32=.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewSpec\x12O\n\x06status\x18\x05 \x01(\x0b\x32?.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n\x15NonResourceAttributes\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04verb\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"v\n\x0fNonResourceRule\x12\x1b\n\x13non_resource_u_r_ls\x18\x01 \x03(\t\x12\r\n\x05verbs\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc3\x01\n\x12ResourceAttributes\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x10\n\x08resource\x18\x04 \x01(\t\x12\x13\n\x0bsubresource\x18\x05 \x01(\t\x12\x0c\n\x04verb\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x01\n\x0cResourceRule\x12\x12\n\napi_groups\x18\x01 \x03(\t\x12\x16\n\x0eresource_names\x18\x02 \x03(\t\x12\x11\n\tresources\x18\x03 \x03(\t\x12\r\n\x05verbs\x18\x04 \x03(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe4\x02\n\x17SelfSubjectAccessReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x04 \x01(\x0b\x32\x41.oak9.tython.k8s.api.authorization.v1.SelfSubjectAccessReviewSpec\x12O\n\x06status\x18\x05 \x01(\x0b\x32?.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x02\n\x1bSelfSubjectAccessReviewSpec\x12\\\n\x17non_resource_attributes\x18\x01 \x01(\x0b\x32;.oak9.tython.k8s.api.authorization.v1.NonResourceAttributes\x12U\n\x13resource_attributes\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.api.authorization.v1.ResourceAttributes\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe1\x02\n\x16SelfSubjectRulesReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x04 \x01(\x0b\x32@.oak9.tython.k8s.api.authorization.v1.SelfSubjectRulesReviewSpec\x12N\n\x06status\x18\x05 \x01(\x0b\x32>.oak9.tython.k8s.api.authorization.v1.SubjectRulesReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"h\n\x1aSelfSubjectRulesReviewSpec\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdc\x02\n\x13SubjectAccessReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12K\n\x04spec\x18\x04 \x01(\x0b\x32=.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewSpec\x12O\n\x06status\x18\x05 \x01(\x0b\x32?.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x03\n\x17SubjectAccessReviewSpec\x12W\n\x05\x65xtra\x18\x01 \x03(\x0b\x32H.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewSpec.ExtraEntry\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12\\\n\x17non_resource_attributes\x18\x03 \x01(\x0b\x32;.oak9.tython.k8s.api.authorization.v1.NonResourceAttributes\x12U\n\x13resource_attributes\x18\x04 \x01(\x0b\x32\x38.oak9.tython.k8s.api.authorization.v1.ResourceAttributes\x12\x0b\n\x03uid\x18\x05 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9f\x01\n\x19SubjectAccessReviewStatus\x12\x0f\n\x07\x61llowed\x18\x01 \x01(\x08\x12\x0e\n\x06\x64\x65nied\x18\x02 \x01(\x08\x12\x18\n\x10\x65valuation_error\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa0\x02\n\x18SubjectRulesReviewStatus\x12\x18\n\x10\x65valuation_error\x18\x01 \x01(\t\x12\x12\n\nincomplete\x18\x02 \x01(\x08\x12Q\n\x12non_resource_rules\x18\x03 \x03(\x0b\x32\x35.oak9.tython.k8s.api.authorization.v1.NonResourceRule\x12J\n\x0eresource_rules\x18\x04 \x03(\x0b\x32\x32.oak9.tython.k8s.api.authorization.v1.ResourceRule\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.authorization.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUBJECTACCESSREVIEWSPEC_EXTRAENTRY._options = None
  _SUBJECTACCESSREVIEWSPEC_EXTRAENTRY._serialized_options = b'8\001'
  _LOCALSUBJECTACCESSREVIEW._serialized_start=185
  _LOCALSUBJECTACCESSREVIEW._serialized_end=538
  _NONRESOURCEATTRIBUTES._serialized_start=540
  _NONRESOURCEATTRIBUTES._serialized_end=648
  _NONRESOURCERULE._serialized_start=650
  _NONRESOURCERULE._serialized_end=768
  _RESOURCEATTRIBUTES._serialized_start=771
  _RESOURCEATTRIBUTES._serialized_end=966
  _RESOURCERULE._serialized_start=969
  _RESOURCERULE._serialized_end=1118
  _SELFSUBJECTACCESSREVIEW._serialized_start=1121
  _SELFSUBJECTACCESSREVIEW._serialized_end=1477
  _SELFSUBJECTACCESSREVIEWSPEC._serialized_start=1480
  _SELFSUBJECTACCESSREVIEWSPEC._serialized_end=1747
  _SELFSUBJECTRULESREVIEW._serialized_start=1750
  _SELFSUBJECTRULESREVIEW._serialized_end=2103
  _SELFSUBJECTRULESREVIEWSPEC._serialized_start=2105
  _SELFSUBJECTRULESREVIEWSPEC._serialized_end=2209
  _SUBJECTACCESSREVIEW._serialized_start=2212
  _SUBJECTACCESSREVIEW._serialized_end=2560
  _SUBJECTACCESSREVIEWSPEC._serialized_start=2563
  _SUBJECTACCESSREVIEWSPEC._serialized_end=3004
  _SUBJECTACCESSREVIEWSPEC_EXTRAENTRY._serialized_start=2960
  _SUBJECTACCESSREVIEWSPEC_EXTRAENTRY._serialized_end=3004
  _SUBJECTACCESSREVIEWSTATUS._serialized_start=3007
  _SUBJECTACCESSREVIEWSTATUS._serialized_end=3166
  _SUBJECTRULESREVIEWSTATUS._serialized_start=3169
  _SUBJECTRULESREVIEWSTATUS._serialized_end=3457
# @@protoc_insertion_point(module_scope)
