# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_redshift.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_redshift.proto\x12\x18oak9.tython.aws.redshift\x1a\x13shared/shared.proto\"\x7f\n\x18\x43lusterLoggingProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x62ucket_name\x18\x02 \x01(\t\x12\x15\n\rs3_key_prefix\x18\x03 \x01(\t\"\xf3\x07\n\x07\x43luster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x61llow_version_upgrade\x18\x02 \x01(\x08\x12+\n#automated_snapshot_retention_period\x18\x03 \x01(\x05\x12\x19\n\x11\x61vailability_zone\x18\x04 \x01(\t\x12\x1a\n\x12\x63luster_identifier\x18\x05 \x01(\t\x12$\n\x1c\x63luster_parameter_group_name\x18\x06 \x01(\t\x12\x1f\n\x17\x63luster_security_groups\x18\x07 \x03(\t\x12!\n\x19\x63luster_subnet_group_name\x18\x08 \x01(\t\x12\x14\n\x0c\x63luster_type\x18\t \x01(\t\x12\x17\n\x0f\x63luster_version\x18\n \x01(\t\x12\x0f\n\x07\x64\x62_name\x18\x0b \x01(\t\x12\x12\n\nelastic_ip\x18\x0c \x01(\t\x12\x11\n\tencrypted\x18\r \x01(\x08\x12)\n!hsm_client_certificate_identifier\x18\x0e \x01(\t\x12$\n\x1chsm_configuration_identifier\x18\x0f \x01(\t\x12\x11\n\tiam_roles\x18\x10 \x03(\t\x12\x12\n\nkms_key_id\x18\x11 \x01(\t\x12N\n\x12logging_properties\x18\x12 \x01(\x0b\x32\x32.oak9.tython.aws.redshift.ClusterLoggingProperties\x12\x1c\n\x14master_user_password\x18\x13 \x01(\t\x12\x17\n\x0fmaster_username\x18\x14 \x01(\t\x12\x11\n\tnode_type\x18\x15 \x01(\t\x12\x17\n\x0fnumber_of_nodes\x18\x16 \x01(\x05\x12\x15\n\rowner_account\x18\x17 \x01(\t\x12\x0c\n\x04port\x18\x18 \x01(\x05\x12$\n\x1cpreferred_maintenance_window\x18\x19 \x01(\t\x12\x1b\n\x13publicly_accessible\x18\x1a \x01(\x08\x12#\n\x1bsnapshot_cluster_identifier\x18\x1b \x01(\t\x12\x1b\n\x13snapshot_identifier\x18\x1c \x01(\t\x12\x39\n\x04tags\x18\x1d \x03(\x0b\x32+.oak9.tython.aws.redshift.Cluster.TagsEntry\x12\x1e\n\x16vpc_security_group_ids\x18\x1e \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x03\n\x08Redshift\x12\x32\n\x07\x63luster\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.redshift.Cluster\x12P\n\x17\x63luster_parameter_group\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.redshift.ClusterParameterGroup\x12N\n\x16\x63luster_security_group\x18\x03 \x03(\x0b\x32..oak9.tython.aws.redshift.ClusterSecurityGroup\x12]\n\x1e\x63luster_security_group_ingress\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.redshift.ClusterSecurityGroupIngress\x12J\n\x14\x63luster_subnet_group\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.redshift.ClusterSubnetGroup\"\x8a\x01\n\x1e\x43lusterParameterGroupParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eparameter_name\x18\x02 \x01(\t\x12\x17\n\x0fparameter_value\x18\x03 \x01(\t\"\xc9\x02\n\x15\x43lusterParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x16parameter_group_family\x18\x03 \x01(\t\x12L\n\nparameters\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.redshift.ClusterParameterGroupParameter\x12G\n\x04tags\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.redshift.ClusterParameterGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x01\n\x14\x43lusterSecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x46\n\x04tags\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.redshift.ClusterSecurityGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd4\x01\n\x1b\x43lusterSecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12#\n\x1b\x63luster_security_group_name\x18\x03 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x04 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x05 \x01(\t\"\xe9\x01\n\x12\x43lusterSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x44\n\x04tags\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.redshift.ClusterSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_redshift_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLUSTER_TAGSENTRY._options = None
  _CLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERPARAMETERGROUP_TAGSENTRY._options = None
  _CLUSTERPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERSECURITYGROUP_TAGSENTRY._options = None
  _CLUSTERSECURITYGROUP_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERSUBNETGROUP_TAGSENTRY._options = None
  _CLUSTERSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERLOGGINGPROPERTIES._serialized_start=73
  _CLUSTERLOGGINGPROPERTIES._serialized_end=200
  _CLUSTER._serialized_start=203
  _CLUSTER._serialized_end=1214
  _CLUSTER_TAGSENTRY._serialized_start=1171
  _CLUSTER_TAGSENTRY._serialized_end=1214
  _REDSHIFT._serialized_start=1217
  _REDSHIFT._serialized_end=1612
  _CLUSTERPARAMETERGROUPPARAMETER._serialized_start=1615
  _CLUSTERPARAMETERGROUPPARAMETER._serialized_end=1753
  _CLUSTERPARAMETERGROUP._serialized_start=1756
  _CLUSTERPARAMETERGROUP._serialized_end=2085
  _CLUSTERPARAMETERGROUP_TAGSENTRY._serialized_start=1171
  _CLUSTERPARAMETERGROUP_TAGSENTRY._serialized_end=1214
  _CLUSTERSECURITYGROUP._serialized_start=2088
  _CLUSTERSECURITYGROUP._serialized_end=2305
  _CLUSTERSECURITYGROUP_TAGSENTRY._serialized_start=1171
  _CLUSTERSECURITYGROUP_TAGSENTRY._serialized_end=1214
  _CLUSTERSECURITYGROUPINGRESS._serialized_start=2308
  _CLUSTERSECURITYGROUPINGRESS._serialized_end=2520
  _CLUSTERSUBNETGROUP._serialized_start=2523
  _CLUSTERSUBNETGROUP._serialized_end=2756
  _CLUSTERSUBNETGROUP_TAGSENTRY._serialized_start=1171
  _CLUSTERSUBNETGROUP_TAGSENTRY._serialized_end=1214
# @@protoc_insertion_point(module_scope)
