"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeHttpHealthCheckXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeHttpHealthCheckXTimeouts = ComputeHttpHealthCheckXTimeouts

@typing_extensions.final
class ComputeHttpHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECK_INTERVAL_SEC_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    check_interval_sec: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    healthy_threshold: builtins.float
    host: builtins.str
    id: builtins.str
    name: builtins.str
    port: builtins.float
    project: builtins.str
    request_path: builtins.str
    self_link: builtins.str
    timeout_sec: builtins.float
    unhealthy_threshold: builtins.float
    @property
    def timeouts(self) -> global___ComputeHttpHealthCheckXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        check_interval_sec: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        healthy_threshold: builtins.float = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        request_path: builtins.str = ...,
        self_link: builtins.str = ...,
        timeout_sec: builtins.float = ...,
        unhealthy_threshold: builtins.float = ...,
        timeouts: global___ComputeHttpHealthCheckXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_interval_sec", b"check_interval_sec", "creation_timestamp", b"creation_timestamp", "description", b"description", "healthy_threshold", b"healthy_threshold", "host", b"host", "id", b"id", "name", b"name", "port", b"port", "project", b"project", "request_path", b"request_path", "resource_info", b"resource_info", "self_link", b"self_link", "timeout_sec", b"timeout_sec", "timeouts", b"timeouts", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...

global___ComputeHttpHealthCheck = ComputeHttpHealthCheck
