# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: shared/shared.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13shared/shared.proto\x12\x12oak9.tython.shared\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\xc6\x05\n\tBlueprint\x12\x14\n\x0c\x62lueprint_id\x18\x01 \x01(\t\x12\x1b\n\x13parent_blueprint_id\x18\x02 \x01(\t\x12\x16\n\x0e\x62lueprint_name\x18\x03 \x01(\t\x12\x13\n\x06status\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x10\n\x08revision\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x0e\n\x06\x61uthor\x18\t \x01(\t\x12\x1d\n\x15\x63ompliance_objectives\x18\n \x03(\t\x12\x33\n\x0flast_updated_on\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x0e\x63omponent_info\x18\x0c \x01(\x0b\x32!.oak9.tython.shared.ComponentInfo\x12M\n\x13\x62lueprint_reference\x18\r \x01(\x0b\x32+.oak9.tython.shared.ReferencedDocumentModelH\x01\x88\x01\x01\x12\x35\n\x0crequirements\x18\x0e \x03(\x0b\x32\x1f.oak9.tython.shared.Requirement\x12\x12\n\nis_deleted\x18\x0f \x01(\x08\x12!\n\x14reference_project_id\x18\x10 \x01(\tH\x02\x88\x01\x01\x12,\n\x07\x63ontext\x18\x11 \x01(\x0b\x32\x1b.oak9.tython.shared.Context\x12\x31\n\nblueprints\x18\x12 \x03(\x0b\x32\x1d.oak9.tython.shared.Blueprint\x12\x1a\n\x12\x62lueprint_location\x18\x13 \x01(\tB\t\n\x07_statusB\x16\n\x14_blueprint_referenceB\x17\n\x15_reference_project_id\"\xcf\x01\n\rComponentInfo\x12\x14\n\x0c\x63omponent_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x19\n\x11\x63omponent_type_id\x18\x04 \x01(\t\x12\x12\n\nx_position\x18\x05 \x01(\x11\x12\x12\n\ny_position\x18\x06 \x01(\x11\x12\x36\n\x0b\x63onnections\x18\x07 \x03(\x0b\x32!.oak9.tython.shared.ComponentInfo\x12\x11\n\tcollapsed\x18\x08 \x01(\x08\"\x98\x01\n\x17ReferencedDocumentModel\x12\x13\n\x0b\x65ntity_type\x18\x01 \x01(\t\x12\x16\n\x0ereference_type\x18\x02 \x01(\t\x12\x15\n\rreference_key\x18\x03 \x01(\t\x12\x1c\n\x14\x64ocument_primary_key\x18\x04 \x01(\t\x12\x1b\n\x13\x64ocument_entity_key\x18\x05 \x01(\t\"\xf7\x04\n\x0bRequirement\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12,\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x1b.oak9.tython.shared.Context\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07version\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04type\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08\x63\x61tegory\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0csub_category\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tcomponent\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x11\n\x04tags\x18\t \x01(\tH\x07\x88\x01\x01\x12\x15\n\x08guidance\x18\n \x01(\tH\x08\x88\x01\x01\x12\x1d\n\x10hi_trust_mapping\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x1f\n\x12hi_trust94_mapping\x18\x0c \x01(\tH\n\x88\x01\x01\x12\x19\n\x0cnist_mapping\x18\r \x01(\tH\x0b\x88\x01\x01\x12N\n\x13industry_frameworks\x18\x0e \x03(\x0b\x32\x31.oak9.tython.shared.IndustryFrameworkMappingModel\x12\x12\n\x05hl_rs\x18\x0f \x01(\tH\x0c\x88\x01\x01\x42\x05\n\x03_idB\x0e\n\x0c_descriptionB\n\n\x08_versionB\x07\n\x05_typeB\x0b\n\t_categoryB\x0f\n\r_sub_categoryB\x0c\n\n_componentB\x07\n\x05_tagsB\x0b\n\t_guidanceB\x13\n\x11_hi_trust_mappingB\x15\n\x13_hi_trust94_mappingB\x0f\n\r_nist_mappingB\x08\n\x06_hl_rs\"[\n\x1dIndustryFrameworkMappingModel\x12\x1d\n\x15industry_framework_id\x18\x01 \x01(\t\x12\x1b\n\x13mapped_requirements\x18\x02 \x03(\t\"\xaf\x02\n\x07\x43ontext\x12\x42\n\raccessibility\x18\x01 \x01(\x0b\x32+.oak9.tython.shared.AccessibilityAttributes\x12\x44\n\x0esusceptibility\x18\x02 \x01(\x0b\x32,.oak9.tython.shared.SusceptibilityAttributes\x12G\n\x10\x61pp_architecture\x18\x03 \x01(\x0b\x32-.oak9.tython.shared.AppArchitectureAttributes\x12Q\n\x15security_architecture\x18\x04 \x01(\x0b\x32\x32.oak9.tython.shared.SecurityArchitectureAttributes\"\x8f\x02\n\x17\x41\x63\x63\x65ssibilityAttributes\x12/\n\tend_users\x18\x01 \x01(\x0b\x32\x1c.oak9.tython.shared.EndUsers\x12:\n\x0flevel_of_access\x18\x02 \x01(\x0b\x32!.oak9.tython.shared.LevelOfAccess\x12\x33\n\x0b\x61\x63\x63\x65ss_type\x18\x03 \x01(\x0b\x32\x1e.oak9.tython.shared.AccessType\x12R\n\x1b\x61pplicable_component_slices\x18\x04 \x01(\x0b\x32-.oak9.tython.shared.ApplicableComponentSlices\"K\n\x08\x45ndUsers\x12\x11\n\tworkforce\x18\x01 \x01(\t\x12\x11\n\tconsumers\x18\x02 \x01(\t\x12\x19\n\x11\x62usiness_partners\x18\x03 \x01(\t\"\x8a\x01\n\rLevelOfAccess\x12\x10\n\x08physical\x18\x01 \x01(\t\x12\x0c\n\x04open\x18\x02 \x01(\t\x12\x1e\n\x16limited_sensitive_data\x18\x03 \x01(\t\x12\x1c\n\x14\x62road_sensitive_data\x18\x04 \x01(\t\x12\x1b\n\x13security_privileged\x18\x05 \x01(\t\"\x87\x01\n\nAccessType\x12\x17\n\x0f\x65xternal_access\x18\x01 \x01(\t\x12\x17\n\x0finternal_access\x18\x02 \x01(\t\x12\x15\n\rremote_access\x18\x03 \x01(\t\x12\x17\n\x0fwireless_access\x18\x04 \x01(\t\x12\x17\n\x0foutbound_access\x18\x05 \x01(\t\"i\n\x19\x41pplicableComponentSlices\x12\x16\n\x0e\x63omponent_core\x18\x01 \x01(\t\x12\x16\n\x0euser_interface\x18\x02 \x01(\t\x12\x1c\n\x14management_interface\x18\x03 \x01(\t\"M\n\x18SusceptibilityAttributes\x12\x18\n\x10\x64\x61ta_sensitivity\x18\x01 \x01(\t\x12\x17\n\x0f\x62usiness_impact\x18\x02 \x01(\t\"5\n\x19\x41ppArchitectureAttributes\x12\x18\n\x10\x64\x65ployment_model\x18\x01 \x01(\t\"8\n\x1eSecurityArchitectureAttributes\x12\x16\n\x0esecurity_level\x18\x01 \x01(\t\"\x9e\x03\n\tDesignGap\x12\x15\n\rcapability_id\x18\x01 \x01(\t\x12\x17\n\x0f\x63\x61pability_name\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\x13\n\x0bresource_id\x18\x05 \x01(\t\x12\x15\n\rresource_type\x18\x06 \x01(\t\x12\x19\n\x0cresource_gap\x18\x07 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0fresource_impact\x18\x08 \x01(\tH\x01\x88\x01\x01\x12\x31\n\nviolations\x18\t \x03(\x0b\x32\x1d.oak9.tython.shared.Violation\x12\x1a\n\roak9_guidance\x18\n \x01(\tH\x02\x88\x01\x01\x12O\n\x1amapped_industry_frameworks\x18\x0b \x03(\x0b\x32+.oak9.tython.shared.MappedIndustryFrameworkB\x0f\n\r_resource_gapB\x12\n\x10_resource_impactB\x10\n\x0e_oak9_guidance\"\xc9\x04\n\tViolation\x12\x15\n\x08severity\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nconfig_gap\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rcapability_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0bresource_id\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rresource_type\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tconfig_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x19\n\x0c\x63onfig_value\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1a\n\roak9_guidance\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1c\n\x0fpreffered_value\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1c\n\x0f\x63\x61pability_name\x18\n \x01(\tH\t\x88\x01\x01\x12\x17\n\nconfig_fix\x18\x0b \x01(\tH\n\x88\x01\x01\x12\x1a\n\rconfig_impact\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x1c\n\x0f\x65xisting_config\x18\r \x01(\x08H\x0c\x88\x01\x01\x42\x0b\n\t_severityB\r\n\x0b_config_gapB\x10\n\x0e_capability_idB\x0e\n\x0c_resource_idB\x10\n\x0e_resource_typeB\x0c\n\n_config_idB\x0f\n\r_config_valueB\x10\n\x0e_oak9_guidanceB\x12\n\x10_preffered_valueB\x12\n\x10_capability_nameB\r\n\x0b_config_fixB\x10\n\x0e_config_impactB\x12\n\x10_existing_config\"_\n\x17MappedIndustryFramework\x12\x19\n\x11industry_standard\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\";\n\x05Graph\x12\x32\n\nroot_nodes\x18\x01 \x03(\x0b\x32\x1e.oak9.tython.shared.Connection\"\x8d\x01\n\nConnection\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.oak9.tython.shared.Vertex\x12\"\n\x04\x65\x64ge\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x31\n\tneighbors\x18\x03 \x03(\x0b\x32\x1e.oak9.tython.shared.Connection\"\x90\x01\n\x06Vertex\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x33\n\x0bvertex_type\x18\x02 \x01(\x0e\x32\x1e.oak9.tython.shared.VertexType\x12\x0e\n\x06labels\x18\x03 \x03(\t\x12.\n\x08resource\x18\x04 \x01(\x0b\x32\x1c.oak9.tython.shared.Resource\"\xdc\x02\n\x0cResourceInfo\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03\x63sp\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rresource_type\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x38\n\x04tags\x18\x05 \x03(\x0b\x32*.oak9.tython.shared.ResourceInfo.TagsEntry\x12\x19\n\x0c\x62lueprint_id\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x31\n\x07\x63ontext\x18\x07 \x01(\x0b\x32\x1b.oak9.tython.shared.ContextH\x05\x88\x01\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x06\n\x04_cspB\x10\n\x0e_resource_typeB\x0f\n\r_blueprint_idB\n\n\x08_context\".\n\x08Resource\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"<\n\x0fRunnerException\x12\x12\n\nerror_code\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\"\xda\x01\n\x0bRunnerInput\x12(\n\x05graph\x18\x01 \x01(\x0b\x32\x19.oak9.tython.shared.Graph\x12\x30\n\tblueprint\x18\x02 \x01(\x0b\x32\x1d.oak9.tython.shared.Blueprint\x12\x34\n\x0fproject_context\x18\x03 \x01(\x0b\x32\x1b.oak9.tython.shared.Context\x12\x39\n\tmeta_info\x18\x04 \x01(\x0b\x32&.oak9.tython.shared.ValidationMetaInfo\"\xb0\x01\n\x12ValidationMetaInfo\x12\x0e\n\x06\x63\x61ller\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x15\n\rresource_type\x18\x03 \x01(\t\x12\x14\n\x0c\x62lueprint_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x13\n\x0bresource_id\x18\x06 \x01(\t\x12\x1d\n\x15\x63ompliance_objectives\x18\x07 \x03(\t\"\xbf\x01\n\x0fValidationReply\x12\x32\n\x0b\x64\x65sign_gaps\x18\x01 \x03(\x0b\x32\x1d.oak9.tython.shared.DesignGap\x12?\n\x0crequirements\x18\x02 \x03(\x0b\x32).oak9.tython.shared.ValidationRequirement\x12\x37\n\nexceptions\x18\x03 \x03(\x0b\x32#.oak9.tython.shared.RunnerException\"j\n\x15ValidationRequirement\x12=\n\x10requirement_type\x18\x01 \x01(\x0e\x32#.oak9.tython.shared.RequirementType\x12\x12\n\nparameters\x18\x02 \x03(\t*\x99\x02\n\nVertexType\x12\x0b\n\x07GENERIC\x10\x00\x12\x0f\n\x0bREQUIREMENT\x10\x01\x12\x18\n\x14\x44\x45TAILED_REQUIREMENT\x10\x02\x12\x16\n\x12IL_MAPPING_KEYWORD\x10\x03\x12\x19\n\x15\x41WS_INSTANCE_RESOURCE\x10\x04\x12\x17\n\x13\x41WS_SUBNET_RESOURCE\x10\x05\x12\x14\n\x10\x41WS_VPC_RESOURCE\x10\x06\x12\x1f\n\x1b\x41WS_SECURITY_GROUP_RESOURCE\x10\x07\x12\x1b\n\x17\x41WS_ELASTIC_LB_RESOURCE\x10\x08\x12\x17\n\x13\x43LOUDFRONT_RESOURCE\x10\t\x12\x1a\n\x16LOAD_BALANCER_RESOURCE\x10\n*l\n\x0fRequirementType\x12\x11\n\rALL_NEIGHBORS\x10\x00\x12\x15\n\x11NEIGHBORS_OF_TYPE\x10\x01\x12\x1e\n\x1aNEIGHBOR_WITH_RELATIONSHIP\x10\x02\x12\x0f\n\x0bWHOLE_GRAPH\x10\x03\x32[\n\x06Runner\x12Q\n\x03Run\x12\x1f.oak9.tython.shared.RunnerInput\x1a#.oak9.tython.shared.ValidationReply\"\x00(\x01\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'shared.shared_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCEINFO_TAGSENTRY._options = None
  _RESOURCEINFO_TAGSENTRY._serialized_options = b'8\001'
  _VERTEXTYPE._serialized_start=5761
  _VERTEXTYPE._serialized_end=6042
  _REQUIREMENTTYPE._serialized_start=6044
  _REQUIREMENTTYPE._serialized_end=6152
  _BLUEPRINT._serialized_start=104
  _BLUEPRINT._serialized_end=814
  _COMPONENTINFO._serialized_start=817
  _COMPONENTINFO._serialized_end=1024
  _REFERENCEDDOCUMENTMODEL._serialized_start=1027
  _REFERENCEDDOCUMENTMODEL._serialized_end=1179
  _REQUIREMENT._serialized_start=1182
  _REQUIREMENT._serialized_end=1813
  _INDUSTRYFRAMEWORKMAPPINGMODEL._serialized_start=1815
  _INDUSTRYFRAMEWORKMAPPINGMODEL._serialized_end=1906
  _CONTEXT._serialized_start=1909
  _CONTEXT._serialized_end=2212
  _ACCESSIBILITYATTRIBUTES._serialized_start=2215
  _ACCESSIBILITYATTRIBUTES._serialized_end=2486
  _ENDUSERS._serialized_start=2488
  _ENDUSERS._serialized_end=2563
  _LEVELOFACCESS._serialized_start=2566
  _LEVELOFACCESS._serialized_end=2704
  _ACCESSTYPE._serialized_start=2707
  _ACCESSTYPE._serialized_end=2842
  _APPLICABLECOMPONENTSLICES._serialized_start=2844
  _APPLICABLECOMPONENTSLICES._serialized_end=2949
  _SUSCEPTIBILITYATTRIBUTES._serialized_start=2951
  _SUSCEPTIBILITYATTRIBUTES._serialized_end=3028
  _APPARCHITECTUREATTRIBUTES._serialized_start=3030
  _APPARCHITECTUREATTRIBUTES._serialized_end=3083
  _SECURITYARCHITECTUREATTRIBUTES._serialized_start=3085
  _SECURITYARCHITECTUREATTRIBUTES._serialized_end=3141
  _DESIGNGAP._serialized_start=3144
  _DESIGNGAP._serialized_end=3558
  _VIOLATION._serialized_start=3561
  _VIOLATION._serialized_end=4146
  _MAPPEDINDUSTRYFRAMEWORK._serialized_start=4148
  _MAPPEDINDUSTRYFRAMEWORK._serialized_end=4243
  _GRAPH._serialized_start=4245
  _GRAPH._serialized_end=4304
  _CONNECTION._serialized_start=4307
  _CONNECTION._serialized_end=4448
  _VERTEX._serialized_start=4451
  _VERTEX._serialized_end=4595
  _RESOURCEINFO._serialized_start=4598
  _RESOURCEINFO._serialized_end=4946
  _RESOURCEINFO_TAGSENTRY._serialized_start=4832
  _RESOURCEINFO_TAGSENTRY._serialized_end=4875
  _RESOURCE._serialized_start=4948
  _RESOURCE._serialized_end=4994
  _RUNNEREXCEPTION._serialized_start=4996
  _RUNNEREXCEPTION._serialized_end=5056
  _RUNNERINPUT._serialized_start=5059
  _RUNNERINPUT._serialized_end=5277
  _VALIDATIONMETAINFO._serialized_start=5280
  _VALIDATIONMETAINFO._serialized_end=5456
  _VALIDATIONREPLY._serialized_start=5459
  _VALIDATIONREPLY._serialized_end=5650
  _VALIDATIONREQUIREMENT._serialized_start=5652
  _VALIDATIONREQUIREMENT._serialized_end=5758
  _RUNNER._serialized_start=6154
  _RUNNER._serialized_end=6245
# @@protoc_insertion_point(module_scope)
