"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.apps.v1_pb2
import kubernetes.kubernetes_io.k8s.api.autoscaling.v2_pb2
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.api.networking.v1_pb2
import kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Kubernetes_Namespaced(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BINDING_FIELD_NUMBER: builtins.int
    CONFIG_MAP_FIELD_NUMBER: builtins.int
    POD_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    DAEMON_SET_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    REPLICA_SET_FIELD_NUMBER: builtins.int
    STATEFUL_SET_FIELD_NUMBER: builtins.int
    HORIZONTAL_POD_AUTOSCALER_FIELD_NUMBER: builtins.int
    POD_TEMPLATE_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    ROLE_BINDING_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    INGRESS_FIELD_NUMBER: builtins.int
    NETWORK_POLICY_FIELD_NUMBER: builtins.int
    @property
    def binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Binding]: ...
    @property
    def config_map(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ConfigMap]: ...
    @property
    def pod(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Pod]: ...
    @property
    def service_account(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ServiceAccount]: ...
    @property
    def service(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Service]: ...
    @property
    def daemon_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.DaemonSet]: ...
    @property
    def deployment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.Deployment]: ...
    @property
    def replica_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.ReplicaSet]: ...
    @property
    def stateful_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.StatefulSet]: ...
    @property
    def horizontal_pod_autoscaler(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.autoscaling.v2_pb2.HorizontalPodAutoscaler]: ...
    @property
    def pod_template(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplate]: ...
    @property
    def secret(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Secret]: ...
    @property
    def role_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.RoleBinding]: ...
    @property
    def role(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.Role]: ...
    @property
    def ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.Ingress]: ...
    @property
    def network_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.NetworkPolicy]: ...
    def __init__(
        self,
        *,
        binding: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Binding] | None = ...,
        config_map: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ConfigMap] | None = ...,
        pod: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Pod] | None = ...,
        service_account: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ServiceAccount] | None = ...,
        service: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Service] | None = ...,
        daemon_set: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.DaemonSet] | None = ...,
        deployment: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.Deployment] | None = ...,
        replica_set: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.ReplicaSet] | None = ...,
        stateful_set: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.StatefulSet] | None = ...,
        horizontal_pod_autoscaler: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.autoscaling.v2_pb2.HorizontalPodAutoscaler] | None = ...,
        pod_template: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplate] | None = ...,
        secret: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Secret] | None = ...,
        role_binding: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.RoleBinding] | None = ...,
        role: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.Role] | None = ...,
        ingress: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.Ingress] | None = ...,
        network_policy: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.NetworkPolicy] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["binding", b"binding", "config_map", b"config_map", "daemon_set", b"daemon_set", "deployment", b"deployment", "horizontal_pod_autoscaler", b"horizontal_pod_autoscaler", "ingress", b"ingress", "network_policy", b"network_policy", "pod", b"pod", "pod_template", b"pod_template", "replica_set", b"replica_set", "role", b"role", "role_binding", b"role_binding", "secret", b"secret", "service", b"service", "service_account", b"service_account", "stateful_set", b"stateful_set"]) -> None: ...

global___Kubernetes_Namespaced = Kubernetes_Namespaced
