"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_cloud_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleCloudTasks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_TASKS_QUEUE_FIELD_NUMBER: builtins.int
    CLOUD_TASKS_QUEUE_IAM_BINDING_FIELD_NUMBER: builtins.int
    CLOUD_TASKS_QUEUE_IAM_MEMBER_FIELD_NUMBER: builtins.int
    CLOUD_TASKS_QUEUE_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def cloud_tasks_queue(self) -> gcp.gcp_cloud_pb2.CloudTasksQueue: ...
    @property
    def cloud_tasks_queue_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_cloud_pb2.CloudTasksQueueIamBinding]: ...
    @property
    def cloud_tasks_queue_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_cloud_pb2.CloudTasksQueueIamMember]: ...
    @property
    def cloud_tasks_queue_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_cloud_pb2.CloudTasksQueueIamPolicy]: ...
    def __init__(
        self,
        *,
        cloud_tasks_queue: gcp.gcp_cloud_pb2.CloudTasksQueue | None = ...,
        cloud_tasks_queue_iam_binding: collections.abc.Iterable[gcp.gcp_cloud_pb2.CloudTasksQueueIamBinding] | None = ...,
        cloud_tasks_queue_iam_member: collections.abc.Iterable[gcp.gcp_cloud_pb2.CloudTasksQueueIamMember] | None = ...,
        cloud_tasks_queue_iam_policy: collections.abc.Iterable[gcp.gcp_cloud_pb2.CloudTasksQueueIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_tasks_queue", b"cloud_tasks_queue"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_tasks_queue", b"cloud_tasks_queue", "cloud_tasks_queue_iam_binding", b"cloud_tasks_queue_iam_binding", "cloud_tasks_queue_iam_member", b"cloud_tasks_queue_iam_member", "cloud_tasks_queue_iam_policy", b"cloud_tasks_queue_iam_policy"]) -> None: ...

global___GoogleCloudTasks = GoogleCloudTasks
