# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_lambda.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_lambda.proto\x12\x16oak9.tython.aws.lambda\x1a\x13shared/shared.proto\"\x8e\x01\n(AliasProvisionedConcurrencyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12)\n!provisioned_concurrent_executions\x18\x02 \x01(\x05\"\x80\x01\n\x12\x41liasVersionWeight\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x66unction_version\x18\x02 \x01(\t\x12\x17\n\x0f\x66unction_weight\x18\x03 \x01(\x01\"\xa9\x01\n\x1e\x41liasAliasRoutingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\x1a\x61\x64\x64itional_version_weights\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.lambda.AliasVersionWeight\"\xce\x02\n\x05\x41lias\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x15\n\rfunction_name\x18\x03 \x01(\t\x12\x18\n\x10\x66unction_version\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12h\n\x1eprovisioned_concurrency_config\x18\x06 \x01(\x0b\x32@.oak9.tython.aws.lambda.AliasProvisionedConcurrencyConfiguration\x12N\n\x0erouting_config\x18\x07 \x01(\x0b\x32\x36.oak9.tython.aws.lambda.AliasAliasRoutingConfiguration\"\xf5\x03\n\x06Lambda\x12,\n\x05\x61lias\x18\x01 \x01(\x0b\x32\x1d.oak9.tython.aws.lambda.Alias\x12\x46\n\x13\x65vent_invoke_config\x18\x02 \x01(\x0b\x32).oak9.tython.aws.lambda.EventInvokeConfig\x12H\n\x14\x65vent_source_mapping\x18\x03 \x01(\x0b\x32*.oak9.tython.aws.lambda.EventSourceMapping\x12\x32\n\x08\x66unction\x18\x04 \x01(\x0b\x32 .oak9.tython.aws.lambda.Function\x12;\n\rlayer_version\x18\x05 \x01(\x0b\x32$.oak9.tython.aws.lambda.LayerVersion\x12P\n\x18layer_version_permission\x18\x06 \x01(\x0b\x32..oak9.tython.aws.lambda.LayerVersionPermission\x12\x36\n\npermission\x18\x07 \x01(\x0b\x32\".oak9.tython.aws.lambda.Permission\x12\x30\n\x07version\x18\x08 \x01(\x0b\x32\x1f.oak9.tython.aws.lambda.Version\"j\n\x1a\x45ventInvokeConfigOnSuccess\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\"j\n\x1a\x45ventInvokeConfigOnFailure\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\"\xed\x01\n\"EventInvokeConfigDestinationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\non_success\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.lambda.EventInvokeConfigOnSuccess\x12\x46\n\non_failure\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.lambda.EventInvokeConfigOnFailure\"\x94\x02\n\x11\x45ventInvokeConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rfunction_name\x18\x02 \x01(\t\x12\x1e\n\x16maximum_retry_attempts\x18\x03 \x01(\x05\x12V\n\x12\x64\x65stination_config\x18\x04 \x01(\x0b\x32:.oak9.tython.aws.lambda.EventInvokeConfigDestinationConfig\x12\x11\n\tqualifier\x18\x05 \x01(\t\x12$\n\x1cmaximum_event_age_in_seconds\x18\x06 \x01(\x05\"k\n\x1b\x45ventSourceMappingOnFailure\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\"\xa7\x01\n#EventSourceMappingDestinationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\non_failure\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.lambda.EventSourceMappingOnFailure\"\xe2\x03\n\x12\x45ventSourceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\x12&\n\x1e\x62isect_batch_on_function_error\x18\x03 \x01(\x08\x12W\n\x12\x64\x65stination_config\x18\x04 \x01(\x0b\x32;.oak9.tython.aws.lambda.EventSourceMappingDestinationConfig\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x18\n\x10\x65vent_source_arn\x18\x06 \x01(\t\x12\x15\n\rfunction_name\x18\x07 \x01(\t\x12*\n\"maximum_batching_window_in_seconds\x18\x08 \x01(\x05\x12%\n\x1dmaximum_record_age_in_seconds\x18\t \x01(\x05\x12\x1e\n\x16maximum_retry_attempts\x18\n \x01(\x05\x12\x1e\n\x16parallelization_factor\x18\x0b \x01(\x05\x12\x19\n\x11starting_position\x18\x0c \x01(\t\x12\x0e\n\x06topics\x18\r \x03(\t\"\xaa\x01\n\x0c\x46unctionCode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x0e\n\x06s3_key\x18\x03 \x01(\t\x12\x19\n\x11s3_object_version\x18\x04 \x01(\t\x12\x10\n\x08zip_file\x18\x05 \x01(\t\x12\x11\n\timage_uri\x18\x06 \x01(\t\"g\n\x18\x46unctionDeadLetterConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntarget_arn\x18\x02 \x01(\t\"\xde\x01\n\x13\x46unctionEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\tvariables\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.lambda.FunctionEnvironment.VariablesEntry\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x18\x46unctionFileSystemConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x18\n\x10local_mount_path\x18\x03 \x01(\t\"^\n\x15\x46unctionTracingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04mode\x18\x02 \x01(\t\"\x8c\x01\n\x11\x46unctionVpcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x0e\n\x06vpc_id\x18\x04 \x01(\t\"\x8b\x07\n\x08\x46unction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x32\n\x04\x63ode\x18\x02 \x01(\x0b\x32$.oak9.tython.aws.lambda.FunctionCode\x12L\n\x12\x64\x65\x61\x64_letter_config\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.lambda.FunctionDeadLetterConfig\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12@\n\x0b\x65nvironment\x18\x05 \x01(\x0b\x32+.oak9.tython.aws.lambda.FunctionEnvironment\x12M\n\x13\x66ile_system_configs\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.lambda.FunctionFileSystemConfig\x12\x15\n\rfunction_name\x18\x07 \x01(\t\x12\x0f\n\x07handler\x18\x08 \x01(\t\x12\x13\n\x0bkms_key_arn\x18\t \x01(\t\x12\x0e\n\x06layers\x18\n \x03(\t\x12\x13\n\x0bmemory_size\x18\x0b \x01(\x05\x12&\n\x1ereserved_concurrent_executions\x18\x0c \x01(\x05\x12\x0c\n\x04role\x18\r \x01(\t\x12\x0f\n\x07runtime\x18\x0e \x01(\t\x12\x38\n\x04tags\x18\x0f \x03(\x0b\x32*.oak9.tython.aws.lambda.Function.TagsEntry\x12\x0f\n\x07timeout\x18\x10 \x01(\x05\x12\x45\n\x0etracing_config\x18\x11 \x01(\x0b\x32-.oak9.tython.aws.lambda.FunctionTracingConfig\x12=\n\nvpc_config\x18\x12 \x01(\x0b\x32).oak9.tython.aws.lambda.FunctionVpcConfig\x12\x13\n\x0brevision_id\x18\x13 \x01(\t\x12\x12\n\nmaster_arn\x18\x14 \x01(\t\x12\x0f\n\x07version\x18\x15 \x01(\t\x12\x15\n\rlast_modified\x18\x16 \x01(\t\x12\x11\n\tcode_size\x18\x17 \x01(\t\x12\x13\n\x0b\x63ode_sha256\x18\x18 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc6\x01\n\x13LayerVersionContent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11s3_object_version\x18\x02 \x01(\t\x12\x11\n\ts3_bucket\x18\x03 \x01(\t\x12\x0e\n\x06s3_key\x18\x04 \x01(\t\x12\x13\n\x0b\x63ode_sha256\x18\x05 \x01(\t\x12\x11\n\tcode_size\x18\x06 \x01(\t\x12\x10\n\x08location\x18\x07 \x01(\t\"\xb6\x02\n\x0cLayerVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63ompatible_runtimes\x18\x02 \x03(\t\x12\x14\n\x0clicense_info\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\nlayer_name\x18\x05 \x01(\t\x12<\n\x07\x63ontent\x18\x06 \x01(\x0b\x32+.oak9.tython.aws.lambda.LayerVersionContent\x12\x11\n\tlayer_arn\x18\x07 \x01(\t\x12\x19\n\x11layer_version_arn\x18\x08 \x01(\t\x12\x0f\n\x07version\x18\t \x01(\t\x12\x14\n\x0c\x63reated_date\x18\n \x01(\t\"\xa8\x01\n\x16LayerVersionPermission\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x19\n\x11layer_version_arn\x18\x03 \x01(\t\x12\x17\n\x0forganization_id\x18\x04 \x01(\t\x12\x11\n\tprincipal\x18\x05 \x01(\t\"\xc7\x01\n\nPermission\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x1a\n\x12\x65vent_source_token\x18\x03 \x01(\t\x12\x15\n\rfunction_name\x18\x04 \x01(\t\x12\x11\n\tprincipal\x18\x05 \x01(\t\x12\x16\n\x0esource_account\x18\x06 \x01(\t\x12\x12\n\nsource_arn\x18\x07 \x01(\t\"\x90\x01\n*VersionProvisionedConcurrencyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12)\n!provisioned_concurrent_executions\x18\x02 \x01(\x05\"\xef\x01\n\x07Version\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63ode_sha256\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rfunction_name\x18\x04 \x01(\t\x12j\n\x1eprovisioned_concurrency_config\x18\x05 \x01(\x0b\x32\x42.oak9.tython.aws.lambda.VersionProvisionedConcurrencyConfigurationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_lambda_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FUNCTIONENVIRONMENT_VARIABLESENTRY._options = None
  _FUNCTIONENVIRONMENT_VARIABLESENTRY._serialized_options = b'8\001'
  _FUNCTION_TAGSENTRY._options = None
  _FUNCTION_TAGSENTRY._serialized_options = b'8\001'
  _ALIASPROVISIONEDCONCURRENCYCONFIGURATION._serialized_start=70
  _ALIASPROVISIONEDCONCURRENCYCONFIGURATION._serialized_end=212
  _ALIASVERSIONWEIGHT._serialized_start=215
  _ALIASVERSIONWEIGHT._serialized_end=343
  _ALIASALIASROUTINGCONFIGURATION._serialized_start=346
  _ALIASALIASROUTINGCONFIGURATION._serialized_end=515
  _ALIAS._serialized_start=518
  _ALIAS._serialized_end=852
  _LAMBDA._serialized_start=855
  _LAMBDA._serialized_end=1356
  _EVENTINVOKECONFIGONSUCCESS._serialized_start=1358
  _EVENTINVOKECONFIGONSUCCESS._serialized_end=1464
  _EVENTINVOKECONFIGONFAILURE._serialized_start=1466
  _EVENTINVOKECONFIGONFAILURE._serialized_end=1572
  _EVENTINVOKECONFIGDESTINATIONCONFIG._serialized_start=1575
  _EVENTINVOKECONFIGDESTINATIONCONFIG._serialized_end=1812
  _EVENTINVOKECONFIG._serialized_start=1815
  _EVENTINVOKECONFIG._serialized_end=2091
  _EVENTSOURCEMAPPINGONFAILURE._serialized_start=2093
  _EVENTSOURCEMAPPINGONFAILURE._serialized_end=2200
  _EVENTSOURCEMAPPINGDESTINATIONCONFIG._serialized_start=2203
  _EVENTSOURCEMAPPINGDESTINATIONCONFIG._serialized_end=2370
  _EVENTSOURCEMAPPING._serialized_start=2373
  _EVENTSOURCEMAPPING._serialized_end=2855
  _FUNCTIONCODE._serialized_start=2858
  _FUNCTIONCODE._serialized_end=3028
  _FUNCTIONDEADLETTERCONFIG._serialized_start=3030
  _FUNCTIONDEADLETTERCONFIG._serialized_end=3133
  _FUNCTIONENVIRONMENT._serialized_start=3136
  _FUNCTIONENVIRONMENT._serialized_end=3358
  _FUNCTIONENVIRONMENT_VARIABLESENTRY._serialized_start=3310
  _FUNCTIONENVIRONMENT_VARIABLESENTRY._serialized_end=3358
  _FUNCTIONFILESYSTEMCONFIG._serialized_start=3360
  _FUNCTIONFILESYSTEMCONFIG._serialized_end=3482
  _FUNCTIONTRACINGCONFIG._serialized_start=3484
  _FUNCTIONTRACINGCONFIG._serialized_end=3578
  _FUNCTIONVPCCONFIG._serialized_start=3581
  _FUNCTIONVPCCONFIG._serialized_end=3721
  _FUNCTION._serialized_start=3724
  _FUNCTION._serialized_end=4631
  _FUNCTION_TAGSENTRY._serialized_start=4588
  _FUNCTION_TAGSENTRY._serialized_end=4631
  _LAYERVERSIONCONTENT._serialized_start=4634
  _LAYERVERSIONCONTENT._serialized_end=4832
  _LAYERVERSION._serialized_start=4835
  _LAYERVERSION._serialized_end=5145
  _LAYERVERSIONPERMISSION._serialized_start=5148
  _LAYERVERSIONPERMISSION._serialized_end=5316
  _PERMISSION._serialized_start=5319
  _PERMISSION._serialized_end=5518
  _VERSIONPROVISIONEDCONCURRENCYCONFIGURATION._serialized_start=5521
  _VERSIONPROVISIONEDCONCURRENCYCONFIGURATION._serialized_end=5665
  _VERSION._serialized_start=5668
  _VERSION._serialized_end=5907
# @@protoc_insertion_point(module_scope)
