# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticbeanstalk.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_elasticbeanstalk.proto\x12 oak9.tython.aws.elasticbeanstalk\x1a\x13shared/shared.proto\"\x99\x01\n\x15\x41pplicationMaxAgeRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_source_from_s3\x18\x02 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x17\n\x0fmax_age_in_days\x18\x04 \x01(\x05\"\x95\x01\n\x17\x41pplicationMaxCountRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_source_from_s3\x18\x02 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x11\n\tmax_count\x18\x04 \x01(\x05\"\x89\x02\n,ApplicationApplicationVersionLifecycleConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x0cmax_age_rule\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.elasticbeanstalk.ApplicationMaxAgeRule\x12Q\n\x0emax_count_rule\x18\x03 \x01(\x0b\x32\x39.oak9.tython.aws.elasticbeanstalk.ApplicationMaxCountRule\"\xf0\x01\n-ApplicationApplicationResourceLifecycleConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cservice_role\x18\x02 \x01(\t\x12p\n\x18version_lifecycle_config\x18\x03 \x01(\x0b\x32N.oak9.tython.aws.elasticbeanstalk.ApplicationApplicationVersionLifecycleConfig\"\xe9\x01\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12r\n\x19resource_lifecycle_config\x18\x04 \x01(\x0b\x32O.oak9.tython.aws.elasticbeanstalk.ApplicationApplicationResourceLifecycleConfig\"\xc6\x02\n\x10\x45lasticBeanstalk\x12\x42\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32-.oak9.tython.aws.elasticbeanstalk.Application\x12Q\n\x13\x61pplication_version\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.elasticbeanstalk.ApplicationVersion\x12W\n\x16\x63onfiguration_template\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.elasticbeanstalk.ConfigurationTemplate\x12\x42\n\x0b\x65nvironment\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.elasticbeanstalk.Environment\"|\n\x1e\x41pplicationVersionSourceBundle\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x0e\n\x06s3_key\x18\x03 \x01(\t\"\xd5\x01\n\x12\x41pplicationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12W\n\rsource_bundle\x18\x04 \x01(\x0b\x32@.oak9.tython.aws.elasticbeanstalk.ApplicationVersionSourceBundle\"\xb8\x01\n/ConfigurationTemplateConfigurationOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"\x94\x01\n(ConfigurationTemplateSourceConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x15\n\rtemplate_name\x18\x03 \x01(\t\"\xa0\x03\n\x15\x43onfigurationTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x04 \x01(\t\x12j\n\x0foption_settings\x18\x05 \x03(\x0b\x32Q.oak9.tython.aws.elasticbeanstalk.ConfigurationTemplateConfigurationOptionSetting\x12\x14\n\x0cplatform_arn\x18\x06 \x01(\t\x12\x1b\n\x13solution_stack_name\x18\x07 \x01(\t\x12h\n\x14source_configuration\x18\x08 \x01(\x0b\x32J.oak9.tython.aws.elasticbeanstalk.ConfigurationTemplateSourceConfiguration\"\xa1\x01\n\x18\x45nvironmentOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"i\n\x0f\x45nvironmentTier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\x90\x04\n\x0b\x45nvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x14\n\x0c\x63name_prefix\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x18\n\x10\x65nvironment_name\x18\x05 \x01(\t\x12S\n\x0foption_settings\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.elasticbeanstalk.EnvironmentOptionSetting\x12\x14\n\x0cplatform_arn\x18\x07 \x01(\t\x12\x1b\n\x13solution_stack_name\x18\x08 \x01(\t\x12\x45\n\x04tags\x18\t \x03(\x0b\x32\x37.oak9.tython.aws.elasticbeanstalk.Environment.TagsEntry\x12\x15\n\rtemplate_name\x18\n \x01(\t\x12?\n\x04tier\x18\x0b \x01(\x0b\x32\x31.oak9.tython.aws.elasticbeanstalk.EnvironmentTier\x12\x15\n\rversion_label\x18\x0c \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticbeanstalk_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVIRONMENT_TAGSENTRY._options = None
  _ENVIRONMENT_TAGSENTRY._serialized_options = b'8\001'
  _APPLICATIONMAXAGERULE._serialized_start=90
  _APPLICATIONMAXAGERULE._serialized_end=243
  _APPLICATIONMAXCOUNTRULE._serialized_start=246
  _APPLICATIONMAXCOUNTRULE._serialized_end=395
  _APPLICATIONAPPLICATIONVERSIONLIFECYCLECONFIG._serialized_start=398
  _APPLICATIONAPPLICATIONVERSIONLIFECYCLECONFIG._serialized_end=663
  _APPLICATIONAPPLICATIONRESOURCELIFECYCLECONFIG._serialized_start=666
  _APPLICATIONAPPLICATIONRESOURCELIFECYCLECONFIG._serialized_end=906
  _APPLICATION._serialized_start=909
  _APPLICATION._serialized_end=1142
  _ELASTICBEANSTALK._serialized_start=1145
  _ELASTICBEANSTALK._serialized_end=1471
  _APPLICATIONVERSIONSOURCEBUNDLE._serialized_start=1473
  _APPLICATIONVERSIONSOURCEBUNDLE._serialized_end=1597
  _APPLICATIONVERSION._serialized_start=1600
  _APPLICATIONVERSION._serialized_end=1813
  _CONFIGURATIONTEMPLATECONFIGURATIONOPTIONSETTING._serialized_start=1816
  _CONFIGURATIONTEMPLATECONFIGURATIONOPTIONSETTING._serialized_end=2000
  _CONFIGURATIONTEMPLATESOURCECONFIGURATION._serialized_start=2003
  _CONFIGURATIONTEMPLATESOURCECONFIGURATION._serialized_end=2151
  _CONFIGURATIONTEMPLATE._serialized_start=2154
  _CONFIGURATIONTEMPLATE._serialized_end=2570
  _ENVIRONMENTOPTIONSETTING._serialized_start=2573
  _ENVIRONMENTOPTIONSETTING._serialized_end=2734
  _ENVIRONMENTTIER._serialized_start=2736
  _ENVIRONMENTTIER._serialized_end=2841
  _ENVIRONMENT._serialized_start=2844
  _ENVIRONMENT._serialized_end=3372
  _ENVIRONMENT_TAGSENTRY._serialized_start=3329
  _ENVIRONMENT_TAGSENTRY._serialized_end=3372
# @@protoc_insertion_point(module_scope)
