# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_acmpca.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_acmpca.proto\x12\x16oak9.tython.aws.acmpca\x1a\x13shared/shared.proto\"]\n\x13\x43\x65rtificateValidity\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\x05\"\xfe\x01\n\x0b\x43\x65rtificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x65rtificate_authority_arn\x18\x02 \x01(\t\x12#\n\x1b\x63\x65rtificate_signing_request\x18\x03 \x01(\t\x12\x19\n\x11signing_algorithm\x18\x04 \x01(\t\x12\x14\n\x0ctemplate_arn\x18\x05 \x01(\t\x12=\n\x08validity\x18\x06 \x01(\x0b\x32+.oak9.tython.aws.acmpca.CertificateValidity\"\xf1\x01\n\x06\x41\x43MPCA\x12\x38\n\x0b\x63\x65rtificate\x18\x01 \x03(\x0b\x32#.oak9.tython.aws.acmpca.Certificate\x12K\n\x15\x63\x65rtificate_authority\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.acmpca.CertificateAuthority\x12`\n certificate_authority_activation\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.acmpca.CertificateAuthorityActivation\"\x84\x03\n\x1b\x43\x65rtificateAuthoritySubject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x14\n\x0corganization\x18\x03 \x01(\t\x12\x1b\n\x13organizational_unit\x18\x04 \x01(\t\x12$\n\x1c\x64istinguished_name_qualifier\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x13\n\x0b\x63ommon_name\x18\x07 \x01(\t\x12\x15\n\rserial_number\x18\x08 \x01(\t\x12\x10\n\x08locality\x18\t \x01(\t\x12\r\n\x05title\x18\n \x01(\t\x12\x0f\n\x07surname\x18\x0b \x01(\t\x12\x12\n\ngiven_name\x18\x0c \x01(\t\x12\x10\n\x08initials\x18\r \x01(\t\x12\x11\n\tpseudonym\x18\x0e \x01(\t\x12\x1c\n\x14generation_qualifier\x18\x0f \x01(\t\"\xba\x01\n$CertificateAuthorityCrlConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x1a\n\x12\x65xpiration_in_days\x18\x03 \x01(\x05\x12\x14\n\x0c\x63ustom_cname\x18\x04 \x01(\t\x12\x16\n\x0es3_bucket_name\x18\x05 \x01(\t\"\xbf\x01\n+CertificateAuthorityRevocationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x11\x63rl_configuration\x18\x02 \x01(\x0b\x32<.oak9.tython.aws.acmpca.CertificateAuthorityCrlConfiguration\"\xaf\x03\n\x14\x43\x65rtificateAuthority\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x15\n\rkey_algorithm\x18\x03 \x01(\t\x12\x19\n\x11signing_algorithm\x18\x04 \x01(\t\x12\x44\n\x07subject\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.acmpca.CertificateAuthoritySubject\x12\x65\n\x18revocation_configuration\x18\x06 \x01(\x0b\x32\x43.oak9.tython.aws.acmpca.CertificateAuthorityRevocationConfiguration\x12\x44\n\x04tags\x18\x07 \x03(\x0b\x32\x36.oak9.tython.aws.acmpca.CertificateAuthority.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x1e\x43\x65rtificateAuthorityActivation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x65rtificate_authority_arn\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x03 \x01(\t\x12\x19\n\x11\x63\x65rtificate_chain\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_acmpca_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CERTIFICATEAUTHORITY_TAGSENTRY._options = None
  _CERTIFICATEAUTHORITY_TAGSENTRY._serialized_options = b'8\001'
  _CERTIFICATEVALIDITY._serialized_start=69
  _CERTIFICATEVALIDITY._serialized_end=162
  _CERTIFICATE._serialized_start=165
  _CERTIFICATE._serialized_end=419
  _ACMPCA._serialized_start=422
  _ACMPCA._serialized_end=663
  _CERTIFICATEAUTHORITYSUBJECT._serialized_start=666
  _CERTIFICATEAUTHORITYSUBJECT._serialized_end=1054
  _CERTIFICATEAUTHORITYCRLCONFIGURATION._serialized_start=1057
  _CERTIFICATEAUTHORITYCRLCONFIGURATION._serialized_end=1243
  _CERTIFICATEAUTHORITYREVOCATIONCONFIGURATION._serialized_start=1246
  _CERTIFICATEAUTHORITYREVOCATIONCONFIGURATION._serialized_end=1437
  _CERTIFICATEAUTHORITY._serialized_start=1440
  _CERTIFICATEAUTHORITY._serialized_end=1871
  _CERTIFICATEAUTHORITY_TAGSENTRY._serialized_start=1828
  _CERTIFICATEAUTHORITY_TAGSENTRY._serialized_end=1871
  _CERTIFICATEAUTHORITYACTIVATION._serialized_start=1874
  _CERTIFICATEAUTHORITYACTIVATION._serialized_end=2062
# @@protoc_insertion_point(module_scope)
