# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_appsync.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_appsync.proto\x12\x17oak9.tython.aws.appsync\x1a\x13shared/shared.proto\"\xd4\x01\n\x08\x41piCache\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\"\n\x1atransit_encryption_enabled\x18\x03 \x01(\x08\x12\"\n\x1a\x61t_rest_encryption_enabled\x18\x04 \x01(\x08\x12\x0e\n\x06\x61pi_id\x18\x05 \x01(\t\x12\x1c\n\x14\x61pi_caching_behavior\x18\x06 \x01(\t\x12\x0b\n\x03ttl\x18\x07 \x01(\x01\"\xad\x04\n\x07\x41ppSync\x12\x34\n\tapi_cache\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.appsync.ApiCache\x12\x30\n\x07\x61pi_key\x18\x02 \x03(\x0b\x32\x1f.oak9.tython.aws.appsync.ApiKey\x12\x38\n\x0b\x64\x61ta_source\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.appsync.DataSource\x12N\n\x16\x66unction_configuration\x18\x04 \x03(\x0b\x32..oak9.tython.aws.appsync.FunctionConfiguration\x12:\n\rgraph_q_l_api\x18\x05 \x03(\x0b\x32#.oak9.tython.aws.appsync.GraphQLApi\x12@\n\x10graph_q_l_schema\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.appsync.GraphQLSchema\x12\x33\n\x08resolver\x18\x07 \x03(\x0b\x32!.oak9.tython.aws.appsync.Resolver\x12}\n0graph_q_l_api_additional_authentication_provider\x18\x08 \x03(\x0b\x32\x43.oak9.tython.aws.appsync.GraphQLApiAdditionalAuthenticationProvider\"w\n\x06\x41piKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x65xpires\x18\x03 \x01(\x01\x12\x0e\n\x06\x61pi_id\x18\x04 \x01(\t\"\x87\x01\n\x16\x44\x61taSourceAwsIamConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0esigning_region\x18\x02 \x01(\t\x12\x1c\n\x14signing_service_name\x18\x03 \x01(\t\"\xbd\x01\n\x1d\x44\x61taSourceAuthorizationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x0e\x61ws_iam_config\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.appsync.DataSourceAwsIamConfig\x12\x1a\n\x12\x61uthorization_type\x18\x03 \x01(\t\"\xb7\x01\n\x14\x44\x61taSourceHttpConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12T\n\x14\x61uthorization_config\x18\x03 \x01(\x0b\x32\x36.oak9.tython.aws.appsync.DataSourceAuthorizationConfig\"\xd2\x01\n\x1f\x44\x61taSourceRdsHttpEndpointConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\naws_region\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x15\n\rdatabase_name\x18\x04 \x01(\t\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x05 \x01(\t\x12\x1c\n\x14\x61ws_secret_store_arn\x18\x06 \x01(\t\"\xe2\x01\n\"DataSourceRelationalDatabaseConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x18rds_http_endpoint_config\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.appsync.DataSourceRdsHttpEndpointConfig\x12\'\n\x1frelational_database_source_type\x18\x03 \x01(\t\"n\n\x16\x44\x61taSourceLambdaConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13lambda_function_arn\x18\x02 \x01(\t\"\xa9\x01\n\x19\x44\x61taSourceDeltaSyncConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x62\x61se_table_ttl\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65lta_sync_table_ttl\x18\x03 \x01(\t\x12\x1d\n\x15\x64\x65lta_sync_table_name\x18\x04 \x01(\t\"\xfd\x01\n\x18\x44\x61taSourceDynamoDBConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x12\n\naws_region\x18\x03 \x01(\t\x12\x11\n\tversioned\x18\x04 \x01(\x08\x12M\n\x11\x64\x65lta_sync_config\x18\x05 \x01(\x0b\x32\x32.oak9.tython.aws.appsync.DataSourceDeltaSyncConfig\x12\x1e\n\x16use_caller_credentials\x18\x06 \x01(\x08\"~\n\x1d\x44\x61taSourceElasticsearchConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\naws_region\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\"\xb0\x04\n\nDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10service_role_arn\x18\x04 \x01(\t\x12\x42\n\x0bhttp_config\x18\x05 \x01(\x0b\x32-.oak9.tython.aws.appsync.DataSourceHttpConfig\x12_\n\x1arelational_database_config\x18\x06 \x01(\x0b\x32;.oak9.tython.aws.appsync.DataSourceRelationalDatabaseConfig\x12\x46\n\rlambda_config\x18\x07 \x01(\x0b\x32/.oak9.tython.aws.appsync.DataSourceLambdaConfig\x12\x0e\n\x06\x61pi_id\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12K\n\x10\x64ynamo_db_config\x18\n \x01(\x0b\x32\x31.oak9.tython.aws.appsync.DataSourceDynamoDBConfig\x12T\n\x14\x65lasticsearch_config\x18\x0b \x01(\x0b\x32\x36.oak9.tython.aws.appsync.DataSourceElasticsearchConfig\"\xd9\x02\n\x15\x46unctionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12-\n%response_mapping_template_s3_location\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10\x64\x61ta_source_name\x18\x04 \x01(\t\x12 \n\x18request_mapping_template\x18\x05 \x01(\t\x12!\n\x19response_mapping_template\x18\x06 \x01(\t\x12\x18\n\x10\x66unction_version\x18\x07 \x01(\t\x12,\n$request_mapping_template_s3_location\x18\x08 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\"\x9e\x01\n\x1dGraphQLApiOpenIDConnectConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x10\n\x08\x61uth_ttl\x18\x04 \x01(\x01\x12\x0f\n\x07iat_ttl\x18\x05 \x01(\x01\"\xb2\x01\n\x18GraphQLApiUserPoolConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61pp_id_client_regex\x18\x02 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x12\n\naws_region\x18\x04 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x05 \x01(\t\"I\n\x0eGraphQLApiTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x13GraphQLApiLogConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63loud_watch_logs_role_arn\x18\x02 \x01(\t\x12\x1f\n\x17\x65xclude_verbose_content\x18\x03 \x01(\x08\x12\x17\n\x0f\x66ield_log_level\x18\x04 \x01(\t\"f\n+GraphQLApiAdditionalAuthenticationProviders\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x97\x04\n\nGraphQLApi\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x16open_id_connect_config\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.appsync.GraphQLApiOpenIDConnectConfig\x12\x14\n\x0cxray_enabled\x18\x03 \x01(\x08\x12K\n\x10user_pool_config\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.appsync.GraphQLApiUserPoolConfig\x12\x35\n\x04tags\x18\x05 \x01(\x0b\x32\'.oak9.tython.aws.appsync.GraphQLApiTags\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13\x61uthentication_type\x18\x07 \x01(\t\x12@\n\nlog_config\x18\x08 \x01(\x0b\x32,.oak9.tython.aws.appsync.GraphQLApiLogConfig\x12q\n#additional_authentication_providers\x18\t \x01(\x0b\x32\x44.oak9.tython.aws.appsync.GraphQLApiAdditionalAuthenticationProviders\"\x8c\x01\n\rGraphQLSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x65\x66inition_s3_location\x18\x03 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x04 \x01(\t\"d\n\x16ResolverPipelineConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfunctions\x18\x02 \x03(\t\"s\n\x15ResolverCachingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63\x61\x63hing_keys\x18\x02 \x03(\t\x12\x0b\n\x03ttl\x18\x03 \x01(\x01\"\x83\x01\n#ResolverLambdaConflictHandlerConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1blambda_conflict_handler_arn\x18\x02 \x01(\t\"\xe9\x01\n\x12ResolverSyncConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63onflict_handler\x18\x02 \x01(\t\x12\x1a\n\x12\x63onflict_detection\x18\x03 \x01(\t\x12\x64\n\x1elambda_conflict_handler_config\x18\x04 \x01(\x0b\x32<.oak9.tython.aws.appsync.ResolverLambdaConflictHandlerConfig\"\x98\x04\n\x08Resolver\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12-\n%response_mapping_template_s3_location\x18\x02 \x01(\t\x12\x11\n\ttype_name\x18\x03 \x01(\t\x12H\n\x0fpipeline_config\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.appsync.ResolverPipelineConfig\x12\x18\n\x10\x64\x61ta_source_name\x18\x05 \x01(\t\x12 \n\x18request_mapping_template\x18\x06 \x01(\t\x12!\n\x19response_mapping_template\x18\x07 \x01(\t\x12\x0c\n\x04kind\x18\x08 \x01(\t\x12\x46\n\x0e\x63\x61\x63hing_config\x18\t \x01(\x0b\x32..oak9.tython.aws.appsync.ResolverCachingConfig\x12@\n\x0bsync_config\x18\n \x01(\x0b\x32+.oak9.tython.aws.appsync.ResolverSyncConfig\x12,\n$request_mapping_template_s3_location\x18\x0b \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x0c \x01(\t\x12\x12\n\nfield_name\x18\r \x01(\t\"\xa1\x01\n\x1fGraphQLApiCognitoUserPoolConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61pp_id_client_regex\x18\x02 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x12\n\naws_region\x18\x04 \x01(\t\"\xae\x02\n*GraphQLApiAdditionalAuthenticationProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x16open_id_connect_config\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.appsync.GraphQLApiOpenIDConnectConfig\x12R\n\x10user_pool_config\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.appsync.GraphQLApiCognitoUserPoolConfig\x12\x1b\n\x13\x61uthentication_type\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_appsync_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APICACHE._serialized_start=72
  _APICACHE._serialized_end=284
  _APPSYNC._serialized_start=287
  _APPSYNC._serialized_end=844
  _APIKEY._serialized_start=846
  _APIKEY._serialized_end=965
  _DATASOURCEAWSIAMCONFIG._serialized_start=968
  _DATASOURCEAWSIAMCONFIG._serialized_end=1103
  _DATASOURCEAUTHORIZATIONCONFIG._serialized_start=1106
  _DATASOURCEAUTHORIZATIONCONFIG._serialized_end=1295
  _DATASOURCEHTTPCONFIG._serialized_start=1298
  _DATASOURCEHTTPCONFIG._serialized_end=1481
  _DATASOURCERDSHTTPENDPOINTCONFIG._serialized_start=1484
  _DATASOURCERDSHTTPENDPOINTCONFIG._serialized_end=1694
  _DATASOURCERELATIONALDATABASECONFIG._serialized_start=1697
  _DATASOURCERELATIONALDATABASECONFIG._serialized_end=1923
  _DATASOURCELAMBDACONFIG._serialized_start=1925
  _DATASOURCELAMBDACONFIG._serialized_end=2035
  _DATASOURCEDELTASYNCCONFIG._serialized_start=2038
  _DATASOURCEDELTASYNCCONFIG._serialized_end=2207
  _DATASOURCEDYNAMODBCONFIG._serialized_start=2210
  _DATASOURCEDYNAMODBCONFIG._serialized_end=2463
  _DATASOURCEELASTICSEARCHCONFIG._serialized_start=2465
  _DATASOURCEELASTICSEARCHCONFIG._serialized_end=2591
  _DATASOURCE._serialized_start=2594
  _DATASOURCE._serialized_end=3154
  _FUNCTIONCONFIGURATION._serialized_start=3157
  _FUNCTIONCONFIGURATION._serialized_end=3502
  _GRAPHQLAPIOPENIDCONNECTCONFIG._serialized_start=3505
  _GRAPHQLAPIOPENIDCONNECTCONFIG._serialized_end=3663
  _GRAPHQLAPIUSERPOOLCONFIG._serialized_start=3666
  _GRAPHQLAPIUSERPOOLCONFIG._serialized_end=3844
  _GRAPHQLAPITAGS._serialized_start=3846
  _GRAPHQLAPITAGS._serialized_end=3919
  _GRAPHQLAPILOGCONFIG._serialized_start=3922
  _GRAPHQLAPILOGCONFIG._serialized_end=4093
  _GRAPHQLAPIADDITIONALAUTHENTICATIONPROVIDERS._serialized_start=4095
  _GRAPHQLAPIADDITIONALAUTHENTICATIONPROVIDERS._serialized_end=4197
  _GRAPHQLAPI._serialized_start=4200
  _GRAPHQLAPI._serialized_end=4735
  _GRAPHQLSCHEMA._serialized_start=4738
  _GRAPHQLSCHEMA._serialized_end=4878
  _RESOLVERPIPELINECONFIG._serialized_start=4880
  _RESOLVERPIPELINECONFIG._serialized_end=4980
  _RESOLVERCACHINGCONFIG._serialized_start=4982
  _RESOLVERCACHINGCONFIG._serialized_end=5097
  _RESOLVERLAMBDACONFLICTHANDLERCONFIG._serialized_start=5100
  _RESOLVERLAMBDACONFLICTHANDLERCONFIG._serialized_end=5231
  _RESOLVERSYNCCONFIG._serialized_start=5234
  _RESOLVERSYNCCONFIG._serialized_end=5467
  _RESOLVER._serialized_start=5470
  _RESOLVER._serialized_end=6006
  _GRAPHQLAPICOGNITOUSERPOOLCONFIG._serialized_start=6009
  _GRAPHQLAPICOGNITOUSERPOOLCONFIG._serialized_end=6170
  _GRAPHQLAPIADDITIONALAUTHENTICATIONPROVIDER._serialized_start=6173
  _GRAPHQLAPIADDITIONALAUTHENTICATIONPROVIDER._serialized_end=6475
# @@protoc_insertion_point(module_scope)
