# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_rds_dbinstance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_rds_dbinstance.proto\x12\x1eoak9.tython.aws.rds_dbinstance\x1a\x13shared/shared.proto\"{\n\x18\x44\x42InstanceDBInstanceRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"r\n\x1a\x44\x42InstanceProcessorFeature\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xf2\r\n\nDBInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61llocated_storage\x18\x02 \x01(\t\x12#\n\x1b\x61llow_major_version_upgrade\x18\x03 \x01(\x08\x12R\n\x10\x61ssociated_roles\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.rds_dbinstance.DBInstanceDBInstanceRole\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x05 \x01(\x08\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12\x1f\n\x17\x62\x61\x63kup_retention_period\x18\x07 \x01(\x05\x12!\n\x19\x63\x61_certificate_identifier\x18\x08 \x01(\t\x12\x1a\n\x12\x63haracter_set_name\x18\t \x01(\t\x12\x1d\n\x15\x63opy_tags_to_snapshot\x18\n \x01(\x08\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x0b \x01(\t\x12\x19\n\x11\x64\x62_instance_class\x18\x0c \x01(\t\x12\x1e\n\x16\x64\x62_instance_identifier\x18\r \x01(\t\x12\x0f\n\x07\x64\x62_name\x18\x0e \x01(\t\x12\x1f\n\x17\x64\x62_parameter_group_name\x18\x0f \x01(\t\x12\x1a\n\x12\x64\x62_security_groups\x18\x10 \x03(\t\x12\x1e\n\x16\x64\x62_snapshot_identifier\x18\x11 \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x12 \x01(\t\x12 \n\x18\x64\x65lete_automated_backups\x18\x13 \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x12\x0e\n\x06\x64omain\x18\x15 \x01(\t\x12\x1c\n\x14\x64omain_iam_role_name\x18\x16 \x01(\t\x12&\n\x1e\x65nable_cloudwatch_logs_exports\x18\x17 \x03(\t\x12*\n\"enable_iam_database_authentication\x18\x18 \x01(\x08\x12#\n\x1b\x65nable_performance_insights\x18\x19 \x01(\x08\x12\x0e\n\x06\x65ngine\x18\x1a \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x1b \x01(\t\x12\x0c\n\x04iops\x18\x1c \x01(\x05\x12\x12\n\nkms_key_id\x18\x1d \x01(\t\x12\x15\n\rlicense_model\x18\x1e \x01(\t\x12\x1c\n\x14master_user_password\x18\x1f \x01(\t\x12\x17\n\x0fmaster_username\x18  \x01(\t\x12\x1d\n\x15max_allocated_storage\x18! \x01(\x05\x12\x1b\n\x13monitoring_interval\x18\" \x01(\x05\x12\x1b\n\x13monitoring_role_arn\x18# \x01(\t\x12\x10\n\x08multi_az\x18$ \x01(\x08\x12\x19\n\x11option_group_name\x18% \x01(\t\x12\'\n\x1fperformance_insights_kms_key_id\x18& \x01(\t\x12-\n%performance_insights_retention_period\x18\' \x01(\x05\x12\x0c\n\x04port\x18( \x01(\t\x12\x1f\n\x17preferred_backup_window\x18) \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18* \x01(\t\x12V\n\x12processor_features\x18+ \x03(\x0b\x32:.oak9.tython.aws.rds_dbinstance.DBInstanceProcessorFeature\x12\x16\n\x0epromotion_tier\x18, \x01(\x05\x12\x1b\n\x13publicly_accessible\x18- \x01(\x08\x12%\n\x1dsource_db_instance_identifier\x18. \x01(\t\x12\x15\n\rsource_region\x18/ \x01(\t\x12\x19\n\x11storage_encrypted\x18\x30 \x01(\x08\x12\x14\n\x0cstorage_type\x18\x31 \x01(\t\x12\x42\n\x04tags\x18\x32 \x03(\x0b\x32\x34.oak9.tython.aws.rds_dbinstance.DBInstance.TagsEntry\x12\x10\n\x08timezone\x18\x33 \x01(\t\x12&\n\x1euse_default_processor_features\x18\x34 \x01(\x08\x12\x1b\n\x13vpc_security_groups\x18\x35 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xae\x05\n\x0eRDS_DBInstance\x12?\n\x0b\x64\x62_instance\x18\x01 \x01(\x0b\x32*.oak9.tython.aws.rds_dbinstance.DBInstance\x12L\n\x12\x64\x62_parameter_group\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.rds_dbinstance.DBParameterGroup\x12\x39\n\x08\x64\x62_proxy\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.rds_dbinstance.DBProxy\x12Q\n\x15\x64\x62_proxy_target_group\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.rds_dbinstance.DBProxyTargetGroup\x12J\n\x11\x64\x62_security_group\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.rds_dbinstance.DBSecurityGroup\x12Y\n\x19\x64\x62_security_group_ingress\x18\x06 \x03(\x0b\x32\x36.oak9.tython.aws.rds_dbinstance.DBSecurityGroupIngress\x12\x46\n\x0f\x64\x62_subnet_group\x18\x07 \x01(\x0b\x32-.oak9.tython.aws.rds_dbinstance.DBSubnetGroup\x12M\n\x12\x65vent_subscription\x18\x08 \x01(\x0b\x32\x31.oak9.tython.aws.rds_dbinstance.EventSubscription\x12\x41\n\x0coption_group\x18\t \x01(\x0b\x32+.oak9.tython.aws.rds_dbinstance.OptionGroup\"\xf0\x02\n\x10\x44\x42ParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\x12T\n\nparameters\x18\x04 \x03(\x0b\x32@.oak9.tython.aws.rds_dbinstance.DBParameterGroup.ParametersEntry\x12H\n\x04tags\x18\x05 \x03(\x0b\x32:.oak9.tython.aws.rds_dbinstance.DBParameterGroup.TagsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x10\x44\x42ProxyTagFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfe\x02\n\x07\x44\x42Proxy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdb_proxy_name\x18\x02 \x01(\t\x12\x15\n\rdebug_logging\x18\x03 \x01(\x08\x12\x15\n\rengine_family\x18\x04 \x01(\t\x12\x1b\n\x13idle_client_timeout\x18\x05 \x01(\x05\x12\x13\n\x0brequire_tls\x18\x06 \x01(\x08\x12\x10\n\x08role_arn\x18\x07 \x01(\t\x12>\n\x04tags\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.rds_dbinstance.DBProxyTagFormat\x12\x1e\n\x16vpc_security_group_ids\x18\t \x03(\t\x12\x16\n\x0evpc_subnet_ids\x18\n \x03(\t\x12\x39\n\x04\x61uth\x18\x0b \x03(\x0b\x32+.oak9.tython.aws.rds_dbinstance.DBProxyAuth\"\x91\x02\n7DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17max_connections_percent\x18\x02 \x01(\x05\x12$\n\x1cmax_idle_connections_percent\x18\x03 \x01(\x05\x12!\n\x19\x63onnection_borrow_timeout\x18\x04 \x01(\x05\x12\x1f\n\x17session_pinning_filters\x18\x05 \x03(\t\x12\x12\n\ninit_query\x18\x06 \x01(\t\"\xc6\x02\n\x12\x44\x42ProxyTargetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdb_proxy_name\x18\x02 \x01(\t\x12\x19\n\x11target_group_name\x18\x03 \x01(\t\x12\x83\x01\n\"connection_pool_configuration_info\x18\x04 \x01(\x0b\x32W.oak9.tython.aws.rds_dbinstance.DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x1f\n\x17\x64\x62_instance_identifiers\x18\x05 \x03(\t\x12\x1e\n\x16\x64\x62_cluster_identifiers\x18\x06 \x03(\t\"\xca\x01\n\x16\x44\x42SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x1e\n\x16\x65_c2_security_group_id\x18\x03 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x04 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x05 \x01(\t\"\xcb\x02\n\x0f\x44\x42SecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x19\x64\x62_security_group_ingress\x18\x02 \x03(\x0b\x32\x36.oak9.tython.aws.rds_dbinstance.DBSecurityGroupIngress\x12\x13\n\x0b\x65_c2_vpc_id\x18\x03 \x01(\t\x12\x19\n\x11group_description\x18\x04 \x01(\t\x12G\n\x04tags\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.rds_dbinstance.DBSecurityGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\x02\n\rDBSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x64\x62_subnet_group_description\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12\x45\n\x04tags\x18\x05 \x03(\x0b\x32\x37.oak9.tython.aws.rds_dbinstance.DBSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x01\n\x11\x45ventSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x18\n\x10\x65vent_categories\x18\x03 \x03(\t\x12\x15\n\rsns_topic_arn\x18\x04 \x01(\t\x12\x12\n\nsource_ids\x18\x05 \x03(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\t\"p\n\x18OptionGroupOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb6\x02\n\x1eOptionGroupOptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1d\x64\x62_security_group_memberships\x18\x02 \x03(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12Q\n\x0foption_settings\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.rds_dbinstance.OptionGroupOptionSetting\x12\x16\n\x0eoption_version\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12&\n\x1evpc_security_group_memberships\x18\x07 \x03(\t\"\xa9\x01\n\x0b\x44\x42ProxyAuth\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61uth_scheme\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08iam_auth\x18\x04 \x01(\t\x12\x12\n\nsecret_arn\x18\x05 \x01(\t\x12\x11\n\tuser_name\x18\x06 \x01(\t\"\xec\x02\n\x0bOptionGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65ngine_name\x18\x02 \x01(\t\x12\x1c\n\x14major_engine_version\x18\x03 \x01(\t\x12]\n\x15option_configurations\x18\x04 \x03(\x0b\x32>.oak9.tython.aws.rds_dbinstance.OptionGroupOptionConfiguration\x12 \n\x18option_group_description\x18\x05 \x01(\t\x12\x43\n\x04tags\x18\x06 \x03(\x0b\x32\x35.oak9.tython.aws.rds_dbinstance.OptionGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_rds_dbinstance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DBINSTANCE_TAGSENTRY._options = None
  _DBINSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _DBPARAMETERGROUP_PARAMETERSENTRY._options = None
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_options = b'8\001'
  _DBPARAMETERGROUP_TAGSENTRY._options = None
  _DBPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSECURITYGROUP_TAGSENTRY._options = None
  _DBSECURITYGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSUBNETGROUP_TAGSENTRY._options = None
  _DBSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _OPTIONGROUP_TAGSENTRY._options = None
  _OPTIONGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBINSTANCEDBINSTANCEROLE._serialized_start=85
  _DBINSTANCEDBINSTANCEROLE._serialized_end=208
  _DBINSTANCEPROCESSORFEATURE._serialized_start=210
  _DBINSTANCEPROCESSORFEATURE._serialized_end=324
  _DBINSTANCE._serialized_start=327
  _DBINSTANCE._serialized_end=2105
  _DBINSTANCE_TAGSENTRY._serialized_start=2062
  _DBINSTANCE_TAGSENTRY._serialized_end=2105
  _RDS_DBINSTANCE._serialized_start=2108
  _RDS_DBINSTANCE._serialized_end=2794
  _DBPARAMETERGROUP._serialized_start=2797
  _DBPARAMETERGROUP._serialized_end=3165
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_start=3071
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_end=3120
  _DBPARAMETERGROUP_TAGSENTRY._serialized_start=2062
  _DBPARAMETERGROUP_TAGSENTRY._serialized_end=2105
  _DBPROXYTAGFORMAT._serialized_start=3167
  _DBPROXYTAGFORMAT._serialized_end=3270
  _DBPROXY._serialized_start=3273
  _DBPROXY._serialized_end=3655
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_start=3658
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_end=3931
  _DBPROXYTARGETGROUP._serialized_start=3934
  _DBPROXYTARGETGROUP._serialized_end=4260
  _DBSECURITYGROUPINGRESS._serialized_start=4263
  _DBSECURITYGROUPINGRESS._serialized_end=4465
  _DBSECURITYGROUP._serialized_start=4468
  _DBSECURITYGROUP._serialized_end=4799
  _DBSECURITYGROUP_TAGSENTRY._serialized_start=2062
  _DBSECURITYGROUP_TAGSENTRY._serialized_end=2105
  _DBSUBNETGROUP._serialized_start=4802
  _DBSUBNETGROUP._serialized_end=5077
  _DBSUBNETGROUP_TAGSENTRY._serialized_start=2062
  _DBSUBNETGROUP_TAGSENTRY._serialized_end=2105
  _EVENTSUBSCRIPTION._serialized_start=5080
  _EVENTSUBSCRIPTION._serialized_end=5263
  _OPTIONGROUPOPTIONSETTING._serialized_start=5265
  _OPTIONGROUPOPTIONSETTING._serialized_end=5377
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_start=5380
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_end=5690
  _DBPROXYAUTH._serialized_start=5693
  _DBPROXYAUTH._serialized_end=5862
  _OPTIONGROUP._serialized_start=5865
  _OPTIONGROUP._serialized_end=6229
  _OPTIONGROUP_TAGSENTRY._serialized_start=2062
  _OPTIONGROUP_TAGSENTRY._serialized_end=2105
# @@protoc_insertion_point(module_scope)
