# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_globalaccelerator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61ws/aws_globalaccelerator.proto\x12!oak9.tython.aws.globalaccelerator\x1a\x13shared/shared.proto\"\x89\x02\n\x0b\x41\x63\x63\x65lerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fip_address_type\x18\x03 \x01(\t\x12\x14\n\x0cip_addresses\x18\x04 \x03(\t\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x46\n\x04tags\x18\x06 \x03(\x0b\x32\x38.oak9.tython.aws.globalaccelerator.Accelerator.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe1\x01\n\x11GlobalAccelerator\x12\x43\n\x0b\x61\x63\x63\x65lerator\x18\x01 \x03(\x0b\x32..oak9.tython.aws.globalaccelerator.Accelerator\x12H\n\x0e\x65ndpoint_group\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.globalaccelerator.EndpointGroup\x12=\n\x08listener\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.globalaccelerator.Listener\"\xaa\x01\n\"EndpointGroupEndpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65ndpoint_id\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\x12&\n\x1e\x63lient_ip_preservation_enabled\x18\x04 \x01(\x08\"\x9b\x03\n\rEndpointGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0clistener_arn\x18\x02 \x01(\t\x12\x1d\n\x15\x65ndpoint_group_region\x18\x03 \x01(\t\x12\x66\n\x17\x65ndpoint_configurations\x18\x04 \x03(\x0b\x32\x45.oak9.tython.aws.globalaccelerator.EndpointGroupEndpointConfiguration\x12\x1f\n\x17traffic_dial_percentage\x18\x05 \x01(\x01\x12\x19\n\x11health_check_port\x18\x06 \x01(\x05\x12\x1d\n\x15health_check_protocol\x18\x07 \x01(\t\x12\x19\n\x11health_check_path\x18\x08 \x01(\t\x12%\n\x1dhealth_check_interval_seconds\x18\t \x01(\x05\x12\x17\n\x0fthreshold_count\x18\n \x01(\x05\"p\n\x11ListenerPortRange\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfrom_port\x18\x02 \x01(\x05\x12\x0f\n\x07to_port\x18\x03 \x01(\x05\"\xd2\x01\n\x08Listener\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x63\x63\x65lerator_arn\x18\x02 \x01(\t\x12I\n\x0bport_ranges\x18\x03 \x03(\x0b\x32\x34.oak9.tython.aws.globalaccelerator.ListenerPortRange\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x17\n\x0f\x63lient_affinity\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_globalaccelerator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCELERATOR_TAGSENTRY._options = None
  _ACCELERATOR_TAGSENTRY._serialized_options = b'8\001'
  _ACCELERATOR._serialized_start=92
  _ACCELERATOR._serialized_end=357
  _ACCELERATOR_TAGSENTRY._serialized_start=314
  _ACCELERATOR_TAGSENTRY._serialized_end=357
  _GLOBALACCELERATOR._serialized_start=360
  _GLOBALACCELERATOR._serialized_end=585
  _ENDPOINTGROUPENDPOINTCONFIGURATION._serialized_start=588
  _ENDPOINTGROUPENDPOINTCONFIGURATION._serialized_end=758
  _ENDPOINTGROUP._serialized_start=761
  _ENDPOINTGROUP._serialized_end=1172
  _LISTENERPORTRANGE._serialized_start=1174
  _LISTENERPORTRANGE._serialized_end=1286
  _LISTENER._serialized_start=1289
  _LISTENER._serialized_end=1499
# @@protoc_insertion_point(module_scope)
