"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class IamWorkloadIdentityPoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IamWorkloadIdentityPoolXTimeouts = IamWorkloadIdentityPoolXTimeouts

@typing_extensions.final
class IamWorkloadIdentityPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_POOL_ID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    workload_identity_pool_id: builtins.str
    @property
    def timeouts(self) -> global___IamWorkloadIdentityPoolXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        workload_identity_pool_id: builtins.str = ...,
        timeouts: global___IamWorkloadIdentityPoolXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "display_name", b"display_name", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "workload_identity_pool_id", b"workload_identity_pool_id"]) -> None: ...

global___IamWorkloadIdentityPool = IamWorkloadIdentityPool

@typing_extensions.final
class IamWorkloadIdentityPoolProviderXAws(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id"]) -> None: ...

global___IamWorkloadIdentityPoolProviderXAws = IamWorkloadIdentityPoolProviderXAws

@typing_extensions.final
class IamWorkloadIdentityPoolProviderXOidc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_AUDIENCES_FIELD_NUMBER: builtins.int
    ISSUER_URI_FIELD_NUMBER: builtins.int
    @property
    def allowed_audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    issuer_uri: builtins.str
    def __init__(
        self,
        *,
        allowed_audiences: collections.abc.Iterable[builtins.str] | None = ...,
        issuer_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_audiences", b"allowed_audiences", "issuer_uri", b"issuer_uri"]) -> None: ...

global___IamWorkloadIdentityPoolProviderXOidc = IamWorkloadIdentityPoolProviderXOidc

@typing_extensions.final
class IamWorkloadIdentityPoolProviderXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IamWorkloadIdentityPoolProviderXTimeouts = IamWorkloadIdentityPoolProviderXTimeouts

@typing_extensions.final
class IamWorkloadIdentityPoolProvider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributeMappingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ATTRIBUTE_CONDITION_FIELD_NUMBER: builtins.int
    ATTRIBUTE_MAPPING_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_POOL_ID_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_POOL_PROVIDER_ID_FIELD_NUMBER: builtins.int
    AWS_FIELD_NUMBER: builtins.int
    OIDC_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    attribute_condition: builtins.str
    @property
    def attribute_mapping(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    description: builtins.str
    disabled: builtins.bool
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    workload_identity_pool_id: builtins.str
    workload_identity_pool_provider_id: builtins.str
    @property
    def aws(self) -> global___IamWorkloadIdentityPoolProviderXAws: ...
    @property
    def oidc(self) -> global___IamWorkloadIdentityPoolProviderXOidc: ...
    @property
    def timeouts(self) -> global___IamWorkloadIdentityPoolProviderXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        attribute_condition: builtins.str = ...,
        attribute_mapping: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        workload_identity_pool_id: builtins.str = ...,
        workload_identity_pool_provider_id: builtins.str = ...,
        aws: global___IamWorkloadIdentityPoolProviderXAws | None = ...,
        oidc: global___IamWorkloadIdentityPoolProviderXOidc | None = ...,
        timeouts: global___IamWorkloadIdentityPoolProviderXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws", b"aws", "oidc", b"oidc", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute_condition", b"attribute_condition", "attribute_mapping", b"attribute_mapping", "aws", b"aws", "description", b"description", "disabled", b"disabled", "display_name", b"display_name", "id", b"id", "name", b"name", "oidc", b"oidc", "project", b"project", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "workload_identity_pool_id", b"workload_identity_pool_id", "workload_identity_pool_provider_id", b"workload_identity_pool_provider_id"]) -> None: ...

global___IamWorkloadIdentityPoolProvider = IamWorkloadIdentityPoolProvider
