"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HealthCheckHealthCheckTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___HealthCheckHealthCheckTag = HealthCheckHealthCheckTag

@typing_extensions.final
class HealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HealthCheckConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_CONFIG_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def health_check_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def health_check_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthCheckHealthCheckTag]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        health_check_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        health_check_tags: collections.abc.Iterable[global___HealthCheckHealthCheckTag] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_config", b"health_check_config", "health_check_tags", b"health_check_tags", "resource_info", b"resource_info"]) -> None: ...

global___HealthCheck = HealthCheck

@typing_extensions.final
class Route53(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_FIELD_NUMBER: builtins.int
    RECORD_SET_FIELD_NUMBER: builtins.int
    RECORD_SET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def health_check(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthCheck]: ...
    @property
    def hosted_zone(self) -> global___HostedZone: ...
    @property
    def record_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordSet]: ...
    @property
    def record_set_group(self) -> global___RecordSetGroup: ...
    def __init__(
        self,
        *,
        health_check: collections.abc.Iterable[global___HealthCheck] | None = ...,
        hosted_zone: global___HostedZone | None = ...,
        record_set: collections.abc.Iterable[global___RecordSet] | None = ...,
        record_set_group: global___RecordSetGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hosted_zone", b"hosted_zone", "record_set_group", b"record_set_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check", b"health_check", "hosted_zone", b"hosted_zone", "record_set", b"record_set", "record_set_group", b"record_set_group"]) -> None: ...

global___Route53 = Route53

@typing_extensions.final
class HostedZoneHostedZoneConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    comment: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        comment: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment", "resource_info", b"resource_info"]) -> None: ...

global___HostedZoneHostedZoneConfig = HostedZoneHostedZoneConfig

@typing_extensions.final
class HostedZoneHostedZoneTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___HostedZoneHostedZoneTag = HostedZoneHostedZoneTag

@typing_extensions.final
class HostedZoneQueryLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGS_LOG_GROUP_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cloud_watch_logs_log_group_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logs_log_group_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logs_log_group_arn", b"cloud_watch_logs_log_group_arn", "resource_info", b"resource_info"]) -> None: ...

global___HostedZoneQueryLoggingConfig = HostedZoneQueryLoggingConfig

@typing_extensions.final
class HostedZoneVPC(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    VPC_REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    vpc_id: builtins.str
    vpc_region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        vpc_id: builtins.str = ...,
        vpc_region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "vpc_id", b"vpc_id", "vpc_region", b"vpc_region"]) -> None: ...

global___HostedZoneVPC = HostedZoneVPC

@typing_extensions.final
class HostedZone(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_CONFIG_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    QUERY_LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    VPCS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def hosted_zone_config(self) -> global___HostedZoneHostedZoneConfig: ...
    @property
    def hosted_zone_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostedZoneHostedZoneTag]: ...
    name: builtins.str
    @property
    def query_logging_config(self) -> global___HostedZoneQueryLoggingConfig: ...
    @property
    def vpcs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostedZoneVPC]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hosted_zone_config: global___HostedZoneHostedZoneConfig | None = ...,
        hosted_zone_tags: collections.abc.Iterable[global___HostedZoneHostedZoneTag] | None = ...,
        name: builtins.str = ...,
        query_logging_config: global___HostedZoneQueryLoggingConfig | None = ...,
        vpcs: collections.abc.Iterable[global___HostedZoneVPC] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hosted_zone_config", b"hosted_zone_config", "query_logging_config", b"query_logging_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosted_zone_config", b"hosted_zone_config", "hosted_zone_tags", b"hosted_zone_tags", "name", b"name", "query_logging_config", b"query_logging_config", "resource_info", b"resource_info", "vpcs", b"vpcs"]) -> None: ...

global___HostedZone = HostedZone

@typing_extensions.final
class RecordSetAliasTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DNS_NAME_FIELD_NUMBER: builtins.int
    EVALUATE_TARGET_HEALTH_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    dns_name: builtins.str
    evaluate_target_health: builtins.bool
    hosted_zone_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dns_name: builtins.str = ...,
        evaluate_target_health: builtins.bool = ...,
        hosted_zone_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_name", b"dns_name", "evaluate_target_health", b"evaluate_target_health", "hosted_zone_id", b"hosted_zone_id", "resource_info", b"resource_info"]) -> None: ...

global___RecordSetAliasTarget = RecordSetAliasTarget

@typing_extensions.final
class RecordSetGeoLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTINENT_CODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    SUBDIVISION_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    continent_code: builtins.str
    country_code: builtins.str
    subdivision_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        continent_code: builtins.str = ...,
        country_code: builtins.str = ...,
        subdivision_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continent_code", b"continent_code", "country_code", b"country_code", "resource_info", b"resource_info", "subdivision_code", b"subdivision_code"]) -> None: ...

global___RecordSetGeoLocation = RecordSetGeoLocation

@typing_extensions.final
class RecordSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALIAS_TARGET_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    FAILOVER_FIELD_NUMBER: builtins.int
    GEO_LOCATION_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_NAME_FIELD_NUMBER: builtins.int
    MULTI_VALUE_ANSWER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_RECORDS_FIELD_NUMBER: builtins.int
    SET_IDENTIFIER_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alias_target(self) -> global___RecordSetAliasTarget: ...
    comment: builtins.str
    failover: builtins.str
    @property
    def geo_location(self) -> global___RecordSetGeoLocation: ...
    health_check_id: builtins.str
    hosted_zone_id: builtins.str
    hosted_zone_name: builtins.str
    multi_value_answer: builtins.bool
    name: builtins.str
    region: builtins.str
    @property
    def resource_records(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    set_identifier: builtins.str
    ttl: builtins.str
    type: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alias_target: global___RecordSetAliasTarget | None = ...,
        comment: builtins.str = ...,
        failover: builtins.str = ...,
        geo_location: global___RecordSetGeoLocation | None = ...,
        health_check_id: builtins.str = ...,
        hosted_zone_id: builtins.str = ...,
        hosted_zone_name: builtins.str = ...,
        multi_value_answer: builtins.bool = ...,
        name: builtins.str = ...,
        region: builtins.str = ...,
        resource_records: collections.abc.Iterable[builtins.str] | None = ...,
        set_identifier: builtins.str = ...,
        ttl: builtins.str = ...,
        type: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alias_target", b"alias_target", "geo_location", b"geo_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias_target", b"alias_target", "comment", b"comment", "failover", b"failover", "geo_location", b"geo_location", "health_check_id", b"health_check_id", "hosted_zone_id", b"hosted_zone_id", "hosted_zone_name", b"hosted_zone_name", "multi_value_answer", b"multi_value_answer", "name", b"name", "region", b"region", "resource_info", b"resource_info", "resource_records", b"resource_records", "set_identifier", b"set_identifier", "ttl", b"ttl", "type", b"type", "weight", b"weight"]) -> None: ...

global___RecordSet = RecordSet

@typing_extensions.final
class RecordSetGroupAliasTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DNS_NAME_FIELD_NUMBER: builtins.int
    EVALUATE_TARGET_HEALTH_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    dns_name: builtins.str
    evaluate_target_health: builtins.bool
    hosted_zone_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dns_name: builtins.str = ...,
        evaluate_target_health: builtins.bool = ...,
        hosted_zone_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_name", b"dns_name", "evaluate_target_health", b"evaluate_target_health", "hosted_zone_id", b"hosted_zone_id", "resource_info", b"resource_info"]) -> None: ...

global___RecordSetGroupAliasTarget = RecordSetGroupAliasTarget

@typing_extensions.final
class RecordSetGroupGeoLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTINENT_CODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    SUBDIVISION_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    continent_code: builtins.str
    country_code: builtins.str
    subdivision_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        continent_code: builtins.str = ...,
        country_code: builtins.str = ...,
        subdivision_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continent_code", b"continent_code", "country_code", b"country_code", "resource_info", b"resource_info", "subdivision_code", b"subdivision_code"]) -> None: ...

global___RecordSetGroupGeoLocation = RecordSetGroupGeoLocation

@typing_extensions.final
class RecordSetGroupRecordSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALIAS_TARGET_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    FAILOVER_FIELD_NUMBER: builtins.int
    GEO_LOCATION_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_NAME_FIELD_NUMBER: builtins.int
    MULTI_VALUE_ANSWER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_RECORDS_FIELD_NUMBER: builtins.int
    SET_IDENTIFIER_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alias_target(self) -> global___RecordSetGroupAliasTarget: ...
    comment: builtins.str
    failover: builtins.str
    @property
    def geo_location(self) -> global___RecordSetGroupGeoLocation: ...
    health_check_id: builtins.str
    hosted_zone_id: builtins.str
    hosted_zone_name: builtins.str
    multi_value_answer: builtins.bool
    name: builtins.str
    region: builtins.str
    @property
    def resource_records(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    set_identifier: builtins.str
    ttl: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alias_target: global___RecordSetGroupAliasTarget | None = ...,
        comment: builtins.str = ...,
        failover: builtins.str = ...,
        geo_location: global___RecordSetGroupGeoLocation | None = ...,
        health_check_id: builtins.str = ...,
        hosted_zone_id: builtins.str = ...,
        hosted_zone_name: builtins.str = ...,
        multi_value_answer: builtins.bool = ...,
        name: builtins.str = ...,
        region: builtins.str = ...,
        resource_records: collections.abc.Iterable[builtins.str] | None = ...,
        set_identifier: builtins.str = ...,
        ttl: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alias_target", b"alias_target", "geo_location", b"geo_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias_target", b"alias_target", "comment", b"comment", "failover", b"failover", "geo_location", b"geo_location", "health_check_id", b"health_check_id", "hosted_zone_id", b"hosted_zone_id", "hosted_zone_name", b"hosted_zone_name", "multi_value_answer", b"multi_value_answer", "name", b"name", "region", b"region", "resource_info", b"resource_info", "resource_records", b"resource_records", "set_identifier", b"set_identifier", "ttl", b"ttl", "weight", b"weight"]) -> None: ...

global___RecordSetGroupRecordSet = RecordSetGroupRecordSet

@typing_extensions.final
class RecordSetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_NAME_FIELD_NUMBER: builtins.int
    RECORD_SETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    comment: builtins.str
    hosted_zone_id: builtins.str
    hosted_zone_name: builtins.str
    @property
    def record_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordSetGroupRecordSet]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        comment: builtins.str = ...,
        hosted_zone_id: builtins.str = ...,
        hosted_zone_name: builtins.str = ...,
        record_sets: collections.abc.Iterable[global___RecordSetGroupRecordSet] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment", "hosted_zone_id", b"hosted_zone_id", "hosted_zone_name", b"hosted_zone_name", "record_sets", b"record_sets", "resource_info", b"resource_info"]) -> None: ...

global___RecordSetGroup = RecordSetGroup
