# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_tpu.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_tpu.proto\x12\x13oak9.tython.gcp.tpu\x1a\x13shared/shared.proto\"/\n\x18TpuNodeXSchedulingConfig\x12\x13\n\x0bpreemptible\x18\x01 \x01(\x08\"B\n\x10TpuNodeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x98\x05\n\x07TpuNode\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x01 \x01(\t\x12\x12\n\ncidr_block\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x38\n\x06labels\x18\x05 \x03(\x0b\x32(.oak9.tython.gcp.tpu.TpuNode.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07network\x18\x07 \x01(\t\x12M\n\x11network_endpoints\x18\x08 \x03(\x0b\x32\x32.oak9.tython.gcp.tpu.TpuNode.NetworkEndpointsEntry\x12\x0f\n\x07project\x18\t \x01(\t\x12\x17\n\x0fservice_account\x18\n \x01(\t\x12\x1a\n\x12tensorflow_version\x18\x0b \x01(\t\x12\x1e\n\x16use_service_networking\x18\x0c \x01(\x08\x12\x0c\n\x04zone\x18\r \x01(\t\x12H\n\x11scheduling_config\x18\x0e \x01(\x0b\x32-.oak9.tython.gcp.tpu.TpuNodeXSchedulingConfig\x12\x37\n\x08timeouts\x18\x0f \x01(\x0b\x32%.oak9.tython.gcp.tpu.TpuNodeXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15NetworkEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_tpu_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TPUNODE_LABELSENTRY._options = None
  _TPUNODE_LABELSENTRY._serialized_options = b'8\001'
  _TPUNODE_NETWORKENDPOINTSENTRY._options = None
  _TPUNODE_NETWORKENDPOINTSENTRY._serialized_options = b'8\001'
  _TPUNODEXSCHEDULINGCONFIG._serialized_start=63
  _TPUNODEXSCHEDULINGCONFIG._serialized_end=110
  _TPUNODEXTIMEOUTS._serialized_start=112
  _TPUNODEXTIMEOUTS._serialized_end=178
  _TPUNODE._serialized_start=181
  _TPUNODE._serialized_end=845
  _TPUNODE_LABELSENTRY._serialized_start=743
  _TPUNODE_LABELSENTRY._serialized_end=788
  _TPUNODE_NETWORKENDPOINTSENTRY._serialized_start=790
  _TPUNODE_NETWORKENDPOINTSENTRY._serialized_end=845
# @@protoc_insertion_point(module_scope)
