# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_lakeformation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_lakeformation.proto\x12\x1doak9.tython.aws.lakeformation\x1a\x13shared/shared.proto\"Q\n\x16\x44\x61taLakeSettingsAdmins\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x92\x01\n\x10\x44\x61taLakeSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x06\x61\x64mins\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.lakeformation.DataLakeSettingsAdmins\"\xca\x02\n\rLakeFormation\x12K\n\x12\x64\x61ta_lake_settings\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.lakeformation.DataLakeSettings\x12?\n\x0bpermissions\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.lakeformation.Permissions\x12\x39\n\x08resource\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.lakeformation.Resource\x12p\n&data_lake_settings_data_lake_principal\x18\x04 \x03(\x0b\x32@.oak9.tython.aws.lakeformation.DataLakeSettingsDataLakePrincipal\"\x7f\n\x1cPermissionsDataLakePrincipal\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x64\x61ta_lake_principal_identifier\x18\x02 \x01(\t\"S\n\x18PermissionsTableWildcard\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdd\x01\n\x18PermissionsTableResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12O\n\x0etable_wildcard\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.lakeformation.PermissionsTableWildcard\x12\x0c\n\x04name\x18\x05 \x01(\t\"x\n\x1bPermissionsDatabaseResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x83\x01\n\x1fPermissionsDataLocationResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bs3_resource\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\"s\n\x19PermissionsColumnWildcard\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x65xcluded_column_names\x18\x02 \x03(\t\"\x80\x02\n#PermissionsTableWithColumnsResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63olumn_names\x18\x02 \x03(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12Q\n\x0f\x63olumn_wildcard\x18\x06 \x01(\x0b\x32\x38.oak9.tython.aws.lakeformation.PermissionsColumnWildcard\"\xbf\x03\n\x13PermissionsResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x0etable_resource\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.lakeformation.PermissionsTableResource\x12U\n\x11\x64\x61tabase_resource\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.lakeformation.PermissionsDatabaseResource\x12^\n\x16\x64\x61ta_location_resource\x18\x04 \x01(\x0b\x32>.oak9.tython.aws.lakeformation.PermissionsDataLocationResource\x12g\n\x1btable_with_columns_resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.aws.lakeformation.PermissionsTableWithColumnsResource\"\xa2\x02\n\x0bPermissions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x13\x64\x61ta_lake_principal\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.lakeformation.PermissionsDataLakePrincipal\x12\x44\n\x08resource\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.lakeformation.PermissionsResource\x12\x13\n\x0bpermissions\x18\x04 \x03(\t\x12%\n\x1dpermissions_with_grant_option\x18\x05 \x03(\t\"\x8c\x01\n\x08Resource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x1f\n\x17use_service_linked_role\x18\x03 \x01(\x08\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\x84\x01\n!DataLakeSettingsDataLakePrincipal\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x64\x61ta_lake_principal_identifier\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_lakeformation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATALAKESETTINGSADMINS._serialized_start=83
  _DATALAKESETTINGSADMINS._serialized_end=164
  _DATALAKESETTINGS._serialized_start=167
  _DATALAKESETTINGS._serialized_end=313
  _LAKEFORMATION._serialized_start=316
  _LAKEFORMATION._serialized_end=646
  _PERMISSIONSDATALAKEPRINCIPAL._serialized_start=648
  _PERMISSIONSDATALAKEPRINCIPAL._serialized_end=775
  _PERMISSIONSTABLEWILDCARD._serialized_start=777
  _PERMISSIONSTABLEWILDCARD._serialized_end=860
  _PERMISSIONSTABLERESOURCE._serialized_start=863
  _PERMISSIONSTABLERESOURCE._serialized_end=1084
  _PERMISSIONSDATABASERESOURCE._serialized_start=1086
  _PERMISSIONSDATABASERESOURCE._serialized_end=1206
  _PERMISSIONSDATALOCATIONRESOURCE._serialized_start=1209
  _PERMISSIONSDATALOCATIONRESOURCE._serialized_end=1340
  _PERMISSIONSCOLUMNWILDCARD._serialized_start=1342
  _PERMISSIONSCOLUMNWILDCARD._serialized_end=1457
  _PERMISSIONSTABLEWITHCOLUMNSRESOURCE._serialized_start=1460
  _PERMISSIONSTABLEWITHCOLUMNSRESOURCE._serialized_end=1716
  _PERMISSIONSRESOURCE._serialized_start=1719
  _PERMISSIONSRESOURCE._serialized_end=2166
  _PERMISSIONS._serialized_start=2169
  _PERMISSIONS._serialized_end=2459
  _RESOURCE._serialized_start=2462
  _RESOURCE._serialized_end=2602
  _DATALAKESETTINGSDATALAKEPRINCIPAL._serialized_start=2605
  _DATALAKESETTINGSDATALAKEPRINCIPAL._serialized_end=2737
# @@protoc_insertion_point(module_scope)
