# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_identity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_identity.proto\x12\x18oak9.tython.gcp.identity\x1a\x13shared/shared.proto\"d\n2IdentityPlatformDefaultSupportedIdpConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xba\x02\n)IdentityPlatformDefaultSupportedIdpConfig\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0e\n\x06idp_id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12^\n\x08timeouts\x18\x08 \x01(\x0b\x32L.oak9.tython.gcp.identity.IdentityPlatformDefaultSupportedIdpConfigXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n;IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates\x12\x18\n\x10x509_certificate\x18\x01 \x01(\t\"\xdc\x01\n+IdentityPlatformInboundSamlConfigXIdpConfig\x12\x15\n\ridp_entity_id\x18\x01 \x01(\t\x12\x14\n\x0csign_request\x18\x02 \x01(\x08\x12\x0f\n\x07sso_url\x18\x03 \x01(\t\x12o\n\x10idp_certificates\x18\x04 \x03(\x0b\x32U.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates\"\x82\x02\n*IdentityPlatformInboundSamlConfigXSpConfig\x12\x14\n\x0c\x63\x61llback_uri\x18\x01 \x01(\t\x12q\n\x0fsp_certificates\x18\x02 \x03(\x0b\x32X.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXSpConfig.SpCertificatesEntry\x12\x14\n\x0csp_entity_id\x18\x03 \x01(\t\x1a\x35\n\x13SpCertificatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n*IdentityPlatformInboundSamlConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xba\x03\n!IdentityPlatformInboundSamlConfig\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12Y\n\nidp_config\x18\x06 \x01(\x0b\x32\x45.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXIdpConfig\x12W\n\tsp_config\x18\x07 \x01(\x0b\x32\x44.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXSpConfig\x12V\n\x08timeouts\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\'IdentityPlatformOauthIdpConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xba\x02\n\x1eIdentityPlatformOauthIdpConfig\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12S\n\x08timeouts\x18\t \x01(\x0b\x32\x41.oak9.tython.gcp.identity.IdentityPlatformOauthIdpConfigXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Q\n\x1fIdentityPlatformTenantXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb6\x02\n\x16IdentityPlatformTenant\x12\x1d\n\x15\x61llow_password_signup\x18\x01 \x01(\x08\x12\x14\n\x0c\x64isable_auth\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12 \n\x18\x65nable_email_link_signin\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12K\n\x08timeouts\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.identity.IdentityPlatformTenantXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"j\n8IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x02\n/IdentityPlatformTenantDefaultSupportedIdpConfig\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0e\n\x06idp_id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06tenant\x18\x08 \x01(\t\x12\x64\n\x08timeouts\x18\t \x01(\x0b\x32R.oak9.tython.gcp.identity.IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\nAIdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates\x12\x18\n\x10x509_certificate\x18\x01 \x01(\t\"\xe8\x01\n1IdentityPlatformTenantInboundSamlConfigXIdpConfig\x12\x15\n\ridp_entity_id\x18\x01 \x01(\t\x12\x14\n\x0csign_request\x18\x02 \x01(\x08\x12\x0f\n\x07sso_url\x18\x03 \x01(\t\x12u\n\x10idp_certificates\x18\x04 \x03(\x0b\x32[.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates\"\x8e\x02\n0IdentityPlatformTenantInboundSamlConfigXSpConfig\x12\x14\n\x0c\x63\x61llback_uri\x18\x01 \x01(\t\x12w\n\x0fsp_certificates\x18\x02 \x03(\x0b\x32^.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXSpConfig.SpCertificatesEntry\x12\x14\n\x0csp_entity_id\x18\x03 \x01(\t\x1a\x35\n\x13SpCertificatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n0IdentityPlatformTenantInboundSamlConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe2\x03\n\'IdentityPlatformTenantInboundSamlConfig\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06tenant\x18\x06 \x01(\t\x12_\n\nidp_config\x18\x07 \x01(\x0b\x32K.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXIdpConfig\x12]\n\tsp_config\x18\x08 \x01(\x0b\x32J.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXSpConfig\x12\\\n\x08timeouts\x18\t \x01(\x0b\x32J.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n-IdentityPlatformTenantOauthIdpConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x02\n$IdentityPlatformTenantOauthIdpConfig\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0e\n\x06tenant\x18\t \x01(\t\x12Y\n\x08timeouts\x18\n \x01(\x0b\x32G.oak9.tython.gcp.identity.IdentityPlatformTenantOauthIdpConfigXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_identity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._options = None
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_options = b'8\001'
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._options = None
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_options = b'8\001'
  _IDENTITYPLATFORMDEFAULTSUPPORTEDIDPCONFIGXTIMEOUTS._serialized_start=73
  _IDENTITYPLATFORMDEFAULTSUPPORTEDIDPCONFIGXTIMEOUTS._serialized_end=173
  _IDENTITYPLATFORMDEFAULTSUPPORTEDIDPCONFIG._serialized_start=176
  _IDENTITYPLATFORMDEFAULTSUPPORTEDIDPCONFIG._serialized_end=490
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXIDPCONFIGXIDPCERTIFICATES._serialized_start=492
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXIDPCONFIGXIDPCERTIFICATES._serialized_end=579
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXIDPCONFIG._serialized_start=582
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXIDPCONFIG._serialized_end=802
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG._serialized_start=805
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG._serialized_end=1063
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_start=1010
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_end=1063
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXTIMEOUTS._serialized_start=1065
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXTIMEOUTS._serialized_end=1157
  _IDENTITYPLATFORMINBOUNDSAMLCONFIG._serialized_start=1160
  _IDENTITYPLATFORMINBOUNDSAMLCONFIG._serialized_end=1602
  _IDENTITYPLATFORMOAUTHIDPCONFIGXTIMEOUTS._serialized_start=1604
  _IDENTITYPLATFORMOAUTHIDPCONFIGXTIMEOUTS._serialized_end=1693
  _IDENTITYPLATFORMOAUTHIDPCONFIG._serialized_start=1696
  _IDENTITYPLATFORMOAUTHIDPCONFIG._serialized_end=2010
  _IDENTITYPLATFORMTENANTXTIMEOUTS._serialized_start=2012
  _IDENTITYPLATFORMTENANTXTIMEOUTS._serialized_end=2093
  _IDENTITYPLATFORMTENANT._serialized_start=2096
  _IDENTITYPLATFORMTENANT._serialized_end=2406
  _IDENTITYPLATFORMTENANTDEFAULTSUPPORTEDIDPCONFIGXTIMEOUTS._serialized_start=2408
  _IDENTITYPLATFORMTENANTDEFAULTSUPPORTEDIDPCONFIGXTIMEOUTS._serialized_end=2514
  _IDENTITYPLATFORMTENANTDEFAULTSUPPORTEDIDPCONFIG._serialized_start=2517
  _IDENTITYPLATFORMTENANTDEFAULTSUPPORTEDIDPCONFIG._serialized_end=2859
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXIDPCONFIGXIDPCERTIFICATES._serialized_start=2861
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXIDPCONFIGXIDPCERTIFICATES._serialized_end=2954
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXIDPCONFIG._serialized_start=2957
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXIDPCONFIG._serialized_end=3189
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG._serialized_start=3192
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG._serialized_end=3462
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_start=1010
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_end=1063
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXTIMEOUTS._serialized_start=3464
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXTIMEOUTS._serialized_end=3562
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIG._serialized_start=3565
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIG._serialized_end=4047
  _IDENTITYPLATFORMTENANTOAUTHIDPCONFIGXTIMEOUTS._serialized_start=4049
  _IDENTITYPLATFORMTENANTOAUTHIDPCONFIGXTIMEOUTS._serialized_end=4144
  _IDENTITYPLATFORMTENANTOAUTHIDPCONFIG._serialized_start=4147
  _IDENTITYPLATFORMTENANTOAUTHIDPCONFIG._serialized_end=4489
# @@protoc_insertion_point(module_scope)
