# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_sql_databases.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)azure/azure_microsoft_sql_databases.proto\x12)oak9.tython.azure.microsoft_sql_databases\x1a\x13shared/shared.proto\"\xd7\x0f\n\x17Microsoft_Sql_Databases\x12V\n\x11servers_databases\x18\x01 \x01(\x0b\x32;.oak9.tython.azure.microsoft_sql_databases.ServersDatabases\x12x\n#servers_databases_auditing_settings\x18\x02 \x01(\x0b\x32K.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesAuditingSettings\x12\x99\x01\n5servers_databases_backup_long_term_retention_policies\x18\x03 \x01(\x0b\x32Z.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesBackupLongTermRetentionPolicies\x12\x9b\x01\n6servers_databases_backup_short_term_retention_policies\x18\x04 \x01(\x0b\x32[.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesBackupShortTermRetentionPolicies\x12\x89\x01\n,servers_databases_extended_auditing_settings\x18\x05 \x01(\x0b\x32S.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesExtendedAuditingSettings\x12k\n\x1cservers_databases_extensions\x18\x06 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesExtensions\x12\x83\x01\n)servers_databases_security_alert_policies\x18\x07 \x01(\x0b\x32P.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesSecurityAlertPolicies\x12l\n\x1dservers_databases_sync_groups\x18\x08 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesSyncGroups\x12\x84\x01\n*servers_databases_sync_groups_sync_members\x18\t \x03(\x0b\x32P.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesSyncGroupsSyncMembers\x12\x8b\x01\n-servers_databases_transparent_data_encryption\x18\n \x01(\x0b\x32T.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesTransparentDataEncryption\x12\x88\x01\n+servers_databases_vulnerability_assessments\x18\x0b \x01(\x0b\x32S.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesVulnerabilityAssessments\x12\xa6\x01\n;servers_databases_vulnerability_assessments_rules_baselines\x18\x0c \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesVulnerabilityAssessmentsRulesBaselines\x12|\n%servers_databases_connection_policies\x18\r \x01(\x0b\x32M.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesConnectionPolicies\x12\x7f\n\'servers_databases_data_masking_policies\x18\x0e \x01(\x0b\x32N.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesDataMaskingPolicies\x12{\n%servers_databases_geo_backup_policies\x18\x0f \x01(\x0b\x32L.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesGeoBackupPolicies\"\xc9\x01\n!ServersDatabasesGeoBackupPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x14\n\x0cstorage_type\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\"\xeb\x01\n#ServersDatabasesDataMaskingPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x1a\n\x12\x64\x61ta_masking_state\x18\x05 \x01(\t\x12\x1e\n\x16\x61pplication_principals\x18\x06 \x01(\t\x12\x19\n\x11\x65xempt_principals\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\"\xbe\x01\n\"ServersDatabasesConnectionPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x04 \x01(\t\x12\x0c\n\x04kind\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\"\xe9\x01\n1ServersDatabasesWorkloadGroupsWorkloadClassifiers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\t\x12\x12\n\nimportance\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x13\n\x0bmember_name\x18\x07 \x01(\t\x12\x12\n\nstart_time\x18\x08 \x01(\t\"\xcb\x03\n\x1eServersDatabasesWorkloadGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nimportance\x18\x03 \x01(\t\x12\x1c\n\x14max_resource_percent\x18\x04 \x01(\x05\x12(\n max_resource_percent_per_request\x18\x05 \x01(\x01\x12\x1c\n\x14min_resource_percent\x18\x06 \x01(\x05\x12(\n min_resource_percent_per_request\x18\x07 \x01(\x01\x12\x1f\n\x17query_execution_timeout\x18\x08 \x01(\x05\x12\x9c\x01\n6servers_databases_workload_groups_workload_classifiers\x18\t \x03(\x0b\x32\\.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesWorkloadGroupsWorkloadClassifiers\"\xf5\x01\n6ServersDatabasesVulnerabilityAssessmentsRulesBaselines\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12t\n\x10\x62\x61seline_results\x18\x03 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_sql_databases.DatabaseVulnerabilityAssessmentRuleBaselineItem\"A\n/DatabaseVulnerabilityAssessmentRuleBaselineItem\x12\x0e\n\x06result\x18\x01 \x03(\t\"\xae\x03\n(ServersDatabasesVulnerabilityAssessments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12s\n\x0frecurring_scans\x18\x03 \x01(\x0b\x32Z.oak9.tython.azure.microsoft_sql_databases.VulnerabilityAssessmentRecurringScansProperties\x12\"\n\x1astorage_account_access_key\x18\x04 \x01(\t\x12\x1e\n\x16storage_container_path\x18\x05 \x01(\t\x12!\n\x19storage_container_sas_key\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12\x0e\n\x06\x65mails\x18\t \x01(\t\x12!\n\x19\x65mail_subscription_admins\x18\n \x01(\t\x12\x12\n\nis_enabled\x18\x0b \x01(\t\"x\n/VulnerabilityAssessmentRecurringScansProperties\x12\x0e\n\x06\x65mails\x18\x01 \x03(\t\x12!\n\x19\x65mail_subscription_admins\x18\x02 \x01(\x08\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\"\x9b\x01\n)ServersDatabasesTransparentDataEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\"\xfa\x02\n%ServersDatabasesSyncGroupsSyncMembers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\x12\x15\n\rdatabase_type\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12\x13\n\x0bserver_name\x18\x06 \x01(\t\x12\x1e\n\x16sql_server_database_id\x18\x07 \x01(\t\x12\x15\n\rsync_agent_id\x18\x08 \x01(\t\x12\x16\n\x0esync_direction\x18\t \x01(\t\x12.\n&sync_member_azure_database_resource_id\x18\n \x01(\t\x12#\n\x1buse_private_link_connection\x18\x0b \x01(\x08\x12\x11\n\tuser_name\x18\x0c \x01(\t\"\xed\x03\n\x1aServersDatabasesSyncGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\"conflict_logging_retention_in_days\x18\x03 \x01(\x05\x12\"\n\x1a\x63onflict_resolution_policy\x18\x04 \x01(\t\x12\x1f\n\x17\x65nable_conflict_logging\x18\x05 \x01(\x08\x12\x1d\n\x15hub_database_password\x18\x06 \x01(\t\x12\x1e\n\x16hub_database_user_name\x18\x07 \x01(\t\x12\x10\n\x08interval\x18\x08 \x01(\x05\x12J\n\x06schema\x18\t \x01(\x0b\x32:.oak9.tython.azure.microsoft_sql_databases.SyncGroupSchema\x12\x18\n\x10sync_database_id\x18\n \x01(\t\x12#\n\x1buse_private_link_connection\x18\x0b \x01(\x08\x12;\n\x03sku\x18\x0c \x01(\x0b\x32..oak9.tython.azure.microsoft_sql_databases.Sku\"\x83\x01\n\x0fSyncGroupSchema\x12\x1f\n\x17master_sync_member_name\x18\x01 \x01(\t\x12O\n\x06tables\x18\x02 \x03(\x0b\x32?.oak9.tython.azure.microsoft_sql_databases.SyncGroupSchemaTable\"\x83\x01\n\x14SyncGroupSchemaTable\x12V\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_databases.SyncGroupSchemaTableColumn\x12\x13\n\x0bquoted_name\x18\x02 \x01(\t\"W\n\x1aSyncGroupSchemaTableColumn\x12\x11\n\tdata_size\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x13\n\x0bquoted_name\x18\x03 \x01(\t\"\xbd\x02\n%ServersDatabasesSecurityAlertPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x64isabled_alerts\x18\x03 \x03(\t\x12\x1c\n\x14\x65mail_account_admins\x18\x04 \x01(\x08\x12\x17\n\x0f\x65mail_addresses\x18\x05 \x03(\t\x12\x16\n\x0eretention_days\x18\x06 \x01(\x05\x12\r\n\x05state\x18\x07 \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x08 \x01(\t\x12\x18\n\x10storage_endpoint\x18\t \x01(\t\x12\n\n\x02id\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\"\xe9\x01\n5ServersDatabasesSchemasTablesColumnsSensitivityLabels\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10information_type\x18\x03 \x01(\t\x12\x1b\n\x13information_type_id\x18\x04 \x01(\t\x12\x10\n\x08label_id\x18\x05 \x01(\t\x12\x12\n\nlabel_name\x18\x06 \x01(\t\x12\x0c\n\x04rank\x18\x07 \x01(\t\"\xc7\x01\n\"ServersDatabasesMaintenanceWindows\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Z\n\x0btime_ranges\x18\x03 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_databases.MaintenanceWindowTimeRange\"W\n\x1aMaintenanceWindowTimeRange\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\"\x8d\x01\n#ServersDatabasesLedgerDigestUploads\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1f\n\x17\x64igest_storage_endpoint\x18\x03 \x01(\t\"\xd1\x03\n\x1aServersDatabasesExtensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13\x61\x64ministrator_login\x18\x03 \x01(\t\x12$\n\x1c\x61\x64ministrator_login_password\x18\x04 \x01(\t\x12\x1b\n\x13\x61uthentication_type\x18\x05 \x01(\t\x12\x18\n\x10\x64\x61tabase_edition\x18\x06 \x01(\t\x12\x16\n\x0emax_size_bytes\x18\x07 \x01(\t\x12^\n\x11network_isolation\x18\x08 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_sql_databases.NetworkIsolationSettings\x12\x16\n\x0eoperation_mode\x18\t \x01(\t\x12\x1e\n\x16service_objective_name\x18\n \x01(\t\x12\x13\n\x0bstorage_key\x18\x0b \x01(\t\x12\x18\n\x10storage_key_type\x18\x0c \x01(\t\x12\x13\n\x0bstorage_uri\x18\r \x01(\t\"_\n\x18NetworkIsolationSettings\x12\x1e\n\x16sql_server_resource_id\x18\x01 \x01(\t\x12#\n\x1bstorage_account_resource_id\x18\x02 \x01(\t\"\xa9\x03\n(ServersDatabasesExtendedAuditingSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x18\x61udit_actions_and_groups\x18\x03 \x03(\t\x12\'\n\x1fis_azure_monitor_target_enabled\x18\x04 \x01(\x08\x12\'\n\x1fis_storage_secondary_key_in_use\x18\x05 \x01(\x08\x12\x1c\n\x14predicate_expression\x18\x06 \x01(\t\x12\x16\n\x0equeue_delay_ms\x18\x07 \x01(\x05\x12\x16\n\x0eretention_days\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\t\x12\"\n\x1astorage_account_access_key\x18\n \x01(\t\x12\'\n\x1fstorage_account_subscription_id\x18\x0b \x01(\t\x12\x18\n\x10storage_endpoint\x18\x0c \x01(\t\"\xd2\x01\n0ServersDatabasesBackupShortTermRetentionPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x1d\x64iff_backup_interval_in_hours\x18\x03 \x01(\x05\x12\x16\n\x0eretention_days\x18\x04 \x01(\x05\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\"\xf7\x01\n/ServersDatabasesBackupLongTermRetentionPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11monthly_retention\x18\x03 \x01(\t\x12\x18\n\x10weekly_retention\x18\x04 \x01(\t\x12\x14\n\x0cweek_of_year\x18\x05 \x01(\x05\x12\x18\n\x10yearly_retention\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\"\xc1\x03\n ServersDatabasesAuditingSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x18\x61udit_actions_and_groups\x18\x03 \x03(\t\x12\'\n\x1fis_azure_monitor_target_enabled\x18\x04 \x01(\x08\x12\'\n\x1fis_storage_secondary_key_in_use\x18\x05 \x01(\x08\x12\x16\n\x0equeue_delay_ms\x18\x06 \x01(\x05\x12\x16\n\x0eretention_days\x18\x07 \x01(\x05\x12\r\n\x05state\x18\x08 \x01(\t\x12\"\n\x1astorage_account_access_key\x18\t \x01(\t\x12\'\n\x1fstorage_account_subscription_id\x18\n \x01(\t\x12\x18\n\x10storage_endpoint\x18\x0b \x01(\t\x12\x0c\n\x04kind\x18\x0c \x01(\t\x12\"\n\x1ais_managed_identity_in_use\x18\r \x01(\t\x12\n\n\x02id\x18\x0e \x01(\t\"\xe6\x0b\n\x10ServersDatabases\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x08identity\x18\x02 \x01(\x0b\x32;.oak9.tython.azure.microsoft_sql_databases.DatabaseIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x18\n\x10\x61uto_pause_delay\x18\x05 \x01(\x05\x12\x19\n\x11\x63\x61talog_collation\x18\x06 \x01(\t\x12\x11\n\tcollation\x18\x07 \x01(\t\x12\x13\n\x0b\x63reate_mode\x18\x08 \x01(\t\x12\x17\n\x0f\x65lastic_pool_id\x18\t \x01(\t\x12\x1b\n\x13\x66\x65\x64\x65rated_client_id\x18\n \x01(\t\x12\'\n\x1fhigh_availability_replica_count\x18\x0b \x01(\x05\x12\x14\n\x0cis_ledger_on\x18\x0c \x01(\x08\x12\x14\n\x0clicense_type\x18\r \x01(\t\x12.\n&long_term_retention_backup_resource_id\x18\x0e \x01(\t\x12$\n\x1cmaintenance_configuration_id\x18\x0f \x01(\t\x12\x16\n\x0emax_size_bytes\x18\x10 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x11 \x01(\x01\x12,\n$primary_delegated_identity_client_id\x18\x12 \x01(\t\x12\x12\n\nread_scale\x18\x13 \x01(\t\x12\x1f\n\x17recoverable_database_id\x18\x14 \x01(\t\x12+\n#recovery_services_recovery_point_id\x18\x15 \x01(\t\x12+\n#requested_backup_storage_redundancy\x18\x16 \x01(\t\x12&\n\x1erestorable_dropped_database_id\x18\x17 \x01(\t\x12\x1d\n\x15restore_point_in_time\x18\x18 \x01(\t\x12\x13\n\x0bsample_name\x18\x19 \x01(\t\x12\x16\n\x0esecondary_type\x18\x1a \x01(\t\x12%\n\x1dsource_database_deletion_date\x18\x1b \x01(\t\x12\x1a\n\x12source_database_id\x18\x1c \x01(\t\x12\x16\n\x0ezone_redundant\x18\x1d \x01(\x08\x12;\n\x03sku\x18\x1e \x01(\x0b\x32..oak9.tython.azure.microsoft_sql_databases.Sku\x12S\n\x04tags\x18\x1f \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_databases.ServersDatabases.TagsEntry\x12\x7f\n\'servers_databases_ledger_digest_uploads\x18  \x03(\x0b\x32N.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesLedgerDigestUploads\x12|\n%servers_databases_maintenance_windows\x18! \x03(\x0b\x32M.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesMaintenanceWindows\x12t\n!servers_databases_workload_groups\x18\" \x03(\x0b\x32I.oak9.tython.azure.microsoft_sql_databases.ServersDatabasesWorkloadGroups\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\x0c\n\x04tier\x18\x05 \x01(\t\"\x87\x03\n\x10\x44\x61tabaseIdentity\x12p\n\x13\x64\x65legated_resources\x18\x01 \x03(\x0b\x32S.oak9.tython.azure.microsoft_sql_databases.DatabaseIdentity.DelegatedResourcesEntry\x12\x0c\n\x04type\x18\x02 \x01(\t\x12y\n\x18user_assigned_identities\x18\x03 \x03(\x0b\x32W.oak9.tython.azure.microsoft_sql_databases.DatabaseIdentity.UserAssignedIdentitiesEntry\x1a\x39\n\x17\x44\x65legatedResourcesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_sql_databases_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVERSDATABASES_TAGSENTRY._options = None
  _SERVERSDATABASES_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEIDENTITY_DELEGATEDRESOURCESENTRY._options = None
  _DATABASEIDENTITY_DELEGATEDRESOURCESENTRY._serialized_options = b'8\001'
  _DATABASEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _DATABASEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_SQL_DATABASES._serialized_start=110
  _MICROSOFT_SQL_DATABASES._serialized_end=2117
  _SERVERSDATABASESGEOBACKUPPOLICIES._serialized_start=2120
  _SERVERSDATABASESGEOBACKUPPOLICIES._serialized_end=2321
  _SERVERSDATABASESDATAMASKINGPOLICIES._serialized_start=2324
  _SERVERSDATABASESDATAMASKINGPOLICIES._serialized_end=2559
  _SERVERSDATABASESCONNECTIONPOLICIES._serialized_start=2562
  _SERVERSDATABASESCONNECTIONPOLICIES._serialized_end=2752
  _SERVERSDATABASESWORKLOADGROUPSWORKLOADCLASSIFIERS._serialized_start=2755
  _SERVERSDATABASESWORKLOADGROUPSWORKLOADCLASSIFIERS._serialized_end=2988
  _SERVERSDATABASESWORKLOADGROUPS._serialized_start=2991
  _SERVERSDATABASESWORKLOADGROUPS._serialized_end=3450
  _SERVERSDATABASESVULNERABILITYASSESSMENTSRULESBASELINES._serialized_start=3453
  _SERVERSDATABASESVULNERABILITYASSESSMENTSRULESBASELINES._serialized_end=3698
  _DATABASEVULNERABILITYASSESSMENTRULEBASELINEITEM._serialized_start=3700
  _DATABASEVULNERABILITYASSESSMENTRULEBASELINEITEM._serialized_end=3765
  _SERVERSDATABASESVULNERABILITYASSESSMENTS._serialized_start=3768
  _SERVERSDATABASESVULNERABILITYASSESSMENTS._serialized_end=4198
  _VULNERABILITYASSESSMENTRECURRINGSCANSPROPERTIES._serialized_start=4200
  _VULNERABILITYASSESSMENTRECURRINGSCANSPROPERTIES._serialized_end=4320
  _SERVERSDATABASESTRANSPARENTDATAENCRYPTION._serialized_start=4323
  _SERVERSDATABASESTRANSPARENTDATAENCRYPTION._serialized_end=4478
  _SERVERSDATABASESSYNCGROUPSSYNCMEMBERS._serialized_start=4481
  _SERVERSDATABASESSYNCGROUPSSYNCMEMBERS._serialized_end=4859
  _SERVERSDATABASESSYNCGROUPS._serialized_start=4862
  _SERVERSDATABASESSYNCGROUPS._serialized_end=5355
  _SYNCGROUPSCHEMA._serialized_start=5358
  _SYNCGROUPSCHEMA._serialized_end=5489
  _SYNCGROUPSCHEMATABLE._serialized_start=5492
  _SYNCGROUPSCHEMATABLE._serialized_end=5623
  _SYNCGROUPSCHEMATABLECOLUMN._serialized_start=5625
  _SYNCGROUPSCHEMATABLECOLUMN._serialized_end=5712
  _SERVERSDATABASESSECURITYALERTPOLICIES._serialized_start=5715
  _SERVERSDATABASESSECURITYALERTPOLICIES._serialized_end=6032
  _SERVERSDATABASESSCHEMASTABLESCOLUMNSSENSITIVITYLABELS._serialized_start=6035
  _SERVERSDATABASESSCHEMASTABLESCOLUMNSSENSITIVITYLABELS._serialized_end=6268
  _SERVERSDATABASESMAINTENANCEWINDOWS._serialized_start=6271
  _SERVERSDATABASESMAINTENANCEWINDOWS._serialized_end=6470
  _MAINTENANCEWINDOWTIMERANGE._serialized_start=6472
  _MAINTENANCEWINDOWTIMERANGE._serialized_end=6559
  _SERVERSDATABASESLEDGERDIGESTUPLOADS._serialized_start=6562
  _SERVERSDATABASESLEDGERDIGESTUPLOADS._serialized_end=6703
  _SERVERSDATABASESEXTENSIONS._serialized_start=6706
  _SERVERSDATABASESEXTENSIONS._serialized_end=7171
  _NETWORKISOLATIONSETTINGS._serialized_start=7173
  _NETWORKISOLATIONSETTINGS._serialized_end=7268
  _SERVERSDATABASESEXTENDEDAUDITINGSETTINGS._serialized_start=7271
  _SERVERSDATABASESEXTENDEDAUDITINGSETTINGS._serialized_end=7696
  _SERVERSDATABASESBACKUPSHORTTERMRETENTIONPOLICIES._serialized_start=7699
  _SERVERSDATABASESBACKUPSHORTTERMRETENTIONPOLICIES._serialized_end=7909
  _SERVERSDATABASESBACKUPLONGTERMRETENTIONPOLICIES._serialized_start=7912
  _SERVERSDATABASESBACKUPLONGTERMRETENTIONPOLICIES._serialized_end=8159
  _SERVERSDATABASESAUDITINGSETTINGS._serialized_start=8162
  _SERVERSDATABASESAUDITINGSETTINGS._serialized_end=8611
  _SERVERSDATABASES._serialized_start=8614
  _SERVERSDATABASES._serialized_end=10124
  _SERVERSDATABASES_TAGSENTRY._serialized_start=10081
  _SERVERSDATABASES_TAGSENTRY._serialized_end=10124
  _SKU._serialized_start=10126
  _SKU._serialized_end=10207
  _DATABASEIDENTITY._serialized_start=10210
  _DATABASEIDENTITY._serialized_end=10601
  _DATABASEIDENTITY_DELEGATEDRESOURCESENTRY._serialized_start=10481
  _DATABASEIDENTITY_DELEGATEDRESOURCESENTRY._serialized_end=10538
  _DATABASEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=10540
  _DATABASEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=10601
# @@protoc_insertion_point(module_scope)
