# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_privateca.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_privateca.proto\x12\x19oak9.tython.gcp.privateca\x1a\x13shared/shared.proto\"|\n3PrivatecaCaPoolXIssuancePolicyXAllowedIssuanceModes\x12#\n\x1b\x61llow_config_based_issuance\x18\x01 \x01(\x08\x12 \n\x18\x61llow_csr_based_issuance\x18\x02 \x01(\x08\"[\n<PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXEllipticCurve\x12\x1b\n\x13signature_algorithm\x18\x01 \x01(\t\"h\n2PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXRsa\x12\x18\n\x10max_modulus_size\x18\x01 \x01(\t\x12\x18\n\x10min_modulus_size\x18\x02 \x01(\t\"\xfd\x01\n.PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypes\x12o\n\x0e\x65lliptic_curve\x18\x01 \x01(\x0b\x32W.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXEllipticCurve\x12Z\n\x03rsa\x18\x02 \x01(\x0b\x32M.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXRsa\"e\nKPrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensionsXObjectId\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xe0\x01\nBPrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensions\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\x12y\n\tobject_id\x18\x03 \x01(\x0b\x32\x66.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensionsXObjectId\"\x9d\x01\n7PrivatecaCaPoolXIssuancePolicyXBaselineValuesXCaOptions\x12\r\n\x05is_ca\x18\x01 \x01(\x08\x12\x1e\n\x16max_issuer_path_length\x18\x02 \x01(\x01\x12\x0e\n\x06non_ca\x18\x03 \x01(\x08\x12#\n\x1bzero_max_issuer_path_length\x18\x04 \x01(\x08\"\x9b\x02\nCPrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXBaseKeyUsage\x12\x11\n\tcert_sign\x18\x01 \x01(\x08\x12\x1a\n\x12\x63ontent_commitment\x18\x02 \x01(\x08\x12\x10\n\x08\x63rl_sign\x18\x03 \x01(\x08\x12\x19\n\x11\x64\x61ta_encipherment\x18\x04 \x01(\x08\x12\x15\n\rdecipher_only\x18\x05 \x01(\x08\x12\x19\n\x11\x64igital_signature\x18\x06 \x01(\x08\x12\x15\n\rencipher_only\x18\x07 \x01(\x08\x12\x15\n\rkey_agreement\x18\x08 \x01(\x08\x12\x18\n\x10key_encipherment\x18\t \x01(\x08\"\xd0\x01\nGPrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXExtendedKeyUsage\x12\x13\n\x0b\x63lient_auth\x18\x01 \x01(\x08\x12\x14\n\x0c\x63ode_signing\x18\x02 \x01(\x08\x12\x18\n\x10\x65mail_protection\x18\x03 \x01(\x08\x12\x14\n\x0cocsp_signing\x18\x04 \x01(\x08\x12\x13\n\x0bserver_auth\x18\x05 \x01(\x08\x12\x15\n\rtime_stamping\x18\x06 \x01(\x08\"i\nOPrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXUnknownExtendedKeyUsages\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xc2\x03\n6PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsage\x12v\n\x0e\x62\x61se_key_usage\x18\x01 \x01(\x0b\x32^.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXBaseKeyUsage\x12~\n\x12\x65xtended_key_usage\x18\x02 \x01(\x0b\x32\x62.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXExtendedKeyUsage\x12\x8f\x01\n\x1bunknown_extended_key_usages\x18\x03 \x03(\x0b\x32j.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXUnknownExtendedKeyUsages\"Q\n7PrivatecaCaPoolXIssuancePolicyXBaselineValuesXPolicyIds\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xfd\x03\n-PrivatecaCaPoolXIssuancePolicyXBaselineValues\x12\x18\n\x10\x61ia_ocsp_servers\x18\x01 \x03(\t\x12|\n\x15\x61\x64\x64itional_extensions\x18\x02 \x03(\x0b\x32].oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensions\x12\x66\n\nca_options\x18\x03 \x01(\x0b\x32R.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValuesXCaOptions\x12\x64\n\tkey_usage\x18\x04 \x01(\x0b\x32Q.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsage\x12\x66\n\npolicy_ids\x18\x05 \x03(\x0b\x32R.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValuesXPolicyIds\"\x8c\x01\n@PrivatecaCaPoolXIssuancePolicyXIdentityConstraintsXCelExpression\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"\xf9\x01\n2PrivatecaCaPoolXIssuancePolicyXIdentityConstraints\x12+\n#allow_subject_alt_names_passthrough\x18\x01 \x01(\x08\x12!\n\x19\x61llow_subject_passthrough\x18\x02 \x01(\x08\x12s\n\x0e\x63\x65l_expression\x18\x03 \x01(\x0b\x32[.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXIdentityConstraintsXCelExpression\"\xe0\x03\n\x1ePrivatecaCaPoolXIssuancePolicy\x12\x18\n\x10maximum_lifetime\x18\x01 \x01(\t\x12n\n\x16\x61llowed_issuance_modes\x18\x02 \x01(\x0b\x32N.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXAllowedIssuanceModes\x12\x64\n\x11\x61llowed_key_types\x18\x03 \x03(\x0b\x32I.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypes\x12\x61\n\x0f\x62\x61seline_values\x18\x04 \x01(\x0b\x32H.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXBaselineValues\x12k\n\x14identity_constraints\x18\x05 \x01(\x0b\x32M.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicyXIdentityConstraints\"Q\n!PrivatecaCaPoolXPublishingOptions\x12\x17\n\x0fpublish_ca_cert\x18\x01 \x01(\x08\x12\x13\n\x0bpublish_crl\x18\x02 \x01(\x08\"J\n\x18PrivatecaCaPoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x81\x04\n\x0fPrivatecaCaPool\x12\n\n\x02id\x18\x01 \x01(\t\x12\x46\n\x06labels\x18\x02 \x03(\x0b\x32\x36.oak9.tython.gcp.privateca.PrivatecaCaPool.LabelsEntry\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04tier\x18\x06 \x01(\t\x12R\n\x0fissuance_policy\x18\x07 \x01(\x0b\x32\x39.oak9.tython.gcp.privateca.PrivatecaCaPoolXIssuancePolicy\x12X\n\x12publishing_options\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.privateca.PrivatecaCaPoolXPublishingOptions\x12\x45\n\x08timeouts\x18\t \x01(\x0b\x32\x33.oak9.tython.gcp.privateca.PrivatecaCaPoolXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n#PrivatecaCaPoolIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x94\x02\n\x19PrivatecaCaPoolIamBinding\x12\x0f\n\x07\x63\x61_pool\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0f\n\x07members\x18\x05 \x03(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12Q\n\tcondition\x18\x08 \x01(\x0b\x32>.oak9.tython.gcp.privateca.PrivatecaCaPoolIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"PrivatecaCaPoolIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x91\x02\n\x18PrivatecaCaPoolIamMember\x12\x0f\n\x07\x63\x61_pool\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0e\n\x06member\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12P\n\tcondition\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.privateca.PrivatecaCaPoolIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb6\x01\n\x18PrivatecaCaPoolIamPolicy\x12\x0f\n\x07\x63\x61_pool\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"D\n%PrivatecaCertificateXConfigXPublicKey\x12\x0e\n\x06\x66ormat\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\xe2\x01\n1PrivatecaCertificateXConfigXSubjectConfigXSubject\x12\x13\n\x0b\x63ommon_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x10\n\x08locality\x18\x03 \x01(\t\x12\x14\n\x0corganization\x18\x04 \x01(\t\x12\x1b\n\x13organizational_unit\x18\x05 \x01(\t\x12\x13\n\x0bpostal_code\x18\x06 \x01(\t\x12\x10\n\x08province\x18\x07 \x01(\t\x12\x16\n\x0estreet_address\x18\x08 \x01(\t\"\x8a\x01\n8PrivatecaCertificateXConfigXSubjectConfigXSubjectAltName\x12\x11\n\tdns_names\x18\x01 \x03(\t\x12\x17\n\x0f\x65mail_addresses\x18\x02 \x03(\t\x12\x14\n\x0cip_addresses\x18\x03 \x03(\t\x12\x0c\n\x04uris\x18\x04 \x03(\t\"\xf9\x01\n)PrivatecaCertificateXConfigXSubjectConfig\x12]\n\x07subject\x18\x01 \x01(\x0b\x32L.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXSubjectConfigXSubject\x12m\n\x10subject_alt_name\x18\x02 \x01(\x0b\x32S.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXSubjectConfigXSubjectAltName\"^\nDPrivatecaCertificateXConfigXX509ConfigXAdditionalExtensionsXObjectId\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xd2\x01\n;PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensions\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\x12r\n\tobject_id\x18\x03 \x01(\x0b\x32_.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensionsXObjectId\"\x96\x01\n0PrivatecaCertificateXConfigXX509ConfigXCaOptions\x12\r\n\x05is_ca\x18\x01 \x01(\x08\x12\x1e\n\x16max_issuer_path_length\x18\x02 \x01(\x01\x12\x0e\n\x06non_ca\x18\x03 \x01(\x08\x12#\n\x1bzero_max_issuer_path_length\x18\x04 \x01(\x08\"\x94\x02\n<PrivatecaCertificateXConfigXX509ConfigXKeyUsageXBaseKeyUsage\x12\x11\n\tcert_sign\x18\x01 \x01(\x08\x12\x1a\n\x12\x63ontent_commitment\x18\x02 \x01(\x08\x12\x10\n\x08\x63rl_sign\x18\x03 \x01(\x08\x12\x19\n\x11\x64\x61ta_encipherment\x18\x04 \x01(\x08\x12\x15\n\rdecipher_only\x18\x05 \x01(\x08\x12\x19\n\x11\x64igital_signature\x18\x06 \x01(\x08\x12\x15\n\rencipher_only\x18\x07 \x01(\x08\x12\x15\n\rkey_agreement\x18\x08 \x01(\x08\x12\x18\n\x10key_encipherment\x18\t \x01(\x08\"\xc9\x01\n@PrivatecaCertificateXConfigXX509ConfigXKeyUsageXExtendedKeyUsage\x12\x13\n\x0b\x63lient_auth\x18\x01 \x01(\x08\x12\x14\n\x0c\x63ode_signing\x18\x02 \x01(\x08\x12\x18\n\x10\x65mail_protection\x18\x03 \x01(\x08\x12\x14\n\x0cocsp_signing\x18\x04 \x01(\x08\x12\x13\n\x0bserver_auth\x18\x05 \x01(\x08\x12\x15\n\rtime_stamping\x18\x06 \x01(\x08\"b\nHPrivatecaCertificateXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xa6\x03\n/PrivatecaCertificateXConfigXX509ConfigXKeyUsage\x12o\n\x0e\x62\x61se_key_usage\x18\x01 \x01(\x0b\x32W.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509ConfigXKeyUsageXBaseKeyUsage\x12w\n\x12\x65xtended_key_usage\x18\x02 \x01(\x0b\x32[.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509ConfigXKeyUsageXExtendedKeyUsage\x12\x88\x01\n\x1bunknown_extended_key_usages\x18\x03 \x03(\x0b\x32\x63.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages\"J\n0PrivatecaCertificateXConfigXX509ConfigXPolicyIds\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xda\x03\n&PrivatecaCertificateXConfigXX509Config\x12\x18\n\x10\x61ia_ocsp_servers\x18\x01 \x03(\t\x12u\n\x15\x61\x64\x64itional_extensions\x18\x02 \x03(\x0b\x32V.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensions\x12_\n\nca_options\x18\x03 \x01(\x0b\x32K.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509ConfigXCaOptions\x12]\n\tkey_usage\x18\x04 \x01(\x0b\x32J.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509ConfigXKeyUsage\x12_\n\npolicy_ids\x18\x05 \x03(\x0b\x32K.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509ConfigXPolicyIds\"\xa9\x02\n\x1bPrivatecaCertificateXConfig\x12T\n\npublic_key\x18\x01 \x01(\x0b\x32@.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXPublicKey\x12\\\n\x0esubject_config\x18\x02 \x01(\x0b\x32\x44.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXSubjectConfig\x12V\n\x0bx509_config\x18\x03 \x01(\x0b\x32\x41.oak9.tython.gcp.privateca.PrivatecaCertificateXConfigXX509Config\"O\n\x1dPrivatecaCertificateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf7\x07\n\x14PrivatecaCertificate\x12\x1d\n\x15\x63\x65rtificate_authority\x18\x01 \x01(\t\x12l\n\x17\x63\x65rtificate_description\x18\x02 \x03(\x0b\x32K.oak9.tython.gcp.privateca.PrivatecaCertificate.CertificateDescriptionEntry\x12\x1c\n\x14\x63\x65rtificate_template\x18\x03 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12$\n\x1cissuer_certificate_authority\x18\x06 \x01(\t\x12K\n\x06labels\x18\x07 \x03(\x0b\x32;.oak9.tython.gcp.privateca.PrivatecaCertificate.LabelsEntry\x12\x10\n\x08lifetime\x18\x08 \x01(\t\x12\x10\n\x08location\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x17\n\x0fpem_certificate\x18\x0b \x01(\t\x12\x1d\n\x15pem_certificate_chain\x18\x0c \x03(\t\x12\x18\n\x10pem_certificates\x18\r \x03(\t\x12\x0f\n\x07pem_csr\x18\x0e \x01(\t\x12\x0c\n\x04pool\x18\x0f \x01(\t\x12\x0f\n\x07project\x18\x10 \x01(\t\x12\x62\n\x12revocation_details\x18\x11 \x03(\x0b\x32\x46.oak9.tython.gcp.privateca.PrivatecaCertificate.RevocationDetailsEntry\x12\x13\n\x0bupdate_time\x18\x12 \x01(\t\x12\x46\n\x06\x63onfig\x18\x13 \x01(\x0b\x32\x36.oak9.tython.gcp.privateca.PrivatecaCertificateXConfig\x12J\n\x08timeouts\x18\x14 \x01(\x0b\x32\x38.oak9.tython.gcp.privateca.PrivatecaCertificateXTimeouts\x12\x37\n\rresource_info\x18\x15 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a=\n\x1b\x43\x65rtificateDescriptionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16RevocationDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n:PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubject\x12\x13\n\x0b\x63ommon_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x10\n\x08locality\x18\x03 \x01(\t\x12\x14\n\x0corganization\x18\x04 \x01(\t\x12\x1b\n\x13organizational_unit\x18\x05 \x01(\t\x12\x13\n\x0bpostal_code\x18\x06 \x01(\t\x12\x10\n\x08province\x18\x07 \x01(\t\x12\x16\n\x0estreet_address\x18\x08 \x01(\t\"\x93\x01\nAPrivatecaCertificateAuthorityXConfigXSubjectConfigXSubjectAltName\x12\x11\n\tdns_names\x18\x01 \x03(\t\x12\x17\n\x0f\x65mail_addresses\x18\x02 \x03(\t\x12\x14\n\x0cip_addresses\x18\x03 \x03(\t\x12\x0c\n\x04uris\x18\x04 \x03(\t\"\x94\x02\n2PrivatecaCertificateAuthorityXConfigXSubjectConfig\x12\x66\n\x07subject\x18\x01 \x01(\x0b\x32U.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubject\x12v\n\x10subject_alt_name\x18\x02 \x01(\x0b\x32\\.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubjectAltName\"g\nMPrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensionsXObjectId\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xe4\x01\nDPrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensions\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\x12{\n\tobject_id\x18\x03 \x01(\x0b\x32h.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensionsXObjectId\"\x9f\x01\n9PrivatecaCertificateAuthorityXConfigXX509ConfigXCaOptions\x12\r\n\x05is_ca\x18\x01 \x01(\x08\x12\x1e\n\x16max_issuer_path_length\x18\x02 \x01(\x01\x12\x0e\n\x06non_ca\x18\x03 \x01(\x08\x12#\n\x1bzero_max_issuer_path_length\x18\x04 \x01(\x08\"\x9d\x02\nEPrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXBaseKeyUsage\x12\x11\n\tcert_sign\x18\x01 \x01(\x08\x12\x1a\n\x12\x63ontent_commitment\x18\x02 \x01(\x08\x12\x10\n\x08\x63rl_sign\x18\x03 \x01(\x08\x12\x19\n\x11\x64\x61ta_encipherment\x18\x04 \x01(\x08\x12\x15\n\rdecipher_only\x18\x05 \x01(\x08\x12\x19\n\x11\x64igital_signature\x18\x06 \x01(\x08\x12\x15\n\rencipher_only\x18\x07 \x01(\x08\x12\x15\n\rkey_agreement\x18\x08 \x01(\x08\x12\x18\n\x10key_encipherment\x18\t \x01(\x08\"\xd2\x01\nIPrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXExtendedKeyUsage\x12\x13\n\x0b\x63lient_auth\x18\x01 \x01(\x08\x12\x14\n\x0c\x63ode_signing\x18\x02 \x01(\x08\x12\x18\n\x10\x65mail_protection\x18\x03 \x01(\x08\x12\x14\n\x0cocsp_signing\x18\x04 \x01(\x08\x12\x13\n\x0bserver_auth\x18\x05 \x01(\x08\x12\x15\n\rtime_stamping\x18\x06 \x01(\x08\"k\nQPrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xcb\x03\n8PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsage\x12x\n\x0e\x62\x61se_key_usage\x18\x01 \x01(\x0b\x32`.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXBaseKeyUsage\x12\x80\x01\n\x12\x65xtended_key_usage\x18\x02 \x01(\x0b\x32\x64.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXExtendedKeyUsage\x12\x91\x01\n\x1bunknown_extended_key_usages\x18\x03 \x03(\x0b\x32l.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages\"S\n9PrivatecaCertificateAuthorityXConfigXX509ConfigXPolicyIds\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\x87\x04\n/PrivatecaCertificateAuthorityXConfigXX509Config\x12\x18\n\x10\x61ia_ocsp_servers\x18\x01 \x03(\t\x12~\n\x15\x61\x64\x64itional_extensions\x18\x02 \x03(\x0b\x32_.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensions\x12h\n\nca_options\x18\x03 \x01(\x0b\x32T.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509ConfigXCaOptions\x12\x66\n\tkey_usage\x18\x04 \x01(\x0b\x32S.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsage\x12h\n\npolicy_ids\x18\x05 \x03(\x0b\x32T.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509ConfigXPolicyIds\"\xee\x01\n$PrivatecaCertificateAuthorityXConfig\x12\x65\n\x0esubject_config\x18\x01 \x01(\x0b\x32M.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXSubjectConfig\x12_\n\x0bx509_config\x18\x02 \x01(\x0b\x32J.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfigXX509Config\"Y\n%PrivatecaCertificateAuthorityXKeySpec\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x1d\n\x15\x63loud_kms_key_version\x18\x02 \x01(\t\"Z\n>PrivatecaCertificateAuthorityXSubordinateConfigXPemIssuerChain\x12\x18\n\x10pem_certificates\x18\x01 \x03(\t\"\xc5\x01\n/PrivatecaCertificateAuthorityXSubordinateConfig\x12\x1d\n\x15\x63\x65rtificate_authority\x18\x01 \x01(\t\x12s\n\x10pem_issuer_chain\x18\x02 \x01(\x0b\x32Y.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXSubordinateConfigXPemIssuerChain\"X\n&PrivatecaCertificateAuthorityXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc8\x08\n\x1dPrivatecaCertificateAuthority\x12]\n\x0b\x61\x63\x63\x65ss_urls\x18\x01 \x03(\x0b\x32H.oak9.tython.gcp.privateca.PrivatecaCertificateAuthority.AccessUrlsEntry\x12 \n\x18\x63\x65rtificate_authority_id\x18\x02 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x04 \x01(\x08\x12\x15\n\rdesired_state\x18\x05 \x01(\t\x12\x12\n\ngcs_bucket\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12.\n&ignore_active_certificates_on_deletion\x18\x08 \x01(\x08\x12T\n\x06labels\x18\t \x03(\x0b\x32\x44.oak9.tython.gcp.privateca.PrivatecaCertificateAuthority.LabelsEntry\x12\x10\n\x08lifetime\x18\n \x01(\t\x12\x10\n\x08location\x18\x0b \x01(\t\x12\x0c\n\x04name\x18\x0c \x01(\t\x12\x1a\n\x12pem_ca_certificate\x18\r \x01(\t\x12\x1b\n\x13pem_ca_certificates\x18\x0e \x03(\t\x12\x0c\n\x04pool\x18\x0f \x01(\t\x12\x0f\n\x07project\x18\x10 \x01(\t\x12\r\n\x05state\x18\x11 \x01(\t\x12\x0c\n\x04type\x18\x12 \x01(\t\x12\x13\n\x0bupdate_time\x18\x13 \x01(\t\x12O\n\x06\x63onfig\x18\x14 \x01(\x0b\x32?.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXConfig\x12R\n\x08key_spec\x18\x15 \x01(\x0b\x32@.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXKeySpec\x12\x66\n\x12subordinate_config\x18\x16 \x01(\x0b\x32J.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXSubordinateConfig\x12S\n\x08timeouts\x18\x17 \x01(\x0b\x32\x41.oak9.tython.gcp.privateca.PrivatecaCertificateAuthorityXTimeouts\x12\x37\n\rresource_info\x18\x18 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0f\x41\x63\x63\x65ssUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n>PrivatecaCertificateTemplateXIdentityConstraintsXCelExpression\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"\xf5\x01\n0PrivatecaCertificateTemplateXIdentityConstraints\x12+\n#allow_subject_alt_names_passthrough\x18\x01 \x01(\x08\x12!\n\x19\x61llow_subject_passthrough\x18\x02 \x01(\x08\x12q\n\x0e\x63\x65l_expression\x18\x03 \x01(\x0b\x32Y.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXIdentityConstraintsXCelExpression\"a\nGPrivatecaCertificateTemplateXPassthroughExtensionsXAdditionalExtensions\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xd2\x01\n2PrivatecaCertificateTemplateXPassthroughExtensions\x12\x18\n\x10known_extensions\x18\x01 \x03(\t\x12\x81\x01\n\x15\x61\x64\x64itional_extensions\x18\x02 \x03(\x0b\x32\x62.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPassthroughExtensionsXAdditionalExtensions\"e\nKPrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensionsXObjectId\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xe0\x01\nBPrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensions\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\x12y\n\tobject_id\x18\x03 \x01(\x0b\x32\x66.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensionsXObjectId\"h\n7PrivatecaCertificateTemplateXPredefinedValuesXCaOptions\x12\r\n\x05is_ca\x18\x01 \x01(\x08\x12\x1e\n\x16max_issuer_path_length\x18\x02 \x01(\x01\"\x9b\x02\nCPrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXBaseKeyUsage\x12\x11\n\tcert_sign\x18\x01 \x01(\x08\x12\x1a\n\x12\x63ontent_commitment\x18\x02 \x01(\x08\x12\x10\n\x08\x63rl_sign\x18\x03 \x01(\x08\x12\x19\n\x11\x64\x61ta_encipherment\x18\x04 \x01(\x08\x12\x15\n\rdecipher_only\x18\x05 \x01(\x08\x12\x19\n\x11\x64igital_signature\x18\x06 \x01(\x08\x12\x15\n\rencipher_only\x18\x07 \x01(\x08\x12\x15\n\rkey_agreement\x18\x08 \x01(\x08\x12\x18\n\x10key_encipherment\x18\t \x01(\x08\"\xd0\x01\nGPrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXExtendedKeyUsage\x12\x13\n\x0b\x63lient_auth\x18\x01 \x01(\x08\x12\x14\n\x0c\x63ode_signing\x18\x02 \x01(\x08\x12\x18\n\x10\x65mail_protection\x18\x03 \x01(\x08\x12\x14\n\x0cocsp_signing\x18\x04 \x01(\x08\x12\x13\n\x0bserver_auth\x18\x05 \x01(\x08\x12\x15\n\rtime_stamping\x18\x06 \x01(\x08\"i\nOPrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXUnknownExtendedKeyUsages\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xc2\x03\n6PrivatecaCertificateTemplateXPredefinedValuesXKeyUsage\x12v\n\x0e\x62\x61se_key_usage\x18\x01 \x01(\x0b\x32^.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXBaseKeyUsage\x12~\n\x12\x65xtended_key_usage\x18\x02 \x01(\x0b\x32\x62.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXExtendedKeyUsage\x12\x8f\x01\n\x1bunknown_extended_key_usages\x18\x03 \x03(\x0b\x32j.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXUnknownExtendedKeyUsages\"Q\n7PrivatecaCertificateTemplateXPredefinedValuesXPolicyIds\x12\x16\n\x0eobject_id_path\x18\x01 \x03(\x01\"\xfd\x03\n-PrivatecaCertificateTemplateXPredefinedValues\x12\x18\n\x10\x61ia_ocsp_servers\x18\x01 \x03(\t\x12|\n\x15\x61\x64\x64itional_extensions\x18\x02 \x03(\x0b\x32].oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensions\x12\x66\n\nca_options\x18\x03 \x01(\x0b\x32R.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValuesXCaOptions\x12\x64\n\tkey_usage\x18\x04 \x01(\x0b\x32Q.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValuesXKeyUsage\x12\x66\n\npolicy_ids\x18\x05 \x03(\x0b\x32R.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValuesXPolicyIds\"W\n%PrivatecaCertificateTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xea\x05\n\x1cPrivatecaCertificateTemplate\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12S\n\x06labels\x18\x04 \x03(\x0b\x32\x43.oak9.tython.gcp.privateca.PrivatecaCertificateTemplate.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12i\n\x14identity_constraints\x18\t \x01(\x0b\x32K.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXIdentityConstraints\x12m\n\x16passthrough_extensions\x18\n \x01(\x0b\x32M.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPassthroughExtensions\x12\x63\n\x11predefined_values\x18\x0b \x01(\x0b\x32H.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXPredefinedValues\x12R\n\x08timeouts\x18\x0c \x01(\x0b\x32@.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n0PrivatecaCertificateTemplateIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xbb\x02\n&PrivatecaCertificateTemplateIamBinding\x12\x1c\n\x14\x63\x65rtificate_template\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0f\n\x07members\x18\x05 \x03(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12^\n\tcondition\x18\x08 \x01(\x0b\x32K.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"i\n/PrivatecaCertificateTemplateIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xb8\x02\n%PrivatecaCertificateTemplateIamMember\x12\x1c\n\x14\x63\x65rtificate_template\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0e\n\x06member\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12]\n\tcondition\x18\x08 \x01(\x0b\x32J.oak9.tython.gcp.privateca.PrivatecaCertificateTemplateIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd0\x01\n%PrivatecaCertificateTemplateIamPolicy\x12\x1c\n\x14\x63\x65rtificate_template\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_privateca_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVATECACAPOOL_LABELSENTRY._options = None
  _PRIVATECACAPOOL_LABELSENTRY._serialized_options = b'8\001'
  _PRIVATECACERTIFICATE_CERTIFICATEDESCRIPTIONENTRY._options = None
  _PRIVATECACERTIFICATE_CERTIFICATEDESCRIPTIONENTRY._serialized_options = b'8\001'
  _PRIVATECACERTIFICATE_LABELSENTRY._options = None
  _PRIVATECACERTIFICATE_LABELSENTRY._serialized_options = b'8\001'
  _PRIVATECACERTIFICATE_REVOCATIONDETAILSENTRY._options = None
  _PRIVATECACERTIFICATE_REVOCATIONDETAILSENTRY._serialized_options = b'8\001'
  _PRIVATECACERTIFICATEAUTHORITY_ACCESSURLSENTRY._options = None
  _PRIVATECACERTIFICATEAUTHORITY_ACCESSURLSENTRY._serialized_options = b'8\001'
  _PRIVATECACERTIFICATEAUTHORITY_LABELSENTRY._options = None
  _PRIVATECACERTIFICATEAUTHORITY_LABELSENTRY._serialized_options = b'8\001'
  _PRIVATECACERTIFICATETEMPLATE_LABELSENTRY._options = None
  _PRIVATECACERTIFICATETEMPLATE_LABELSENTRY._serialized_options = b'8\001'
  _PRIVATECACAPOOLXISSUANCEPOLICYXALLOWEDISSUANCEMODES._serialized_start=75
  _PRIVATECACAPOOLXISSUANCEPOLICYXALLOWEDISSUANCEMODES._serialized_end=199
  _PRIVATECACAPOOLXISSUANCEPOLICYXALLOWEDKEYTYPESXELLIPTICCURVE._serialized_start=201
  _PRIVATECACAPOOLXISSUANCEPOLICYXALLOWEDKEYTYPESXELLIPTICCURVE._serialized_end=292
  _PRIVATECACAPOOLXISSUANCEPOLICYXALLOWEDKEYTYPESXRSA._serialized_start=294
  _PRIVATECACAPOOLXISSUANCEPOLICYXALLOWEDKEYTYPESXRSA._serialized_end=398
  _PRIVATECACAPOOLXISSUANCEPOLICYXALLOWEDKEYTYPES._serialized_start=401
  _PRIVATECACAPOOLXISSUANCEPOLICYXALLOWEDKEYTYPES._serialized_end=654
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXADDITIONALEXTENSIONSXOBJECTID._serialized_start=656
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXADDITIONALEXTENSIONSXOBJECTID._serialized_end=757
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXADDITIONALEXTENSIONS._serialized_start=760
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXADDITIONALEXTENSIONS._serialized_end=984
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXCAOPTIONS._serialized_start=987
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXCAOPTIONS._serialized_end=1144
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXKEYUSAGEXBASEKEYUSAGE._serialized_start=1147
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXKEYUSAGEXBASEKEYUSAGE._serialized_end=1430
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXKEYUSAGEXEXTENDEDKEYUSAGE._serialized_start=1433
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXKEYUSAGEXEXTENDEDKEYUSAGE._serialized_end=1641
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXKEYUSAGEXUNKNOWNEXTENDEDKEYUSAGES._serialized_start=1643
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXKEYUSAGEXUNKNOWNEXTENDEDKEYUSAGES._serialized_end=1748
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXKEYUSAGE._serialized_start=1751
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXKEYUSAGE._serialized_end=2201
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXPOLICYIDS._serialized_start=2203
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUESXPOLICYIDS._serialized_end=2284
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUES._serialized_start=2287
  _PRIVATECACAPOOLXISSUANCEPOLICYXBASELINEVALUES._serialized_end=2796
  _PRIVATECACAPOOLXISSUANCEPOLICYXIDENTITYCONSTRAINTSXCELEXPRESSION._serialized_start=2799
  _PRIVATECACAPOOLXISSUANCEPOLICYXIDENTITYCONSTRAINTSXCELEXPRESSION._serialized_end=2939
  _PRIVATECACAPOOLXISSUANCEPOLICYXIDENTITYCONSTRAINTS._serialized_start=2942
  _PRIVATECACAPOOLXISSUANCEPOLICYXIDENTITYCONSTRAINTS._serialized_end=3191
  _PRIVATECACAPOOLXISSUANCEPOLICY._serialized_start=3194
  _PRIVATECACAPOOLXISSUANCEPOLICY._serialized_end=3674
  _PRIVATECACAPOOLXPUBLISHINGOPTIONS._serialized_start=3676
  _PRIVATECACAPOOLXPUBLISHINGOPTIONS._serialized_end=3757
  _PRIVATECACAPOOLXTIMEOUTS._serialized_start=3759
  _PRIVATECACAPOOLXTIMEOUTS._serialized_end=3833
  _PRIVATECACAPOOL._serialized_start=3836
  _PRIVATECACAPOOL._serialized_end=4349
  _PRIVATECACAPOOL_LABELSENTRY._serialized_start=4304
  _PRIVATECACAPOOL_LABELSENTRY._serialized_end=4349
  _PRIVATECACAPOOLIAMBINDINGXCONDITION._serialized_start=4351
  _PRIVATECACAPOOLIAMBINDINGXCONDITION._serialized_end=4444
  _PRIVATECACAPOOLIAMBINDING._serialized_start=4447
  _PRIVATECACAPOOLIAMBINDING._serialized_end=4723
  _PRIVATECACAPOOLIAMMEMBERXCONDITION._serialized_start=4725
  _PRIVATECACAPOOLIAMMEMBERXCONDITION._serialized_end=4817
  _PRIVATECACAPOOLIAMMEMBER._serialized_start=4820
  _PRIVATECACAPOOLIAMMEMBER._serialized_end=5093
  _PRIVATECACAPOOLIAMPOLICY._serialized_start=5096
  _PRIVATECACAPOOLIAMPOLICY._serialized_end=5278
  _PRIVATECACERTIFICATEXCONFIGXPUBLICKEY._serialized_start=5280
  _PRIVATECACERTIFICATEXCONFIGXPUBLICKEY._serialized_end=5348
  _PRIVATECACERTIFICATEXCONFIGXSUBJECTCONFIGXSUBJECT._serialized_start=5351
  _PRIVATECACERTIFICATEXCONFIGXSUBJECTCONFIGXSUBJECT._serialized_end=5577
  _PRIVATECACERTIFICATEXCONFIGXSUBJECTCONFIGXSUBJECTALTNAME._serialized_start=5580
  _PRIVATECACERTIFICATEXCONFIGXSUBJECTCONFIGXSUBJECTALTNAME._serialized_end=5718
  _PRIVATECACERTIFICATEXCONFIGXSUBJECTCONFIG._serialized_start=5721
  _PRIVATECACERTIFICATEXCONFIGXSUBJECTCONFIG._serialized_end=5970
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXADDITIONALEXTENSIONSXOBJECTID._serialized_start=5972
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXADDITIONALEXTENSIONSXOBJECTID._serialized_end=6066
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXADDITIONALEXTENSIONS._serialized_start=6069
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXADDITIONALEXTENSIONS._serialized_end=6279
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXCAOPTIONS._serialized_start=6282
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXCAOPTIONS._serialized_end=6432
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXKEYUSAGEXBASEKEYUSAGE._serialized_start=6435
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXKEYUSAGEXBASEKEYUSAGE._serialized_end=6711
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXKEYUSAGEXEXTENDEDKEYUSAGE._serialized_start=6714
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXKEYUSAGEXEXTENDEDKEYUSAGE._serialized_end=6915
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXKEYUSAGEXUNKNOWNEXTENDEDKEYUSAGES._serialized_start=6917
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXKEYUSAGEXUNKNOWNEXTENDEDKEYUSAGES._serialized_end=7015
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXKEYUSAGE._serialized_start=7018
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXKEYUSAGE._serialized_end=7440
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXPOLICYIDS._serialized_start=7442
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIGXPOLICYIDS._serialized_end=7516
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIG._serialized_start=7519
  _PRIVATECACERTIFICATEXCONFIGXX509CONFIG._serialized_end=7993
  _PRIVATECACERTIFICATEXCONFIG._serialized_start=7996
  _PRIVATECACERTIFICATEXCONFIG._serialized_end=8293
  _PRIVATECACERTIFICATEXTIMEOUTS._serialized_start=8295
  _PRIVATECACERTIFICATEXTIMEOUTS._serialized_end=8374
  _PRIVATECACERTIFICATE._serialized_start=8377
  _PRIVATECACERTIFICATE._serialized_end=9392
  _PRIVATECACERTIFICATE_CERTIFICATEDESCRIPTIONENTRY._serialized_start=9226
  _PRIVATECACERTIFICATE_CERTIFICATEDESCRIPTIONENTRY._serialized_end=9287
  _PRIVATECACERTIFICATE_LABELSENTRY._serialized_start=4304
  _PRIVATECACERTIFICATE_LABELSENTRY._serialized_end=4349
  _PRIVATECACERTIFICATE_REVOCATIONDETAILSENTRY._serialized_start=9336
  _PRIVATECACERTIFICATE_REVOCATIONDETAILSENTRY._serialized_end=9392
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXSUBJECTCONFIGXSUBJECT._serialized_start=9395
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXSUBJECTCONFIGXSUBJECT._serialized_end=9630
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXSUBJECTCONFIGXSUBJECTALTNAME._serialized_start=9633
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXSUBJECTCONFIGXSUBJECTALTNAME._serialized_end=9780
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXSUBJECTCONFIG._serialized_start=9783
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXSUBJECTCONFIG._serialized_end=10059
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXADDITIONALEXTENSIONSXOBJECTID._serialized_start=10061
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXADDITIONALEXTENSIONSXOBJECTID._serialized_end=10164
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXADDITIONALEXTENSIONS._serialized_start=10167
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXADDITIONALEXTENSIONS._serialized_end=10395
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXCAOPTIONS._serialized_start=10398
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXCAOPTIONS._serialized_end=10557
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXKEYUSAGEXBASEKEYUSAGE._serialized_start=10560
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXKEYUSAGEXBASEKEYUSAGE._serialized_end=10845
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXKEYUSAGEXEXTENDEDKEYUSAGE._serialized_start=10848
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXKEYUSAGEXEXTENDEDKEYUSAGE._serialized_end=11058
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXKEYUSAGEXUNKNOWNEXTENDEDKEYUSAGES._serialized_start=11060
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXKEYUSAGEXUNKNOWNEXTENDEDKEYUSAGES._serialized_end=11167
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXKEYUSAGE._serialized_start=11170
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXKEYUSAGE._serialized_end=11629
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXPOLICYIDS._serialized_start=11631
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIGXPOLICYIDS._serialized_end=11714
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIG._serialized_start=11717
  _PRIVATECACERTIFICATEAUTHORITYXCONFIGXX509CONFIG._serialized_end=12236
  _PRIVATECACERTIFICATEAUTHORITYXCONFIG._serialized_start=12239
  _PRIVATECACERTIFICATEAUTHORITYXCONFIG._serialized_end=12477
  _PRIVATECACERTIFICATEAUTHORITYXKEYSPEC._serialized_start=12479
  _PRIVATECACERTIFICATEAUTHORITYXKEYSPEC._serialized_end=12568
  _PRIVATECACERTIFICATEAUTHORITYXSUBORDINATECONFIGXPEMISSUERCHAIN._serialized_start=12570
  _PRIVATECACERTIFICATEAUTHORITYXSUBORDINATECONFIGXPEMISSUERCHAIN._serialized_end=12660
  _PRIVATECACERTIFICATEAUTHORITYXSUBORDINATECONFIG._serialized_start=12663
  _PRIVATECACERTIFICATEAUTHORITYXSUBORDINATECONFIG._serialized_end=12860
  _PRIVATECACERTIFICATEAUTHORITYXTIMEOUTS._serialized_start=12862
  _PRIVATECACERTIFICATEAUTHORITYXTIMEOUTS._serialized_end=12950
  _PRIVATECACERTIFICATEAUTHORITY._serialized_start=12953
  _PRIVATECACERTIFICATEAUTHORITY._serialized_end=14049
  _PRIVATECACERTIFICATEAUTHORITY_ACCESSURLSENTRY._serialized_start=13953
  _PRIVATECACERTIFICATEAUTHORITY_ACCESSURLSENTRY._serialized_end=14002
  _PRIVATECACERTIFICATEAUTHORITY_LABELSENTRY._serialized_start=4304
  _PRIVATECACERTIFICATEAUTHORITY_LABELSENTRY._serialized_end=4349
  _PRIVATECACERTIFICATETEMPLATEXIDENTITYCONSTRAINTSXCELEXPRESSION._serialized_start=14052
  _PRIVATECACERTIFICATETEMPLATEXIDENTITYCONSTRAINTSXCELEXPRESSION._serialized_end=14190
  _PRIVATECACERTIFICATETEMPLATEXIDENTITYCONSTRAINTS._serialized_start=14193
  _PRIVATECACERTIFICATETEMPLATEXIDENTITYCONSTRAINTS._serialized_end=14438
  _PRIVATECACERTIFICATETEMPLATEXPASSTHROUGHEXTENSIONSXADDITIONALEXTENSIONS._serialized_start=14440
  _PRIVATECACERTIFICATETEMPLATEXPASSTHROUGHEXTENSIONSXADDITIONALEXTENSIONS._serialized_end=14537
  _PRIVATECACERTIFICATETEMPLATEXPASSTHROUGHEXTENSIONS._serialized_start=14540
  _PRIVATECACERTIFICATETEMPLATEXPASSTHROUGHEXTENSIONS._serialized_end=14750
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXADDITIONALEXTENSIONSXOBJECTID._serialized_start=14752
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXADDITIONALEXTENSIONSXOBJECTID._serialized_end=14853
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXADDITIONALEXTENSIONS._serialized_start=14856
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXADDITIONALEXTENSIONS._serialized_end=15080
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXCAOPTIONS._serialized_start=15082
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXCAOPTIONS._serialized_end=15186
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXKEYUSAGEXBASEKEYUSAGE._serialized_start=15189
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXKEYUSAGEXBASEKEYUSAGE._serialized_end=15472
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXKEYUSAGEXEXTENDEDKEYUSAGE._serialized_start=15475
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXKEYUSAGEXEXTENDEDKEYUSAGE._serialized_end=15683
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXKEYUSAGEXUNKNOWNEXTENDEDKEYUSAGES._serialized_start=15685
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXKEYUSAGEXUNKNOWNEXTENDEDKEYUSAGES._serialized_end=15790
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXKEYUSAGE._serialized_start=15793
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXKEYUSAGE._serialized_end=16243
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXPOLICYIDS._serialized_start=16245
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUESXPOLICYIDS._serialized_end=16326
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUES._serialized_start=16329
  _PRIVATECACERTIFICATETEMPLATEXPREDEFINEDVALUES._serialized_end=16838
  _PRIVATECACERTIFICATETEMPLATEXTIMEOUTS._serialized_start=16840
  _PRIVATECACERTIFICATETEMPLATEXTIMEOUTS._serialized_end=16927
  _PRIVATECACERTIFICATETEMPLATE._serialized_start=16930
  _PRIVATECACERTIFICATETEMPLATE._serialized_end=17676
  _PRIVATECACERTIFICATETEMPLATE_LABELSENTRY._serialized_start=4304
  _PRIVATECACERTIFICATETEMPLATE_LABELSENTRY._serialized_end=4349
  _PRIVATECACERTIFICATETEMPLATEIAMBINDINGXCONDITION._serialized_start=17678
  _PRIVATECACERTIFICATETEMPLATEIAMBINDINGXCONDITION._serialized_end=17784
  _PRIVATECACERTIFICATETEMPLATEIAMBINDING._serialized_start=17787
  _PRIVATECACERTIFICATETEMPLATEIAMBINDING._serialized_end=18102
  _PRIVATECACERTIFICATETEMPLATEIAMMEMBERXCONDITION._serialized_start=18104
  _PRIVATECACERTIFICATETEMPLATEIAMMEMBERXCONDITION._serialized_end=18209
  _PRIVATECACERTIFICATETEMPLATEIAMMEMBER._serialized_start=18212
  _PRIVATECACERTIFICATETEMPLATEIAMMEMBER._serialized_end=18524
  _PRIVATECACERTIFICATETEMPLATEIAMPOLICY._serialized_start=18527
  _PRIVATECACERTIFICATETEMPLATEIAMPOLICY._serialized_end=18735
# @@protoc_insertion_point(module_scope)
