# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_apigateway.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_apigateway.proto\x12\x1aoak9.tython.aws.apigateway\x1a\x13shared/shared.proto\"`\n\x07\x41\x63\x63ount\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63loud_watch_role_arn\x18\x02 \x01(\t\"\xd6\x06\n\nApiGateway\x12\x34\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32#.oak9.tython.aws.apigateway.Account\x12\x33\n\x07\x61pi_key\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.apigateway.ApiKey\x12:\n\nauthorizer\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.apigateway.Authorizer\x12\x46\n\x11\x62\x61se_path_mapping\x18\x04 \x01(\x0b\x32+.oak9.tython.aws.apigateway.BasePathMapping\x12:\n\ndeployment\x18\x05 \x01(\x0b\x32&.oak9.tython.aws.apigateway.Deployment\x12;\n\x0b\x64omain_name\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.apigateway.DomainName\x12\x45\n\x10gateway_response\x18\x07 \x03(\x0b\x32+.oak9.tython.aws.apigateway.GatewayResponse\x12\x32\n\x06method\x18\x08 \x03(\x0b\x32\".oak9.tython.aws.apigateway.Method\x12G\n\x11request_validator\x18\t \x01(\x0b\x32,.oak9.tython.aws.apigateway.RequestValidator\x12\x36\n\x08resource\x18\n \x03(\x0b\x32$.oak9.tython.aws.apigateway.Resource\x12\x35\n\x08rest_api\x18\x0b \x01(\x0b\x32#.oak9.tython.aws.apigateway.RestApi\x12\x30\n\x05stage\x18\x0c \x03(\x0b\x32!.oak9.tython.aws.apigateway.Stage\x12\x39\n\nusage_plan\x18\r \x01(\x0b\x32%.oak9.tython.aws.apigateway.UsagePlan\x12@\n\x0eusage_plan_key\x18\x0e \x01(\x0b\x32(.oak9.tython.aws.apigateway.UsagePlanKey\"r\n\x0e\x41piKeyStageKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0brest_api_id\x18\x02 \x01(\t\x12\x12\n\nstage_name\x18\x03 \x01(\t\"\xe0\x02\n\x06\x41piKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x1c\n\x14generate_distinct_id\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12>\n\nstage_keys\x18\x07 \x03(\x0b\x32*.oak9.tython.aws.apigateway.ApiKeyStageKey\x12:\n\x04tags\x18\x08 \x03(\x0b\x32,.oak9.tython.aws.apigateway.ApiKey.TagsEntry\x12\r\n\x05value\x18\t \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc3\x02\n\nAuthorizer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tauth_type\x18\x02 \x01(\t\x12\x1e\n\x16\x61uthorizer_credentials\x18\x03 \x01(\t\x12(\n authorizer_result_ttl_in_seconds\x18\x04 \x01(\x05\x12\x16\n\x0e\x61uthorizer_uri\x18\x05 \x01(\t\x12\x17\n\x0fidentity_source\x18\x06 \x01(\t\x12&\n\x1eidentity_validation_expression\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x15\n\rprovider_arns\x18\t \x03(\t\x12\x13\n\x0brest_api_id\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\"\x96\x01\n\x0f\x42\x61sePathMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tbase_path\x18\x02 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\x12\r\n\x05stage\x18\x05 \x01(\t\"\xd5\x01\n\x11\x43lientCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x45\n\x04tags\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.apigateway.ClientCertificate.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x02\n\"DeploymentDeploymentCanarySettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fpercent_traffic\x18\x02 \x01(\x01\x12|\n\x18stage_variable_overrides\x18\x03 \x03(\x0b\x32Z.oak9.tython.aws.apigateway.DeploymentDeploymentCanarySettings.StageVariableOverridesEntry\x12\x17\n\x0fuse_stage_cache\x18\x04 \x01(\x08\x1a=\n\x1bStageVariableOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1a\x44\x65ploymentAccessLogSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64\x65stination_arn\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\xb6\x02\n\x17\x44\x65ploymentCanarySetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fpercent_traffic\x18\x02 \x01(\x01\x12q\n\x18stage_variable_overrides\x18\x03 \x03(\x0b\x32O.oak9.tython.aws.apigateway.DeploymentCanarySetting.StageVariableOverridesEntry\x12\x17\n\x0fuse_stage_cache\x18\x04 \x01(\x08\x1a=\n\x1bStageVariableOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xde\x02\n\x17\x44\x65ploymentMethodSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63\x61\x63he_data_encrypted\x18\x02 \x01(\x08\x12\x1c\n\x14\x63\x61\x63he_ttl_in_seconds\x18\x03 \x01(\x05\x12\x17\n\x0f\x63\x61\x63hing_enabled\x18\x04 \x01(\x08\x12\x1a\n\x12\x64\x61ta_trace_enabled\x18\x05 \x01(\x08\x12\x13\n\x0bhttp_method\x18\x06 \x01(\t\x12\x15\n\rlogging_level\x18\x07 \x01(\t\x12\x17\n\x0fmetrics_enabled\x18\x08 \x01(\x08\x12\x15\n\rresource_path\x18\t \x01(\t\x12\x1e\n\x16throttling_burst_limit\x18\n \x01(\x05\x12\x1d\n\x15throttling_rate_limit\x18\x0b \x01(\x01\"\xd4\x07\n\x1a\x44\x65ploymentStageDescription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x12\x61\x63\x63\x65ss_log_setting\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.apigateway.DeploymentAccessLogSetting\x12\x1d\n\x15\x63\x61\x63he_cluster_enabled\x18\x03 \x01(\x08\x12\x1a\n\x12\x63\x61\x63he_cluster_size\x18\x04 \x01(\t\x12\x1c\n\x14\x63\x61\x63he_data_encrypted\x18\x05 \x01(\x08\x12\x1c\n\x14\x63\x61\x63he_ttl_in_seconds\x18\x06 \x01(\x05\x12\x17\n\x0f\x63\x61\x63hing_enabled\x18\x07 \x01(\x08\x12K\n\x0e\x63\x61nary_setting\x18\x08 \x01(\x0b\x32\x33.oak9.tython.aws.apigateway.DeploymentCanarySetting\x12\x1d\n\x15\x63lient_certificate_id\x18\t \x01(\t\x12\x1a\n\x12\x64\x61ta_trace_enabled\x18\n \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\x12\x1d\n\x15\x64ocumentation_version\x18\x0c \x01(\t\x12\x15\n\rlogging_level\x18\r \x01(\t\x12L\n\x0fmethod_settings\x18\x0e \x03(\x0b\x32\x33.oak9.tython.aws.apigateway.DeploymentMethodSetting\x12\x17\n\x0fmetrics_enabled\x18\x0f \x01(\x08\x12N\n\x04tags\x18\x10 \x03(\x0b\x32@.oak9.tython.aws.apigateway.DeploymentStageDescription.TagsEntry\x12\x1e\n\x16throttling_burst_limit\x18\x11 \x01(\x05\x12\x1d\n\x15throttling_rate_limit\x18\x12 \x01(\x01\x12\x17\n\x0ftracing_enabled\x18\x13 \x01(\x08\x12X\n\tvariables\x18\x14 \x03(\x0b\x32\x45.oak9.tython.aws.apigateway.DeploymentStageDescription.VariablesEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xba\x02\n\nDeployment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x1a\x64\x65ployment_canary_settings\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.apigateway.DeploymentDeploymentCanarySettings\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\x12Q\n\x11stage_description\x18\x05 \x01(\x0b\x32\x36.oak9.tython.aws.apigateway.DeploymentStageDescription\x12\x12\n\nstage_name\x18\x06 \x01(\t\"\x95\x01\n\x19\x44ocumentationPartLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x13\n\x0bstatus_code\x18\x05 \x01(\t\"\xbe\x01\n\x11\x44ocumentationPart\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x08location\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.apigateway.DocumentationPartLocation\x12\x12\n\nproperties\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\"\x98\x01\n\x14\x44ocumentationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1d\n\x15\x64ocumentation_version\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\"i\n\x1f\x44omainNameEndpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05types\x18\x02 \x03(\t\"\x90\x01\n!DomainNameMutualTlsAuthentication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0etruststore_uri\x18\x02 \x01(\t\x12\x1a\n\x12truststore_version\x18\x03 \x01(\t\"\xda\x03\n\nDomainName\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12[\n\x16\x65ndpoint_configuration\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.apigateway.DomainNameEndpointConfiguration\x12`\n\x19mutual_tls_authentication\x18\x04 \x01(\x0b\x32=.oak9.tython.aws.apigateway.DomainNameMutualTlsAuthentication\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\x12 \n\x18regional_certificate_arn\x18\x06 \x01(\t\x12\x17\n\x0fsecurity_policy\x18\x07 \x01(\t\x12>\n\x04tags\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.apigateway.DomainName.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x03\n\x0fGatewayResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x13response_parameters\x18\x02 \x03(\x0b\x32\x43.oak9.tython.aws.apigateway.GatewayResponse.ResponseParametersEntry\x12^\n\x12response_templates\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.apigateway.GatewayResponse.ResponseTemplatesEntry\x12\x15\n\rresponse_type\x18\x04 \x01(\t\x12\x13\n\x0brest_api_id\x18\x05 \x01(\t\x12\x13\n\x0bstatus_code\x18\x06 \x01(\t\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16ResponseTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe9\x03\n\x19MethodIntegrationResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63ontent_handling\x18\x02 \x01(\t\x12j\n\x13response_parameters\x18\x03 \x03(\x0b\x32M.oak9.tython.aws.apigateway.MethodIntegrationResponse.ResponseParametersEntry\x12h\n\x12response_templates\x18\x04 \x03(\x0b\x32L.oak9.tython.aws.apigateway.MethodIntegrationResponse.ResponseTemplatesEntry\x12\x19\n\x11selection_pattern\x18\x05 \x01(\t\x12\x13\n\x0bstatus_code\x18\x06 \x01(\t\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16ResponseTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd4\x05\n\x11MethodIntegration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63\x61\x63he_key_parameters\x18\x02 \x03(\t\x12\x17\n\x0f\x63\x61\x63he_namespace\x18\x03 \x01(\t\x12\x15\n\rconnection_id\x18\x04 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x05 \x01(\t\x12\x18\n\x10\x63ontent_handling\x18\x06 \x01(\t\x12\x13\n\x0b\x63redentials\x18\x07 \x01(\t\x12\x1f\n\x17integration_http_method\x18\x08 \x01(\t\x12T\n\x15integration_responses\x18\t \x03(\x0b\x32\x35.oak9.tython.aws.apigateway.MethodIntegrationResponse\x12\x1c\n\x14passthrough_behavior\x18\n \x01(\t\x12`\n\x12request_parameters\x18\x0b \x03(\x0b\x32\x44.oak9.tython.aws.apigateway.MethodIntegration.RequestParametersEntry\x12^\n\x11request_templates\x18\x0c \x03(\x0b\x32\x43.oak9.tython.aws.apigateway.MethodIntegration.RequestTemplatesEntry\x12\x19\n\x11timeout_in_millis\x18\r \x01(\x05\x12\x0b\n\x03uri\x18\x0e \x01(\t\x1a\x38\n\x16RequestParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15RequestTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x03\n\x14MethodMethodResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x0fresponse_models\x18\x02 \x03(\x0b\x32\x44.oak9.tython.aws.apigateway.MethodMethodResponse.ResponseModelsEntry\x12\x65\n\x13response_parameters\x18\x03 \x03(\x0b\x32H.oak9.tython.aws.apigateway.MethodMethodResponse.ResponseParametersEntry\x12\x13\n\x0bstatus_code\x18\x04 \x01(\t\x1a\x35\n\x13ResponseModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdb\x05\n\x06Method\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pi_key_required\x18\x02 \x01(\x08\x12\x1c\n\x14\x61uthorization_scopes\x18\x03 \x03(\t\x12\x1a\n\x12\x61uthorization_type\x18\x04 \x01(\t\x12\x15\n\rauthorizer_id\x18\x05 \x01(\t\x12\x13\n\x0bhttp_method\x18\x06 \x01(\t\x12\x42\n\x0bintegration\x18\x07 \x01(\x0b\x32-.oak9.tython.aws.apigateway.MethodIntegration\x12J\n\x10method_responses\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.apigateway.MethodMethodResponse\x12\x16\n\x0eoperation_name\x18\t \x01(\t\x12M\n\x0erequest_models\x18\n \x03(\x0b\x32\x35.oak9.tython.aws.apigateway.Method.RequestModelsEntry\x12U\n\x12request_parameters\x18\x0b \x03(\x0b\x32\x39.oak9.tython.aws.apigateway.Method.RequestParametersEntry\x12\x1c\n\x14request_validator_id\x18\x0c \x01(\t\x12\x13\n\x0bresource_id\x18\r \x01(\t\x12\x13\n\x0brest_api_id\x18\x0e \x01(\t\x12\x12\n\ndepends_on\x18\x0f \x01(\t\x1a\x34\n\x12RequestModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16RequestParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfc\x01\n\x05Model\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0brest_api_id\x18\x05 \x01(\t\x12=\n\x06schema\x18\x06 \x03(\x0b\x32-.oak9.tython.aws.apigateway.Model.SchemaEntry\x1a-\n\x0bSchemaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x01\n\x10RequestValidator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0brest_api_id\x18\x03 \x01(\t\x12\x1d\n\x15validate_request_body\x18\x04 \x01(\x08\x12#\n\x1bvalidate_request_parameters\x18\x05 \x01(\x08\"~\n\x08Resource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x11\n\tpath_part\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\"\x89\x01\n\x11RestApiS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\r\n\x05\x65_tag\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\"\x80\x01\n\x1cRestApiEndpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05types\x18\x02 \x03(\t\x12\x18\n\x10vpc_endpoint_ids\x18\x03 \x03(\t\"\xaf\x06\n\x07RestApi\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61pi_key_source_type\x18\x02 \x01(\t\x12\x1a\n\x12\x62inary_media_types\x18\x03 \x03(\t\x12;\n\x04\x62ody\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.apigateway.RestApi.BodyEntry\x12G\n\x10\x62ody_s3_location\x18\x05 \x01(\x0b\x32-.oak9.tython.aws.apigateway.RestApiS3Location\x12\x12\n\nclone_from\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12X\n\x16\x65ndpoint_configuration\x18\x08 \x01(\x0b\x32\x38.oak9.tython.aws.apigateway.RestApiEndpointConfiguration\x12\x18\n\x10\x66\x61il_on_warnings\x18\t \x01(\x08\x12 \n\x18minimum_compression_size\x18\n \x01(\x05\x12\x0c\n\x04name\x18\x0b \x01(\t\x12G\n\nparameters\x18\x0c \x03(\x0b\x32\x33.oak9.tython.aws.apigateway.RestApi.ParametersEntry\x12\x0e\n\x06policy\x18\r \x01(\t\x12;\n\x04tags\x18\x0e \x03(\x0b\x32-.oak9.tython.aws.apigateway.RestApi.TagsEntry\x12$\n\x1c\x64isable_execute_api_endpoint\x18\x0f \x01(\t\x12\x16\n\x0e\x61pi_key_source\x18\x10 \x01(\t\x1a+\n\tBodyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x15StageAccessLogSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64\x65stination_arn\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\xc3\x02\n\x12StageCanarySetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\x17\n\x0fpercent_traffic\x18\x03 \x01(\x01\x12l\n\x18stage_variable_overrides\x18\x04 \x03(\x0b\x32J.oak9.tython.aws.apigateway.StageCanarySetting.StageVariableOverridesEntry\x12\x17\n\x0fuse_stage_cache\x18\x05 \x01(\x08\x1a=\n\x1bStageVariableOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x02\n\x12StageMethodSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63\x61\x63he_data_encrypted\x18\x02 \x01(\x08\x12\x1c\n\x14\x63\x61\x63he_ttl_in_seconds\x18\x03 \x01(\x05\x12\x17\n\x0f\x63\x61\x63hing_enabled\x18\x04 \x01(\x08\x12\x1a\n\x12\x64\x61ta_trace_enabled\x18\x05 \x01(\x08\x12\x13\n\x0bhttp_method\x18\x06 \x01(\t\x12\x15\n\rlogging_level\x18\x07 \x01(\t\x12\x17\n\x0fmetrics_enabled\x18\x08 \x01(\x08\x12\x15\n\rresource_path\x18\t \x01(\t\x12\x1e\n\x16throttling_burst_limit\x18\n \x01(\x05\x12\x1d\n\x15throttling_rate_limit\x18\x0b \x01(\x01\"\xe6\x05\n\x05Stage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x12\x61\x63\x63\x65ss_log_setting\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.apigateway.StageAccessLogSetting\x12\x1d\n\x15\x63\x61\x63he_cluster_enabled\x18\x03 \x01(\x08\x12\x1a\n\x12\x63\x61\x63he_cluster_size\x18\x04 \x01(\t\x12\x46\n\x0e\x63\x61nary_setting\x18\x05 \x01(\x0b\x32..oak9.tython.aws.apigateway.StageCanarySetting\x12\x1d\n\x15\x63lient_certificate_id\x18\x06 \x01(\t\x12\x15\n\rdeployment_id\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x1d\n\x15\x64ocumentation_version\x18\t \x01(\t\x12G\n\x0fmethod_settings\x18\n \x03(\x0b\x32..oak9.tython.aws.apigateway.StageMethodSetting\x12\x13\n\x0brest_api_id\x18\x0b \x01(\t\x12\x12\n\nstage_name\x18\x0c \x01(\t\x12\x39\n\x04tags\x18\r \x03(\x0b\x32+.oak9.tython.aws.apigateway.Stage.TagsEntry\x12\x17\n\x0ftracing_enabled\x18\x0e \x01(\x08\x12\x43\n\tvariables\x18\x0f \x03(\x0b\x32\x30.oak9.tython.aws.apigateway.Stage.VariablesEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n\x11UsagePlanApiStage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61pi_id\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12M\n\x08throttle\x18\x04 \x03(\x0b\x32;.oak9.tython.aws.apigateway.UsagePlanApiStage.ThrottleEntry\x1a/\n\rThrottleEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\x16UsagePlanQuotaSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x0e\n\x06period\x18\x04 \x01(\t\"}\n\x19UsagePlanThrottleSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x62urst_limit\x18\x02 \x01(\x05\x12\x12\n\nrate_limit\x18\x03 \x01(\x01\"\xad\x03\n\tUsagePlan\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\napi_stages\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.apigateway.UsagePlanApiStage\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x41\n\x05quota\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.apigateway.UsagePlanQuotaSettings\x12=\n\x04tags\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.apigateway.UsagePlan.TagsEntry\x12G\n\x08throttle\x18\x06 \x01(\x0b\x32\x35.oak9.tython.aws.apigateway.UsagePlanThrottleSettings\x12\x17\n\x0fusage_plan_name\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\x0cUsagePlanKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12\x10\n\x08key_type\x18\x03 \x01(\t\x12\x15\n\rusage_plan_id\x18\x04 \x01(\t\"z\n\x07VpcLink\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0btarget_arns\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_apigateway_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APIKEY_TAGSENTRY._options = None
  _APIKEY_TAGSENTRY._serialized_options = b'8\001'
  _CLIENTCERTIFICATE_TAGSENTRY._options = None
  _CLIENTCERTIFICATE_TAGSENTRY._serialized_options = b'8\001'
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS_STAGEVARIABLEOVERRIDESENTRY._options = None
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS_STAGEVARIABLEOVERRIDESENTRY._serialized_options = b'8\001'
  _DEPLOYMENTCANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._options = None
  _DEPLOYMENTCANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_options = b'8\001'
  _DEPLOYMENTSTAGEDESCRIPTION_TAGSENTRY._options = None
  _DEPLOYMENTSTAGEDESCRIPTION_TAGSENTRY._serialized_options = b'8\001'
  _DEPLOYMENTSTAGEDESCRIPTION_VARIABLESENTRY._options = None
  _DEPLOYMENTSTAGEDESCRIPTION_VARIABLESENTRY._serialized_options = b'8\001'
  _DOMAINNAME_TAGSENTRY._options = None
  _DOMAINNAME_TAGSENTRY._serialized_options = b'8\001'
  _GATEWAYRESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _GATEWAYRESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _GATEWAYRESPONSE_RESPONSETEMPLATESENTRY._options = None
  _GATEWAYRESPONSE_RESPONSETEMPLATESENTRY._serialized_options = b'8\001'
  _METHODINTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _METHODINTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _METHODINTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._options = None
  _METHODINTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_options = b'8\001'
  _METHODINTEGRATION_REQUESTPARAMETERSENTRY._options = None
  _METHODINTEGRATION_REQUESTPARAMETERSENTRY._serialized_options = b'8\001'
  _METHODINTEGRATION_REQUESTTEMPLATESENTRY._options = None
  _METHODINTEGRATION_REQUESTTEMPLATESENTRY._serialized_options = b'8\001'
  _METHODMETHODRESPONSE_RESPONSEMODELSENTRY._options = None
  _METHODMETHODRESPONSE_RESPONSEMODELSENTRY._serialized_options = b'8\001'
  _METHODMETHODRESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _METHODMETHODRESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _METHOD_REQUESTMODELSENTRY._options = None
  _METHOD_REQUESTMODELSENTRY._serialized_options = b'8\001'
  _METHOD_REQUESTPARAMETERSENTRY._options = None
  _METHOD_REQUESTPARAMETERSENTRY._serialized_options = b'8\001'
  _MODEL_SCHEMAENTRY._options = None
  _MODEL_SCHEMAENTRY._serialized_options = b'8\001'
  _RESTAPI_BODYENTRY._options = None
  _RESTAPI_BODYENTRY._serialized_options = b'8\001'
  _RESTAPI_PARAMETERSENTRY._options = None
  _RESTAPI_PARAMETERSENTRY._serialized_options = b'8\001'
  _RESTAPI_TAGSENTRY._options = None
  _RESTAPI_TAGSENTRY._serialized_options = b'8\001'
  _STAGECANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._options = None
  _STAGECANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_options = b'8\001'
  _STAGE_TAGSENTRY._options = None
  _STAGE_TAGSENTRY._serialized_options = b'8\001'
  _STAGE_VARIABLESENTRY._options = None
  _STAGE_VARIABLESENTRY._serialized_options = b'8\001'
  _USAGEPLANAPISTAGE_THROTTLEENTRY._options = None
  _USAGEPLANAPISTAGE_THROTTLEENTRY._serialized_options = b'8\001'
  _USAGEPLAN_TAGSENTRY._options = None
  _USAGEPLAN_TAGSENTRY._serialized_options = b'8\001'
  _ACCOUNT._serialized_start=77
  _ACCOUNT._serialized_end=173
  _APIGATEWAY._serialized_start=176
  _APIGATEWAY._serialized_end=1030
  _APIKEYSTAGEKEY._serialized_start=1032
  _APIKEYSTAGEKEY._serialized_end=1146
  _APIKEY._serialized_start=1149
  _APIKEY._serialized_end=1501
  _APIKEY_TAGSENTRY._serialized_start=1458
  _APIKEY_TAGSENTRY._serialized_end=1501
  _AUTHORIZER._serialized_start=1504
  _AUTHORIZER._serialized_end=1827
  _BASEPATHMAPPING._serialized_start=1830
  _BASEPATHMAPPING._serialized_end=1980
  _CLIENTCERTIFICATE._serialized_start=1983
  _CLIENTCERTIFICATE._serialized_end=2196
  _CLIENTCERTIFICATE_TAGSENTRY._serialized_start=1458
  _CLIENTCERTIFICATE_TAGSENTRY._serialized_end=1501
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS._serialized_start=2199
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS._serialized_end=2531
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS_STAGEVARIABLEOVERRIDESENTRY._serialized_start=2470
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS_STAGEVARIABLEOVERRIDESENTRY._serialized_end=2531
  _DEPLOYMENTACCESSLOGSETTING._serialized_start=2533
  _DEPLOYMENTACCESSLOGSETTING._serialized_end=2659
  _DEPLOYMENTCANARYSETTING._serialized_start=2662
  _DEPLOYMENTCANARYSETTING._serialized_end=2972
  _DEPLOYMENTCANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_start=2470
  _DEPLOYMENTCANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_end=2531
  _DEPLOYMENTMETHODSETTING._serialized_start=2975
  _DEPLOYMENTMETHODSETTING._serialized_end=3325
  _DEPLOYMENTSTAGEDESCRIPTION._serialized_start=3328
  _DEPLOYMENTSTAGEDESCRIPTION._serialized_end=4308
  _DEPLOYMENTSTAGEDESCRIPTION_TAGSENTRY._serialized_start=1458
  _DEPLOYMENTSTAGEDESCRIPTION_TAGSENTRY._serialized_end=1501
  _DEPLOYMENTSTAGEDESCRIPTION_VARIABLESENTRY._serialized_start=4260
  _DEPLOYMENTSTAGEDESCRIPTION_VARIABLESENTRY._serialized_end=4308
  _DEPLOYMENT._serialized_start=4311
  _DEPLOYMENT._serialized_end=4625
  _DOCUMENTATIONPARTLOCATION._serialized_start=4628
  _DOCUMENTATIONPARTLOCATION._serialized_end=4777
  _DOCUMENTATIONPART._serialized_start=4780
  _DOCUMENTATIONPART._serialized_end=4970
  _DOCUMENTATIONVERSION._serialized_start=4973
  _DOCUMENTATIONVERSION._serialized_end=5125
  _DOMAINNAMEENDPOINTCONFIGURATION._serialized_start=5127
  _DOMAINNAMEENDPOINTCONFIGURATION._serialized_end=5232
  _DOMAINNAMEMUTUALTLSAUTHENTICATION._serialized_start=5235
  _DOMAINNAMEMUTUALTLSAUTHENTICATION._serialized_end=5379
  _DOMAINNAME._serialized_start=5382
  _DOMAINNAME._serialized_end=5856
  _DOMAINNAME_TAGSENTRY._serialized_start=1458
  _DOMAINNAME_TAGSENTRY._serialized_end=1501
  _GATEWAYRESPONSE._serialized_start=5859
  _GATEWAYRESPONSE._serialized_end=6309
  _GATEWAYRESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=6194
  _GATEWAYRESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=6251
  _GATEWAYRESPONSE_RESPONSETEMPLATESENTRY._serialized_start=6253
  _GATEWAYRESPONSE_RESPONSETEMPLATESENTRY._serialized_end=6309
  _METHODINTEGRATIONRESPONSE._serialized_start=6312
  _METHODINTEGRATIONRESPONSE._serialized_end=6801
  _METHODINTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=6194
  _METHODINTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=6251
  _METHODINTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_start=6253
  _METHODINTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_end=6309
  _METHODINTEGRATION._serialized_start=6804
  _METHODINTEGRATION._serialized_end=7528
  _METHODINTEGRATION_REQUESTPARAMETERSENTRY._serialized_start=7415
  _METHODINTEGRATION_REQUESTPARAMETERSENTRY._serialized_end=7471
  _METHODINTEGRATION_REQUESTTEMPLATESENTRY._serialized_start=7473
  _METHODINTEGRATION_REQUESTTEMPLATESENTRY._serialized_end=7528
  _METHODMETHODRESPONSE._serialized_start=7531
  _METHODMETHODRESPONSE._serialized_end=7943
  _METHODMETHODRESPONSE_RESPONSEMODELSENTRY._serialized_start=7831
  _METHODMETHODRESPONSE_RESPONSEMODELSENTRY._serialized_end=7884
  _METHODMETHODRESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=6194
  _METHODMETHODRESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=6251
  _METHOD._serialized_start=7946
  _METHOD._serialized_end=8677
  _METHOD_REQUESTMODELSENTRY._serialized_start=8567
  _METHOD_REQUESTMODELSENTRY._serialized_end=8619
  _METHOD_REQUESTPARAMETERSENTRY._serialized_start=7415
  _METHOD_REQUESTPARAMETERSENTRY._serialized_end=7471
  _MODEL._serialized_start=8680
  _MODEL._serialized_end=8932
  _MODEL_SCHEMAENTRY._serialized_start=8887
  _MODEL_SCHEMAENTRY._serialized_end=8932
  _REQUESTVALIDATOR._serialized_start=8935
  _REQUESTVALIDATOR._serialized_end=9113
  _RESOURCE._serialized_start=9115
  _RESOURCE._serialized_end=9241
  _RESTAPIS3LOCATION._serialized_start=9244
  _RESTAPIS3LOCATION._serialized_end=9381
  _RESTAPIENDPOINTCONFIGURATION._serialized_start=9384
  _RESTAPIENDPOINTCONFIGURATION._serialized_end=9512
  _RESTAPI._serialized_start=9515
  _RESTAPI._serialized_end=10330
  _RESTAPI_BODYENTRY._serialized_start=10191
  _RESTAPI_BODYENTRY._serialized_end=10234
  _RESTAPI_PARAMETERSENTRY._serialized_start=10236
  _RESTAPI_PARAMETERSENTRY._serialized_end=10285
  _RESTAPI_TAGSENTRY._serialized_start=1458
  _RESTAPI_TAGSENTRY._serialized_end=1501
  _STAGEACCESSLOGSETTING._serialized_start=10332
  _STAGEACCESSLOGSETTING._serialized_end=10453
  _STAGECANARYSETTING._serialized_start=10456
  _STAGECANARYSETTING._serialized_end=10779
  _STAGECANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_start=2470
  _STAGECANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_end=2531
  _STAGEMETHODSETTING._serialized_start=10782
  _STAGEMETHODSETTING._serialized_end=11127
  _STAGE._serialized_start=11130
  _STAGE._serialized_end=11872
  _STAGE_TAGSENTRY._serialized_start=1458
  _STAGE_TAGSENTRY._serialized_end=1501
  _STAGE_VARIABLESENTRY._serialized_start=4260
  _STAGE_VARIABLESENTRY._serialized_end=4308
  _USAGEPLANAPISTAGE._serialized_start=11875
  _USAGEPLANAPISTAGE._serialized_end=12110
  _USAGEPLANAPISTAGE_THROTTLEENTRY._serialized_start=12063
  _USAGEPLANAPISTAGE_THROTTLEENTRY._serialized_end=12110
  _USAGEPLANQUOTASETTINGS._serialized_start=12113
  _USAGEPLANQUOTASETTINGS._serialized_end=12241
  _USAGEPLANTHROTTLESETTINGS._serialized_start=12243
  _USAGEPLANTHROTTLESETTINGS._serialized_end=12368
  _USAGEPLAN._serialized_start=12371
  _USAGEPLAN._serialized_end=12800
  _USAGEPLAN_TAGSENTRY._serialized_start=1458
  _USAGEPLAN_TAGSENTRY._serialized_end=1501
  _USAGEPLANKEY._serialized_start=12803
  _USAGEPLANKEY._serialized_end=12931
  _VPCLINK._serialized_start=12933
  _VPCLINK._serialized_end=13055
# @@protoc_insertion_point(module_scope)
