"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DeliveryStreamElasticsearchBufferingHints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTERVAL_IN_SECONDS_FIELD_NUMBER: builtins.int
    SIZE_IN_MBS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    interval_in_seconds: builtins.int
    size_in_mbs: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        interval_in_seconds: builtins.int = ...,
        size_in_mbs: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["interval_in_seconds", b"interval_in_seconds", "resource_info", b"resource_info", "size_in_mbs", b"size_in_mbs"]) -> None: ...

global___DeliveryStreamElasticsearchBufferingHints = DeliveryStreamElasticsearchBufferingHints

@typing_extensions.final
class DeliveryStreamCloudWatchLoggingOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    LOG_STREAM_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    log_group_name: builtins.str
    log_stream_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        log_group_name: builtins.str = ...,
        log_stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "log_group_name", b"log_group_name", "log_stream_name", b"log_stream_name", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamCloudWatchLoggingOptions = DeliveryStreamCloudWatchLoggingOptions

@typing_extensions.final
class DeliveryStreamProcessorParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETER_NAME_FIELD_NUMBER: builtins.int
    PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    parameter_name: builtins.str
    parameter_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameter_name: builtins.str = ...,
        parameter_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_name", b"parameter_name", "parameter_value", b"parameter_value", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamProcessorParameter = DeliveryStreamProcessorParameter

@typing_extensions.final
class DeliveryStreamProcessor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryStreamProcessorParameter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameters: collections.abc.Iterable[global___DeliveryStreamProcessorParameter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamProcessor = DeliveryStreamProcessor

@typing_extensions.final
class DeliveryStreamProcessingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    PROCESSORS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    @property
    def processors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryStreamProcessor]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        processors: collections.abc.Iterable[global___DeliveryStreamProcessor] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "processors", b"processors", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamProcessingConfiguration = DeliveryStreamProcessingConfiguration

@typing_extensions.final
class DeliveryStreamElasticsearchRetryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamElasticsearchRetryOptions = DeliveryStreamElasticsearchRetryOptions

@typing_extensions.final
class DeliveryStreamBufferingHints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTERVAL_IN_SECONDS_FIELD_NUMBER: builtins.int
    SIZE_IN_MBS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    interval_in_seconds: builtins.int
    size_in_mbs: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        interval_in_seconds: builtins.int = ...,
        size_in_mbs: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["interval_in_seconds", b"interval_in_seconds", "resource_info", b"resource_info", "size_in_mbs", b"size_in_mbs"]) -> None: ...

global___DeliveryStreamBufferingHints = DeliveryStreamBufferingHints

@typing_extensions.final
class DeliveryStreamKMSEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    aws_kms_key_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_kms_key_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_kms_key_arn", b"aws_kms_key_arn", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamKMSEncryptionConfig = DeliveryStreamKMSEncryptionConfig

@typing_extensions.final
class DeliveryStreamEncryptionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    NO_ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def kms_encryption_config(self) -> global___DeliveryStreamKMSEncryptionConfig: ...
    no_encryption_config: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_encryption_config: global___DeliveryStreamKMSEncryptionConfig | None = ...,
        no_encryption_config: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kms_encryption_config", b"kms_encryption_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_encryption_config", b"kms_encryption_config", "no_encryption_config", b"no_encryption_config", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamEncryptionConfiguration = DeliveryStreamEncryptionConfiguration

@typing_extensions.final
class DeliveryStreamS3DestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_ARN_FIELD_NUMBER: builtins.int
    BUFFERING_HINTS_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    COMPRESSION_FORMAT_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    ERROR_OUTPUT_PREFIX_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_arn: builtins.str
    @property
    def buffering_hints(self) -> global___DeliveryStreamBufferingHints: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    compression_format: builtins.str
    @property
    def encryption_configuration(self) -> global___DeliveryStreamEncryptionConfiguration: ...
    error_output_prefix: builtins.str
    prefix: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_arn: builtins.str = ...,
        buffering_hints: global___DeliveryStreamBufferingHints | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        compression_format: builtins.str = ...,
        encryption_configuration: global___DeliveryStreamEncryptionConfiguration | None = ...,
        error_output_prefix: builtins.str = ...,
        prefix: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "encryption_configuration", b"encryption_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_arn", b"bucket_arn", "buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "compression_format", b"compression_format", "encryption_configuration", b"encryption_configuration", "error_output_prefix", b"error_output_prefix", "prefix", b"prefix", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___DeliveryStreamS3DestinationConfiguration = DeliveryStreamS3DestinationConfiguration

@typing_extensions.final
class DeliveryStreamVpcConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    role_arn: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        role_arn: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "role_arn", b"role_arn", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___DeliveryStreamVpcConfiguration = DeliveryStreamVpcConfiguration

@typing_extensions.final
class DeliveryStreamElasticsearchDestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUFFERING_HINTS_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    DOMAIN_ARN_FIELD_NUMBER: builtins.int
    INDEX_NAME_FIELD_NUMBER: builtins.int
    INDEX_ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    RETRY_OPTIONS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    CLUSTER_ENDPOINT_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    VPC_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def buffering_hints(self) -> global___DeliveryStreamElasticsearchBufferingHints: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    domain_arn: builtins.str
    index_name: builtins.str
    index_rotation_period: builtins.str
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    @property
    def retry_options(self) -> global___DeliveryStreamElasticsearchRetryOptions: ...
    role_arn: builtins.str
    s3_backup_mode: builtins.str
    @property
    def s3_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    cluster_endpoint: builtins.str
    type_name: builtins.str
    @property
    def vpc_configuration(self) -> global___DeliveryStreamVpcConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        buffering_hints: global___DeliveryStreamElasticsearchBufferingHints | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        domain_arn: builtins.str = ...,
        index_name: builtins.str = ...,
        index_rotation_period: builtins.str = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        retry_options: global___DeliveryStreamElasticsearchRetryOptions | None = ...,
        role_arn: builtins.str = ...,
        s3_backup_mode: builtins.str = ...,
        s3_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        cluster_endpoint: builtins.str = ...,
        type_name: builtins.str = ...,
        vpc_configuration: global___DeliveryStreamVpcConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_configuration", b"s3_configuration", "vpc_configuration", b"vpc_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "cluster_endpoint", b"cluster_endpoint", "domain_arn", b"domain_arn", "index_name", b"index_name", "index_rotation_period", b"index_rotation_period", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "role_arn", b"role_arn", "s3_backup_mode", b"s3_backup_mode", "s3_configuration", b"s3_configuration", "type_name", b"type_name", "vpc_configuration", b"vpc_configuration"]) -> None: ...

global___DeliveryStreamElasticsearchDestinationConfiguration = DeliveryStreamElasticsearchDestinationConfiguration

@typing_extensions.final
class DeliveryStreamHiveJsonSerDe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIMESTAMP_FORMATS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def timestamp_formats(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        timestamp_formats: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timestamp_formats", b"timestamp_formats"]) -> None: ...

global___DeliveryStreamHiveJsonSerDe = DeliveryStreamHiveJsonSerDe

@typing_extensions.final
class DeliveryStreamOpenXJsonSerDe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ColumnToJsonKeyMappingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CASE_INSENSITIVE_FIELD_NUMBER: builtins.int
    COLUMN_TO_JSON_KEY_MAPPINGS_FIELD_NUMBER: builtins.int
    CONVERT_DOTS_IN_JSON_KEYS_TO_UNDERSCORES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    case_insensitive: builtins.bool
    @property
    def column_to_json_key_mappings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    convert_dots_in_json_keys_to_underscores: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        case_insensitive: builtins.bool = ...,
        column_to_json_key_mappings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        convert_dots_in_json_keys_to_underscores: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["case_insensitive", b"case_insensitive", "column_to_json_key_mappings", b"column_to_json_key_mappings", "convert_dots_in_json_keys_to_underscores", b"convert_dots_in_json_keys_to_underscores", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamOpenXJsonSerDe = DeliveryStreamOpenXJsonSerDe

@typing_extensions.final
class DeliveryStreamDeserializer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HIVE_JSON_SER_DE_FIELD_NUMBER: builtins.int
    OPEN_X_JSON_SER_DE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def hive_json_ser_de(self) -> global___DeliveryStreamHiveJsonSerDe: ...
    @property
    def open_x_json_ser_de(self) -> global___DeliveryStreamOpenXJsonSerDe: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hive_json_ser_de: global___DeliveryStreamHiveJsonSerDe | None = ...,
        open_x_json_ser_de: global___DeliveryStreamOpenXJsonSerDe | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hive_json_ser_de", b"hive_json_ser_de", "open_x_json_ser_de", b"open_x_json_ser_de", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hive_json_ser_de", b"hive_json_ser_de", "open_x_json_ser_de", b"open_x_json_ser_de", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamDeserializer = DeliveryStreamDeserializer

@typing_extensions.final
class DeliveryStreamInputFormatConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESERIALIZER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def deserializer(self) -> global___DeliveryStreamDeserializer: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deserializer: global___DeliveryStreamDeserializer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deserializer", b"deserializer", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deserializer", b"deserializer", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamInputFormatConfiguration = DeliveryStreamInputFormatConfiguration

@typing_extensions.final
class DeliveryStreamOrcSerDe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_BYTES_FIELD_NUMBER: builtins.int
    BLOOM_FILTER_COLUMNS_FIELD_NUMBER: builtins.int
    BLOOM_FILTER_FALSE_POSITIVE_PROBABILITY_FIELD_NUMBER: builtins.int
    COMPRESSION_FIELD_NUMBER: builtins.int
    DICTIONARY_KEY_THRESHOLD_FIELD_NUMBER: builtins.int
    ENABLE_PADDING_FIELD_NUMBER: builtins.int
    FORMAT_VERSION_FIELD_NUMBER: builtins.int
    PADDING_TOLERANCE_FIELD_NUMBER: builtins.int
    ROW_INDEX_STRIDE_FIELD_NUMBER: builtins.int
    STRIPE_SIZE_BYTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    block_size_bytes: builtins.int
    @property
    def bloom_filter_columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    bloom_filter_false_positive_probability: builtins.float
    compression: builtins.str
    dictionary_key_threshold: builtins.float
    enable_padding: builtins.bool
    format_version: builtins.str
    padding_tolerance: builtins.float
    row_index_stride: builtins.int
    stripe_size_bytes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        block_size_bytes: builtins.int = ...,
        bloom_filter_columns: collections.abc.Iterable[builtins.str] | None = ...,
        bloom_filter_false_positive_probability: builtins.float = ...,
        compression: builtins.str = ...,
        dictionary_key_threshold: builtins.float = ...,
        enable_padding: builtins.bool = ...,
        format_version: builtins.str = ...,
        padding_tolerance: builtins.float = ...,
        row_index_stride: builtins.int = ...,
        stripe_size_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_size_bytes", b"block_size_bytes", "bloom_filter_columns", b"bloom_filter_columns", "bloom_filter_false_positive_probability", b"bloom_filter_false_positive_probability", "compression", b"compression", "dictionary_key_threshold", b"dictionary_key_threshold", "enable_padding", b"enable_padding", "format_version", b"format_version", "padding_tolerance", b"padding_tolerance", "resource_info", b"resource_info", "row_index_stride", b"row_index_stride", "stripe_size_bytes", b"stripe_size_bytes"]) -> None: ...

global___DeliveryStreamOrcSerDe = DeliveryStreamOrcSerDe

@typing_extensions.final
class DeliveryStreamParquetSerDe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_BYTES_FIELD_NUMBER: builtins.int
    COMPRESSION_FIELD_NUMBER: builtins.int
    ENABLE_DICTIONARY_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_PADDING_BYTES_FIELD_NUMBER: builtins.int
    PAGE_SIZE_BYTES_FIELD_NUMBER: builtins.int
    WRITER_VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    block_size_bytes: builtins.int
    compression: builtins.str
    enable_dictionary_compression: builtins.bool
    max_padding_bytes: builtins.int
    page_size_bytes: builtins.int
    writer_version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        block_size_bytes: builtins.int = ...,
        compression: builtins.str = ...,
        enable_dictionary_compression: builtins.bool = ...,
        max_padding_bytes: builtins.int = ...,
        page_size_bytes: builtins.int = ...,
        writer_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_size_bytes", b"block_size_bytes", "compression", b"compression", "enable_dictionary_compression", b"enable_dictionary_compression", "max_padding_bytes", b"max_padding_bytes", "page_size_bytes", b"page_size_bytes", "resource_info", b"resource_info", "writer_version", b"writer_version"]) -> None: ...

global___DeliveryStreamParquetSerDe = DeliveryStreamParquetSerDe

@typing_extensions.final
class DeliveryStreamSerializer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ORC_SER_DE_FIELD_NUMBER: builtins.int
    PARQUET_SER_DE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def orc_ser_de(self) -> global___DeliveryStreamOrcSerDe: ...
    @property
    def parquet_ser_de(self) -> global___DeliveryStreamParquetSerDe: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        orc_ser_de: global___DeliveryStreamOrcSerDe | None = ...,
        parquet_ser_de: global___DeliveryStreamParquetSerDe | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["orc_ser_de", b"orc_ser_de", "parquet_ser_de", b"parquet_ser_de", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["orc_ser_de", b"orc_ser_de", "parquet_ser_de", b"parquet_ser_de", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamSerializer = DeliveryStreamSerializer

@typing_extensions.final
class DeliveryStreamOutputFormatConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SERIALIZER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def serializer(self) -> global___DeliveryStreamSerializer: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        serializer: global___DeliveryStreamSerializer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "serializer", b"serializer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "serializer", b"serializer"]) -> None: ...

global___DeliveryStreamOutputFormatConfiguration = DeliveryStreamOutputFormatConfiguration

@typing_extensions.final
class DeliveryStreamSchemaConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    catalog_id: builtins.str
    database_name: builtins.str
    region: builtins.str
    role_arn: builtins.str
    table_name: builtins.str
    version_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        catalog_id: builtins.str = ...,
        database_name: builtins.str = ...,
        region: builtins.str = ...,
        role_arn: builtins.str = ...,
        table_name: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "database_name", b"database_name", "region", b"region", "resource_info", b"resource_info", "role_arn", b"role_arn", "table_name", b"table_name", "version_id", b"version_id"]) -> None: ...

global___DeliveryStreamSchemaConfiguration = DeliveryStreamSchemaConfiguration

@typing_extensions.final
class DeliveryStreamDataFormatConversionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    INPUT_FORMAT_CONFIGURATION_FIELD_NUMBER: builtins.int
    OUTPUT_FORMAT_CONFIGURATION_FIELD_NUMBER: builtins.int
    SCHEMA_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    @property
    def input_format_configuration(self) -> global___DeliveryStreamInputFormatConfiguration: ...
    @property
    def output_format_configuration(self) -> global___DeliveryStreamOutputFormatConfiguration: ...
    @property
    def schema_configuration(self) -> global___DeliveryStreamSchemaConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        input_format_configuration: global___DeliveryStreamInputFormatConfiguration | None = ...,
        output_format_configuration: global___DeliveryStreamOutputFormatConfiguration | None = ...,
        schema_configuration: global___DeliveryStreamSchemaConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input_format_configuration", b"input_format_configuration", "output_format_configuration", b"output_format_configuration", "resource_info", b"resource_info", "schema_configuration", b"schema_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "input_format_configuration", b"input_format_configuration", "output_format_configuration", b"output_format_configuration", "resource_info", b"resource_info", "schema_configuration", b"schema_configuration"]) -> None: ...

global___DeliveryStreamDataFormatConversionConfiguration = DeliveryStreamDataFormatConversionConfiguration

@typing_extensions.final
class DeliveryStreamExtendedS3DestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_ARN_FIELD_NUMBER: builtins.int
    BUFFERING_HINTS_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    COMPRESSION_FORMAT_FIELD_NUMBER: builtins.int
    DATA_FORMAT_CONVERSION_CONFIGURATION_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    ERROR_OUTPUT_PREFIX_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    S3_BACKUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_arn: builtins.str
    @property
    def buffering_hints(self) -> global___DeliveryStreamBufferingHints: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    compression_format: builtins.str
    @property
    def data_format_conversion_configuration(self) -> global___DeliveryStreamDataFormatConversionConfiguration: ...
    @property
    def encryption_configuration(self) -> global___DeliveryStreamEncryptionConfiguration: ...
    error_output_prefix: builtins.str
    prefix: builtins.str
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    role_arn: builtins.str
    @property
    def s3_backup_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    s3_backup_mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_arn: builtins.str = ...,
        buffering_hints: global___DeliveryStreamBufferingHints | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        compression_format: builtins.str = ...,
        data_format_conversion_configuration: global___DeliveryStreamDataFormatConversionConfiguration | None = ...,
        encryption_configuration: global___DeliveryStreamEncryptionConfiguration | None = ...,
        error_output_prefix: builtins.str = ...,
        prefix: builtins.str = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        role_arn: builtins.str = ...,
        s3_backup_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        s3_backup_mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "data_format_conversion_configuration", b"data_format_conversion_configuration", "encryption_configuration", b"encryption_configuration", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "s3_backup_configuration", b"s3_backup_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_arn", b"bucket_arn", "buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "compression_format", b"compression_format", "data_format_conversion_configuration", b"data_format_conversion_configuration", "encryption_configuration", b"encryption_configuration", "error_output_prefix", b"error_output_prefix", "prefix", b"prefix", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "role_arn", b"role_arn", "s3_backup_configuration", b"s3_backup_configuration", "s3_backup_mode", b"s3_backup_mode"]) -> None: ...

global___DeliveryStreamExtendedS3DestinationConfiguration = DeliveryStreamExtendedS3DestinationConfiguration

@typing_extensions.final
class DeliveryStreamKinesisStreamSourceConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KINESIS_STREAM_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kinesis_stream_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kinesis_stream_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kinesis_stream_arn", b"kinesis_stream_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___DeliveryStreamKinesisStreamSourceConfiguration = DeliveryStreamKinesisStreamSourceConfiguration

@typing_extensions.final
class DeliveryStreamCopyCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COPY_OPTIONS_FIELD_NUMBER: builtins.int
    DATA_TABLE_COLUMNS_FIELD_NUMBER: builtins.int
    DATA_TABLE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    copy_options: builtins.str
    data_table_columns: builtins.str
    data_table_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        copy_options: builtins.str = ...,
        data_table_columns: builtins.str = ...,
        data_table_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["copy_options", b"copy_options", "data_table_columns", b"data_table_columns", "data_table_name", b"data_table_name", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamCopyCommand = DeliveryStreamCopyCommand

@typing_extensions.final
class DeliveryStreamRedshiftRetryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamRedshiftRetryOptions = DeliveryStreamRedshiftRetryOptions

@typing_extensions.final
class DeliveryStreamRedshiftDestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    CLUSTER_J_DB_C_U_R_L_FIELD_NUMBER: builtins.int
    COPY_COMMAND_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    RETRY_OPTIONS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    S3_BACKUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    cluster_j_db_c_u_r_l: builtins.str
    @property
    def copy_command(self) -> global___DeliveryStreamCopyCommand: ...
    password: builtins.str
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    @property
    def retry_options(self) -> global___DeliveryStreamRedshiftRetryOptions: ...
    role_arn: builtins.str
    @property
    def s3_backup_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    s3_backup_mode: builtins.str
    @property
    def s3_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        cluster_j_db_c_u_r_l: builtins.str = ...,
        copy_command: global___DeliveryStreamCopyCommand | None = ...,
        password: builtins.str = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        retry_options: global___DeliveryStreamRedshiftRetryOptions | None = ...,
        role_arn: builtins.str = ...,
        s3_backup_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        s3_backup_mode: builtins.str = ...,
        s3_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_logging_options", b"cloud_watch_logging_options", "copy_command", b"copy_command", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_backup_configuration", b"s3_backup_configuration", "s3_configuration", b"s3_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logging_options", b"cloud_watch_logging_options", "cluster_j_db_c_u_r_l", b"cluster_j_db_c_u_r_l", "copy_command", b"copy_command", "password", b"password", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "role_arn", b"role_arn", "s3_backup_configuration", b"s3_backup_configuration", "s3_backup_mode", b"s3_backup_mode", "s3_configuration", b"s3_configuration", "username", b"username"]) -> None: ...

global___DeliveryStreamRedshiftDestinationConfiguration = DeliveryStreamRedshiftDestinationConfiguration

@typing_extensions.final
class DeliveryStreamSplunkRetryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamSplunkRetryOptions = DeliveryStreamSplunkRetryOptions

@typing_extensions.final
class DeliveryStreamSplunkDestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    HECACKNOWLEDGMENT_TIMEOUT_IN_SECONDS_FIELD_NUMBER: builtins.int
    HEC_ENDPOINT_FIELD_NUMBER: builtins.int
    HEC_ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    HEC_TOKEN_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    RETRY_OPTIONS_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    hecacknowledgment_timeout_in_seconds: builtins.int
    hec_endpoint: builtins.str
    hec_endpoint_type: builtins.str
    hec_token: builtins.str
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    @property
    def retry_options(self) -> global___DeliveryStreamSplunkRetryOptions: ...
    s3_backup_mode: builtins.str
    @property
    def s3_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        hecacknowledgment_timeout_in_seconds: builtins.int = ...,
        hec_endpoint: builtins.str = ...,
        hec_endpoint_type: builtins.str = ...,
        hec_token: builtins.str = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        retry_options: global___DeliveryStreamSplunkRetryOptions | None = ...,
        s3_backup_mode: builtins.str = ...,
        s3_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_logging_options", b"cloud_watch_logging_options", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_configuration", b"s3_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logging_options", b"cloud_watch_logging_options", "hec_endpoint", b"hec_endpoint", "hec_endpoint_type", b"hec_endpoint_type", "hec_token", b"hec_token", "hecacknowledgment_timeout_in_seconds", b"hecacknowledgment_timeout_in_seconds", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_backup_mode", b"s3_backup_mode", "s3_configuration", b"s3_configuration"]) -> None: ...

global___DeliveryStreamSplunkDestinationConfiguration = DeliveryStreamSplunkDestinationConfiguration

@typing_extensions.final
class DeliveryStreamHttpEndpointConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ACCESS_KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    url: builtins.str
    access_key: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        url: builtins.str = ...,
        access_key: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "name", b"name", "resource_info", b"resource_info", "url", b"url"]) -> None: ...

global___DeliveryStreamHttpEndpointConfiguration = DeliveryStreamHttpEndpointConfiguration

@typing_extensions.final
class DeliveryStreamHttpEndpointCommonAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    attribute_name: builtins.str
    attribute_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attribute_name: builtins.str = ...,
        attribute_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute_name", b"attribute_name", "attribute_value", b"attribute_value", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamHttpEndpointCommonAttribute = DeliveryStreamHttpEndpointCommonAttribute

@typing_extensions.final
class DeliveryStreamHttpEndpointRequestConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_ENCODING_FIELD_NUMBER: builtins.int
    COMMON_ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content_encoding: builtins.str
    @property
    def common_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryStreamHttpEndpointCommonAttribute]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content_encoding: builtins.str = ...,
        common_attributes: collections.abc.Iterable[global___DeliveryStreamHttpEndpointCommonAttribute] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_attributes", b"common_attributes", "content_encoding", b"content_encoding", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamHttpEndpointRequestConfiguration = DeliveryStreamHttpEndpointRequestConfiguration

@typing_extensions.final
class DeliveryStreamRetryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamRetryOptions = DeliveryStreamRetryOptions

@typing_extensions.final
class DeliveryStreamHttpEndpointDestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIGURATION_FIELD_NUMBER: builtins.int
    REQUEST_CONFIGURATION_FIELD_NUMBER: builtins.int
    BUFFERING_HINTS_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    RETRY_OPTIONS_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    role_arn: builtins.str
    @property
    def endpoint_configuration(self) -> global___DeliveryStreamHttpEndpointConfiguration: ...
    @property
    def request_configuration(self) -> global___DeliveryStreamHttpEndpointRequestConfiguration: ...
    @property
    def buffering_hints(self) -> global___DeliveryStreamBufferingHints: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    @property
    def retry_options(self) -> global___DeliveryStreamRetryOptions: ...
    s3_backup_mode: builtins.str
    @property
    def s3_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        role_arn: builtins.str = ...,
        endpoint_configuration: global___DeliveryStreamHttpEndpointConfiguration | None = ...,
        request_configuration: global___DeliveryStreamHttpEndpointRequestConfiguration | None = ...,
        buffering_hints: global___DeliveryStreamBufferingHints | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        retry_options: global___DeliveryStreamRetryOptions | None = ...,
        s3_backup_mode: builtins.str = ...,
        s3_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "endpoint_configuration", b"endpoint_configuration", "processing_configuration", b"processing_configuration", "request_configuration", b"request_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_configuration", b"s3_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "endpoint_configuration", b"endpoint_configuration", "processing_configuration", b"processing_configuration", "request_configuration", b"request_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "role_arn", b"role_arn", "s3_backup_mode", b"s3_backup_mode", "s3_configuration", b"s3_configuration"]) -> None: ...

global___DeliveryStreamHttpEndpointDestinationConfiguration = DeliveryStreamHttpEndpointDestinationConfiguration

@typing_extensions.final
class DeliveryStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELIVERY_STREAM_NAME_FIELD_NUMBER: builtins.int
    DELIVERY_STREAM_TYPE_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    EXTENDED_S3_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    KINESIS_STREAM_SOURCE_CONFIGURATION_FIELD_NUMBER: builtins.int
    REDSHIFT_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    S3_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    SPLUNK_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    HTTP_ENDPOINT_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delivery_stream_name: builtins.str
    delivery_stream_type: builtins.str
    @property
    def elasticsearch_destination_configuration(self) -> global___DeliveryStreamElasticsearchDestinationConfiguration: ...
    @property
    def extended_s3_destination_configuration(self) -> global___DeliveryStreamExtendedS3DestinationConfiguration: ...
    @property
    def kinesis_stream_source_configuration(self) -> global___DeliveryStreamKinesisStreamSourceConfiguration: ...
    @property
    def redshift_destination_configuration(self) -> global___DeliveryStreamRedshiftDestinationConfiguration: ...
    @property
    def s3_destination_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    @property
    def splunk_destination_configuration(self) -> global___DeliveryStreamSplunkDestinationConfiguration: ...
    @property
    def http_endpoint_destination_configuration(self) -> global___DeliveryStreamHttpEndpointDestinationConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delivery_stream_name: builtins.str = ...,
        delivery_stream_type: builtins.str = ...,
        elasticsearch_destination_configuration: global___DeliveryStreamElasticsearchDestinationConfiguration | None = ...,
        extended_s3_destination_configuration: global___DeliveryStreamExtendedS3DestinationConfiguration | None = ...,
        kinesis_stream_source_configuration: global___DeliveryStreamKinesisStreamSourceConfiguration | None = ...,
        redshift_destination_configuration: global___DeliveryStreamRedshiftDestinationConfiguration | None = ...,
        s3_destination_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        splunk_destination_configuration: global___DeliveryStreamSplunkDestinationConfiguration | None = ...,
        http_endpoint_destination_configuration: global___DeliveryStreamHttpEndpointDestinationConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["elasticsearch_destination_configuration", b"elasticsearch_destination_configuration", "extended_s3_destination_configuration", b"extended_s3_destination_configuration", "http_endpoint_destination_configuration", b"http_endpoint_destination_configuration", "kinesis_stream_source_configuration", b"kinesis_stream_source_configuration", "redshift_destination_configuration", b"redshift_destination_configuration", "resource_info", b"resource_info", "s3_destination_configuration", b"s3_destination_configuration", "splunk_destination_configuration", b"splunk_destination_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_stream_name", b"delivery_stream_name", "delivery_stream_type", b"delivery_stream_type", "elasticsearch_destination_configuration", b"elasticsearch_destination_configuration", "extended_s3_destination_configuration", b"extended_s3_destination_configuration", "http_endpoint_destination_configuration", b"http_endpoint_destination_configuration", "kinesis_stream_source_configuration", b"kinesis_stream_source_configuration", "redshift_destination_configuration", b"redshift_destination_configuration", "resource_info", b"resource_info", "s3_destination_configuration", b"s3_destination_configuration", "splunk_destination_configuration", b"splunk_destination_configuration"]) -> None: ...

global___DeliveryStream = DeliveryStream

@typing_extensions.final
class KinesisFirehose(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_STREAM_FIELD_NUMBER: builtins.int
    @property
    def delivery_stream(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryStream]: ...
    def __init__(
        self,
        *,
        delivery_stream: collections.abc.Iterable[global___DeliveryStream] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_stream", b"delivery_stream"]) -> None: ...

global___KinesisFirehose = KinesisFirehose
