# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_groundstation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_groundstation.proto\x12\x1doak9.tython.aws.groundstation\x1a\x13shared/shared.proto\"\xba\x02\n\x06\x43onfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\x04tags\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.groundstation.Config.TagsEntry\x12J\n\x0b\x63onfig_data\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.groundstation.Config.ConfigDataEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x43onfigDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe5\x01\n\rGroundStation\x12\x35\n\x06\x63onfig\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.groundstation.Config\x12U\n\x17\x64\x61taflow_endpoint_group\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.groundstation.DataflowEndpointGroup\x12\x46\n\x0fmission_profile\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.groundstation.MissionProfile\"\xa1\x01\n$DataflowEndpointGroupSecurityDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nsubnet_ids\x18\x02 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x03 \x03(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"y\n\"DataflowEndpointGroupSocketAddress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\"\xdf\x01\n%DataflowEndpointGroupDataflowEndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12R\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.groundstation.DataflowEndpointGroupSocketAddress\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0b\n\x03mtu\x18\x05 \x01(\x05\"\x96\x02\n$DataflowEndpointGroupEndpointDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x10security_details\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.groundstation.DataflowEndpointGroupSecurityDetails\x12V\n\x08\x65ndpoint\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.groundstation.DataflowEndpointGroupDataflowEndpoint\"\xaa\x02\n\x15\x44\x61taflowEndpointGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x10\x65ndpoint_details\x18\x02 \x03(\x0b\x32\x43.oak9.tython.aws.groundstation.DataflowEndpointGroupEndpointDetails\x12L\n\x04tags\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.groundstation.DataflowEndpointGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x1aMissionProfileDataflowEdge\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x03 \x01(\t\"\xc3\x03\n\x0eMissionProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n!contact_pre_pass_duration_seconds\x18\x03 \x01(\x05\x12*\n\"contact_post_pass_duration_seconds\x18\x04 \x01(\x05\x12/\n\'minimum_viable_contact_duration_seconds\x18\x05 \x01(\x05\x12Q\n\x0e\x64\x61taflow_edges\x18\x06 \x03(\x0b\x32\x39.oak9.tython.aws.groundstation.MissionProfileDataflowEdge\x12\x1b\n\x13tracking_config_arn\x18\x07 \x01(\t\x12\x45\n\x04tags\x18\x08 \x03(\x0b\x32\x37.oak9.tython.aws.groundstation.MissionProfile.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_groundstation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONFIG_TAGSENTRY._options = None
  _CONFIG_TAGSENTRY._serialized_options = b'8\001'
  _CONFIG_CONFIGDATAENTRY._options = None
  _CONFIG_CONFIGDATAENTRY._serialized_options = b'8\001'
  _DATAFLOWENDPOINTGROUP_TAGSENTRY._options = None
  _DATAFLOWENDPOINTGROUP_TAGSENTRY._serialized_options = b'8\001'
  _MISSIONPROFILE_TAGSENTRY._options = None
  _MISSIONPROFILE_TAGSENTRY._serialized_options = b'8\001'
  _CONFIG._serialized_start=84
  _CONFIG._serialized_end=398
  _CONFIG_TAGSENTRY._serialized_start=304
  _CONFIG_TAGSENTRY._serialized_end=347
  _CONFIG_CONFIGDATAENTRY._serialized_start=349
  _CONFIG_CONFIGDATAENTRY._serialized_end=398
  _GROUNDSTATION._serialized_start=401
  _GROUNDSTATION._serialized_end=630
  _DATAFLOWENDPOINTGROUPSECURITYDETAILS._serialized_start=633
  _DATAFLOWENDPOINTGROUPSECURITYDETAILS._serialized_end=794
  _DATAFLOWENDPOINTGROUPSOCKETADDRESS._serialized_start=796
  _DATAFLOWENDPOINTGROUPSOCKETADDRESS._serialized_end=917
  _DATAFLOWENDPOINTGROUPDATAFLOWENDPOINT._serialized_start=920
  _DATAFLOWENDPOINTGROUPDATAFLOWENDPOINT._serialized_end=1143
  _DATAFLOWENDPOINTGROUPENDPOINTDETAILS._serialized_start=1146
  _DATAFLOWENDPOINTGROUPENDPOINTDETAILS._serialized_end=1424
  _DATAFLOWENDPOINTGROUP._serialized_start=1427
  _DATAFLOWENDPOINTGROUP._serialized_end=1725
  _DATAFLOWENDPOINTGROUP_TAGSENTRY._serialized_start=304
  _DATAFLOWENDPOINTGROUP_TAGSENTRY._serialized_end=347
  _MISSIONPROFILEDATAFLOWEDGE._serialized_start=1727
  _MISSIONPROFILEDATAFLOWEDGE._serialized_end=1849
  _MISSIONPROFILE._serialized_start=1852
  _MISSIONPROFILE._serialized_end=2303
  _MISSIONPROFILE_TAGSENTRY._serialized_start=304
  _MISSIONPROFILE_TAGSENTRY._serialized_end=347
# @@protoc_insertion_point(module_scope)
