# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_kinesisanalyticsv2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n aws/aws_kinesisanalyticsv2.proto\x12\"oak9.tython.aws.kinesisanalyticsv2\x1a\x13shared/shared.proto\"\x95\x01\n\x1c\x41pplicationS3ContentLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbucket_arn\x18\x02 \x01(\t\x12\x10\n\x08\x66ile_key\x18\x03 \x01(\t\x12\x16\n\x0eobject_version\x18\x04 \x01(\t\"\xe0\x01\n\x16\x41pplicationCodeContent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10zip_file_content\x18\x02 \x01(\t\x12]\n\x13s3_content_location\x18\x03 \x01(\x0b\x32@.oak9.tython.aws.kinesisanalyticsv2.ApplicationS3ContentLocation\x12\x14\n\x0ctext_content\x18\x04 \x01(\t\"\xcf\x01\n\'ApplicationApplicationCodeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63ode_content_type\x18\x02 \x01(\t\x12P\n\x0c\x63ode_content\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.kinesisanalyticsv2.ApplicationCodeContent\"\x87\x02\n\x18\x41pplicationPropertyGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x0cproperty_map\x18\x02 \x03(\x0b\x32M.oak9.tython.aws.kinesisanalyticsv2.ApplicationPropertyGroup.PropertyMapEntry\x12\x19\n\x11property_group_id\x18\x03 \x01(\t\x1a\x32\n\x10PropertyMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x01\n ApplicationEnvironmentProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x0fproperty_groups\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.kinesisanalyticsv2.ApplicationPropertyGroup\"\xdc\x01\n\"ApplicationCheckpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63onfiguration_type\x18\x02 \x01(\t\x12\x1b\n\x13\x63heckpoint_interval\x18\x03 \x01(\x05\x12%\n\x1dmin_pause_between_checkpoints\x18\x04 \x01(\x05\x12\x1d\n\x15\x63heckpointing_enabled\x18\x05 \x01(\x08\"\xcc\x01\n#ApplicationParallelismConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63onfiguration_type\x18\x02 \x01(\t\x12\x1d\n\x15parallelism_per_k_p_u\x18\x03 \x01(\x05\x12\x1c\n\x14\x61uto_scaling_enabled\x18\x04 \x01(\x08\x12\x13\n\x0bparallelism\x18\x05 \x01(\x05\"\xa3\x01\n\"ApplicationMonitoringConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63onfiguration_type\x18\x02 \x01(\t\x12\x15\n\rmetrics_level\x18\x03 \x01(\t\x12\x11\n\tlog_level\x18\x04 \x01(\t\"\xa3\x03\n(ApplicationFlinkApplicationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\x18\x63heckpoint_configuration\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisanalyticsv2.ApplicationCheckpointConfiguration\x12j\n\x19parallelism_configuration\x18\x03 \x01(\x0b\x32G.oak9.tython.aws.kinesisanalyticsv2.ApplicationParallelismConfiguration\x12h\n\x18monitoring_configuration\x18\x04 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisanalyticsv2.ApplicationMonitoringConfiguration\"\x83\x01\n\x17\x41pplicationRecordColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07mapping\x18\x02 \x01(\t\x12\x10\n\x08sql_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"t\n ApplicationJSONMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_row_path\x18\x02 \x01(\t\"\x99\x01\n\x1f\x41pplicationCSVMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14record_row_delimiter\x18\x02 \x01(\t\x12\x1f\n\x17record_column_delimiter\x18\x03 \x01(\t\"\xa4\x02\n\x1c\x41pplicationMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x65\n\x17json_mapping_parameters\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.kinesisanalyticsv2.ApplicationJSONMappingParameters\x12\x64\n\x17\x63s_v_mapping_parameters\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.kinesisanalyticsv2.ApplicationCSVMappingParameters\"\xcc\x01\n\x17\x41pplicationRecordFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x12mapping_parameters\x18\x02 \x01(\x0b\x32@.oak9.tython.aws.kinesisanalyticsv2.ApplicationMappingParameters\x12\x1a\n\x12record_format_type\x18\x03 \x01(\t\"\x93\x02\n\x16\x41pplicationInputSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_encoding\x18\x02 \x01(\t\x12S\n\x0erecord_columns\x18\x03 \x03(\x0b\x32;.oak9.tython.aws.kinesisanalyticsv2.ApplicationRecordColumn\x12R\n\rrecord_format\x18\x04 \x01(\x0b\x32;.oak9.tython.aws.kinesisanalyticsv2.ApplicationRecordFormat\"o\n\x1e\x41pplicationKinesisStreamsInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"p\n\x1f\x41pplicationKinesisFirehoseInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"p\n\x1f\x41pplicationInputLambdaProcessor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"\xc7\x01\n\'ApplicationInputProcessingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x16input_lambda_processor\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.kinesisanalyticsv2.ApplicationInputLambdaProcessor\"e\n\x1b\x41pplicationInputParallelism\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\xcb\x04\n\x10\x41pplicationInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bname_prefix\x18\x02 \x01(\t\x12P\n\x0cinput_schema\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.kinesisanalyticsv2.ApplicationInputSchema\x12\x61\n\x15kinesis_streams_input\x18\x04 \x01(\x0b\x32\x42.oak9.tython.aws.kinesisanalyticsv2.ApplicationKinesisStreamsInput\x12\x63\n\x16kinesis_firehose_input\x18\x05 \x01(\x0b\x32\x43.oak9.tython.aws.kinesisanalyticsv2.ApplicationKinesisFirehoseInput\x12s\n\x1einput_processing_configuration\x18\x06 \x01(\x0b\x32K.oak9.tython.aws.kinesisanalyticsv2.ApplicationInputProcessingConfiguration\x12Z\n\x11input_parallelism\x18\x07 \x01(\x0b\x32?.oak9.tython.aws.kinesisanalyticsv2.ApplicationInputParallelism\"\xa7\x01\n&ApplicationSqlApplicationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x06inputs\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.kinesisanalyticsv2.ApplicationInput\"\x81\x01\n+ApplicationApplicationSnapshotConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11snapshots_enabled\x18\x02 \x01(\x08\"\xa0\x05\n#ApplicationApplicationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12s\n\x1e\x61pplication_code_configuration\x18\x02 \x01(\x0b\x32K.oak9.tython.aws.kinesisanalyticsv2.ApplicationApplicationCodeConfiguration\x12\x64\n\x16\x65nvironment_properties\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.kinesisanalyticsv2.ApplicationEnvironmentProperties\x12u\n\x1f\x66link_application_configuration\x18\x04 \x01(\x0b\x32L.oak9.tython.aws.kinesisanalyticsv2.ApplicationFlinkApplicationConfiguration\x12q\n\x1dsql_application_configuration\x18\x05 \x01(\x0b\x32J.oak9.tython.aws.kinesisanalyticsv2.ApplicationSqlApplicationConfiguration\x12{\n\"application_snapshot_configuration\x18\x06 \x01(\x0b\x32O.oak9.tython.aws.kinesisanalyticsv2.ApplicationApplicationSnapshotConfiguration\"\xa0\x03\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x1b\n\x13runtime_environment\x18\x03 \x01(\t\x12j\n\x19\x61pplication_configuration\x18\x04 \x01(\x0b\x32G.oak9.tython.aws.kinesisanalyticsv2.ApplicationApplicationConfiguration\x12\x1f\n\x17\x61pplication_description\x18\x05 \x01(\t\x12G\n\x04tags\x18\x06 \x03(\x0b\x32\x39.oak9.tython.aws.kinesisanalyticsv2.Application.TagsEntry\x12\x1e\n\x16service_execution_role\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x94\x03\n\x12KinesisAnalyticsV2\x12\x44\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.kinesisanalyticsv2.Application\x12v\n&application_cloud_watch_logging_option\x18\x02 \x03(\x0b\x32\x46.oak9.tython.aws.kinesisanalyticsv2.ApplicationCloudWatchLoggingOption\x12Q\n\x12\x61pplication_output\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutput\x12m\n!application_reference_data_source\x18\x04 \x03(\x0b\x32\x42.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSource\"\x8c\x01\n9ApplicationCloudWatchLoggingOptionCloudWatchLoggingOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_stream_arn\x18\x02 \x01(\t\"\xfb\x01\n\"ApplicationCloudWatchLoggingOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x81\x01\n\x1a\x63loud_watch_logging_option\x18\x03 \x01(\x0b\x32].oak9.tython.aws.kinesisanalyticsv2.ApplicationCloudWatchLoggingOptionCloudWatchLoggingOption\"y\n\"ApplicationOutputDestinationSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12record_format_type\x18\x02 \x01(\t\"n\n\x1d\x41pplicationOutputLambdaOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"w\n&ApplicationOutputKinesisFirehoseOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"v\n%ApplicationOutputKinesisStreamsOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\"\xf6\x03\n\x17\x41pplicationOutputOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x12\x64\x65stination_schema\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputDestinationSchema\x12X\n\rlambda_output\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputLambdaOutput\x12k\n\x17kinesis_firehose_output\x18\x04 \x01(\x0b\x32J.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputKinesisFirehoseOutput\x12i\n\x16kinesis_streams_output\x18\x05 \x01(\x0b\x32I.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputKinesisStreamsOutput\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xb3\x01\n\x11\x41pplicationOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12K\n\x06output\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.kinesisanalyticsv2.ApplicationOutputOutput\"\x96\x01\n*ApplicationReferenceDataSourceRecordColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07mapping\x18\x02 \x01(\t\x12\x10\n\x08sql_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x87\x01\n3ApplicationReferenceDataSourceJSONMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_row_path\x18\x02 \x01(\t\"\xac\x01\n2ApplicationReferenceDataSourceCSVMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14record_row_delimiter\x18\x02 \x01(\t\x12\x1f\n\x17record_column_delimiter\x18\x03 \x01(\t\"\xdd\x02\n/ApplicationReferenceDataSourceMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12x\n\x17json_mapping_parameters\x18\x02 \x01(\x0b\x32W.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceJSONMappingParameters\x12w\n\x17\x63s_v_mapping_parameters\x18\x03 \x01(\x0b\x32V.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceCSVMappingParameters\"\xf2\x01\n*ApplicationReferenceDataSourceRecordFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12o\n\x12mapping_parameters\x18\x02 \x01(\x0b\x32S.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceMappingParameters\x12\x1a\n\x12record_format_type\x18\x03 \x01(\t\"\xd0\x02\n-ApplicationReferenceDataSourceReferenceSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_encoding\x18\x02 \x01(\t\x12\x66\n\x0erecord_columns\x18\x03 \x03(\x0b\x32N.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceRecordColumn\x12\x65\n\rrecord_format\x18\x04 \x01(\x0b\x32N.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceRecordFormat\"\x94\x01\n3ApplicationReferenceDataSourceS3ReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbucket_arn\x18\x02 \x01(\t\x12\x10\n\x08\x66ile_key\x18\x03 \x01(\t\"\xe8\x02\n1ApplicationReferenceDataSourceReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12k\n\x10reference_schema\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceReferenceSchema\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12y\n\x18s3_reference_data_source\x18\x04 \x01(\x0b\x32W.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceS3ReferenceDataSource\"\xe9\x01\n\x1e\x41pplicationReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12t\n\x15reference_data_source\x18\x03 \x01(\x0b\x32U.oak9.tython.aws.kinesisanalyticsv2.ApplicationReferenceDataSourceReferenceDataSourceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_kinesisanalyticsv2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATIONPROPERTYGROUP_PROPERTYMAPENTRY._options = None
  _APPLICATIONPROPERTYGROUP_PROPERTYMAPENTRY._serialized_options = b'8\001'
  _APPLICATION_TAGSENTRY._options = None
  _APPLICATION_TAGSENTRY._serialized_options = b'8\001'
  _APPLICATIONS3CONTENTLOCATION._serialized_start=94
  _APPLICATIONS3CONTENTLOCATION._serialized_end=243
  _APPLICATIONCODECONTENT._serialized_start=246
  _APPLICATIONCODECONTENT._serialized_end=470
  _APPLICATIONAPPLICATIONCODECONFIGURATION._serialized_start=473
  _APPLICATIONAPPLICATIONCODECONFIGURATION._serialized_end=680
  _APPLICATIONPROPERTYGROUP._serialized_start=683
  _APPLICATIONPROPERTYGROUP._serialized_end=946
  _APPLICATIONPROPERTYGROUP_PROPERTYMAPENTRY._serialized_start=896
  _APPLICATIONPROPERTYGROUP_PROPERTYMAPENTRY._serialized_end=946
  _APPLICATIONENVIRONMENTPROPERTIES._serialized_start=949
  _APPLICATIONENVIRONMENTPROPERTIES._serialized_end=1127
  _APPLICATIONCHECKPOINTCONFIGURATION._serialized_start=1130
  _APPLICATIONCHECKPOINTCONFIGURATION._serialized_end=1350
  _APPLICATIONPARALLELISMCONFIGURATION._serialized_start=1353
  _APPLICATIONPARALLELISMCONFIGURATION._serialized_end=1557
  _APPLICATIONMONITORINGCONFIGURATION._serialized_start=1560
  _APPLICATIONMONITORINGCONFIGURATION._serialized_end=1723
  _APPLICATIONFLINKAPPLICATIONCONFIGURATION._serialized_start=1726
  _APPLICATIONFLINKAPPLICATIONCONFIGURATION._serialized_end=2145
  _APPLICATIONRECORDCOLUMN._serialized_start=2148
  _APPLICATIONRECORDCOLUMN._serialized_end=2279
  _APPLICATIONJSONMAPPINGPARAMETERS._serialized_start=2281
  _APPLICATIONJSONMAPPINGPARAMETERS._serialized_end=2397
  _APPLICATIONCSVMAPPINGPARAMETERS._serialized_start=2400
  _APPLICATIONCSVMAPPINGPARAMETERS._serialized_end=2553
  _APPLICATIONMAPPINGPARAMETERS._serialized_start=2556
  _APPLICATIONMAPPINGPARAMETERS._serialized_end=2848
  _APPLICATIONRECORDFORMAT._serialized_start=2851
  _APPLICATIONRECORDFORMAT._serialized_end=3055
  _APPLICATIONINPUTSCHEMA._serialized_start=3058
  _APPLICATIONINPUTSCHEMA._serialized_end=3333
  _APPLICATIONKINESISSTREAMSINPUT._serialized_start=3335
  _APPLICATIONKINESISSTREAMSINPUT._serialized_end=3446
  _APPLICATIONKINESISFIREHOSEINPUT._serialized_start=3448
  _APPLICATIONKINESISFIREHOSEINPUT._serialized_end=3560
  _APPLICATIONINPUTLAMBDAPROCESSOR._serialized_start=3562
  _APPLICATIONINPUTLAMBDAPROCESSOR._serialized_end=3674
  _APPLICATIONINPUTPROCESSINGCONFIGURATION._serialized_start=3677
  _APPLICATIONINPUTPROCESSINGCONFIGURATION._serialized_end=3876
  _APPLICATIONINPUTPARALLELISM._serialized_start=3878
  _APPLICATIONINPUTPARALLELISM._serialized_end=3979
  _APPLICATIONINPUT._serialized_start=3982
  _APPLICATIONINPUT._serialized_end=4569
  _APPLICATIONSQLAPPLICATIONCONFIGURATION._serialized_start=4572
  _APPLICATIONSQLAPPLICATIONCONFIGURATION._serialized_end=4739
  _APPLICATIONAPPLICATIONSNAPSHOTCONFIGURATION._serialized_start=4742
  _APPLICATIONAPPLICATIONSNAPSHOTCONFIGURATION._serialized_end=4871
  _APPLICATIONAPPLICATIONCONFIGURATION._serialized_start=4874
  _APPLICATIONAPPLICATIONCONFIGURATION._serialized_end=5546
  _APPLICATION._serialized_start=5549
  _APPLICATION._serialized_end=5965
  _APPLICATION_TAGSENTRY._serialized_start=5922
  _APPLICATION_TAGSENTRY._serialized_end=5965
  _KINESISANALYTICSV2._serialized_start=5968
  _KINESISANALYTICSV2._serialized_end=6372
  _APPLICATIONCLOUDWATCHLOGGINGOPTIONCLOUDWATCHLOGGINGOPTION._serialized_start=6375
  _APPLICATIONCLOUDWATCHLOGGINGOPTIONCLOUDWATCHLOGGINGOPTION._serialized_end=6515
  _APPLICATIONCLOUDWATCHLOGGINGOPTION._serialized_start=6518
  _APPLICATIONCLOUDWATCHLOGGINGOPTION._serialized_end=6769
  _APPLICATIONOUTPUTDESTINATIONSCHEMA._serialized_start=6771
  _APPLICATIONOUTPUTDESTINATIONSCHEMA._serialized_end=6892
  _APPLICATIONOUTPUTLAMBDAOUTPUT._serialized_start=6894
  _APPLICATIONOUTPUTLAMBDAOUTPUT._serialized_end=7004
  _APPLICATIONOUTPUTKINESISFIREHOSEOUTPUT._serialized_start=7006
  _APPLICATIONOUTPUTKINESISFIREHOSEOUTPUT._serialized_end=7125
  _APPLICATIONOUTPUTKINESISSTREAMSOUTPUT._serialized_start=7127
  _APPLICATIONOUTPUTKINESISSTREAMSOUTPUT._serialized_end=7245
  _APPLICATIONOUTPUTOUTPUT._serialized_start=7248
  _APPLICATIONOUTPUTOUTPUT._serialized_end=7750
  _APPLICATIONOUTPUT._serialized_start=7753
  _APPLICATIONOUTPUT._serialized_end=7932
  _APPLICATIONREFERENCEDATASOURCERECORDCOLUMN._serialized_start=7935
  _APPLICATIONREFERENCEDATASOURCERECORDCOLUMN._serialized_end=8085
  _APPLICATIONREFERENCEDATASOURCEJSONMAPPINGPARAMETERS._serialized_start=8088
  _APPLICATIONREFERENCEDATASOURCEJSONMAPPINGPARAMETERS._serialized_end=8223
  _APPLICATIONREFERENCEDATASOURCECSVMAPPINGPARAMETERS._serialized_start=8226
  _APPLICATIONREFERENCEDATASOURCECSVMAPPINGPARAMETERS._serialized_end=8398
  _APPLICATIONREFERENCEDATASOURCEMAPPINGPARAMETERS._serialized_start=8401
  _APPLICATIONREFERENCEDATASOURCEMAPPINGPARAMETERS._serialized_end=8750
  _APPLICATIONREFERENCEDATASOURCERECORDFORMAT._serialized_start=8753
  _APPLICATIONREFERENCEDATASOURCERECORDFORMAT._serialized_end=8995
  _APPLICATIONREFERENCEDATASOURCEREFERENCESCHEMA._serialized_start=8998
  _APPLICATIONREFERENCEDATASOURCEREFERENCESCHEMA._serialized_end=9334
  _APPLICATIONREFERENCEDATASOURCES3REFERENCEDATASOURCE._serialized_start=9337
  _APPLICATIONREFERENCEDATASOURCES3REFERENCEDATASOURCE._serialized_end=9485
  _APPLICATIONREFERENCEDATASOURCEREFERENCEDATASOURCE._serialized_start=9488
  _APPLICATIONREFERENCEDATASOURCEREFERENCEDATASOURCE._serialized_end=9848
  _APPLICATIONREFERENCEDATASOURCE._serialized_start=9851
  _APPLICATIONREFERENCEDATASOURCE._serialized_end=10084
# @@protoc_insertion_point(module_scope)
