# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_iam.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_iam.proto\x12\x13oak9.tython.gcp.iam\x1a\x13shared/shared.proto\"R\n IamWorkloadIdentityPoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb5\x02\n\x17IamWorkloadIdentityPool\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\x12!\n\x19workload_identity_pool_id\x18\x08 \x01(\t\x12G\n\x08timeouts\x18\t \x01(\x0b\x32\x35.oak9.tython.gcp.iam.IamWorkloadIdentityPoolXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"9\n#IamWorkloadIdentityPoolProviderXAws\x12\x12\n\naccount_id\x18\x01 \x01(\t\"U\n$IamWorkloadIdentityPoolProviderXOidc\x12\x19\n\x11\x61llowed_audiences\x18\x01 \x03(\t\x12\x12\n\nissuer_uri\x18\x02 \x01(\t\"Z\n(IamWorkloadIdentityPoolProviderXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xbe\x05\n\x1fIamWorkloadIdentityPoolProvider\x12\x1b\n\x13\x61ttribute_condition\x18\x01 \x01(\t\x12\x65\n\x11\x61ttribute_mapping\x18\x02 \x03(\x0b\x32J.oak9.tython.gcp.iam.IamWorkloadIdentityPoolProvider.AttributeMappingEntry\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x64isabled\x18\x04 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12!\n\x19workload_identity_pool_id\x18\n \x01(\t\x12*\n\"workload_identity_pool_provider_id\x18\x0b \x01(\t\x12\x45\n\x03\x61ws\x18\x0c \x01(\x0b\x32\x38.oak9.tython.gcp.iam.IamWorkloadIdentityPoolProviderXAws\x12G\n\x04oidc\x18\r \x01(\x0b\x32\x39.oak9.tython.gcp.iam.IamWorkloadIdentityPoolProviderXOidc\x12O\n\x08timeouts\x18\x0e \x01(\x0b\x32=.oak9.tython.gcp.iam.IamWorkloadIdentityPoolProviderXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15\x41ttributeMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_iam_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IAMWORKLOADIDENTITYPOOLPROVIDER_ATTRIBUTEMAPPINGENTRY._options = None
  _IAMWORKLOADIDENTITYPOOLPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_options = b'8\001'
  _IAMWORKLOADIDENTITYPOOLXTIMEOUTS._serialized_start=63
  _IAMWORKLOADIDENTITYPOOLXTIMEOUTS._serialized_end=145
  _IAMWORKLOADIDENTITYPOOL._serialized_start=148
  _IAMWORKLOADIDENTITYPOOL._serialized_end=457
  _IAMWORKLOADIDENTITYPOOLPROVIDERXAWS._serialized_start=459
  _IAMWORKLOADIDENTITYPOOLPROVIDERXAWS._serialized_end=516
  _IAMWORKLOADIDENTITYPOOLPROVIDERXOIDC._serialized_start=518
  _IAMWORKLOADIDENTITYPOOLPROVIDERXOIDC._serialized_end=603
  _IAMWORKLOADIDENTITYPOOLPROVIDERXTIMEOUTS._serialized_start=605
  _IAMWORKLOADIDENTITYPOOLPROVIDERXTIMEOUTS._serialized_end=695
  _IAMWORKLOADIDENTITYPOOLPROVIDER._serialized_start=698
  _IAMWORKLOADIDENTITYPOOLPROVIDER._serialized_end=1400
  _IAMWORKLOADIDENTITYPOOLPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_start=1345
  _IAMWORKLOADIDENTITYPOOLPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_end=1400
# @@protoc_insertion_point(module_scope)
