# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.batch.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/kubernetes/kubernetes_io.k8s.api.batch.v1.proto\x12\x1coak9.tython.k8s.api.batch.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\"\xa8\x02\n\x07\x43ronJob\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x37\n\x04spec\x18\x04 \x01(\x0b\x32).oak9.tython.k8s.api.batch.v1.CronJobSpec\x12;\n\x06status\x18\x05 \x01(\x0b\x32+.oak9.tython.k8s.api.batch.v1.CronJobStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xea\x01\n\x0b\x43ronJobList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.oak9.tython.k8s.api.batch.v1.CronJob\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xca\x02\n\x0b\x43ronJobSpec\x12\x1a\n\x12\x63oncurrency_policy\x18\x01 \x01(\t\x12!\n\x19\x66\x61iled_jobs_history_limit\x18\x02 \x01(\x05\x12\x43\n\x0cjob_template\x18\x03 \x01(\x0b\x32-.oak9.tython.k8s.api.batch.v1.JobTemplateSpec\x12\x10\n\x08schedule\x18\x04 \x01(\t\x12!\n\x19starting_deadline_seconds\x18\x05 \x01(\x05\x12%\n\x1dsuccessful_jobs_history_limit\x18\x06 \x01(\x05\x12\x0f\n\x07suspend\x18\x07 \x01(\x08\x12\x11\n\ttime_zone\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaa\x02\n\rCronJobStatus\x12<\n\x06\x61\x63tive\x18\x01 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12O\n\x12last_schedule_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12Q\n\x14last_successful_time\x18\x03 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x02\n\x03Job\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x33\n\x04spec\x18\x04 \x01(\x0b\x32%.oak9.tython.k8s.api.batch.v1.JobSpec\x12\x37\n\x06status\x18\x05 \x01(\x0b\x32\'.oak9.tython.k8s.api.batch.v1.JobStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa7\x02\n\x0cJobCondition\x12L\n\x0flast_probe_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12Q\n\x14last_transition_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe2\x01\n\x07JobList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.oak9.tython.k8s.api.batch.v1.Job\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe7\x03\n\x07JobSpec\x12\x1f\n\x17\x61\x63tive_deadline_seconds\x18\x01 \x01(\x05\x12\x15\n\rbackoff_limit\x18\x02 \x01(\x05\x12\x17\n\x0f\x63ompletion_mode\x18\x03 \x01(\t\x12\x13\n\x0b\x63ompletions\x18\x04 \x01(\x05\x12\x17\n\x0fmanual_selector\x18\x05 \x01(\x08\x12\x13\n\x0bparallelism\x18\x06 \x01(\x05\x12J\n\x12pod_failure_policy\x18\x07 \x01(\x0b\x32..oak9.tython.k8s.api.batch.v1.PodFailurePolicy\x12N\n\x08selector\x18\x08 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x0f\n\x07suspend\x18\t \x01(\x08\x12>\n\x08template\x18\n \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12\"\n\x1attl_seconds_after_finished\x18\x0b \x01(\x05\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd2\x03\n\tJobStatus\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x05\x12\x19\n\x11\x63ompleted_indexes\x18\x02 \x01(\t\x12L\n\x0f\x63ompletion_time\x18\x03 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12>\n\nconditions\x18\x04 \x03(\x0b\x32*.oak9.tython.k8s.api.batch.v1.JobCondition\x12\x0e\n\x06\x66\x61iled\x18\x05 \x01(\x05\x12\r\n\x05ready\x18\x06 \x01(\x05\x12G\n\nstart_time\x18\x07 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x11\n\tsucceeded\x18\x08 \x01(\x05\x12X\n\x19uncounted_terminated_pods\x18\t \x01(\x0b\x32\x35.oak9.tython.k8s.api.batch.v1.UncountedTerminatedPods\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x01\n\x0fJobTemplateSpec\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x33\n\x04spec\x18\x02 \x01(\x0b\x32%.oak9.tython.k8s.api.batch.v1.JobSpec\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8e\x01\n\x10PodFailurePolicy\x12\x41\n\x05rules\x18\x01 \x03(\x0b\x32\x32.oak9.tython.k8s.api.batch.v1.PodFailurePolicyRule\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x01\n&PodFailurePolicyOnExitCodesRequirement\x12\x16\n\x0e\x63ontainer_name\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x7f\n&PodFailurePolicyOnPodConditionsPattern\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x02\n\x14PodFailurePolicyRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12[\n\ron_exit_codes\x18\x02 \x01(\x0b\x32\x44.oak9.tython.k8s.api.batch.v1.PodFailurePolicyOnExitCodesRequirement\x12_\n\x11on_pod_conditions\x18\x03 \x03(\x0b\x32\x44.oak9.tython.k8s.api.batch.v1.PodFailurePolicyOnPodConditionsPattern\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"u\n\x17UncountedTerminatedPods\x12\x0e\n\x06\x66\x61iled\x18\x01 \x03(\t\x12\x11\n\tsucceeded\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.batch.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CRONJOB._serialized_start=217
  _CRONJOB._serialized_end=513
  _CRONJOBLIST._serialized_start=516
  _CRONJOBLIST._serialized_end=750
  _CRONJOBSPEC._serialized_start=753
  _CRONJOBSPEC._serialized_end=1083
  _CRONJOBSTATUS._serialized_start=1086
  _CRONJOBSTATUS._serialized_end=1384
  _JOB._serialized_start=1387
  _JOB._serialized_end=1671
  _JOBCONDITION._serialized_start=1674
  _JOBCONDITION._serialized_end=1969
  _JOBLIST._serialized_start=1972
  _JOBLIST._serialized_end=2198
  _JOBSPEC._serialized_start=2201
  _JOBSPEC._serialized_end=2688
  _JOBSTATUS._serialized_start=2691
  _JOBSTATUS._serialized_end=3157
  _JOBTEMPLATESPEC._serialized_start=3160
  _JOBTEMPLATESPEC._serialized_end=3364
  _PODFAILUREPOLICY._serialized_start=3367
  _PODFAILUREPOLICY._serialized_end=3509
  _PODFAILUREPOLICYONEXITCODESREQUIREMENT._serialized_start=3512
  _PODFAILUREPOLICYONEXITCODESREQUIREMENT._serialized_end=3667
  _PODFAILUREPOLICYONPODCONDITIONSPATTERN._serialized_start=3669
  _PODFAILUREPOLICYONPODCONDITIONSPATTERN._serialized_end=3796
  _PODFAILUREPOLICYRULE._serialized_start=3799
  _PODFAILUREPOLICYRULE._serialized_end=4084
  _UNCOUNTEDTERMINATEDPODS._serialized_start=4086
  _UNCOUNTEDTERMINATEDPODS._serialized_end=4203
# @@protoc_insertion_point(module_scope)
