# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_certificate_manager_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_certificate_pb2 as gcp_dot_gcp__certificate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/gcp/gcp_google_certificate_manager_bundle.proto\x12\x31oak9.tython.gcp.google_certificate_manager_bundle\x1a\x13shared/shared.proto\x1a\x19gcp/gcp_certificate.proto\"\xd2\x03\n\x18GoogleCertificateManager\x12\x63\n\x1f\x63\x65rtificate_manager_certificate\x18\x01 \x03(\x0b\x32:.oak9.tython.gcp.certificate.CertificateManagerCertificate\x12j\n#certificate_manager_certificate_map\x18\x02 \x01(\x0b\x32=.oak9.tython.gcp.certificate.CertificateManagerCertificateMap\x12u\n)certificate_manager_certificate_map_entry\x18\x03 \x03(\x0b\x32\x42.oak9.tython.gcp.certificate.CertificateManagerCertificateMapEntry\x12n\n%certificate_manager_dns_authorization\x18\x04 \x03(\x0b\x32?.oak9.tython.gcp.certificate.CertificateManagerDnsAuthorizationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_certificate_manager_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECERTIFICATEMANAGER._serialized_start=151
  _GOOGLECERTIFICATEMANAGER._serialized_end=617
# @@protoc_insertion_point(module_scope)
