# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.networking.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.util import intstr_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_util_dot_intstr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4kubernetes/kubernetes_io.k8s.api.networking.v1.proto\x12!oak9.tython.k8s.api.networking.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a?kubernetes/kubernetes_io.k8s.apimachinery.pkg.util.intstr.proto\"\xaf\x01\n\x0fHTTPIngressPath\x12\x42\n\x07\x62\x61\x63kend\x18\x01 \x01(\x0b\x32\x31.oak9.tython.k8s.api.networking.v1.IngressBackend\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\tpath_type\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x92\x01\n\x14HTTPIngressRuleValue\x12\x41\n\x05paths\x18\x01 \x03(\x0b\x32\x32.oak9.tython.k8s.api.networking.v1.HTTPIngressPath\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n\x07IPBlock\x12\x0c\n\x04\x63idr\x18\x01 \x01(\t\x12\x0e\n\x06\x65xcept\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x02\n\x07Ingress\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12<\n\x04spec\x18\x04 \x01(\x0b\x32..oak9.tython.k8s.api.networking.v1.IngressSpec\x12@\n\x06status\x18\x05 \x01(\x0b\x32\x30.oak9.tython.k8s.api.networking.v1.IngressStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xde\x01\n\x0eIngressBackend\x12H\n\x08resource\x18\x01 \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.TypedLocalObjectReference\x12I\n\x07service\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.api.networking.v1.IngressServiceBackend\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfa\x01\n\x0cIngressClass\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x41\n\x04spec\x18\x04 \x01(\x0b\x32\x33.oak9.tython.k8s.api.networking.v1.IngressClassSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf9\x01\n\x10IngressClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12>\n\x05items\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.networking.v1.IngressClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x1fIngressClassParametersReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb7\x01\n\x10IngressClassSpec\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12V\n\nparameters\x18\x02 \x01(\x0b\x32\x42.oak9.tython.k8s.api.networking.v1.IngressClassParametersReference\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x01\n\x0bIngressList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x39\n\x05items\x18\x02 \x03(\x0b\x32*.oak9.tython.k8s.api.networking.v1.Ingress\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x01\n\x1aIngressLoadBalancerIngress\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x43\n\x05ports\x18\x03 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.IngressPortStatus\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x01\n\x19IngressLoadBalancerStatus\x12N\n\x07ingress\x18\x01 \x03(\x0b\x32=.oak9.tython.k8s.api.networking.v1.IngressLoadBalancerIngress\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"{\n\x11IngressPortStatus\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x01\n\x0bIngressRule\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x45\n\x04http\x18\x02 \x01(\x0b\x32\x37.oak9.tython.k8s.api.networking.v1.HTTPIngressRuleValue\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x01\n\x15IngressServiceBackend\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\x04port\x18\x02 \x01(\x0b\x32\x35.oak9.tython.k8s.api.networking.v1.ServiceBackendPort\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa9\x02\n\x0bIngressSpec\x12J\n\x0f\x64\x65\x66\x61ult_backend\x18\x01 \x01(\x0b\x32\x31.oak9.tython.k8s.api.networking.v1.IngressBackend\x12\x1a\n\x12ingress_class_name\x18\x02 \x01(\t\x12=\n\x05rules\x18\x03 \x03(\x0b\x32..oak9.tython.k8s.api.networking.v1.IngressRule\x12:\n\x03tls\x18\x04 \x03(\x0b\x32-.oak9.tython.k8s.api.networking.v1.IngressTLS\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\rIngressStatus\x12S\n\rload_balancer\x18\x01 \x01(\x0b\x32<.oak9.tython.k8s.api.networking.v1.IngressLoadBalancerStatus\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"i\n\nIngressTLS\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x02\n\rNetworkPolicy\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x42\n\x04spec\x18\x04 \x01(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicySpec\x12\x46\n\x06status\x18\x05 \x01(\x0b\x32\x36.oak9.tython.k8s.api.networking.v1.NetworkPolicyStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd9\x01\n\x17NetworkPolicyEgressRule\x12\x43\n\x05ports\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicyPort\x12@\n\x02to\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicyPeer\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdc\x01\n\x18NetworkPolicyIngressRule\x12\x42\n\x04\x66rom\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicyPeer\x12\x43\n\x05ports\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicyPort\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfb\x01\n\x11NetworkPolicyList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12?\n\x05items\x18\x02 \x03(\x0b\x32\x30.oak9.tython.k8s.api.networking.v1.NetworkPolicy\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x02\n\x11NetworkPolicyPeer\x12<\n\x08ip_block\x18\x01 \x01(\x0b\x32*.oak9.tython.k8s.api.networking.v1.IPBlock\x12X\n\x12namespace_selector\x18\x02 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12R\n\x0cpod_selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x01\n\x11NetworkPolicyPort\x12\x10\n\x08\x65nd_port\x18\x01 \x01(\x05\x12G\n\x04port\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd0\x02\n\x11NetworkPolicySpec\x12J\n\x06\x65gress\x18\x01 \x03(\x0b\x32:.oak9.tython.k8s.api.networking.v1.NetworkPolicyEgressRule\x12L\n\x07ingress\x18\x02 \x03(\x0b\x32;.oak9.tython.k8s.api.networking.v1.NetworkPolicyIngressRule\x12R\n\x0cpod_selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x14\n\x0cpolicy_types\x18\x04 \x03(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x01\n\x13NetworkPolicyStatus\x12L\n\nconditions\x18\x01 \x03(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Condition\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"k\n\x12ServiceBackendPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.networking.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HTTPINGRESSPATH._serialized_start=292
  _HTTPINGRESSPATH._serialized_end=467
  _HTTPINGRESSRULEVALUE._serialized_start=470
  _HTTPINGRESSRULEVALUE._serialized_end=616
  _IPBLOCK._serialized_start=618
  _IPBLOCK._serialized_end=714
  _INGRESS._serialized_start=717
  _INGRESS._serialized_end=1023
  _INGRESSBACKEND._serialized_start=1026
  _INGRESSBACKEND._serialized_end=1248
  _INGRESSCLASS._serialized_start=1251
  _INGRESSCLASS._serialized_end=1501
  _INGRESSCLASSLIST._serialized_start=1504
  _INGRESSCLASSLIST._serialized_end=1753
  _INGRESSCLASSPARAMETERSREFERENCE._serialized_start=1756
  _INGRESSCLASSPARAMETERSREFERENCE._serialized_end=1927
  _INGRESSCLASSSPEC._serialized_start=1930
  _INGRESSCLASSSPEC._serialized_end=2113
  _INGRESSLIST._serialized_start=2116
  _INGRESSLIST._serialized_end=2355
  _INGRESSLOADBALANCERINGRESS._serialized_start=2358
  _INGRESSLOADBALANCERINGRESS._serialized_end=2542
  _INGRESSLOADBALANCERSTATUS._serialized_start=2545
  _INGRESSLOADBALANCERSTATUS._serialized_end=2709
  _INGRESSPORTSTATUS._serialized_start=2711
  _INGRESSPORTSTATUS._serialized_end=2834
  _INGRESSRULE._serialized_start=2837
  _INGRESSRULE._serialized_end=2992
  _INGRESSSERVICEBACKEND._serialized_start=2995
  _INGRESSSERVICEBACKEND._serialized_end=3158
  _INGRESSSPEC._serialized_start=3161
  _INGRESSSPEC._serialized_end=3458
  _INGRESSSTATUS._serialized_start=3461
  _INGRESSSTATUS._serialized_end=3618
  _INGRESSTLS._serialized_start=3620
  _INGRESSTLS._serialized_end=3725
  _NETWORKPOLICY._serialized_start=3728
  _NETWORKPOLICY._serialized_end=4052
  _NETWORKPOLICYEGRESSRULE._serialized_start=4055
  _NETWORKPOLICYEGRESSRULE._serialized_end=4272
  _NETWORKPOLICYINGRESSRULE._serialized_start=4275
  _NETWORKPOLICYINGRESSRULE._serialized_end=4495
  _NETWORKPOLICYLIST._serialized_start=4498
  _NETWORKPOLICYLIST._serialized_end=4749
  _NETWORKPOLICYPEER._serialized_start=4752
  _NETWORKPOLICYPEER._serialized_end=5064
  _NETWORKPOLICYPORT._serialized_start=5067
  _NETWORKPOLICYPORT._serialized_end=5252
  _NETWORKPOLICYSPEC._serialized_start=5255
  _NETWORKPOLICYSPEC._serialized_end=5591
  _NETWORKPOLICYSTATUS._serialized_start=5594
  _NETWORKPOLICYSTATUS._serialized_end=5750
  _SERVICEBACKENDPORT._serialized_start=5752
  _SERVICEBACKENDPORT._serialized_end=5859
# @@protoc_insertion_point(module_scope)
