# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_dns_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_dns_pb2 as gcp_dot_gcp__dns__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgcp/gcp_google_dns_bundle.proto\x12!oak9.tython.gcp.google_dns_bundle\x1a\x13shared/shared.proto\x1a\x11gcp/gcp_dns.proto\"\xb9\x01\n\tGoogleDns\x12=\n\x10\x64ns_managed_zone\x18\x01 \x01(\x0b\x32#.oak9.tython.gcp.dns.DnsManagedZone\x12\x32\n\ndns_policy\x18\x02 \x01(\x0b\x32\x1e.oak9.tython.gcp.dns.DnsPolicy\x12\x39\n\x0e\x64ns_record_set\x18\x03 \x01(\x0b\x32!.oak9.tython.gcp.dns.DnsRecordSetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_dns_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEDNS._serialized_start=111
  _GOOGLEDNS._serialized_end=296
# @@protoc_insertion_point(module_scope)
