# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_dynamodb_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_dynamodb_table.proto\x12\x1eoak9.tython.aws.dynamodb_table\x1a\x13shared/shared.proto\"\x83\x01\n\x18TableAttributeDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x03 \x01(\t\"s\n\x0eTableKeySchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x10\n\x08key_type\x18\x03 \x01(\t\"\x7f\n\x0fTableProjection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12non_key_attributes\x18\x02 \x03(\t\x12\x17\n\x0fprojection_type\x18\x03 \x01(\t\"\x90\x01\n\x1aTableProvisionedThroughput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13read_capacity_units\x18\x02 \x01(\x05\x12\x1c\n\x14write_capacity_units\x18\x03 \x01(\x05\"\xcd\x02\n\x19TableGlobalSecondaryIndex\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12\x42\n\nkey_schema\x18\x03 \x03(\x0b\x32..oak9.tython.aws.dynamodb_table.TableKeySchema\x12\x43\n\nprojection\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.dynamodb_table.TableProjection\x12Z\n\x16provisioned_throughput\x18\x05 \x01(\x0b\x32:.oak9.tython.aws.dynamodb_table.TableProvisionedThroughput\"\xf0\x01\n\x18TableLocalSecondaryIndex\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12\x42\n\nkey_schema\x18\x03 \x03(\x0b\x32..oak9.tython.aws.dynamodb_table.TableKeySchema\x12\x43\n\nprojection\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.dynamodb_table.TableProjection\"\x88\x01\n%TablePointInTimeRecoverySpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1epoint_in_time_recovery_enabled\x18\x02 \x01(\x08\"\x92\x01\n\x15TableSSESpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11kms_master_key_id\x18\x02 \x01(\t\x12\x13\n\x0bsse_enabled\x18\x03 \x01(\x08\x12\x10\n\x08sse_type\x18\x04 \x01(\t\"m\n\x18TableStreamSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10stream_view_type\x18\x02 \x01(\t\"\x80\x01\n\x1cTableTimeToLiveSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"\x88\x08\n\x05Table\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x15\x61ttribute_definitions\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.dynamodb_table.TableAttributeDefinition\x12\x14\n\x0c\x62illing_mode\x18\x03 \x01(\t\x12[\n\x18global_secondary_indexes\x18\x04 \x03(\x0b\x32\x39.oak9.tython.aws.dynamodb_table.TableGlobalSecondaryIndex\x12\x42\n\nkey_schema\x18\x05 \x03(\x0b\x32..oak9.tython.aws.dynamodb_table.TableKeySchema\x12Y\n\x17local_secondary_indexes\x18\x06 \x03(\x0b\x32\x38.oak9.tython.aws.dynamodb_table.TableLocalSecondaryIndex\x12s\n$point_in_time_recovery_specification\x18\x07 \x01(\x0b\x32\x45.oak9.tython.aws.dynamodb_table.TablePointInTimeRecoverySpecification\x12Z\n\x16provisioned_throughput\x18\x08 \x01(\x0b\x32:.oak9.tython.aws.dynamodb_table.TableProvisionedThroughput\x12P\n\x11sse_specification\x18\t \x01(\x0b\x32\x35.oak9.tython.aws.dynamodb_table.TableSSESpecification\x12V\n\x14stream_specification\x18\n \x01(\x0b\x32\x38.oak9.tython.aws.dynamodb_table.TableStreamSpecification\x12\x12\n\ntable_name\x18\x0b \x01(\t\x12=\n\x04tags\x18\x0c \x03(\x0b\x32/.oak9.tython.aws.dynamodb_table.Table.TagsEntry\x12`\n\x1atime_to_live_specification\x18\r \x01(\x0b\x32<.oak9.tython.aws.dynamodb_table.TableTimeToLiveSpecification\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x0e\x44ynamoDB_Table\x12\x34\n\x05table\x18\x01 \x01(\x0b\x32%.oak9.tython.aws.dynamodb_table.Tableb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_dynamodb_table_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TABLE_TAGSENTRY._options = None
  _TABLE_TAGSENTRY._serialized_options = b'8\001'
  _TABLEATTRIBUTEDEFINITION._serialized_start=86
  _TABLEATTRIBUTEDEFINITION._serialized_end=217
  _TABLEKEYSCHEMA._serialized_start=219
  _TABLEKEYSCHEMA._serialized_end=334
  _TABLEPROJECTION._serialized_start=336
  _TABLEPROJECTION._serialized_end=463
  _TABLEPROVISIONEDTHROUGHPUT._serialized_start=466
  _TABLEPROVISIONEDTHROUGHPUT._serialized_end=610
  _TABLEGLOBALSECONDARYINDEX._serialized_start=613
  _TABLEGLOBALSECONDARYINDEX._serialized_end=946
  _TABLELOCALSECONDARYINDEX._serialized_start=949
  _TABLELOCALSECONDARYINDEX._serialized_end=1189
  _TABLEPOINTINTIMERECOVERYSPECIFICATION._serialized_start=1192
  _TABLEPOINTINTIMERECOVERYSPECIFICATION._serialized_end=1328
  _TABLESSESPECIFICATION._serialized_start=1331
  _TABLESSESPECIFICATION._serialized_end=1477
  _TABLESTREAMSPECIFICATION._serialized_start=1479
  _TABLESTREAMSPECIFICATION._serialized_end=1588
  _TABLETIMETOLIVESPECIFICATION._serialized_start=1591
  _TABLETIMETOLIVESPECIFICATION._serialized_end=1719
  _TABLE._serialized_start=1722
  _TABLE._serialized_end=2754
  _TABLE_TAGSENTRY._serialized_start=2711
  _TABLE_TAGSENTRY._serialized_end=2754
  _DYNAMODB_TABLE._serialized_start=2756
  _DYNAMODB_TABLE._serialized_end=2826
# @@protoc_insertion_point(module_scope)
