"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    SHA1_FINGERPRINT_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    sha1_fingerprint: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        sha1_fingerprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["package_name", b"package_name", "sha1_fingerprint", b"sha1_fingerprint"]) -> None: ...

global___ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications = ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications

@typing_extensions.final
class ApikeysKeyXRestrictionsXAndroidKeyRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_APPLICATIONS_FIELD_NUMBER: builtins.int
    @property
    def allowed_applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications]: ...
    def __init__(
        self,
        *,
        allowed_applications: collections.abc.Iterable[global___ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_applications", b"allowed_applications"]) -> None: ...

global___ApikeysKeyXRestrictionsXAndroidKeyRestrictions = ApikeysKeyXRestrictionsXAndroidKeyRestrictions

@typing_extensions.final
class ApikeysKeyXRestrictionsXApiTargets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METHODS_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service: builtins.str
    def __init__(
        self,
        *,
        methods: collections.abc.Iterable[builtins.str] | None = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["methods", b"methods", "service", b"service"]) -> None: ...

global___ApikeysKeyXRestrictionsXApiTargets = ApikeysKeyXRestrictionsXApiTargets

@typing_extensions.final
class ApikeysKeyXRestrictionsXBrowserKeyRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_REFERRERS_FIELD_NUMBER: builtins.int
    @property
    def allowed_referrers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_referrers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_referrers", b"allowed_referrers"]) -> None: ...

global___ApikeysKeyXRestrictionsXBrowserKeyRestrictions = ApikeysKeyXRestrictionsXBrowserKeyRestrictions

@typing_extensions.final
class ApikeysKeyXRestrictionsXIosKeyRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_BUNDLE_IDS_FIELD_NUMBER: builtins.int
    @property
    def allowed_bundle_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_bundle_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_bundle_ids", b"allowed_bundle_ids"]) -> None: ...

global___ApikeysKeyXRestrictionsXIosKeyRestrictions = ApikeysKeyXRestrictionsXIosKeyRestrictions

@typing_extensions.final
class ApikeysKeyXRestrictionsXServerKeyRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_IPS_FIELD_NUMBER: builtins.int
    @property
    def allowed_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_ips: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_ips", b"allowed_ips"]) -> None: ...

global___ApikeysKeyXRestrictionsXServerKeyRestrictions = ApikeysKeyXRestrictionsXServerKeyRestrictions

@typing_extensions.final
class ApikeysKeyXRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANDROID_KEY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    API_TARGETS_FIELD_NUMBER: builtins.int
    BROWSER_KEY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    IOS_KEY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    SERVER_KEY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    @property
    def android_key_restrictions(self) -> global___ApikeysKeyXRestrictionsXAndroidKeyRestrictions: ...
    @property
    def api_targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApikeysKeyXRestrictionsXApiTargets]: ...
    @property
    def browser_key_restrictions(self) -> global___ApikeysKeyXRestrictionsXBrowserKeyRestrictions: ...
    @property
    def ios_key_restrictions(self) -> global___ApikeysKeyXRestrictionsXIosKeyRestrictions: ...
    @property
    def server_key_restrictions(self) -> global___ApikeysKeyXRestrictionsXServerKeyRestrictions: ...
    def __init__(
        self,
        *,
        android_key_restrictions: global___ApikeysKeyXRestrictionsXAndroidKeyRestrictions | None = ...,
        api_targets: collections.abc.Iterable[global___ApikeysKeyXRestrictionsXApiTargets] | None = ...,
        browser_key_restrictions: global___ApikeysKeyXRestrictionsXBrowserKeyRestrictions | None = ...,
        ios_key_restrictions: global___ApikeysKeyXRestrictionsXIosKeyRestrictions | None = ...,
        server_key_restrictions: global___ApikeysKeyXRestrictionsXServerKeyRestrictions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["android_key_restrictions", b"android_key_restrictions", "browser_key_restrictions", b"browser_key_restrictions", "ios_key_restrictions", b"ios_key_restrictions", "server_key_restrictions", b"server_key_restrictions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["android_key_restrictions", b"android_key_restrictions", "api_targets", b"api_targets", "browser_key_restrictions", b"browser_key_restrictions", "ios_key_restrictions", b"ios_key_restrictions", "server_key_restrictions", b"server_key_restrictions"]) -> None: ...

global___ApikeysKeyXRestrictions = ApikeysKeyXRestrictions

@typing_extensions.final
class ApikeysKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ApikeysKeyXTimeouts = ApikeysKeyXTimeouts

@typing_extensions.final
class ApikeysKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_STRING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESTRICTIONS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    id: builtins.str
    key_string: builtins.str
    name: builtins.str
    project: builtins.str
    uid: builtins.str
    @property
    def restrictions(self) -> global___ApikeysKeyXRestrictions: ...
    @property
    def timeouts(self) -> global___ApikeysKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        key_string: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        uid: builtins.str = ...,
        restrictions: global___ApikeysKeyXRestrictions | None = ...,
        timeouts: global___ApikeysKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "restrictions", b"restrictions", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "id", b"id", "key_string", b"key_string", "name", b"name", "project", b"project", "resource_info", b"resource_info", "restrictions", b"restrictions", "timeouts", b"timeouts", "uid", b"uid"]) -> None: ...

global___ApikeysKey = ApikeysKey
