"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_routeTables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTE_TABLES_FIELD_NUMBER: builtins.int
    ROUTE_TABLES_ROUTES_FIELD_NUMBER: builtins.int
    @property
    def route_tables(self) -> global___RouteTables: ...
    @property
    def route_tables_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RouteTablesRoutes]: ...
    def __init__(
        self,
        *,
        route_tables: global___RouteTables | None = ...,
        route_tables_routes: collections.abc.Iterable[global___RouteTablesRoutes] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["route_tables", b"route_tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["route_tables", b"route_tables", "route_tables_routes", b"route_tables_routes"]) -> None: ...

global___Microsoft_Network_routeTables = Microsoft_Network_routeTables

@typing_extensions.final
class RouteTablesRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    NEXT_HOP_TYPE_FIELD_NUMBER: builtins.int
    NEXT_HOP_IP_ADDRESS_FIELD_NUMBER: builtins.int
    HAS_BGP_OVERRIDE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    address_prefix: builtins.str
    next_hop_type: builtins.str
    next_hop_ip_address: builtins.str
    has_bgp_override: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        address_prefix: builtins.str = ...,
        next_hop_type: builtins.str = ...,
        next_hop_ip_address: builtins.str = ...,
        has_bgp_override: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_prefix", b"address_prefix", "has_bgp_override", b"has_bgp_override", "name", b"name", "next_hop_ip_address", b"next_hop_ip_address", "next_hop_type", b"next_hop_type", "resource_info", b"resource_info"]) -> None: ...

global___RouteTablesRoutes = RouteTablesRoutes

@typing_extensions.final
class RouteTables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    DISABLE_BGP_ROUTE_PROPAGATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]: ...
    disable_bgp_route_propagation: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        routes: collections.abc.Iterable[global___Route] | None = ...,
        disable_bgp_route_propagation: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_bgp_route_propagation", b"disable_bgp_route_propagation", "location", b"location", "name", b"name", "resource_info", b"resource_info", "routes", b"routes", "tags", b"tags"]) -> None: ...

global___RouteTables = RouteTables

@typing_extensions.final
class Route(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    NEXT_HOP_TYPE_FIELD_NUMBER: builtins.int
    NEXT_HOP_IP_ADDRESS_FIELD_NUMBER: builtins.int
    HAS_BGP_OVERRIDE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    address_prefix: builtins.str
    next_hop_type: builtins.str
    next_hop_ip_address: builtins.str
    has_bgp_override: builtins.bool
    name: builtins.str
    def __init__(
        self,
        *,
        address_prefix: builtins.str = ...,
        next_hop_type: builtins.str = ...,
        next_hop_ip_address: builtins.str = ...,
        has_bgp_override: builtins.bool = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_prefix", b"address_prefix", "has_bgp_override", b"has_bgp_override", "name", b"name", "next_hop_ip_address", b"next_hop_ip_address", "next_hop_type", b"next_hop_type"]) -> None: ...

global___Route = Route
