# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSkubernetes/kubernetes_io.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.proto\x12@oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xbf\x01\n\x1e\x43ustomResourceColumnDefinition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x11\n\tjson_path\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcb\x01\n\x18\x43ustomResourceConversion\x12\x10\n\x08strategy\x18\x01 \x01(\t\x12\x64\n\x07webhook\x18\x02 \x01(\x0b\x32S.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.WebhookConversion\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x03\n\x18\x43ustomResourceDefinition\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12l\n\x04spec\x18\x04 \x01(\x0b\x32^.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionSpec\x12p\n\x06status\x18\x05 \x01(\x0b\x32`.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xee\x01\n!CustomResourceDefinitionCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x02\n\x1c\x43ustomResourceDefinitionList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12i\n\x05items\x18\x02 \x03(\x0b\x32Z.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinition\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n\x1d\x43ustomResourceDefinitionNames\x12\x12\n\ncategories\x18\x01 \x03(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x11\n\tlist_kind\x18\x03 \x01(\t\x12\x0e\n\x06plural\x18\x04 \x01(\t\x12\x13\n\x0bshort_names\x18\x05 \x03(\t\x12\x10\n\x08singular\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xeb\x03\n\x1c\x43ustomResourceDefinitionSpec\x12n\n\nconversion\x18\x01 \x01(\x0b\x32Z.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceConversion\x12\r\n\x05group\x18\x02 \x01(\t\x12n\n\x05names\x18\x03 \x01(\x0b\x32_.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames\x12\x1f\n\x17preserve_unknown_fields\x18\x04 \x01(\x08\x12\r\n\x05scope\x18\x05 \x01(\t\x12s\n\x08versions\x18\x06 \x03(\x0b\x32\x61.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe4\x02\n\x1e\x43ustomResourceDefinitionStatus\x12w\n\x0e\x61\x63\x63\x65pted_names\x18\x01 \x01(\x0b\x32_.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames\x12w\n\nconditions\x18\x02 \x03(\x0b\x32\x63.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionCondition\x12\x17\n\x0fstored_versions\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa1\x04\n\x1f\x43ustomResourceDefinitionVersion\x12\x84\x01\n\x1a\x61\x64\x64itional_printer_columns\x18\x01 \x03(\x0b\x32`.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceColumnDefinition\x12\x12\n\ndeprecated\x18\x02 \x01(\x08\x12\x1b\n\x13\x64\x65precation_warning\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12j\n\x06schema\x18\x05 \x01(\x0b\x32Z.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceValidation\x12\x0e\n\x06served\x18\x06 \x01(\x08\x12\x0f\n\x07storage\x18\x07 \x01(\x08\x12r\n\x0csubresources\x18\x08 \x01(\x0b\x32\\.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceSubresources\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x01\n\x1e\x43ustomResourceSubresourceScale\x12\x1b\n\x13label_selector_path\x18\x01 \x01(\t\x12\x1a\n\x12spec_replicas_path\x18\x02 \x01(\t\x12\x1c\n\x14status_replicas_path\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n\x1f\x43ustomResourceSubresourceStatus\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x02\n\x1a\x43ustomResourceSubresources\x12o\n\x05scale\x18\x01 \x01(\x0b\x32`.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceSubresourceScale\x12q\n\x06status\x18\x02 \x01(\x0b\x32\x61.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceSubresourceStatus\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n\x18\x43ustomResourceValidation\x12o\n\x14open_a_p_i_v3_schema\x18\x01 \x01(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"r\n\x15\x45xternalDocumentation\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"?\n\x04JSON\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa5\x14\n\x0fJSONSchemaProps\x12q\n\x10\x61\x64\x64itional_items\x18\x01 \x01(\x0b\x32W.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaPropsOrBool\x12v\n\x15\x61\x64\x64itional_properties\x18\x02 \x01(\x0b\x32W.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaPropsOrBool\x12\x61\n\x06\x61ll_of\x18\x03 \x03(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12\x61\n\x06\x61ny_of\x18\x04 \x03(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12W\n\x07\x64\x65\x66\x61ult\x18\x05 \x01(\x0b\x32\x46.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSON\x12w\n\x0b\x64\x65\x66initions\x18\x06 \x03(\x0b\x32\x62.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps.DefinitionsEntry\x12y\n\x0c\x64\x65pendencies\x18\x07 \x03(\x0b\x32\x63.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps.DependenciesEntry\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12T\n\x04\x65num\x18\t \x03(\x0b\x32\x46.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSON\x12W\n\x07\x65xample\x18\n \x01(\x0b\x32\x46.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSON\x12\x19\n\x11\x65xclusive_maximum\x18\x0b \x01(\x08\x12\x19\n\x11\x65xclusive_minimum\x18\x0c \x01(\x08\x12n\n\rexternal_docs\x18\r \x01(\x0b\x32W.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.ExternalDocumentation\x12\x0e\n\x06\x66ormat\x18\x0e \x01(\t\x12\n\n\x02id\x18\x0f \x01(\t\x12g\n\x05items\x18\x10 \x01(\x0b\x32X.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaPropsOrArray\x12\x11\n\tmax_items\x18\x11 \x01(\x05\x12\x12\n\nmax_length\x18\x12 \x01(\x05\x12\x16\n\x0emax_properties\x18\x13 \x01(\x05\x12\x0f\n\x07maximum\x18\x14 \x01(\x01\x12\x11\n\tmin_items\x18\x15 \x01(\x05\x12\x12\n\nmin_length\x18\x16 \x01(\x05\x12\x16\n\x0emin_properties\x18\x17 \x01(\x05\x12\x0f\n\x07minimum\x18\x18 \x01(\x01\x12\x13\n\x0bmultiple_of\x18\x19 \x01(\x01\x12^\n\x03not\x18\x1a \x01(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12\x10\n\x08nullable\x18\x1b \x01(\x08\x12\x61\n\x06one_of\x18\x1c \x03(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12\x0f\n\x07pattern\x18\x1d \x01(\t\x12\x84\x01\n\x12pattern_properties\x18\x1e \x03(\x0b\x32h.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps.PatternPropertiesEntry\x12u\n\nproperties\x18\x1f \x03(\x0b\x32\x61.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps.PropertiesEntry\x12\x10\n\x08required\x18  \x03(\t\x12\r\n\x05title\x18! \x01(\t\x12\x0c\n\x04type\x18\" \x01(\t\x12\x14\n\x0cunique_items\x18# \x01(\x08\x12#\n\x1bxkubernetesembeddedresource\x18$ \x01(\x08\x12\x1e\n\x16xkubernetesintorstring\x18% \x01(\x08\x12\x1e\n\x16xkuberneteslistmapkeys\x18& \x03(\t\x12\x1b\n\x13xkuberneteslisttype\x18\' \x01(\t\x12\x1a\n\x12xkubernetesmaptype\x18( \x01(\t\x12(\n xkubernetespreserveunknownfields\x18) \x01(\x08\x12p\n\x16xkubernetesvalidations\x18* \x03(\x0b\x32P.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.ValidationRule\x12\x37\n\rresource_info\x18+ \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x44\x65\x66initionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x44\x65pendenciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16PatternPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x16JSONSchemaPropsOrArray\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x15JSONSchemaPropsOrBool\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n\x1cJSONSchemaPropsOrStringArray\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x88\x01\n\x10ServiceReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"h\n\x0eValidationRule\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04rule\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd3\x01\n\x13WebhookClientConfig\x12\x11\n\tca_bundle\x18\x01 \x01(\t\x12\x63\n\x07service\x18\x02 \x01(\x0b\x32R.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.ServiceReference\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xde\x01\n\x11WebhookConversion\x12l\n\rclient_config\x18\x01 \x01(\x0b\x32U.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.WebhookClientConfig\x12\"\n\x1a\x63onversion_review_versions\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JSONSCHEMAPROPS_DEFINITIONSENTRY._options = None
  _JSONSCHEMAPROPS_DEFINITIONSENTRY._serialized_options = b'8\001'
  _JSONSCHEMAPROPS_DEPENDENCIESENTRY._options = None
  _JSONSCHEMAPROPS_DEPENDENCIESENTRY._serialized_options = b'8\001'
  _JSONSCHEMAPROPS_PATTERNPROPERTIESENTRY._options = None
  _JSONSCHEMAPROPS_PATTERNPROPERTIESENTRY._serialized_options = b'8\001'
  _JSONSCHEMAPROPS_PROPERTIESENTRY._options = None
  _JSONSCHEMAPROPS_PROPERTIESENTRY._serialized_options = b'8\001'
  _CUSTOMRESOURCECOLUMNDEFINITION._serialized_start=241
  _CUSTOMRESOURCECOLUMNDEFINITION._serialized_end=432
  _CUSTOMRESOURCECONVERSION._serialized_start=435
  _CUSTOMRESOURCECONVERSION._serialized_end=638
  _CUSTOMRESOURCEDEFINITION._serialized_start=641
  _CUSTOMRESOURCEDEFINITION._serialized_end=1060
  _CUSTOMRESOURCEDEFINITIONCONDITION._serialized_start=1063
  _CUSTOMRESOURCEDEFINITIONCONDITION._serialized_end=1301
  _CUSTOMRESOURCEDEFINITIONLIST._serialized_start=1304
  _CUSTOMRESOURCEDEFINITIONLIST._serialized_end=1608
  _CUSTOMRESOURCEDEFINITIONNAMES._serialized_start=1611
  _CUSTOMRESOURCEDEFINITIONNAMES._serialized_end=1807
  _CUSTOMRESOURCEDEFINITIONSPEC._serialized_start=1810
  _CUSTOMRESOURCEDEFINITIONSPEC._serialized_end=2301
  _CUSTOMRESOURCEDEFINITIONSTATUS._serialized_start=2304
  _CUSTOMRESOURCEDEFINITIONSTATUS._serialized_end=2660
  _CUSTOMRESOURCEDEFINITIONVERSION._serialized_start=2663
  _CUSTOMRESOURCEDEFINITIONVERSION._serialized_end=3208
  _CUSTOMRESOURCESUBRESOURCESCALE._serialized_start=3211
  _CUSTOMRESOURCESUBRESOURCESCALE._serialized_end=3387
  _CUSTOMRESOURCESUBRESOURCESTATUS._serialized_start=3389
  _CUSTOMRESOURCESUBRESOURCESTATUS._serialized_end=3479
  _CUSTOMRESOURCESUBRESOURCES._serialized_start=3482
  _CUSTOMRESOURCESUBRESOURCES._serialized_end=3795
  _CUSTOMRESOURCEVALIDATION._serialized_start=3798
  _CUSTOMRESOURCEVALIDATION._serialized_end=3994
  _EXTERNALDOCUMENTATION._serialized_start=3996
  _EXTERNALDOCUMENTATION._serialized_end=4110
  _JSON._serialized_start=4112
  _JSON._serialized_end=4175
  _JSONSCHEMAPROPS._serialized_start=4178
  _JSONSCHEMAPROPS._serialized_end=6775
  _JSONSCHEMAPROPS_DEFINITIONSENTRY._serialized_start=6563
  _JSONSCHEMAPROPS_DEFINITIONSENTRY._serialized_end=6613
  _JSONSCHEMAPROPS_DEPENDENCIESENTRY._serialized_start=6615
  _JSONSCHEMAPROPS_DEPENDENCIESENTRY._serialized_end=6666
  _JSONSCHEMAPROPS_PATTERNPROPERTIESENTRY._serialized_start=6668
  _JSONSCHEMAPROPS_PATTERNPROPERTIESENTRY._serialized_end=6724
  _JSONSCHEMAPROPS_PROPERTIESENTRY._serialized_start=6726
  _JSONSCHEMAPROPS_PROPERTIESENTRY._serialized_end=6775
  _JSONSCHEMAPROPSORARRAY._serialized_start=6777
  _JSONSCHEMAPROPSORARRAY._serialized_end=6858
  _JSONSCHEMAPROPSORBOOL._serialized_start=6860
  _JSONSCHEMAPROPSORBOOL._serialized_end=6940
  _JSONSCHEMAPROPSORSTRINGARRAY._serialized_start=6942
  _JSONSCHEMAPROPSORSTRINGARRAY._serialized_end=7029
  _SERVICEREFERENCE._serialized_start=7032
  _SERVICEREFERENCE._serialized_end=7168
  _VALIDATIONRULE._serialized_start=7170
  _VALIDATIONRULE._serialized_end=7274
  _WEBHOOKCLIENTCONFIG._serialized_start=7277
  _WEBHOOKCLIENTCONFIG._serialized_end=7488
  _WEBHOOKCONVERSION._serialized_start=7491
  _WEBHOOKCONVERSION._serialized_end=7713
# @@protoc_insertion_point(module_scope)
