# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_cloudiot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_cloudiot.proto\x12\x18oak9.tython.gcp.cloudiot\x1a\x13shared/shared.proto\"C\n$CloudiotDeviceXCredentialsXPublicKey\x12\x0e\n\x06\x66ormat\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x89\x01\n\x1a\x43loudiotDeviceXCredentials\x12\x17\n\x0f\x65xpiration_time\x18\x01 \x01(\t\x12R\n\npublic_key\x18\x02 \x01(\x0b\x32>.oak9.tython.gcp.cloudiot.CloudiotDeviceXCredentialsXPublicKey\"\x97\x01\n\x1c\x43loudiotDeviceXGatewayConfig\x12\x1b\n\x13gateway_auth_method\x18\x01 \x01(\t\x12\x14\n\x0cgateway_type\x18\x02 \x01(\t\x12 \n\x18last_accessed_gateway_id\x18\x03 \x01(\t\x12\"\n\x1alast_accessed_gateway_time\x18\x04 \x01(\t\"I\n\x17\x43loudiotDeviceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa2\x08\n\x0e\x43loudiotDevice\x12\x0f\n\x07\x62locked\x18\x01 \x01(\x08\x12\x44\n\x06\x63onfig\x18\x02 \x03(\x0b\x32\x34.oak9.tython.gcp.cloudiot.CloudiotDevice.ConfigEntry\x12\n\n\x02id\x18\x03 \x01(\t\x12\x1c\n\x14last_config_ack_time\x18\x04 \x01(\t\x12\x1d\n\x15last_config_send_time\x18\x05 \x01(\t\x12X\n\x11last_error_status\x18\x06 \x03(\x0b\x32=.oak9.tython.gcp.cloudiot.CloudiotDevice.LastErrorStatusEntry\x12\x17\n\x0flast_error_time\x18\x07 \x01(\t\x12\x17\n\x0flast_event_time\x18\x08 \x01(\t\x12\x1b\n\x13last_heartbeat_time\x18\t \x01(\t\x12\x17\n\x0flast_state_time\x18\n \x01(\t\x12\x11\n\tlog_level\x18\x0b \x01(\t\x12H\n\x08metadata\x18\x0c \x03(\x0b\x32\x36.oak9.tython.gcp.cloudiot.CloudiotDevice.MetadataEntry\x12\x0c\n\x04name\x18\r \x01(\t\x12\x0e\n\x06num_id\x18\x0e \x01(\t\x12\x10\n\x08registry\x18\x0f \x01(\t\x12\x42\n\x05state\x18\x10 \x03(\x0b\x32\x33.oak9.tython.gcp.cloudiot.CloudiotDevice.StateEntry\x12I\n\x0b\x63redentials\x18\x11 \x03(\x0b\x32\x34.oak9.tython.gcp.cloudiot.CloudiotDeviceXCredentials\x12N\n\x0egateway_config\x18\x12 \x01(\x0b\x32\x36.oak9.tython.gcp.cloudiot.CloudiotDeviceXGatewayConfig\x12\x43\n\x08timeouts\x18\x13 \x01(\x0b\x32\x31.oak9.tython.gcp.cloudiot.CloudiotDeviceXTimeouts\x12\x37\n\rresource_info\x18\x14 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14LastErrorStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nStateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcd\x01\n\x1c\x43loudiotRegistryXCredentials\x12p\n\x16public_key_certificate\x18\x01 \x03(\x0b\x32P.oak9.tython.gcp.cloudiot.CloudiotRegistryXCredentials.PublicKeyCertificateEntry\x1a;\n\x19PublicKeyCertificateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n)CloudiotRegistryXEventNotificationConfigs\x12\x19\n\x11pubsub_topic_name\x18\x01 \x01(\t\x12\x19\n\x11subfolder_matches\x18\x02 \x01(\t\"K\n\x19\x43loudiotRegistryXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xca\x06\n\x10\x43loudiotRegistry\x12O\n\x0bhttp_config\x18\x01 \x03(\x0b\x32:.oak9.tython.gcp.cloudiot.CloudiotRegistry.HttpConfigEntry\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tlog_level\x18\x03 \x01(\t\x12O\n\x0bmqtt_config\x18\x04 \x03(\x0b\x32:.oak9.tython.gcp.cloudiot.CloudiotRegistry.MqttConfigEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0e\n\x06region\x18\x07 \x01(\t\x12j\n\x19state_notification_config\x18\x08 \x03(\x0b\x32G.oak9.tython.gcp.cloudiot.CloudiotRegistry.StateNotificationConfigEntry\x12K\n\x0b\x63redentials\x18\t \x03(\x0b\x32\x36.oak9.tython.gcp.cloudiot.CloudiotRegistryXCredentials\x12g\n\x1a\x65vent_notification_configs\x18\n \x03(\x0b\x32\x43.oak9.tython.gcp.cloudiot.CloudiotRegistryXEventNotificationConfigs\x12\x45\n\x08timeouts\x18\x0b \x01(\x0b\x32\x33.oak9.tython.gcp.cloudiot.CloudiotRegistryXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0fHttpConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fMqttConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a>\n\x1cStateNotificationConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n$CloudiotRegistryIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x90\x02\n\x1a\x43loudiotRegistryIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12Q\n\tcondition\x18\x08 \x01(\x0b\x32>.oak9.tython.gcp.cloudiot.CloudiotRegistryIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#CloudiotRegistryIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n\x19\x43loudiotRegistryIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12P\n\tcondition\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.cloudiot.CloudiotRegistryIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x01\n\x19\x43loudiotRegistryIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_cloudiot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDIOTDEVICE_CONFIGENTRY._options = None
  _CLOUDIOTDEVICE_CONFIGENTRY._serialized_options = b'8\001'
  _CLOUDIOTDEVICE_LASTERRORSTATUSENTRY._options = None
  _CLOUDIOTDEVICE_LASTERRORSTATUSENTRY._serialized_options = b'8\001'
  _CLOUDIOTDEVICE_METADATAENTRY._options = None
  _CLOUDIOTDEVICE_METADATAENTRY._serialized_options = b'8\001'
  _CLOUDIOTDEVICE_STATEENTRY._options = None
  _CLOUDIOTDEVICE_STATEENTRY._serialized_options = b'8\001'
  _CLOUDIOTREGISTRYXCREDENTIALS_PUBLICKEYCERTIFICATEENTRY._options = None
  _CLOUDIOTREGISTRYXCREDENTIALS_PUBLICKEYCERTIFICATEENTRY._serialized_options = b'8\001'
  _CLOUDIOTREGISTRY_HTTPCONFIGENTRY._options = None
  _CLOUDIOTREGISTRY_HTTPCONFIGENTRY._serialized_options = b'8\001'
  _CLOUDIOTREGISTRY_MQTTCONFIGENTRY._options = None
  _CLOUDIOTREGISTRY_MQTTCONFIGENTRY._serialized_options = b'8\001'
  _CLOUDIOTREGISTRY_STATENOTIFICATIONCONFIGENTRY._options = None
  _CLOUDIOTREGISTRY_STATENOTIFICATIONCONFIGENTRY._serialized_options = b'8\001'
  _CLOUDIOTDEVICEXCREDENTIALSXPUBLICKEY._serialized_start=73
  _CLOUDIOTDEVICEXCREDENTIALSXPUBLICKEY._serialized_end=140
  _CLOUDIOTDEVICEXCREDENTIALS._serialized_start=143
  _CLOUDIOTDEVICEXCREDENTIALS._serialized_end=280
  _CLOUDIOTDEVICEXGATEWAYCONFIG._serialized_start=283
  _CLOUDIOTDEVICEXGATEWAYCONFIG._serialized_end=434
  _CLOUDIOTDEVICEXTIMEOUTS._serialized_start=436
  _CLOUDIOTDEVICEXTIMEOUTS._serialized_end=509
  _CLOUDIOTDEVICE._serialized_start=512
  _CLOUDIOTDEVICE._serialized_end=1570
  _CLOUDIOTDEVICE_CONFIGENTRY._serialized_start=1374
  _CLOUDIOTDEVICE_CONFIGENTRY._serialized_end=1419
  _CLOUDIOTDEVICE_LASTERRORSTATUSENTRY._serialized_start=1421
  _CLOUDIOTDEVICE_LASTERRORSTATUSENTRY._serialized_end=1475
  _CLOUDIOTDEVICE_METADATAENTRY._serialized_start=1477
  _CLOUDIOTDEVICE_METADATAENTRY._serialized_end=1524
  _CLOUDIOTDEVICE_STATEENTRY._serialized_start=1526
  _CLOUDIOTDEVICE_STATEENTRY._serialized_end=1570
  _CLOUDIOTREGISTRYXCREDENTIALS._serialized_start=1573
  _CLOUDIOTREGISTRYXCREDENTIALS._serialized_end=1778
  _CLOUDIOTREGISTRYXCREDENTIALS_PUBLICKEYCERTIFICATEENTRY._serialized_start=1719
  _CLOUDIOTREGISTRYXCREDENTIALS_PUBLICKEYCERTIFICATEENTRY._serialized_end=1778
  _CLOUDIOTREGISTRYXEVENTNOTIFICATIONCONFIGS._serialized_start=1780
  _CLOUDIOTREGISTRYXEVENTNOTIFICATIONCONFIGS._serialized_end=1877
  _CLOUDIOTREGISTRYXTIMEOUTS._serialized_start=1879
  _CLOUDIOTREGISTRYXTIMEOUTS._serialized_end=1954
  _CLOUDIOTREGISTRY._serialized_start=1957
  _CLOUDIOTREGISTRY._serialized_end=2799
  _CLOUDIOTREGISTRY_HTTPCONFIGENTRY._serialized_start=2635
  _CLOUDIOTREGISTRY_HTTPCONFIGENTRY._serialized_end=2684
  _CLOUDIOTREGISTRY_MQTTCONFIGENTRY._serialized_start=2686
  _CLOUDIOTREGISTRY_MQTTCONFIGENTRY._serialized_end=2735
  _CLOUDIOTREGISTRY_STATENOTIFICATIONCONFIGENTRY._serialized_start=2737
  _CLOUDIOTREGISTRY_STATENOTIFICATIONCONFIGENTRY._serialized_end=2799
  _CLOUDIOTREGISTRYIAMBINDINGXCONDITION._serialized_start=2801
  _CLOUDIOTREGISTRYIAMBINDINGXCONDITION._serialized_end=2895
  _CLOUDIOTREGISTRYIAMBINDING._serialized_start=2898
  _CLOUDIOTREGISTRYIAMBINDING._serialized_end=3170
  _CLOUDIOTREGISTRYIAMMEMBERXCONDITION._serialized_start=3172
  _CLOUDIOTREGISTRYIAMMEMBERXCONDITION._serialized_end=3265
  _CLOUDIOTREGISTRYIAMMEMBER._serialized_start=3268
  _CLOUDIOTREGISTRYIAMMEMBER._serialized_end=3537
  _CLOUDIOTREGISTRYIAMPOLICY._serialized_start=3540
  _CLOUDIOTREGISTRYIAMPOLICY._serialized_end=3718
# @@protoc_insertion_point(module_scope)
