"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_RecoveryServices_SiteRecovery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAULTS_REPLICATION_ALERT_SETTINGS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_NETWORKS_REPLICATION_NETWORK_MAPPINGS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_STORAGE_CLASSIFICATIONS_REPLICATION_STORAGE_CLASSIFICATION_MAPPINGS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_POLICIES_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_PROTECTION_INTENTS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_RECOVERY_PLANS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_VAULT_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def vaults_replication_alert_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationAlertSettings]: ...
    @property
    def vaults_replication_fabrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabrics]: ...
    @property
    def vaults_replication_fabrics_replication_networks_replication_network_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings]: ...
    @property
    def vaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings]: ...
    @property
    def vaults_replication_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationPolicies]: ...
    @property
    def vaults_replication_protection_intents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationProtectionIntents]: ...
    @property
    def vaults_replication_recovery_plans(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationRecoveryPlans]: ...
    @property
    def vaults_replication_vault_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationVaultSettings]: ...
    def __init__(
        self,
        *,
        vaults_replication_alert_settings: collections.abc.Iterable[global___VaultsReplicationAlertSettings] | None = ...,
        vaults_replication_fabrics: collections.abc.Iterable[global___VaultsReplicationFabrics] | None = ...,
        vaults_replication_fabrics_replication_networks_replication_network_mappings: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings] | None = ...,
        vaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings] | None = ...,
        vaults_replication_policies: collections.abc.Iterable[global___VaultsReplicationPolicies] | None = ...,
        vaults_replication_protection_intents: collections.abc.Iterable[global___VaultsReplicationProtectionIntents] | None = ...,
        vaults_replication_recovery_plans: collections.abc.Iterable[global___VaultsReplicationRecoveryPlans] | None = ...,
        vaults_replication_vault_settings: collections.abc.Iterable[global___VaultsReplicationVaultSettings] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vaults_replication_alert_settings", b"vaults_replication_alert_settings", "vaults_replication_fabrics", b"vaults_replication_fabrics", "vaults_replication_fabrics_replication_networks_replication_network_mappings", b"vaults_replication_fabrics_replication_networks_replication_network_mappings", "vaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings", b"vaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings", "vaults_replication_policies", b"vaults_replication_policies", "vaults_replication_protection_intents", b"vaults_replication_protection_intents", "vaults_replication_recovery_plans", b"vaults_replication_recovery_plans", "vaults_replication_vault_settings", b"vaults_replication_vault_settings"]) -> None: ...

global___Microsoft_RecoveryServices_SiteRecovery = Microsoft_RecoveryServices_SiteRecovery

@typing_extensions.final
class VaultsReplicationVaultSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MIGRATION_SOLUTION_ID_FIELD_NUMBER: builtins.int
    VMWARE_TO_AZURE_PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    migration_solution_id: builtins.str
    vmware_to_azure_provider_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        migration_solution_id: builtins.str = ...,
        vmware_to_azure_provider_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["migration_solution_id", b"migration_solution_id", "name", b"name", "resource_info", b"resource_info", "vmware_to_azure_provider_type", b"vmware_to_azure_provider_type"]) -> None: ...

global___VaultsReplicationVaultSettings = VaultsReplicationVaultSettings

@typing_extensions.final
class VaultsReplicationRecoveryPlans(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FAILOVER_DEPLOYMENT_MODEL_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    PRIMARY_FABRIC_ID_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_INPUT_FIELD_NUMBER: builtins.int
    RECOVERY_FABRIC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    failover_deployment_model: builtins.str
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanGroup]: ...
    primary_fabric_id: builtins.str
    @property
    def provider_specific_input(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanProviderSpecificInput]: ...
    recovery_fabric_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        failover_deployment_model: builtins.str = ...,
        groups: collections.abc.Iterable[global___RecoveryPlanGroup] | None = ...,
        primary_fabric_id: builtins.str = ...,
        provider_specific_input: collections.abc.Iterable[global___RecoveryPlanProviderSpecificInput] | None = ...,
        recovery_fabric_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failover_deployment_model", b"failover_deployment_model", "groups", b"groups", "name", b"name", "primary_fabric_id", b"primary_fabric_id", "provider_specific_input", b"provider_specific_input", "recovery_fabric_id", b"recovery_fabric_id", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationRecoveryPlans = VaultsReplicationRecoveryPlans

@typing_extensions.final
class RecoveryPlanProviderSpecificInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RecoveryPlanProviderSpecificInput = RecoveryPlanProviderSpecificInput

@typing_extensions.final
class RecoveryPlanGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_GROUP_ACTIONS_FIELD_NUMBER: builtins.int
    GROUP_TYPE_FIELD_NUMBER: builtins.int
    REPLICATION_PROTECTED_ITEMS_FIELD_NUMBER: builtins.int
    START_GROUP_ACTIONS_FIELD_NUMBER: builtins.int
    @property
    def end_group_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanAction]: ...
    group_type: builtins.str
    @property
    def replication_protected_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanProtectedItem]: ...
    @property
    def start_group_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanAction]: ...
    def __init__(
        self,
        *,
        end_group_actions: collections.abc.Iterable[global___RecoveryPlanAction] | None = ...,
        group_type: builtins.str = ...,
        replication_protected_items: collections.abc.Iterable[global___RecoveryPlanProtectedItem] | None = ...,
        start_group_actions: collections.abc.Iterable[global___RecoveryPlanAction] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_group_actions", b"end_group_actions", "group_type", b"group_type", "replication_protected_items", b"replication_protected_items", "start_group_actions", b"start_group_actions"]) -> None: ...

global___RecoveryPlanGroup = RecoveryPlanGroup

@typing_extensions.final
class RecoveryPlanProtectedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    virtual_machine_id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        virtual_machine_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "virtual_machine_id", b"virtual_machine_id"]) -> None: ...

global___RecoveryPlanProtectedItem = RecoveryPlanProtectedItem

@typing_extensions.final
class RecoveryPlanAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_NAME_FIELD_NUMBER: builtins.int
    CUSTOM_DETAILS_FIELD_NUMBER: builtins.int
    FAILOVER_DIRECTIONS_FIELD_NUMBER: builtins.int
    FAILOVER_TYPES_FIELD_NUMBER: builtins.int
    action_name: builtins.str
    @property
    def custom_details(self) -> global___RecoveryPlanActionDetails: ...
    @property
    def failover_directions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def failover_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        action_name: builtins.str = ...,
        custom_details: global___RecoveryPlanActionDetails | None = ...,
        failover_directions: collections.abc.Iterable[builtins.str] | None = ...,
        failover_types: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_details", b"custom_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_name", b"action_name", "custom_details", b"custom_details", "failover_directions", b"failover_directions", "failover_types", b"failover_types"]) -> None: ...

global___RecoveryPlanAction = RecoveryPlanAction

@typing_extensions.final
class RecoveryPlanActionDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RecoveryPlanActionDetails = RecoveryPlanActionDetails

@typing_extensions.final
class VaultsReplicationProtectionIntents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def provider_specific_details(self) -> global___CreateProtectionIntentProviderSpecificDetails: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        provider_specific_details: global___CreateProtectionIntentProviderSpecificDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationProtectionIntents = VaultsReplicationProtectionIntents

@typing_extensions.final
class CreateProtectionIntentProviderSpecificDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CreateProtectionIntentProviderSpecificDetails = CreateProtectionIntentProviderSpecificDetails

@typing_extensions.final
class VaultsReplicationPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_INPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def provider_specific_input(self) -> global___PolicyProviderSpecificInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        provider_specific_input: global___PolicyProviderSpecificInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationPolicies = VaultsReplicationPolicies

@typing_extensions.final
class PolicyProviderSpecificInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PolicyProviderSpecificInput = PolicyProviderSpecificInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationvCenters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FRIENDLY_NAME_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROCESS_SERVER_ID_FIELD_NUMBER: builtins.int
    RUN_AS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    friendly_name: builtins.str
    ip_address: builtins.str
    port: builtins.str
    process_server_id: builtins.str
    run_as_account_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        friendly_name: builtins.str = ...,
        ip_address: builtins.str = ...,
        port: builtins.str = ...,
        process_server_id: builtins.str = ...,
        run_as_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["friendly_name", b"friendly_name", "ip_address", b"ip_address", "name", b"name", "port", b"port", "process_server_id", b"process_server_id", "resource_info", b"resource_info", "run_as_account_id", b"run_as_account_id"]) -> None: ...

global___VaultsReplicationFabricsReplicationvCenters = VaultsReplicationFabricsReplicationvCenters

@typing_extensions.final
class VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_STORAGE_CLASSIFICATION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    target_storage_classification_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        target_storage_classification_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "target_storage_classification_id", b"target_storage_classification_id"]) -> None: ...

global___VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings = VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings

@typing_extensions.final
class VaultsReplicationFabricsReplicationRecoveryServicesProviders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_IDENTITY_INPUT_FIELD_NUMBER: builtins.int
    BIOS_ID_FIELD_NUMBER: builtins.int
    DATA_PLANE_AUTHENTICATION_IDENTITY_INPUT_FIELD_NUMBER: builtins.int
    MACHINE_ID_FIELD_NUMBER: builtins.int
    MACHINE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_ACCESS_IDENTITY_INPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def authentication_identity_input(self) -> global___IdentityProviderInput: ...
    bios_id: builtins.str
    @property
    def data_plane_authentication_identity_input(self) -> global___IdentityProviderInput: ...
    machine_id: builtins.str
    machine_name: builtins.str
    @property
    def resource_access_identity_input(self) -> global___IdentityProviderInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        authentication_identity_input: global___IdentityProviderInput | None = ...,
        bios_id: builtins.str = ...,
        data_plane_authentication_identity_input: global___IdentityProviderInput | None = ...,
        machine_id: builtins.str = ...,
        machine_name: builtins.str = ...,
        resource_access_identity_input: global___IdentityProviderInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_identity_input", b"authentication_identity_input", "data_plane_authentication_identity_input", b"data_plane_authentication_identity_input", "resource_access_identity_input", b"resource_access_identity_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_identity_input", b"authentication_identity_input", "bios_id", b"bios_id", "data_plane_authentication_identity_input", b"data_plane_authentication_identity_input", "machine_id", b"machine_id", "machine_name", b"machine_name", "name", b"name", "resource_access_identity_input", b"resource_access_identity_input", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationFabricsReplicationRecoveryServicesProviders = VaultsReplicationFabricsReplicationRecoveryServicesProviders

@typing_extensions.final
class IdentityProviderInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AAD_AUTHORITY_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    AUDIENCE_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    aad_authority: builtins.str
    application_id: builtins.str
    audience: builtins.str
    object_id: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        aad_authority: builtins.str = ...,
        application_id: builtins.str = ...,
        audience: builtins.str = ...,
        object_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aad_authority", b"aad_authority", "application_id", b"application_id", "audience", b"audience", "object_id", b"object_id", "tenant_id", b"tenant_id"]) -> None: ...

global___IdentityProviderInput = IdentityProviderInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_INPUT_FIELD_NUMBER: builtins.int
    TARGET_PROTECTION_CONTAINER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    policy_id: builtins.str
    @property
    def provider_specific_input(self) -> global___ReplicationProviderSpecificContainerMappingInput: ...
    target_protection_container_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        policy_id: builtins.str = ...,
        provider_specific_input: global___ReplicationProviderSpecificContainerMappingInput | None = ...,
        target_protection_container_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "policy_id", b"policy_id", "provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info", "target_protection_container_id", b"target_protection_container_id"]) -> None: ...

global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings = VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings

@typing_extensions.final
class ReplicationProviderSpecificContainerMappingInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ReplicationProviderSpecificContainerMappingInput = ReplicationProviderSpecificContainerMappingInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROTECTABLE_ITEM_ID_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    policy_id: builtins.str
    protectable_item_id: builtins.str
    @property
    def provider_specific_details(self) -> global___EnableProtectionProviderSpecificInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        policy_id: builtins.str = ...,
        protectable_item_id: builtins.str = ...,
        provider_specific_details: global___EnableProtectionProviderSpecificInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "policy_id", b"policy_id", "protectable_item_id", b"protectable_item_id", "provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems = VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems

@typing_extensions.final
class EnableProtectionProviderSpecificInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___EnableProtectionProviderSpecificInput = EnableProtectionProviderSpecificInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    policy_id: builtins.str
    @property
    def provider_specific_details(self) -> global___EnableMigrationProviderSpecificInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        policy_id: builtins.str = ...,
        provider_specific_details: global___EnableMigrationProviderSpecificInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "policy_id", b"policy_id", "provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems = VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems

@typing_extensions.final
class EnableMigrationProviderSpecificInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___EnableMigrationProviderSpecificInput = EnableMigrationProviderSpecificInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationProtectionContainers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_INPUT_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_PROTECTION_CONTAINERS_REPLICATION_MIGRATION_ITEMS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_PROTECTION_CONTAINERS_REPLICATION_PROTECTED_ITEMS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_PROTECTION_CONTAINERS_REPLICATION_PROTECTION_CONTAINER_MAPPINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def provider_specific_input(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicationProviderSpecificContainerCreationInput]: ...
    @property
    def vaults_replication_fabrics_replication_protection_containers_replication_migration_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems]: ...
    @property
    def vaults_replication_fabrics_replication_protection_containers_replication_protected_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems]: ...
    @property
    def vaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        provider_specific_input: collections.abc.Iterable[global___ReplicationProviderSpecificContainerCreationInput] | None = ...,
        vaults_replication_fabrics_replication_protection_containers_replication_migration_items: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems] | None = ...,
        vaults_replication_fabrics_replication_protection_containers_replication_protected_items: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems] | None = ...,
        vaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info", "vaults_replication_fabrics_replication_protection_containers_replication_migration_items", b"vaults_replication_fabrics_replication_protection_containers_replication_migration_items", "vaults_replication_fabrics_replication_protection_containers_replication_protected_items", b"vaults_replication_fabrics_replication_protection_containers_replication_protected_items", "vaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings", b"vaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings"]) -> None: ...

global___VaultsReplicationFabricsReplicationProtectionContainers = VaultsReplicationFabricsReplicationProtectionContainers

@typing_extensions.final
class ReplicationProviderSpecificContainerCreationInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ReplicationProviderSpecificContainerCreationInput = ReplicationProviderSpecificContainerCreationInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FABRIC_SPECIFIC_DETAILS_FIELD_NUMBER: builtins.int
    RECOVERY_FABRIC_NAME_FIELD_NUMBER: builtins.int
    RECOVERY_NETWORK_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def fabric_specific_details(self) -> global___FabricSpecificCreateNetworkMappingInput: ...
    recovery_fabric_name: builtins.str
    recovery_network_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        fabric_specific_details: global___FabricSpecificCreateNetworkMappingInput | None = ...,
        recovery_fabric_name: builtins.str = ...,
        recovery_network_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fabric_specific_details", b"fabric_specific_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fabric_specific_details", b"fabric_specific_details", "name", b"name", "recovery_fabric_name", b"recovery_fabric_name", "recovery_network_id", b"recovery_network_id", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings = VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings

@typing_extensions.final
class FabricSpecificCreateNetworkMappingInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___FabricSpecificCreateNetworkMappingInput = FabricSpecificCreateNetworkMappingInput

@typing_extensions.final
class VaultsReplicationFabrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CUSTOM_DETAILS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_PROTECTION_CONTAINERS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_RECOVERY_SERVICES_PROVIDERS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATIONV_CENTERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def custom_details(self) -> global___FabricSpecificCreationInput: ...
    @property
    def vaults_replication_fabrics_replication_protection_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationProtectionContainers]: ...
    @property
    def vaults_replication_fabrics_replication_recovery_services_providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationRecoveryServicesProviders]: ...
    @property
    def vaults_replication_fabrics_replicationv_centers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationvCenters]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        custom_details: global___FabricSpecificCreationInput | None = ...,
        vaults_replication_fabrics_replication_protection_containers: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationProtectionContainers] | None = ...,
        vaults_replication_fabrics_replication_recovery_services_providers: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationRecoveryServicesProviders] | None = ...,
        vaults_replication_fabrics_replicationv_centers: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationvCenters] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_details", b"custom_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_details", b"custom_details", "name", b"name", "resource_info", b"resource_info", "vaults_replication_fabrics_replication_protection_containers", b"vaults_replication_fabrics_replication_protection_containers", "vaults_replication_fabrics_replication_recovery_services_providers", b"vaults_replication_fabrics_replication_recovery_services_providers", "vaults_replication_fabrics_replicationv_centers", b"vaults_replication_fabrics_replicationv_centers"]) -> None: ...

global___VaultsReplicationFabrics = VaultsReplicationFabrics

@typing_extensions.final
class FabricSpecificCreationInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___FabricSpecificCreationInput = FabricSpecificCreationInput

@typing_extensions.final
class VaultsReplicationAlertSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CUSTOM_EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    LOCALE_FIELD_NUMBER: builtins.int
    SEND_TO_OWNERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def custom_email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    locale: builtins.str
    send_to_owners: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        custom_email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        locale: builtins.str = ...,
        send_to_owners: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_email_addresses", b"custom_email_addresses", "locale", b"locale", "name", b"name", "resource_info", b"resource_info", "send_to_owners", b"send_to_owners"]) -> None: ...

global___VaultsReplicationAlertSettings = VaultsReplicationAlertSettings
