# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_apigatewayv2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_apigatewayv2.proto\x12\x1coak9.tython.aws.apigatewayv2\x1a\x13shared/shared.proto\"\x88\x01\n\x11\x41piBodyS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\"\xcb\x01\n\x07\x41piCors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rallow_origins\x18\x02 \x03(\t\x12\x19\n\x11\x61llow_credentials\x18\x03 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x04 \x03(\t\x12\x15\n\rallow_headers\x18\x05 \x03(\t\x12\x0f\n\x07max_age\x18\x06 \x01(\x05\x12\x15\n\rallow_methods\x18\x07 \x03(\t\"\xe3\x05\n\x03\x41pi\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1aroute_selection_expression\x18\x02 \x01(\t\x12I\n\x10\x62ody_s3_location\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.apigatewayv2.ApiBodyS3Location\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tbase_path\x18\x05 \x01(\t\x12\x18\n\x10\x66\x61il_on_warnings\x18\x06 \x01(\x08\x12$\n\x1c\x64isable_execute_api_endpoint\x18\x07 \x01(\x08\x12!\n\x19\x64isable_schema_validation\x18\x08 \x01(\x08\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0e\n\x06target\x18\n \x01(\t\x12\x17\n\x0f\x63redentials_arn\x18\x0b \x01(\t\x12\x41\n\x12\x63ors_configuration\x18\x0c \x01(\x0b\x32%.oak9.tython.aws.apigatewayv2.ApiCors\x12\x0f\n\x07version\x18\r \x01(\t\x12\x15\n\rprotocol_type\x18\x0e \x01(\t\x12\x11\n\troute_key\x18\x0f \x01(\t\x12\x39\n\x04\x62ody\x18\x10 \x03(\x0b\x32+.oak9.tython.aws.apigatewayv2.Api.BodyEntry\x12\x39\n\x04tags\x18\x11 \x03(\x0b\x32+.oak9.tython.aws.apigatewayv2.Api.TagsEntry\x12$\n\x1c\x61pi_key_selection_expression\x18\x12 \x01(\t\x1a+\n\tBodyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x05\n\x0c\x41piGatewayV2\x12.\n\x03\x61pi\x18\x01 \x01(\x0b\x32!.oak9.tython.aws.apigatewayv2.Api\x12=\n\x0b\x61pi_mapping\x18\x02 \x03(\x0b\x32(.oak9.tython.aws.apigatewayv2.ApiMapping\x12<\n\nauthorizer\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.apigatewayv2.Authorizer\x12<\n\ndeployment\x18\x04 \x01(\x0b\x32(.oak9.tython.aws.apigatewayv2.Deployment\x12=\n\x0b\x64omain_name\x18\x05 \x03(\x0b\x32(.oak9.tython.aws.apigatewayv2.DomainName\x12>\n\x0bintegration\x18\x06 \x03(\x0b\x32).oak9.tython.aws.apigatewayv2.Integration\x12O\n\x14integration_response\x18\x07 \x03(\x0b\x32\x31.oak9.tython.aws.apigatewayv2.IntegrationResponse\x12\x32\n\x05model\x18\x08 \x01(\x0b\x32#.oak9.tython.aws.apigatewayv2.Model\x12\x32\n\x05route\x18\t \x03(\x0b\x32#.oak9.tython.aws.apigatewayv2.Route\x12\x43\n\x0eroute_response\x18\n \x03(\x0b\x32+.oak9.tython.aws.apigatewayv2.RouteResponse\x12\x32\n\x05stage\x18\x0b \x03(\x0b\x32#.oak9.tython.aws.apigatewayv2.Stage\"\x92\x01\n\nApiMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x17\n\x0f\x61pi_mapping_key\x18\x04 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x05 \x01(\t\"w\n\x1a\x41uthorizerJWTConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x03(\t\"\xc4\x03\n\nAuthorizer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1eidentity_validation_expression\x18\x02 \x01(\t\x12\x16\n\x0e\x61uthorizer_uri\x18\x03 \x01(\t\x12\"\n\x1a\x61uthorizer_credentials_arn\x18\x04 \x01(\t\x12\x17\n\x0f\x61uthorizer_type\x18\x05 \x01(\t\x12S\n\x11jwt_configuration\x18\x06 \x01(\x0b\x32\x38.oak9.tython.aws.apigatewayv2.AuthorizerJWTConfiguration\x12(\n authorizer_result_ttl_in_seconds\x18\x07 \x01(\x05\x12\x17\n\x0fidentity_source\x18\x08 \x03(\t\x12)\n!authorizer_payload_format_version\x18\t \x01(\t\x12\x1f\n\x17\x65nable_simple_responses\x18\n \x01(\x08\x12\x0e\n\x06\x61pi_id\x18\x0b \x01(\t\x12\x0c\n\x04name\x18\x0c \x01(\t\"~\n\nDeployment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nstage_name\x18\x03 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x04 \x01(\t\"\x90\x01\n!DomainNameMutualTlsAuthentication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12truststore_version\x18\x02 \x01(\t\x12\x16\n\x0etruststore_uri\x18\x03 \x01(\t\"\xbf\x01\n!DomainNameDomainNameConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fsecurity_policy\x18\x02 \x01(\t\x12\x15\n\rendpoint_type\x18\x03 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\x92\x03\n\nDomainName\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x19mutual_tls_authentication\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.apigatewayv2.DomainNameMutualTlsAuthentication\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x63\n\x1a\x64omain_name_configurations\x18\x04 \x03(\x0b\x32?.oak9.tython.aws.apigatewayv2.DomainNameDomainNameConfiguration\x12@\n\x04tags\x18\x05 \x03(\x0b\x32\x32.oak9.tython.aws.apigatewayv2.DomainName.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x14IntegrationTlsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15server_name_to_verify\x18\x02 \x01(\t\"\xb8\x06\n\x0bIntegration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12%\n\x1dtemplate_selection_expression\x18\x03 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x04 \x01(\t\x12\x1a\n\x12integration_method\x18\x05 \x01(\t\x12\x1c\n\x14passthrough_behavior\x18\x06 \x01(\t\x12\\\n\x12request_parameters\x18\x07 \x03(\x0b\x32@.oak9.tython.aws.apigatewayv2.Integration.RequestParametersEntry\x12\x15\n\rconnection_id\x18\x08 \x01(\t\x12\x17\n\x0fintegration_uri\x18\t \x01(\t\x12\x1e\n\x16payload_format_version\x18\n \x01(\t\x12\x17\n\x0f\x63redentials_arn\x18\x0b \x01(\t\x12Z\n\x11request_templates\x18\x0c \x03(\x0b\x32?.oak9.tython.aws.apigatewayv2.Integration.RequestTemplatesEntry\x12\x19\n\x11timeout_in_millis\x18\r \x01(\x05\x12\x46\n\ntls_config\x18\x0e \x01(\x0b\x32\x32.oak9.tython.aws.apigatewayv2.IntegrationTlsConfig\x12!\n\x19\x63ontent_handling_strategy\x18\x0f \x01(\t\x12\x1b\n\x13integration_subtype\x18\x10 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x11 \x01(\t\x12\x18\n\x10integration_type\x18\x12 \x01(\t\x1a\x38\n\x16RequestParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15RequestTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x04\n\x13IntegrationResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x64\n\x12response_templates\x18\x02 \x03(\x0b\x32H.oak9.tython.aws.apigatewayv2.IntegrationResponse.ResponseTemplatesEntry\x12%\n\x1dtemplate_selection_expression\x18\x03 \x01(\t\x12\x66\n\x13response_parameters\x18\x04 \x03(\x0b\x32I.oak9.tython.aws.apigatewayv2.IntegrationResponse.ResponseParametersEntry\x12!\n\x19\x63ontent_handling_strategy\x18\x05 \x01(\t\x12\x16\n\x0eintegration_id\x18\x06 \x01(\t\x12 \n\x18integration_response_key\x18\x07 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x08 \x01(\t\x1a\x38\n\x16ResponseTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x01\n\x05Model\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x03 \x01(\t\x12?\n\x06schema\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.apigatewayv2.Model.SchemaEntry\x12\x0e\n\x06\x61pi_id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a-\n\x0bSchemaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x04\n\x05Route\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06target\x18\x02 \x01(\t\x12+\n#route_response_selection_expression\x18\x03 \x01(\t\x12\x15\n\rauthorizer_id\x18\x04 \x01(\t\x12N\n\x0erequest_models\x18\x05 \x03(\x0b\x32\x36.oak9.tython.aws.apigatewayv2.Route.RequestModelsEntry\x12\x16\n\x0eoperation_name\x18\x06 \x01(\t\x12\x1c\n\x14\x61uthorization_scopes\x18\x07 \x03(\t\x12\x18\n\x10\x61pi_key_required\x18\x08 \x01(\x08\x12\x11\n\troute_key\x18\t \x01(\t\x12\x1a\n\x12\x61uthorization_type\x18\n \x01(\t\x12\"\n\x1amodel_selection_expression\x18\x0b \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x0c \x01(\t\x12V\n\x12request_parameters\x18\r \x03(\x0b\x32:.oak9.tython.aws.apigatewayv2.Route.RequestParametersEntry\x1a\x34\n\x12RequestModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16RequestParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd8\x03\n\rRouteResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12route_response_key\x18\x02 \x01(\t\x12`\n\x13response_parameters\x18\x03 \x03(\x0b\x32\x43.oak9.tython.aws.apigatewayv2.RouteResponse.ResponseParametersEntry\x12\x10\n\x08route_id\x18\x04 \x01(\t\x12\"\n\x1amodel_selection_expression\x18\x05 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x06 \x01(\t\x12X\n\x0fresponse_models\x18\x07 \x03(\x0b\x32?.oak9.tython.aws.apigatewayv2.RouteResponse.ResponseModelsEntry\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13ResponseModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x16StageAccessLogSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65stination_arn\x18\x03 \x01(\t\"\xe1\x01\n\x12StageRouteSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rlogging_level\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x61ta_trace_enabled\x18\x03 \x01(\x08\x12\x1e\n\x16throttling_burst_limit\x18\x04 \x01(\x05\x12 \n\x18\x64\x65tailed_metrics_enabled\x18\x05 \x01(\x08\x12\x1d\n\x15throttling_rate_limit\x18\x06 \x01(\x01\"\xe2\x05\n\x05Stage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63lient_certificate_id\x18\x02 \x01(\t\x12\x15\n\rdeployment_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12Q\n\x13\x61\x63\x63\x65ss_log_settings\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.apigatewayv2.StageAccessLogSettings\x12\x13\n\x0b\x61uto_deploy\x18\x06 \x01(\x08\x12N\n\x0eroute_settings\x18\x07 \x03(\x0b\x32\x36.oak9.tython.aws.apigatewayv2.Stage.RouteSettingsEntry\x12\x12\n\nstage_name\x18\x08 \x01(\t\x12P\n\x0fstage_variables\x18\t \x03(\x0b\x32\x37.oak9.tython.aws.apigatewayv2.Stage.StageVariablesEntry\x12\x0e\n\x06\x61pi_id\x18\n \x01(\t\x12P\n\x16\x64\x65\x66\x61ult_route_settings\x18\x0b \x01(\x0b\x32\x30.oak9.tython.aws.apigatewayv2.StageRouteSettings\x12;\n\x04tags\x18\x0c \x03(\x0b\x32-.oak9.tython.aws.apigatewayv2.Stage.TagsEntry\x1a\x34\n\x12RouteSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13StageVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x19RouteParameterConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08required\x18\x02 \x01(\x08\"n\n!RouteResponseParameterConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08required\x18\x02 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_apigatewayv2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _API_BODYENTRY._options = None
  _API_BODYENTRY._serialized_options = b'8\001'
  _API_TAGSENTRY._options = None
  _API_TAGSENTRY._serialized_options = b'8\001'
  _DOMAINNAME_TAGSENTRY._options = None
  _DOMAINNAME_TAGSENTRY._serialized_options = b'8\001'
  _INTEGRATION_REQUESTPARAMETERSENTRY._options = None
  _INTEGRATION_REQUESTPARAMETERSENTRY._serialized_options = b'8\001'
  _INTEGRATION_REQUESTTEMPLATESENTRY._options = None
  _INTEGRATION_REQUESTTEMPLATESENTRY._serialized_options = b'8\001'
  _INTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._options = None
  _INTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_options = b'8\001'
  _INTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _INTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _MODEL_SCHEMAENTRY._options = None
  _MODEL_SCHEMAENTRY._serialized_options = b'8\001'
  _ROUTE_REQUESTMODELSENTRY._options = None
  _ROUTE_REQUESTMODELSENTRY._serialized_options = b'8\001'
  _ROUTE_REQUESTPARAMETERSENTRY._options = None
  _ROUTE_REQUESTPARAMETERSENTRY._serialized_options = b'8\001'
  _ROUTERESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _ROUTERESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _ROUTERESPONSE_RESPONSEMODELSENTRY._options = None
  _ROUTERESPONSE_RESPONSEMODELSENTRY._serialized_options = b'8\001'
  _STAGE_ROUTESETTINGSENTRY._options = None
  _STAGE_ROUTESETTINGSENTRY._serialized_options = b'8\001'
  _STAGE_STAGEVARIABLESENTRY._options = None
  _STAGE_STAGEVARIABLESENTRY._serialized_options = b'8\001'
  _STAGE_TAGSENTRY._options = None
  _STAGE_TAGSENTRY._serialized_options = b'8\001'
  _APIBODYS3LOCATION._serialized_start=82
  _APIBODYS3LOCATION._serialized_end=218
  _APICORS._serialized_start=221
  _APICORS._serialized_end=424
  _API._serialized_start=427
  _API._serialized_end=1166
  _API_BODYENTRY._serialized_start=1078
  _API_BODYENTRY._serialized_end=1121
  _API_TAGSENTRY._serialized_start=1123
  _API_TAGSENTRY._serialized_end=1166
  _APIGATEWAYV2._serialized_start=1169
  _APIGATEWAYV2._serialized_end=1851
  _APIMAPPING._serialized_start=1854
  _APIMAPPING._serialized_end=2000
  _AUTHORIZERJWTCONFIGURATION._serialized_start=2002
  _AUTHORIZERJWTCONFIGURATION._serialized_end=2121
  _AUTHORIZER._serialized_start=2124
  _AUTHORIZER._serialized_end=2576
  _DEPLOYMENT._serialized_start=2578
  _DEPLOYMENT._serialized_end=2704
  _DOMAINNAMEMUTUALTLSAUTHENTICATION._serialized_start=2707
  _DOMAINNAMEMUTUALTLSAUTHENTICATION._serialized_end=2851
  _DOMAINNAMEDOMAINNAMECONFIGURATION._serialized_start=2854
  _DOMAINNAMEDOMAINNAMECONFIGURATION._serialized_end=3045
  _DOMAINNAME._serialized_start=3048
  _DOMAINNAME._serialized_end=3450
  _DOMAINNAME_TAGSENTRY._serialized_start=1123
  _DOMAINNAME_TAGSENTRY._serialized_end=1166
  _INTEGRATIONTLSCONFIG._serialized_start=3452
  _INTEGRATIONTLSCONFIG._serialized_end=3562
  _INTEGRATION._serialized_start=3565
  _INTEGRATION._serialized_end=4389
  _INTEGRATION_REQUESTPARAMETERSENTRY._serialized_start=4276
  _INTEGRATION_REQUESTPARAMETERSENTRY._serialized_end=4332
  _INTEGRATION_REQUESTTEMPLATESENTRY._serialized_start=4334
  _INTEGRATION_REQUESTTEMPLATESENTRY._serialized_end=4389
  _INTEGRATIONRESPONSE._serialized_start=4392
  _INTEGRATIONRESPONSE._serialized_end=4941
  _INTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_start=4826
  _INTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_end=4882
  _INTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=4884
  _INTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=4941
  _MODEL._serialized_start=4944
  _MODEL._serialized_end=5193
  _MODEL_SCHEMAENTRY._serialized_start=5148
  _MODEL_SCHEMAENTRY._serialized_end=5193
  _ROUTE._serialized_start=5196
  _ROUTE._serialized_end=5803
  _ROUTE_REQUESTMODELSENTRY._serialized_start=5693
  _ROUTE_REQUESTMODELSENTRY._serialized_end=5745
  _ROUTE_REQUESTPARAMETERSENTRY._serialized_start=4276
  _ROUTE_REQUESTPARAMETERSENTRY._serialized_end=4332
  _ROUTERESPONSE._serialized_start=5806
  _ROUTERESPONSE._serialized_end=6278
  _ROUTERESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=4884
  _ROUTERESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=4941
  _ROUTERESPONSE_RESPONSEMODELSENTRY._serialized_start=6225
  _ROUTERESPONSE_RESPONSEMODELSENTRY._serialized_end=6278
  _STAGEACCESSLOGSETTINGS._serialized_start=6280
  _STAGEACCESSLOGSETTINGS._serialized_end=6402
  _STAGEROUTESETTINGS._serialized_start=6405
  _STAGEROUTESETTINGS._serialized_end=6630
  _STAGE._serialized_start=6633
  _STAGE._serialized_end=7371
  _STAGE_ROUTESETTINGSENTRY._serialized_start=7219
  _STAGE_ROUTESETTINGSENTRY._serialized_end=7271
  _STAGE_STAGEVARIABLESENTRY._serialized_start=7273
  _STAGE_STAGEVARIABLESENTRY._serialized_end=7326
  _STAGE_TAGSENTRY._serialized_start=1123
  _STAGE_TAGSENTRY._serialized_end=1166
  _ROUTEPARAMETERCONSTRAINTS._serialized_start=7373
  _ROUTEPARAMETERCONSTRAINTS._serialized_end=7475
  _ROUTERESPONSEPARAMETERCONSTRAINTS._serialized_start=7477
  _ROUTERESPONSEPARAMETERCONSTRAINTS._serialized_end=7587
# @@protoc_insertion_point(module_scope)
