# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_org.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_org.proto\x12\x13oak9.tython.gcp.org\x1a\x13shared/shared.proto\"p\n$OrgPolicyPolicyXSpecXRulesXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"R\n!OrgPolicyPolicyXSpecXRulesXValues\x12\x16\n\x0e\x61llowed_values\x18\x01 \x03(\t\x12\x15\n\rdenied_values\x18\x02 \x03(\t\"\xe8\x01\n\x1aOrgPolicyPolicyXSpecXRules\x12\x11\n\tallow_all\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65ny_all\x18\x02 \x01(\t\x12\x0f\n\x07\x65nforce\x18\x03 \x01(\t\x12L\n\tcondition\x18\x04 \x01(\x0b\x32\x39.oak9.tython.gcp.org.OrgPolicyPolicyXSpecXRulesXCondition\x12\x46\n\x06values\x18\x05 \x01(\x0b\x32\x36.oak9.tython.gcp.org.OrgPolicyPolicyXSpecXRulesXValues\"\xa5\x01\n\x14OrgPolicyPolicyXSpec\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x1b\n\x13inherit_from_parent\x18\x02 \x01(\x08\x12\r\n\x05reset\x18\x03 \x01(\x08\x12\x13\n\x0bupdate_time\x18\x04 \x01(\t\x12>\n\x05rules\x18\x05 \x03(\x0b\x32/.oak9.tython.gcp.org.OrgPolicyPolicyXSpecXRules\"J\n\x18OrgPolicyPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xee\x01\n\x0fOrgPolicyPolicy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\x12\x37\n\x04spec\x18\x04 \x01(\x0b\x32).oak9.tython.gcp.org.OrgPolicyPolicyXSpec\x12?\n\x08timeouts\x18\x05 \x01(\x0b\x32-.oak9.tython.gcp.org.OrgPolicyPolicyXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_org_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ORGPOLICYPOLICYXSPECXRULESXCONDITION._serialized_start=63
  _ORGPOLICYPOLICYXSPECXRULESXCONDITION._serialized_end=175
  _ORGPOLICYPOLICYXSPECXRULESXVALUES._serialized_start=177
  _ORGPOLICYPOLICYXSPECXRULESXVALUES._serialized_end=259
  _ORGPOLICYPOLICYXSPECXRULES._serialized_start=262
  _ORGPOLICYPOLICYXSPECXRULES._serialized_end=494
  _ORGPOLICYPOLICYXSPEC._serialized_start=497
  _ORGPOLICYPOLICYXSPEC._serialized_end=662
  _ORGPOLICYPOLICYXTIMEOUTS._serialized_start=664
  _ORGPOLICYPOLICYXTIMEOUTS._serialized_end=738
  _ORGPOLICYPOLICY._serialized_start=741
  _ORGPOLICYPOLICY._serialized_end=979
# @@protoc_insertion_point(module_scope)
