"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApplicationCustomComponent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    component_name: builtins.str
    @property
    def resource_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        component_name: builtins.str = ...,
        resource_list: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_name", b"component_name", "resource_info", b"resource_info", "resource_list", b"resource_list"]) -> None: ...

global___ApplicationCustomComponent = ApplicationCustomComponent

@typing_extensions.final
class ApplicationLogPattern(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATTERN_NAME_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    pattern_name: builtins.str
    pattern: builtins.str
    rank: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        pattern_name: builtins.str = ...,
        pattern: builtins.str = ...,
        rank: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pattern", b"pattern", "pattern_name", b"pattern_name", "rank", b"rank", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationLogPattern = ApplicationLogPattern

@typing_extensions.final
class ApplicationLogPatternSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATTERN_SET_NAME_FIELD_NUMBER: builtins.int
    LOG_PATTERNS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    pattern_set_name: builtins.str
    @property
    def log_patterns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationLogPattern]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        pattern_set_name: builtins.str = ...,
        log_patterns: collections.abc.Iterable[global___ApplicationLogPattern] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_patterns", b"log_patterns", "pattern_set_name", b"pattern_set_name", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationLogPatternSet = ApplicationLogPatternSet

@typing_extensions.final
class ApplicationAlarmMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_METRIC_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alarm_metric_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_metric_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_metric_name", b"alarm_metric_name", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationAlarmMetric = ApplicationAlarmMetric

@typing_extensions.final
class ApplicationLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    LOG_PATH_FIELD_NUMBER: builtins.int
    LOG_TYPE_FIELD_NUMBER: builtins.int
    ENCODING_FIELD_NUMBER: builtins.int
    PATTERN_SET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_name: builtins.str
    log_path: builtins.str
    log_type: builtins.str
    encoding: builtins.str
    pattern_set: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_name: builtins.str = ...,
        log_path: builtins.str = ...,
        log_type: builtins.str = ...,
        encoding: builtins.str = ...,
        pattern_set: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encoding", b"encoding", "log_group_name", b"log_group_name", "log_path", b"log_path", "log_type", b"log_type", "pattern_set", b"pattern_set", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationLog = ApplicationLog

@typing_extensions.final
class ApplicationWindowsEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    EVENT_NAME_FIELD_NUMBER: builtins.int
    EVENT_LEVELS_FIELD_NUMBER: builtins.int
    PATTERN_SET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_name: builtins.str
    event_name: builtins.str
    @property
    def event_levels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    pattern_set: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_name: builtins.str = ...,
        event_name: builtins.str = ...,
        event_levels: collections.abc.Iterable[builtins.str] | None = ...,
        pattern_set: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_levels", b"event_levels", "event_name", b"event_name", "log_group_name", b"log_group_name", "pattern_set", b"pattern_set", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationWindowsEvent = ApplicationWindowsEvent

@typing_extensions.final
class ApplicationAlarm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_NAME_FIELD_NUMBER: builtins.int
    SEVERITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alarm_name: builtins.str
    severity: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_name: builtins.str = ...,
        severity: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_name", b"alarm_name", "resource_info", b"resource_info", "severity", b"severity"]) -> None: ...

global___ApplicationAlarm = ApplicationAlarm

@typing_extensions.final
class ApplicationConfigurationDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_METRICS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    WINDOWS_EVENTS_FIELD_NUMBER: builtins.int
    ALARMS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alarm_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationAlarmMetric]: ...
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationLog]: ...
    @property
    def windows_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationWindowsEvent]: ...
    @property
    def alarms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationAlarm]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_metrics: collections.abc.Iterable[global___ApplicationAlarmMetric] | None = ...,
        logs: collections.abc.Iterable[global___ApplicationLog] | None = ...,
        windows_events: collections.abc.Iterable[global___ApplicationWindowsEvent] | None = ...,
        alarms: collections.abc.Iterable[global___ApplicationAlarm] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_metrics", b"alarm_metrics", "alarms", b"alarms", "logs", b"logs", "resource_info", b"resource_info", "windows_events", b"windows_events"]) -> None: ...

global___ApplicationConfigurationDetails = ApplicationConfigurationDetails

@typing_extensions.final
class ApplicationSubComponentConfigurationDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_METRICS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    WINDOWS_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alarm_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationAlarmMetric]: ...
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationLog]: ...
    @property
    def windows_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationWindowsEvent]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_metrics: collections.abc.Iterable[global___ApplicationAlarmMetric] | None = ...,
        logs: collections.abc.Iterable[global___ApplicationLog] | None = ...,
        windows_events: collections.abc.Iterable[global___ApplicationWindowsEvent] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_metrics", b"alarm_metrics", "logs", b"logs", "resource_info", b"resource_info", "windows_events", b"windows_events"]) -> None: ...

global___ApplicationSubComponentConfigurationDetails = ApplicationSubComponentConfigurationDetails

@typing_extensions.final
class ApplicationSubComponentTypeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUB_COMPONENT_TYPE_FIELD_NUMBER: builtins.int
    SUB_COMPONENT_CONFIGURATION_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    sub_component_type: builtins.str
    @property
    def sub_component_configuration_details(self) -> global___ApplicationSubComponentConfigurationDetails: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        sub_component_type: builtins.str = ...,
        sub_component_configuration_details: global___ApplicationSubComponentConfigurationDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sub_component_configuration_details", b"sub_component_configuration_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sub_component_configuration_details", b"sub_component_configuration_details", "sub_component_type", b"sub_component_type"]) -> None: ...

global___ApplicationSubComponentTypeConfiguration = ApplicationSubComponentTypeConfiguration

@typing_extensions.final
class ApplicationComponentConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIGURATION_DETAILS_FIELD_NUMBER: builtins.int
    SUB_COMPONENT_TYPE_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def configuration_details(self) -> global___ApplicationConfigurationDetails: ...
    @property
    def sub_component_type_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationSubComponentTypeConfiguration]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        configuration_details: global___ApplicationConfigurationDetails | None = ...,
        sub_component_type_configurations: collections.abc.Iterable[global___ApplicationSubComponentTypeConfiguration] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration_details", b"configuration_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration_details", b"configuration_details", "resource_info", b"resource_info", "sub_component_type_configurations", b"sub_component_type_configurations"]) -> None: ...

global___ApplicationComponentConfiguration = ApplicationComponentConfiguration

@typing_extensions.final
class ApplicationComponentMonitoringSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    COMPONENT_ARN_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    COMPONENT_CONFIGURATION_MODE_FIELD_NUMBER: builtins.int
    DEFAULT_OVERWRITE_COMPONENT_CONFIGURATION_FIELD_NUMBER: builtins.int
    CUSTOM_COMPONENT_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    component_name: builtins.str
    component_arn: builtins.str
    tier: builtins.str
    component_configuration_mode: builtins.str
    @property
    def default_overwrite_component_configuration(self) -> global___ApplicationComponentConfiguration: ...
    @property
    def custom_component_configuration(self) -> global___ApplicationComponentConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        component_name: builtins.str = ...,
        component_arn: builtins.str = ...,
        tier: builtins.str = ...,
        component_configuration_mode: builtins.str = ...,
        default_overwrite_component_configuration: global___ApplicationComponentConfiguration | None = ...,
        custom_component_configuration: global___ApplicationComponentConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_component_configuration", b"custom_component_configuration", "default_overwrite_component_configuration", b"default_overwrite_component_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_arn", b"component_arn", "component_configuration_mode", b"component_configuration_mode", "component_name", b"component_name", "custom_component_configuration", b"custom_component_configuration", "default_overwrite_component_configuration", b"default_overwrite_component_configuration", "resource_info", b"resource_info", "tier", b"tier"]) -> None: ...

global___ApplicationComponentMonitoringSetting = ApplicationComponentMonitoringSetting

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    CWE_MONITOR_ENABLED_FIELD_NUMBER: builtins.int
    OPS_CENTER_ENABLED_FIELD_NUMBER: builtins.int
    OPS_ITEM_SNS_TOPIC_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CUSTOM_COMPONENTS_FIELD_NUMBER: builtins.int
    LOG_PATTERN_SETS_FIELD_NUMBER: builtins.int
    AUTO_CONFIGURATION_ENABLED_FIELD_NUMBER: builtins.int
    COMPONENT_MONITORING_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_group_name: builtins.str
    cwe_monitor_enabled: builtins.bool
    ops_center_enabled: builtins.bool
    ops_item_sns_topic_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def custom_components(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationCustomComponent]: ...
    @property
    def log_pattern_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationLogPatternSet]: ...
    auto_configuration_enabled: builtins.bool
    @property
    def component_monitoring_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationComponentMonitoringSetting]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_group_name: builtins.str = ...,
        cwe_monitor_enabled: builtins.bool = ...,
        ops_center_enabled: builtins.bool = ...,
        ops_item_sns_topic_arn: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        custom_components: collections.abc.Iterable[global___ApplicationCustomComponent] | None = ...,
        log_pattern_sets: collections.abc.Iterable[global___ApplicationLogPatternSet] | None = ...,
        auto_configuration_enabled: builtins.bool = ...,
        component_monitoring_settings: collections.abc.Iterable[global___ApplicationComponentMonitoringSetting] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_configuration_enabled", b"auto_configuration_enabled", "component_monitoring_settings", b"component_monitoring_settings", "custom_components", b"custom_components", "cwe_monitor_enabled", b"cwe_monitor_enabled", "log_pattern_sets", b"log_pattern_sets", "ops_center_enabled", b"ops_center_enabled", "ops_item_sns_topic_arn", b"ops_item_sns_topic_arn", "resource_group_name", b"resource_group_name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Application = Application

@typing_extensions.final
class ApplicationInsights(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Application]: ...
    def __init__(
        self,
        *,
        application: collections.abc.Iterable[global___Application] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___ApplicationInsights = ApplicationInsights
