# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_firebaserules.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgcp/gcp_firebaserules.proto\x12\x1doak9.tython.gcp.firebaserules\x1a\x13shared/shared.proto\"O\n\x1d\x46irebaserulesReleaseXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9c\x02\n\x14\x46irebaserulesRelease\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x14\n\x0cruleset_name\x18\x06 \x01(\t\x12\x13\n\x0bupdate_time\x18\x07 \x01(\t\x12N\n\x08timeouts\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.firebaserules.FirebaserulesReleaseXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n!FirebaserulesRulesetXSourceXFiles\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x80\x01\n\x1b\x46irebaserulesRulesetXSource\x12\x10\n\x08language\x18\x01 \x01(\t\x12O\n\x05\x66iles\x18\x02 \x03(\x0b\x32@.oak9.tython.gcp.firebaserules.FirebaserulesRulesetXSourceXFiles\"?\n\x1d\x46irebaserulesRulesetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xb1\x03\n\x14\x46irebaserulesRuleset\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12S\n\x08metadata\x18\x03 \x03(\x0b\x32\x41.oak9.tython.gcp.firebaserules.FirebaserulesRuleset.MetadataEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12J\n\x06source\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.firebaserules.FirebaserulesRulesetXSource\x12N\n\x08timeouts\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.firebaserules.FirebaserulesRulesetXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_firebaserules_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FIREBASERULESRULESET_METADATAENTRY._options = None
  _FIREBASERULESRULESET_METADATAENTRY._serialized_options = b'8\001'
  _FIREBASERULESRELEASEXTIMEOUTS._serialized_start=83
  _FIREBASERULESRELEASEXTIMEOUTS._serialized_end=162
  _FIREBASERULESRELEASE._serialized_start=165
  _FIREBASERULESRELEASE._serialized_end=449
  _FIREBASERULESRULESETXSOURCEXFILES._serialized_start=451
  _FIREBASERULESRULESETXSOURCEXFILES._serialized_end=538
  _FIREBASERULESRULESETXSOURCE._serialized_start=541
  _FIREBASERULESRULESETXSOURCE._serialized_end=669
  _FIREBASERULESRULESETXTIMEOUTS._serialized_start=671
  _FIREBASERULESRULESETXTIMEOUTS._serialized_end=734
  _FIREBASERULESRULESET._serialized_start=737
  _FIREBASERULESRULESET._serialized_end=1170
  _FIREBASERULESRULESET_METADATAENTRY._serialized_start=1123
  _FIREBASERULESRULESET_METADATAENTRY._serialized_end=1170
# @@protoc_insertion_point(module_scope)
