# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_route53resolver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ws/aws_route53resolver.proto\x12\x1foak9.tython.aws.route53resolver\x1a\x13shared/shared.proto\"z\n ResolverEndpointIpAddressRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\"\xd9\x02\n\x10ResolverEndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x0cip_addresses\x18\x02 \x03(\x0b\x32\x41.oak9.tython.aws.route53resolver.ResolverEndpointIpAddressRequest\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x04 \x03(\t\x12I\n\x04tags\x18\x05 \x03(\x0b\x32;.oak9.tython.aws.route53resolver.ResolverEndpoint.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe1\x03\n\x0fRoute53Resolver\x12L\n\x11resolver_endpoint\x18\x01 \x03(\x0b\x32\x31.oak9.tython.aws.route53resolver.ResolverEndpoint\x12\x62\n\x1dresolver_query_logging_config\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.route53resolver.ResolverQueryLoggingConfig\x12y\n)resolver_query_logging_config_association\x18\x03 \x03(\x0b\x32\x46.oak9.tython.aws.route53resolver.ResolverQueryLoggingConfigAssociation\x12\x44\n\rresolver_rule\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.route53resolver.ResolverRule\x12[\n\x19resolver_rule_association\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.route53resolver.ResolverRuleAssociation\"|\n\x1aResolverQueryLoggingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65stination_arn\x18\x03 \x01(\t\"\x9b\x01\n%ResolverQueryLoggingConfigAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12$\n\x1cresolver_query_log_config_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\"n\n\x19ResolverRuleTargetAddress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\"\xdf\x02\n\x0cResolverRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14resolver_endpoint_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x11\n\trule_type\x18\x04 \x01(\t\x12N\n\ntarget_ips\x18\x05 \x03(\x0b\x32:.oak9.tython.aws.route53resolver.ResolverRuleTargetAddress\x12\x45\n\x04tags\x18\x06 \x03(\x0b\x32\x37.oak9.tython.aws.route53resolver.ResolverRule.TagsEntry\x12\x0c\n\x04name\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\x17ResolverRuleAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\x12\x18\n\x10resolver_rule_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_route53resolver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOLVERENDPOINT_TAGSENTRY._options = None
  _RESOLVERENDPOINT_TAGSENTRY._serialized_options = b'8\001'
  _RESOLVERRULE_TAGSENTRY._options = None
  _RESOLVERRULE_TAGSENTRY._serialized_options = b'8\001'
  _RESOLVERENDPOINTIPADDRESSREQUEST._serialized_start=87
  _RESOLVERENDPOINTIPADDRESSREQUEST._serialized_end=209
  _RESOLVERENDPOINT._serialized_start=212
  _RESOLVERENDPOINT._serialized_end=557
  _RESOLVERENDPOINT_TAGSENTRY._serialized_start=514
  _RESOLVERENDPOINT_TAGSENTRY._serialized_end=557
  _ROUTE53RESOLVER._serialized_start=560
  _ROUTE53RESOLVER._serialized_end=1041
  _RESOLVERQUERYLOGGINGCONFIG._serialized_start=1043
  _RESOLVERQUERYLOGGINGCONFIG._serialized_end=1167
  _RESOLVERQUERYLOGGINGCONFIGASSOCIATION._serialized_start=1170
  _RESOLVERQUERYLOGGINGCONFIGASSOCIATION._serialized_end=1325
  _RESOLVERRULETARGETADDRESS._serialized_start=1327
  _RESOLVERRULETARGETADDRESS._serialized_end=1437
  _RESOLVERRULE._serialized_start=1440
  _RESOLVERRULE._serialized_end=1791
  _RESOLVERRULE_TAGSENTRY._serialized_start=514
  _RESOLVERRULE_TAGSENTRY._serialized_end=557
  _RESOLVERRULEASSOCIATION._serialized_start=1794
  _RESOLVERRULEASSOCIATION._serialized_end=1932
# @@protoc_insertion_point(module_scope)
