"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudbuildTriggerXApprovalConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPROVAL_REQUIRED_FIELD_NUMBER: builtins.int
    approval_required: builtins.bool
    def __init__(
        self,
        *,
        approval_required: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_required", b"approval_required"]) -> None: ...

global___CloudbuildTriggerXApprovalConfig = CloudbuildTriggerXApprovalConfig

@typing_extensions.final
class CloudbuildTriggerXBuildXArtifactsXObjects(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TimingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LOCATION_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    TIMING_FIELD_NUMBER: builtins.int
    location: builtins.str
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def timing(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        location: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        timing: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "paths", b"paths", "timing", b"timing"]) -> None: ...

global___CloudbuildTriggerXBuildXArtifactsXObjects = CloudbuildTriggerXBuildXArtifactsXObjects

@typing_extensions.final
class CloudbuildTriggerXBuildXArtifacts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGES_FIELD_NUMBER: builtins.int
    OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def objects(self) -> global___CloudbuildTriggerXBuildXArtifactsXObjects: ...
    def __init__(
        self,
        *,
        images: collections.abc.Iterable[builtins.str] | None = ...,
        objects: global___CloudbuildTriggerXBuildXArtifactsXObjects | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["objects", b"objects"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["images", b"images", "objects", b"objects"]) -> None: ...

global___CloudbuildTriggerXBuildXArtifacts = CloudbuildTriggerXBuildXArtifacts

@typing_extensions.final
class CloudbuildTriggerXBuildXAvailableSecretsXSecretManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_FIELD_NUMBER: builtins.int
    VERSION_NAME_FIELD_NUMBER: builtins.int
    env: builtins.str
    version_name: builtins.str
    def __init__(
        self,
        *,
        env: builtins.str = ...,
        version_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "version_name", b"version_name"]) -> None: ...

global___CloudbuildTriggerXBuildXAvailableSecretsXSecretManager = CloudbuildTriggerXBuildXAvailableSecretsXSecretManager

@typing_extensions.final
class CloudbuildTriggerXBuildXAvailableSecrets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_MANAGER_FIELD_NUMBER: builtins.int
    @property
    def secret_manager(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXAvailableSecretsXSecretManager]: ...
    def __init__(
        self,
        *,
        secret_manager: collections.abc.Iterable[global___CloudbuildTriggerXBuildXAvailableSecretsXSecretManager] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_manager", b"secret_manager"]) -> None: ...

global___CloudbuildTriggerXBuildXAvailableSecrets = CloudbuildTriggerXBuildXAvailableSecrets

@typing_extensions.final
class CloudbuildTriggerXBuildXOptionsXVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "path", b"path"]) -> None: ...

global___CloudbuildTriggerXBuildXOptionsXVolumes = CloudbuildTriggerXBuildXOptionsXVolumes

@typing_extensions.final
class CloudbuildTriggerXBuildXOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DYNAMIC_SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    LOG_STREAMING_OPTION_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    REQUESTED_VERIFY_OPTION_FIELD_NUMBER: builtins.int
    SECRET_ENV_FIELD_NUMBER: builtins.int
    SOURCE_PROVENANCE_HASH_FIELD_NUMBER: builtins.int
    SUBSTITUTION_OPTION_FIELD_NUMBER: builtins.int
    WORKER_POOL_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    disk_size_gb: builtins.float
    dynamic_substitutions: builtins.bool
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    log_streaming_option: builtins.str
    logging: builtins.str
    machine_type: builtins.str
    requested_verify_option: builtins.str
    @property
    def secret_env(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_provenance_hash(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    substitution_option: builtins.str
    worker_pool: builtins.str
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXOptionsXVolumes]: ...
    def __init__(
        self,
        *,
        disk_size_gb: builtins.float = ...,
        dynamic_substitutions: builtins.bool = ...,
        env: collections.abc.Iterable[builtins.str] | None = ...,
        log_streaming_option: builtins.str = ...,
        logging: builtins.str = ...,
        machine_type: builtins.str = ...,
        requested_verify_option: builtins.str = ...,
        secret_env: collections.abc.Iterable[builtins.str] | None = ...,
        source_provenance_hash: collections.abc.Iterable[builtins.str] | None = ...,
        substitution_option: builtins.str = ...,
        worker_pool: builtins.str = ...,
        volumes: collections.abc.Iterable[global___CloudbuildTriggerXBuildXOptionsXVolumes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_size_gb", b"disk_size_gb", "dynamic_substitutions", b"dynamic_substitutions", "env", b"env", "log_streaming_option", b"log_streaming_option", "logging", b"logging", "machine_type", b"machine_type", "requested_verify_option", b"requested_verify_option", "secret_env", b"secret_env", "source_provenance_hash", b"source_provenance_hash", "substitution_option", b"substitution_option", "volumes", b"volumes", "worker_pool", b"worker_pool"]) -> None: ...

global___CloudbuildTriggerXBuildXOptions = CloudbuildTriggerXBuildXOptions

@typing_extensions.final
class CloudbuildTriggerXBuildXSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SecretEnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    SECRET_ENV_FIELD_NUMBER: builtins.int
    kms_key_name: builtins.str
    @property
    def secret_env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        kms_key_name: builtins.str = ...,
        secret_env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_name", b"kms_key_name", "secret_env", b"secret_env"]) -> None: ...

global___CloudbuildTriggerXBuildXSecret = CloudbuildTriggerXBuildXSecret

@typing_extensions.final
class CloudbuildTriggerXBuildXSourceXRepoSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SubstitutionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BRANCH_NAME_FIELD_NUMBER: builtins.int
    COMMIT_SHA_FIELD_NUMBER: builtins.int
    DIR_FIELD_NUMBER: builtins.int
    INVERT_REGEX_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    REPO_NAME_FIELD_NUMBER: builtins.int
    SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    TAG_NAME_FIELD_NUMBER: builtins.int
    branch_name: builtins.str
    commit_sha: builtins.str
    dir: builtins.str
    invert_regex: builtins.bool
    project_id: builtins.str
    repo_name: builtins.str
    @property
    def substitutions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    tag_name: builtins.str
    def __init__(
        self,
        *,
        branch_name: builtins.str = ...,
        commit_sha: builtins.str = ...,
        dir: builtins.str = ...,
        invert_regex: builtins.bool = ...,
        project_id: builtins.str = ...,
        repo_name: builtins.str = ...,
        substitutions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tag_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_name", b"branch_name", "commit_sha", b"commit_sha", "dir", b"dir", "invert_regex", b"invert_regex", "project_id", b"project_id", "repo_name", b"repo_name", "substitutions", b"substitutions", "tag_name", b"tag_name"]) -> None: ...

global___CloudbuildTriggerXBuildXSourceXRepoSource = CloudbuildTriggerXBuildXSourceXRepoSource

@typing_extensions.final
class CloudbuildTriggerXBuildXSourceXStorageSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation: builtins.str
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation: builtins.str = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation", b"generation", "object", b"object"]) -> None: ...

global___CloudbuildTriggerXBuildXSourceXStorageSource = CloudbuildTriggerXBuildXSourceXStorageSource

@typing_extensions.final
class CloudbuildTriggerXBuildXSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPO_SOURCE_FIELD_NUMBER: builtins.int
    STORAGE_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def repo_source(self) -> global___CloudbuildTriggerXBuildXSourceXRepoSource: ...
    @property
    def storage_source(self) -> global___CloudbuildTriggerXBuildXSourceXStorageSource: ...
    def __init__(
        self,
        *,
        repo_source: global___CloudbuildTriggerXBuildXSourceXRepoSource | None = ...,
        storage_source: global___CloudbuildTriggerXBuildXSourceXStorageSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repo_source", b"repo_source", "storage_source", b"storage_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["repo_source", b"repo_source", "storage_source", b"storage_source"]) -> None: ...

global___CloudbuildTriggerXBuildXSource = CloudbuildTriggerXBuildXSource

@typing_extensions.final
class CloudbuildTriggerXBuildXStepXVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "path", b"path"]) -> None: ...

global___CloudbuildTriggerXBuildXStepXVolumes = CloudbuildTriggerXBuildXStepXVolumes

@typing_extensions.final
class CloudbuildTriggerXBuildXStep(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    DIR_FIELD_NUMBER: builtins.int
    ENTRYPOINT_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SECRET_ENV_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    TIMING_FIELD_NUMBER: builtins.int
    WAIT_FOR_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    dir: builtins.str
    entrypoint: builtins.str
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    name: builtins.str
    @property
    def secret_env(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    timeout: builtins.str
    timing: builtins.str
    @property
    def wait_for(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXStepXVolumes]: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        dir: builtins.str = ...,
        entrypoint: builtins.str = ...,
        env: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        secret_env: collections.abc.Iterable[builtins.str] | None = ...,
        timeout: builtins.str = ...,
        timing: builtins.str = ...,
        wait_for: collections.abc.Iterable[builtins.str] | None = ...,
        volumes: collections.abc.Iterable[global___CloudbuildTriggerXBuildXStepXVolumes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "dir", b"dir", "entrypoint", b"entrypoint", "env", b"env", "id", b"id", "name", b"name", "secret_env", b"secret_env", "timeout", b"timeout", "timing", b"timing", "volumes", b"volumes", "wait_for", b"wait_for"]) -> None: ...

global___CloudbuildTriggerXBuildXStep = CloudbuildTriggerXBuildXStep

@typing_extensions.final
class CloudbuildTriggerXBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SubstitutionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGES_FIELD_NUMBER: builtins.int
    LOGS_BUCKET_FIELD_NUMBER: builtins.int
    QUEUE_TTL_FIELD_NUMBER: builtins.int
    SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    ARTIFACTS_FIELD_NUMBER: builtins.int
    AVAILABLE_SECRETS_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    logs_bucket: builtins.str
    queue_ttl: builtins.str
    @property
    def substitutions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    timeout: builtins.str
    @property
    def artifacts(self) -> global___CloudbuildTriggerXBuildXArtifacts: ...
    @property
    def available_secrets(self) -> global___CloudbuildTriggerXBuildXAvailableSecrets: ...
    @property
    def options(self) -> global___CloudbuildTriggerXBuildXOptions: ...
    @property
    def secret(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXSecret]: ...
    @property
    def source(self) -> global___CloudbuildTriggerXBuildXSource: ...
    @property
    def step(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXStep]: ...
    def __init__(
        self,
        *,
        images: collections.abc.Iterable[builtins.str] | None = ...,
        logs_bucket: builtins.str = ...,
        queue_ttl: builtins.str = ...,
        substitutions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        timeout: builtins.str = ...,
        artifacts: global___CloudbuildTriggerXBuildXArtifacts | None = ...,
        available_secrets: global___CloudbuildTriggerXBuildXAvailableSecrets | None = ...,
        options: global___CloudbuildTriggerXBuildXOptions | None = ...,
        secret: collections.abc.Iterable[global___CloudbuildTriggerXBuildXSecret] | None = ...,
        source: global___CloudbuildTriggerXBuildXSource | None = ...,
        step: collections.abc.Iterable[global___CloudbuildTriggerXBuildXStep] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts", "available_secrets", b"available_secrets", "options", b"options", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts", "available_secrets", b"available_secrets", "images", b"images", "logs_bucket", b"logs_bucket", "options", b"options", "queue_ttl", b"queue_ttl", "secret", b"secret", "source", b"source", "step", b"step", "substitutions", b"substitutions", "tags", b"tags", "timeout", b"timeout"]) -> None: ...

global___CloudbuildTriggerXBuild = CloudbuildTriggerXBuild

@typing_extensions.final
class CloudbuildTriggerXGitFileSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    REPO_TYPE_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    path: builtins.str
    repo_type: builtins.str
    revision: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        repo_type: builtins.str = ...,
        revision: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "repo_type", b"repo_type", "revision", b"revision", "uri", b"uri"]) -> None: ...

global___CloudbuildTriggerXGitFileSource = CloudbuildTriggerXGitFileSource

@typing_extensions.final
class CloudbuildTriggerXGithubXPullRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_FIELD_NUMBER: builtins.int
    COMMENT_CONTROL_FIELD_NUMBER: builtins.int
    INVERT_REGEX_FIELD_NUMBER: builtins.int
    branch: builtins.str
    comment_control: builtins.str
    invert_regex: builtins.bool
    def __init__(
        self,
        *,
        branch: builtins.str = ...,
        comment_control: builtins.str = ...,
        invert_regex: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "comment_control", b"comment_control", "invert_regex", b"invert_regex"]) -> None: ...

global___CloudbuildTriggerXGithubXPullRequest = CloudbuildTriggerXGithubXPullRequest

@typing_extensions.final
class CloudbuildTriggerXGithubXPush(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_FIELD_NUMBER: builtins.int
    INVERT_REGEX_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    branch: builtins.str
    invert_regex: builtins.bool
    tag: builtins.str
    def __init__(
        self,
        *,
        branch: builtins.str = ...,
        invert_regex: builtins.bool = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "invert_regex", b"invert_regex", "tag", b"tag"]) -> None: ...

global___CloudbuildTriggerXGithubXPush = CloudbuildTriggerXGithubXPush

@typing_extensions.final
class CloudbuildTriggerXGithub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    PULL_REQUEST_FIELD_NUMBER: builtins.int
    PUSH_FIELD_NUMBER: builtins.int
    name: builtins.str
    owner: builtins.str
    @property
    def pull_request(self) -> global___CloudbuildTriggerXGithubXPullRequest: ...
    @property
    def push(self) -> global___CloudbuildTriggerXGithubXPush: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        owner: builtins.str = ...,
        pull_request: global___CloudbuildTriggerXGithubXPullRequest | None = ...,
        push: global___CloudbuildTriggerXGithubXPush | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pull_request", b"pull_request", "push", b"push"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "owner", b"owner", "pull_request", b"pull_request", "push", b"push"]) -> None: ...

global___CloudbuildTriggerXGithub = CloudbuildTriggerXGithub

@typing_extensions.final
class CloudbuildTriggerXPubsubConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    service_account_email: builtins.str
    state: builtins.str
    subscription: builtins.str
    topic: builtins.str
    def __init__(
        self,
        *,
        service_account_email: builtins.str = ...,
        state: builtins.str = ...,
        subscription: builtins.str = ...,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_account_email", b"service_account_email", "state", b"state", "subscription", b"subscription", "topic", b"topic"]) -> None: ...

global___CloudbuildTriggerXPubsubConfig = CloudbuildTriggerXPubsubConfig

@typing_extensions.final
class CloudbuildTriggerXSourceToBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REF_FIELD_NUMBER: builtins.int
    REPO_TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ref: builtins.str
    repo_type: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        ref: builtins.str = ...,
        repo_type: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ref", b"ref", "repo_type", b"repo_type", "uri", b"uri"]) -> None: ...

global___CloudbuildTriggerXSourceToBuild = CloudbuildTriggerXSourceToBuild

@typing_extensions.final
class CloudbuildTriggerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudbuildTriggerXTimeouts = CloudbuildTriggerXTimeouts

@typing_extensions.final
class CloudbuildTriggerXTriggerTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_NAME_FIELD_NUMBER: builtins.int
    COMMIT_SHA_FIELD_NUMBER: builtins.int
    DIR_FIELD_NUMBER: builtins.int
    INVERT_REGEX_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    REPO_NAME_FIELD_NUMBER: builtins.int
    TAG_NAME_FIELD_NUMBER: builtins.int
    branch_name: builtins.str
    commit_sha: builtins.str
    dir: builtins.str
    invert_regex: builtins.bool
    project_id: builtins.str
    repo_name: builtins.str
    tag_name: builtins.str
    def __init__(
        self,
        *,
        branch_name: builtins.str = ...,
        commit_sha: builtins.str = ...,
        dir: builtins.str = ...,
        invert_regex: builtins.bool = ...,
        project_id: builtins.str = ...,
        repo_name: builtins.str = ...,
        tag_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_name", b"branch_name", "commit_sha", b"commit_sha", "dir", b"dir", "invert_regex", b"invert_regex", "project_id", b"project_id", "repo_name", b"repo_name", "tag_name", b"tag_name"]) -> None: ...

global___CloudbuildTriggerXTriggerTemplate = CloudbuildTriggerXTriggerTemplate

@typing_extensions.final
class CloudbuildTriggerXWebhookConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    secret: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        secret: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret", b"secret", "state", b"state"]) -> None: ...

global___CloudbuildTriggerXWebhookConfig = CloudbuildTriggerXWebhookConfig

@typing_extensions.final
class CloudbuildTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SubstitutionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IGNORED_FILES_FIELD_NUMBER: builtins.int
    INCLUDE_BUILD_LOGS_FIELD_NUMBER: builtins.int
    INCLUDED_FILES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TRIGGER_ID_FIELD_NUMBER: builtins.int
    APPROVAL_CONFIG_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    GIT_FILE_SOURCE_FIELD_NUMBER: builtins.int
    GITHUB_FIELD_NUMBER: builtins.int
    PUBSUB_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_TO_BUILD_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TRIGGER_TEMPLATE_FIELD_NUMBER: builtins.int
    WEBHOOK_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    disabled: builtins.bool
    filename: builtins.str
    filter: builtins.str
    id: builtins.str
    @property
    def ignored_files(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    include_build_logs: builtins.str
    @property
    def included_files(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    service_account: builtins.str
    @property
    def substitutions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    trigger_id: builtins.str
    @property
    def approval_config(self) -> global___CloudbuildTriggerXApprovalConfig: ...
    @property
    def build(self) -> global___CloudbuildTriggerXBuild: ...
    @property
    def git_file_source(self) -> global___CloudbuildTriggerXGitFileSource: ...
    @property
    def github(self) -> global___CloudbuildTriggerXGithub: ...
    @property
    def pubsub_config(self) -> global___CloudbuildTriggerXPubsubConfig: ...
    @property
    def source_to_build(self) -> global___CloudbuildTriggerXSourceToBuild: ...
    @property
    def timeouts(self) -> global___CloudbuildTriggerXTimeouts: ...
    @property
    def trigger_template(self) -> global___CloudbuildTriggerXTriggerTemplate: ...
    @property
    def webhook_config(self) -> global___CloudbuildTriggerXWebhookConfig: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filename: builtins.str = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        ignored_files: collections.abc.Iterable[builtins.str] | None = ...,
        include_build_logs: builtins.str = ...,
        included_files: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        service_account: builtins.str = ...,
        substitutions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        trigger_id: builtins.str = ...,
        approval_config: global___CloudbuildTriggerXApprovalConfig | None = ...,
        build: global___CloudbuildTriggerXBuild | None = ...,
        git_file_source: global___CloudbuildTriggerXGitFileSource | None = ...,
        github: global___CloudbuildTriggerXGithub | None = ...,
        pubsub_config: global___CloudbuildTriggerXPubsubConfig | None = ...,
        source_to_build: global___CloudbuildTriggerXSourceToBuild | None = ...,
        timeouts: global___CloudbuildTriggerXTimeouts | None = ...,
        trigger_template: global___CloudbuildTriggerXTriggerTemplate | None = ...,
        webhook_config: global___CloudbuildTriggerXWebhookConfig | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["approval_config", b"approval_config", "build", b"build", "git_file_source", b"git_file_source", "github", b"github", "pubsub_config", b"pubsub_config", "resource_info", b"resource_info", "source_to_build", b"source_to_build", "timeouts", b"timeouts", "trigger_template", b"trigger_template", "webhook_config", b"webhook_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_config", b"approval_config", "build", b"build", "create_time", b"create_time", "description", b"description", "disabled", b"disabled", "filename", b"filename", "filter", b"filter", "git_file_source", b"git_file_source", "github", b"github", "id", b"id", "ignored_files", b"ignored_files", "include_build_logs", b"include_build_logs", "included_files", b"included_files", "name", b"name", "project", b"project", "pubsub_config", b"pubsub_config", "resource_info", b"resource_info", "service_account", b"service_account", "source_to_build", b"source_to_build", "substitutions", b"substitutions", "tags", b"tags", "timeouts", b"timeouts", "trigger_id", b"trigger_id", "trigger_template", b"trigger_template", "webhook_config", b"webhook_config"]) -> None: ...

global___CloudbuildTrigger = CloudbuildTrigger

@typing_extensions.final
class CloudbuildWorkerPoolXNetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEERED_NETWORK_FIELD_NUMBER: builtins.int
    peered_network: builtins.str
    def __init__(
        self,
        *,
        peered_network: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["peered_network", b"peered_network"]) -> None: ...

global___CloudbuildWorkerPoolXNetworkConfig = CloudbuildWorkerPoolXNetworkConfig

@typing_extensions.final
class CloudbuildWorkerPoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudbuildWorkerPoolXTimeouts = CloudbuildWorkerPoolXTimeouts

@typing_extensions.final
class CloudbuildWorkerPoolXWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    NO_EXTERNAL_IP_FIELD_NUMBER: builtins.int
    disk_size_gb: builtins.float
    machine_type: builtins.str
    no_external_ip: builtins.bool
    def __init__(
        self,
        *,
        disk_size_gb: builtins.float = ...,
        machine_type: builtins.str = ...,
        no_external_ip: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_size_gb", b"disk_size_gb", "machine_type", b"machine_type", "no_external_ip", b"no_external_ip"]) -> None: ...

global___CloudbuildWorkerPoolXWorkerConfig = CloudbuildWorkerPoolXWorkerConfig

@typing_extensions.final
class CloudbuildWorkerPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DELETE_TIME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    NETWORK_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    WORKER_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    create_time: builtins.str
    delete_time: builtins.str
    display_name: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    uid: builtins.str
    update_time: builtins.str
    @property
    def network_config(self) -> global___CloudbuildWorkerPoolXNetworkConfig: ...
    @property
    def timeouts(self) -> global___CloudbuildWorkerPoolXTimeouts: ...
    @property
    def worker_config(self) -> global___CloudbuildWorkerPoolXWorkerConfig: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        create_time: builtins.str = ...,
        delete_time: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        network_config: global___CloudbuildWorkerPoolXNetworkConfig | None = ...,
        timeouts: global___CloudbuildWorkerPoolXTimeouts | None = ...,
        worker_config: global___CloudbuildWorkerPoolXWorkerConfig | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_config", b"network_config", "resource_info", b"resource_info", "timeouts", b"timeouts", "worker_config", b"worker_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "create_time", b"create_time", "delete_time", b"delete_time", "display_name", b"display_name", "id", b"id", "location", b"location", "name", b"name", "network_config", b"network_config", "project", b"project", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time", "worker_config", b"worker_config"]) -> None: ...

global___CloudbuildWorkerPool = CloudbuildWorkerPool
