# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_app_containerapps.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-azure/azure_microsoft_app_containerapps.proto\x12-oak9.tython.azure.microsoft_app_containerapps\x1a\x13shared/shared.proto\"\xd4\x02\n\x1bMicrosoft_App_containerApps\x12T\n\x0e\x63ontainer_apps\x18\x01 \x01(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ContainerApps\x12l\n\x1b\x63ontainer_apps_auth_configs\x18\x02 \x03(\x0b\x32G.oak9.tython.azure.microsoft_app_containerapps.ContainerAppsAuthConfigs\x12q\n\x1d\x63ontainer_apps_sourcecontrols\x18\x03 \x01(\x0b\x32J.oak9.tython.azure.microsoft_app_containerapps.ContainerAppsSourcecontrols\"\xf5\x01\n\x1b\x43ontainerAppsSourcecontrols\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12m\n\x1bgithub_action_configuration\x18\x04 \x01(\x0b\x32H.oak9.tython.azure.microsoft_app_containerapps.GithubActionConfiguration\x12\x10\n\x08repo_url\x18\x05 \x01(\t\"\xc2\x02\n\x19GithubActionConfiguration\x12Z\n\x11\x61zure_credentials\x18\x01 \x01(\x0b\x32?.oak9.tython.azure.microsoft_app_containerapps.AzureCredentials\x12\x14\n\x0c\x63ontext_path\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\n\n\x02os\x18\x04 \x01(\t\x12\x14\n\x0cpublish_type\x18\x05 \x01(\t\x12R\n\rregistry_info\x18\x06 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.RegistryInfo\x12\x15\n\rruntime_stack\x18\x07 \x01(\t\x12\x17\n\x0fruntime_version\x18\x08 \x01(\t\"[\n\x0cRegistryInfo\x12\x19\n\x11registry_password\x18\x01 \x01(\t\x12\x14\n\x0cregistry_url\x18\x02 \x01(\t\x12\x1a\n\x12registry_user_name\x18\x03 \x01(\t\"h\n\x10\x41zureCredentials\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x17\n\x0fsubscription_id\x18\x03 \x01(\t\x12\x11\n\ttenant_id\x18\x04 \x01(\t\"\x83\x04\n\x18\x43ontainerAppsAuthConfigs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Z\n\x11global_validation\x18\x03 \x01(\x0b\x32?.oak9.tython.azure.microsoft_app_containerapps.GlobalValidation\x12R\n\rhttp_settings\x18\x04 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.HttpSettings\x12\\\n\x12identity_providers\x18\x05 \x01(\x0b\x32@.oak9.tython.azure.microsoft_app_containerapps.IdentityProviders\x12\x43\n\x05login\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app_containerapps.Login\x12M\n\x08platform\x18\x07 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.AuthPlatform\"8\n\x0c\x41uthPlatform\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0fruntime_version\x18\x02 \x01(\t\"\xc7\x02\n\x05Login\x12&\n\x1e\x61llowed_external_redirect_urls\x18\x01 \x03(\t\x12Z\n\x11\x63ookie_expiration\x18\x02 \x01(\x0b\x32?.oak9.tython.azure.microsoft_app_containerapps.CookieExpiration\x12\x43\n\x05nonce\x18\x03 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app_containerapps.Nonce\x12)\n!preserve_url_fragments_for_logins\x18\x04 \x01(\x08\x12J\n\x06routes\x18\x05 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginRoutes\"&\n\x0bLoginRoutes\x12\x17\n\x0flogout_endpoint\x18\x01 \x01(\t\"B\n\x05Nonce\x12!\n\x19nonce_expiration_interval\x18\x01 \x01(\t\x12\x16\n\x0evalidate_nonce\x18\x02 \x01(\x08\"B\n\x10\x43ookieExpiration\x12\x12\n\nconvention\x18\x01 \x01(\t\x12\x1a\n\x12time_to_expiration\x18\x02 \x01(\t\"\x96\x06\n\x11IdentityProviders\x12\x43\n\x05\x61pple\x18\x01 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app_containerapps.Apple\x12\x63\n\x16\x61zure_active_directory\x18\x02 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_app_containerapps.AzureActiveDirectory\x12`\n\x15\x61zure_static_web_apps\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_app_containerapps.AzureStaticWebApps\x12\x8c\x01\n custom_open_id_connect_providers\x18\x04 \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_app_containerapps.IdentityProviders.CustomOpenIdConnectProvidersEntry\x12I\n\x08\x66\x61\x63\x65\x62ook\x18\x05 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_app_containerapps.Facebook\x12\x46\n\x07git_hub\x18\x06 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_app_containerapps.GitHub\x12\x45\n\x06google\x18\x07 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_app_containerapps.Google\x12G\n\x07twitter\x18\x08 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_app_containerapps.Twitter\x1a\x43\n!CustomOpenIdConnectProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x07Twitter\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12X\n\x0cregistration\x18\x02 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_app_containerapps.TwitterRegistration\"Q\n\x13TwitterRegistration\x12\x14\n\x0c\x63onsumer_key\x18\x01 \x01(\t\x12$\n\x1c\x63onsumer_secret_setting_name\x18\x02 \x01(\t\"\x9c\x02\n\x06Google\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12I\n\x05login\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginScopes\x12W\n\x0cregistration\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_app_containerapps.ClientRegistration\x12]\n\nvalidation\x18\x04 \x01(\x0b\x32I.oak9.tython.azure.microsoft_app_containerapps.AllowedAudiencesValidation\"7\n\x1a\x41llowedAudiencesValidation\x12\x19\n\x11\x61llowed_audiences\x18\x01 \x03(\t\"\xbd\x01\n\x06GitHub\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12I\n\x05login\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginScopes\x12W\n\x0cregistration\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_app_containerapps.ClientRegistration\"K\n\x12\x43lientRegistration\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\"\n\x1a\x63lient_secret_setting_name\x18\x02 \x01(\t\"\xd7\x01\n\x08\x46\x61\x63\x65\x62ook\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x19\n\x11graph_api_version\x18\x02 \x01(\t\x12I\n\x05login\x18\x03 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginScopes\x12T\n\x0cregistration\x18\x04 \x01(\x0b\x32>.oak9.tython.azure.microsoft_app_containerapps.AppRegistration\"B\n\x0f\x41ppRegistration\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x1f\n\x17\x61pp_secret_setting_name\x18\x02 \x01(\t\"\x8a\x01\n\x12\x41zureStaticWebApps\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x63\n\x0cregistration\x18\x02 \x01(\x0b\x32M.oak9.tython.azure.microsoft_app_containerapps.AzureStaticWebAppsRegistration\"3\n\x1e\x41zureStaticWebAppsRegistration\x12\x11\n\tclient_id\x18\x01 \x01(\t\"\xe7\x02\n\x14\x41zureActiveDirectory\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1b\n\x13is_auto_provisioned\x18\x02 \x01(\x08\x12W\n\x05login\x18\x03 \x01(\x0b\x32H.oak9.tython.azure.microsoft_app_containerapps.AzureActiveDirectoryLogin\x12\x65\n\x0cregistration\x18\x04 \x01(\x0b\x32O.oak9.tython.azure.microsoft_app_containerapps.AzureActiveDirectoryRegistration\x12\x61\n\nvalidation\x18\x05 \x01(\x0b\x32M.oak9.tython.azure.microsoft_app_containerapps.AzureActiveDirectoryValidation\"\x85\x02\n\x1e\x41zureActiveDirectoryValidation\x12\x19\n\x11\x61llowed_audiences\x18\x01 \x03(\t\x12o\n\x1c\x64\x65\x66\x61ult_authorization_policy\x18\x02 \x01(\x0b\x32I.oak9.tython.azure.microsoft_app_containerapps.DefaultAuthorizationPolicy\x12W\n\x10jwt_claim_checks\x18\x03 \x01(\x0b\x32=.oak9.tython.azure.microsoft_app_containerapps.JwtClaimChecks\"M\n\x0eJwtClaimChecks\x12#\n\x1b\x61llowed_client_applications\x18\x01 \x03(\t\x12\x16\n\x0e\x61llowed_groups\x18\x02 \x03(\t\"\x98\x01\n\x1a\x44\x65\x66\x61ultAuthorizationPolicy\x12\x1c\n\x14\x61llowed_applications\x18\x01 \x03(\t\x12\\\n\x12\x61llowed_principals\x18\x02 \x01(\x0b\x32@.oak9.tython.azure.microsoft_app_containerapps.AllowedPrincipals\"7\n\x11\x41llowedPrincipals\x12\x0e\n\x06groups\x18\x01 \x03(\t\x12\x12\n\nidentities\x18\x02 \x03(\t\"\x85\x02\n AzureActiveDirectoryRegistration\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12(\n client_secret_certificate_issuer\x18\x02 \x01(\t\x12:\n2client_secret_certificate_subject_alternative_name\x18\x03 \x01(\t\x12,\n$client_secret_certificate_thumbprint\x18\x04 \x01(\t\x12\"\n\x1a\x63lient_secret_setting_name\x18\x05 \x01(\t\x12\x16\n\x0eopen_id_issuer\x18\x06 \x01(\t\"Y\n\x19\x41zureActiveDirectoryLogin\x12\"\n\x1a\x64isable_w_w_w_authenticate\x18\x01 \x01(\x08\x12\x18\n\x10login_parameters\x18\x02 \x03(\t\"\xbb\x01\n\x05\x41pple\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12I\n\x05login\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginScopes\x12V\n\x0cregistration\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_app_containerapps.AppleRegistration\"J\n\x11\x41ppleRegistration\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\"\n\x1a\x63lient_secret_setting_name\x18\x02 \x01(\t\"\x1d\n\x0bLoginScopes\x12\x0e\n\x06scopes\x18\x01 \x03(\t\"\xcc\x01\n\x0cHttpSettings\x12R\n\rforward_proxy\x18\x01 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.ForwardProxy\x12\x15\n\rrequire_https\x18\x02 \x01(\x08\x12Q\n\x06routes\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_app_containerapps.HttpSettingsRoutes\"(\n\x12HttpSettingsRoutes\x12\x12\n\napi_prefix\x18\x01 \x01(\t\"e\n\x0c\x46orwardProxy\x12\x12\n\nconvention\x18\x01 \x01(\t\x12\x1f\n\x17\x63ustom_host_header_name\x18\x02 \x01(\t\x12 \n\x18\x63ustom_proto_header_name\x18\x03 \x01(\t\"o\n\x10GlobalValidation\x12\x16\n\x0e\x65xcluded_paths\x18\x01 \x03(\t\x12\x1c\n\x14redirect_to_provider\x18\x02 \x01(\t\x12%\n\x1dunauthenticated_client_action\x18\x03 \x01(\t\"\x97\x05\n\rContainerApps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32?.oak9.tython.azure.microsoft_app_containerapps.ExtendedLocation\x12W\n\x08identity\x18\x03 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_app_containerapps.ManagedServiceIdentity\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12S\n\rconfiguration\x18\x06 \x01(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.Configuration\x12\x16\n\x0e\x65nvironment_id\x18\x07 \x01(\t\x12\x1e\n\x16managed_environment_id\x18\x08 \x01(\t\x12I\n\x08template\x18\t \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_app_containerapps.Template\x12\x1d\n\x15workload_profile_type\x18\n \x01(\t\x12T\n\x04tags\x18\x0b \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_app_containerapps.ContainerApps.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd5\x02\n\x08Template\x12L\n\ncontainers\x18\x01 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_app_containerapps.Container\x12U\n\x0finit_containers\x18\x02 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.InitContainer\x12\x17\n\x0frevision_suffix\x18\x03 \x01(\t\x12\x43\n\x05scale\x18\x04 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app_containerapps.Scale\x12\x46\n\x07volumes\x18\x05 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_app_containerapps.Volume\"B\n\x06Volume\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cstorage_name\x18\x02 \x01(\t\x12\x14\n\x0cstorage_type\x18\x03 \x01(\t\"|\n\x05Scale\x12\x14\n\x0cmax_replicas\x18\x01 \x01(\x05\x12\x14\n\x0cmin_replicas\x18\x02 \x01(\x05\x12G\n\x05rules\x18\x03 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_app_containerapps.ScaleRule\"\xd3\x02\n\tScaleRule\x12R\n\x0b\x61zure_queue\x18\x01 \x01(\x0b\x32=.oak9.tython.azure.microsoft_app_containerapps.QueueScaleRule\x12N\n\x06\x63ustom\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_app_containerapps.CustomScaleRule\x12J\n\x04http\x18\x03 \x01(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.HttpScaleRule\x12\x0c\n\x04name\x18\x04 \x01(\t\x12H\n\x03tcp\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.TcpScaleRule\"\xe8\x01\n\x0cTcpScaleRule\x12J\n\x04\x61uth\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ScaleRuleAuth\x12[\n\x08metadata\x18\x02 \x03(\x0b\x32I.oak9.tython.azure.microsoft_app_containerapps.TcpScaleRule.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\rHttpScaleRule\x12J\n\x04\x61uth\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ScaleRuleAuth\x12\\\n\x08metadata\x18\x02 \x03(\x0b\x32J.oak9.tython.azure.microsoft_app_containerapps.HttpScaleRule.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfc\x01\n\x0f\x43ustomScaleRule\x12J\n\x04\x61uth\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ScaleRuleAuth\x12^\n\x08metadata\x18\x02 \x03(\x0b\x32L.oak9.tython.azure.microsoft_app_containerapps.CustomScaleRule.MetadataEntry\x12\x0c\n\x04type\x18\x03 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x0eQueueScaleRule\x12J\n\x04\x61uth\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ScaleRuleAuth\x12\x14\n\x0cqueue_length\x18\x02 \x01(\x05\x12\x12\n\nqueue_name\x18\x03 \x01(\t\">\n\rScaleRuleAuth\x12\x12\n\nsecret_ref\x18\x01 \x01(\t\x12\x19\n\x11trigger_parameter\x18\x02 \x01(\t\"\xea\x01\n\rInitContainer\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12J\n\x03\x65nv\x18\x03 \x03(\x0b\x32=.oak9.tython.azure.microsoft_app_containerapps.EnvironmentVar\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12Q\n\rvolume_mounts\x18\x06 \x03(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.VolumeMount\"\xb8\x02\n\tContainer\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12J\n\x03\x65nv\x18\x03 \x03(\x0b\x32=.oak9.tython.azure.microsoft_app_containerapps.EnvironmentVar\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12P\n\x06probes\x18\x06 \x03(\x0b\x32@.oak9.tython.azure.microsoft_app_containerapps.ContainerAppProbe\x12Q\n\rvolume_mounts\x18\x07 \x03(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.VolumeMount\"6\n\x0bVolumeMount\x12\x12\n\nmount_path\x18\x01 \x01(\t\x12\x13\n\x0bvolume_name\x18\x02 \x01(\t\"\x8b\x03\n\x11\x43ontainerAppProbe\x12\x19\n\x11\x66\x61ilure_threshold\x18\x01 \x01(\x05\x12Y\n\x08http_get\x18\x02 \x01(\x0b\x32G.oak9.tython.azure.microsoft_app_containerapps.ContainerAppProbeHttpGet\x12\x1d\n\x15initial_delay_seconds\x18\x03 \x01(\x05\x12\x16\n\x0eperiod_seconds\x18\x04 \x01(\x05\x12\x19\n\x11success_threshold\x18\x05 \x01(\x05\x12]\n\ntcp_socket\x18\x06 \x01(\x0b\x32I.oak9.tython.azure.microsoft_app_containerapps.ContainerAppProbeTcpSocket\x12(\n termination_grace_period_seconds\x18\x07 \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\x08 \x01(\x05\x12\x0c\n\x04type\x18\t \x01(\t\"8\n\x1a\x43ontainerAppProbeTcpSocket\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\xc2\x01\n\x18\x43ontainerAppProbeHttpGet\x12\x0c\n\x04host\x18\x01 \x01(\t\x12l\n\x0chttp_headers\x18\x02 \x03(\x0b\x32V.oak9.tython.azure.microsoft_app_containerapps.ContainerAppProbeHttpGetHttpHeadersItem\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x0e\n\x06scheme\x18\x05 \x01(\t\"F\n\'ContainerAppProbeHttpGetHttpHeadersItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"A\n\x0e\x45nvironmentVar\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nsecret_ref\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfa\x02\n\rConfiguration\x12\x1d\n\x15\x61\x63tive_revisions_mode\x18\x01 \x01(\t\x12\x41\n\x04\x64\x61pr\x18\x02 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_app_containerapps.Dapr\x12G\n\x07ingress\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_app_containerapps.Ingress\x12\x1e\n\x16max_inactive_revisions\x18\x04 \x01(\x05\x12V\n\nregistries\x18\x05 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_app_containerapps.RegistryCredentials\x12\x46\n\x07secrets\x18\x06 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_app_containerapps.Secret\"%\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"f\n\x13RegistryCredentials\x12\x10\n\x08identity\x18\x01 \x01(\t\x12\x1b\n\x13password_secret_ref\x18\x02 \x01(\t\x12\x0e\n\x06server\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\"\x81\x03\n\x07Ingress\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12S\n\x0e\x63ustom_domains\x18\x02 \x03(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.CustomDomain\x12\x14\n\x0c\x65xposed_port\x18\x03 \x01(\x05\x12\x10\n\x08\x65xternal\x18\x04 \x01(\x08\x12j\n\x18ip_security_restrictions\x18\x05 \x03(\x0b\x32H.oak9.tython.azure.microsoft_app_containerapps.IpSecurityRestrictionRule\x12\x13\n\x0btarget_port\x18\x06 \x01(\x05\x12M\n\x07traffic\x18\x07 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.TrafficWeight\x12\x11\n\ttransport\x18\x08 \x01(\t\"^\n\rTrafficWeight\x12\r\n\x05label\x18\x01 \x01(\t\x12\x17\n\x0flatest_revision\x18\x02 \x01(\x08\x12\x15\n\rrevision_name\x18\x03 \x01(\t\x12\x0e\n\x06weight\x18\x04 \x01(\x05\"h\n\x19IpSecurityRestrictionRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10ip_address_range\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"J\n\x0c\x43ustomDomain\x12\x14\n\x0c\x62inding_type\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xbc\x01\n\x04\x44\x61pr\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x10\n\x08\x61pp_port\x18\x02 \x01(\x05\x12\x14\n\x0c\x61pp_protocol\x18\x03 \x01(\t\x12\x1a\n\x12\x65nable_api_logging\x18\x04 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x1d\n\x15http_max_request_size\x18\x06 \x01(\x05\x12\x1d\n\x15http_read_buffer_size\x18\x07 \x01(\x05\x12\x11\n\tlog_level\x18\x08 \x01(\t\"\xeb\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x83\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32\x61.oak9.tython.azure.microsoft_app_containerapps.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_app_containerapps_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IDENTITYPROVIDERS_CUSTOMOPENIDCONNECTPROVIDERSENTRY._options = None
  _IDENTITYPROVIDERS_CUSTOMOPENIDCONNECTPROVIDERSENTRY._serialized_options = b'8\001'
  _CONTAINERAPPS_TAGSENTRY._options = None
  _CONTAINERAPPS_TAGSENTRY._serialized_options = b'8\001'
  _TCPSCALERULE_METADATAENTRY._options = None
  _TCPSCALERULE_METADATAENTRY._serialized_options = b'8\001'
  _HTTPSCALERULE_METADATAENTRY._options = None
  _HTTPSCALERULE_METADATAENTRY._serialized_options = b'8\001'
  _CUSTOMSCALERULE_METADATAENTRY._options = None
  _CUSTOMSCALERULE_METADATAENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_APP_CONTAINERAPPS._serialized_start=118
  _MICROSOFT_APP_CONTAINERAPPS._serialized_end=458
  _CONTAINERAPPSSOURCECONTROLS._serialized_start=461
  _CONTAINERAPPSSOURCECONTROLS._serialized_end=706
  _GITHUBACTIONCONFIGURATION._serialized_start=709
  _GITHUBACTIONCONFIGURATION._serialized_end=1031
  _REGISTRYINFO._serialized_start=1033
  _REGISTRYINFO._serialized_end=1124
  _AZURECREDENTIALS._serialized_start=1126
  _AZURECREDENTIALS._serialized_end=1230
  _CONTAINERAPPSAUTHCONFIGS._serialized_start=1233
  _CONTAINERAPPSAUTHCONFIGS._serialized_end=1748
  _AUTHPLATFORM._serialized_start=1750
  _AUTHPLATFORM._serialized_end=1806
  _LOGIN._serialized_start=1809
  _LOGIN._serialized_end=2136
  _LOGINROUTES._serialized_start=2138
  _LOGINROUTES._serialized_end=2176
  _NONCE._serialized_start=2178
  _NONCE._serialized_end=2244
  _COOKIEEXPIRATION._serialized_start=2246
  _COOKIEEXPIRATION._serialized_end=2312
  _IDENTITYPROVIDERS._serialized_start=2315
  _IDENTITYPROVIDERS._serialized_end=3105
  _IDENTITYPROVIDERS_CUSTOMOPENIDCONNECTPROVIDERSENTRY._serialized_start=3038
  _IDENTITYPROVIDERS_CUSTOMOPENIDCONNECTPROVIDERSENTRY._serialized_end=3105
  _TWITTER._serialized_start=3107
  _TWITTER._serialized_end=3223
  _TWITTERREGISTRATION._serialized_start=3225
  _TWITTERREGISTRATION._serialized_end=3306
  _GOOGLE._serialized_start=3309
  _GOOGLE._serialized_end=3593
  _ALLOWEDAUDIENCESVALIDATION._serialized_start=3595
  _ALLOWEDAUDIENCESVALIDATION._serialized_end=3650
  _GITHUB._serialized_start=3653
  _GITHUB._serialized_end=3842
  _CLIENTREGISTRATION._serialized_start=3844
  _CLIENTREGISTRATION._serialized_end=3919
  _FACEBOOK._serialized_start=3922
  _FACEBOOK._serialized_end=4137
  _APPREGISTRATION._serialized_start=4139
  _APPREGISTRATION._serialized_end=4205
  _AZURESTATICWEBAPPS._serialized_start=4208
  _AZURESTATICWEBAPPS._serialized_end=4346
  _AZURESTATICWEBAPPSREGISTRATION._serialized_start=4348
  _AZURESTATICWEBAPPSREGISTRATION._serialized_end=4399
  _AZUREACTIVEDIRECTORY._serialized_start=4402
  _AZUREACTIVEDIRECTORY._serialized_end=4761
  _AZUREACTIVEDIRECTORYVALIDATION._serialized_start=4764
  _AZUREACTIVEDIRECTORYVALIDATION._serialized_end=5025
  _JWTCLAIMCHECKS._serialized_start=5027
  _JWTCLAIMCHECKS._serialized_end=5104
  _DEFAULTAUTHORIZATIONPOLICY._serialized_start=5107
  _DEFAULTAUTHORIZATIONPOLICY._serialized_end=5259
  _ALLOWEDPRINCIPALS._serialized_start=5261
  _ALLOWEDPRINCIPALS._serialized_end=5316
  _AZUREACTIVEDIRECTORYREGISTRATION._serialized_start=5319
  _AZUREACTIVEDIRECTORYREGISTRATION._serialized_end=5580
  _AZUREACTIVEDIRECTORYLOGIN._serialized_start=5582
  _AZUREACTIVEDIRECTORYLOGIN._serialized_end=5671
  _APPLE._serialized_start=5674
  _APPLE._serialized_end=5861
  _APPLEREGISTRATION._serialized_start=5863
  _APPLEREGISTRATION._serialized_end=5937
  _LOGINSCOPES._serialized_start=5939
  _LOGINSCOPES._serialized_end=5968
  _HTTPSETTINGS._serialized_start=5971
  _HTTPSETTINGS._serialized_end=6175
  _HTTPSETTINGSROUTES._serialized_start=6177
  _HTTPSETTINGSROUTES._serialized_end=6217
  _FORWARDPROXY._serialized_start=6219
  _FORWARDPROXY._serialized_end=6320
  _GLOBALVALIDATION._serialized_start=6322
  _GLOBALVALIDATION._serialized_end=6433
  _CONTAINERAPPS._serialized_start=6436
  _CONTAINERAPPS._serialized_end=7099
  _CONTAINERAPPS_TAGSENTRY._serialized_start=7056
  _CONTAINERAPPS_TAGSENTRY._serialized_end=7099
  _TEMPLATE._serialized_start=7102
  _TEMPLATE._serialized_end=7443
  _VOLUME._serialized_start=7445
  _VOLUME._serialized_end=7511
  _SCALE._serialized_start=7513
  _SCALE._serialized_end=7637
  _SCALERULE._serialized_start=7640
  _SCALERULE._serialized_end=7979
  _TCPSCALERULE._serialized_start=7982
  _TCPSCALERULE._serialized_end=8214
  _TCPSCALERULE_METADATAENTRY._serialized_start=8167
  _TCPSCALERULE_METADATAENTRY._serialized_end=8214
  _HTTPSCALERULE._serialized_start=8217
  _HTTPSCALERULE._serialized_end=8451
  _HTTPSCALERULE_METADATAENTRY._serialized_start=8167
  _HTTPSCALERULE_METADATAENTRY._serialized_end=8214
  _CUSTOMSCALERULE._serialized_start=8454
  _CUSTOMSCALERULE._serialized_end=8706
  _CUSTOMSCALERULE_METADATAENTRY._serialized_start=8167
  _CUSTOMSCALERULE_METADATAENTRY._serialized_end=8214
  _QUEUESCALERULE._serialized_start=8709
  _QUEUESCALERULE._serialized_end=8843
  _SCALERULEAUTH._serialized_start=8845
  _SCALERULEAUTH._serialized_end=8907
  _INITCONTAINER._serialized_start=8910
  _INITCONTAINER._serialized_end=9144
  _CONTAINER._serialized_start=9147
  _CONTAINER._serialized_end=9459
  _VOLUMEMOUNT._serialized_start=9461
  _VOLUMEMOUNT._serialized_end=9515
  _CONTAINERAPPPROBE._serialized_start=9518
  _CONTAINERAPPPROBE._serialized_end=9913
  _CONTAINERAPPPROBETCPSOCKET._serialized_start=9915
  _CONTAINERAPPPROBETCPSOCKET._serialized_end=9971
  _CONTAINERAPPPROBEHTTPGET._serialized_start=9974
  _CONTAINERAPPPROBEHTTPGET._serialized_end=10168
  _CONTAINERAPPPROBEHTTPGETHTTPHEADERSITEM._serialized_start=10170
  _CONTAINERAPPPROBEHTTPGETHTTPHEADERSITEM._serialized_end=10240
  _ENVIRONMENTVAR._serialized_start=10242
  _ENVIRONMENTVAR._serialized_end=10307
  _CONFIGURATION._serialized_start=10310
  _CONFIGURATION._serialized_end=10688
  _SECRET._serialized_start=10690
  _SECRET._serialized_end=10727
  _REGISTRYCREDENTIALS._serialized_start=10729
  _REGISTRYCREDENTIALS._serialized_end=10831
  _INGRESS._serialized_start=10834
  _INGRESS._serialized_end=11219
  _TRAFFICWEIGHT._serialized_start=11221
  _TRAFFICWEIGHT._serialized_end=11315
  _IPSECURITYRESTRICTIONRULE._serialized_start=11317
  _IPSECURITYRESTRICTIONRULE._serialized_end=11421
  _CUSTOMDOMAIN._serialized_start=11423
  _CUSTOMDOMAIN._serialized_end=11497
  _DAPR._serialized_start=11500
  _DAPR._serialized_end=11688
  _MANAGEDSERVICEIDENTITY._serialized_start=11691
  _MANAGEDSERVICEIDENTITY._serialized_end=11926
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=11865
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=11926
  _EXTENDEDLOCATION._serialized_start=11928
  _EXTENDEDLOCATION._serialized_end=11974
# @@protoc_insertion_point(module_scope)
