# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ssm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_ssm.proto\x12\x13oak9.tython.aws.ssm\x1a\x13shared/shared.proto\"i\n\x11\x41ssociationTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xad\x01\n\x1b\x41ssociationS3OutputLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10output_s3_region\x18\x02 \x01(\t\x12\x1d\n\x15output_s3_bucket_name\x18\x03 \x01(\t\x12\x1c\n\x14output_s3_key_prefix\x18\x04 \x01(\t\"\xae\x01\n,AssociationInstanceAssociationOutputLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x0bs3_location\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.ssm.AssociationS3OutputLocation\"\xa4\x05\n\x0b\x41ssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61ssociation_name\x18\x02 \x01(\t\x12\x18\n\x10\x64ocument_version\x18\x03 \x01(\t\x12\x13\n\x0binstance_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x44\n\nparameters\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.ssm.Association.ParametersEntry\x12\x1b\n\x13schedule_expression\x18\x07 \x01(\t\x12\x37\n\x07targets\x18\x08 \x03(\x0b\x32&.oak9.tython.aws.ssm.AssociationTarget\x12Z\n\x0foutput_location\x18\t \x01(\x0b\x32\x41.oak9.tython.aws.ssm.AssociationInstanceAssociationOutputLocation\x12(\n automation_target_parameter_name\x18\n \x01(\t\x12\x12\n\nmax_errors\x18\x0b \x01(\t\x12\x17\n\x0fmax_concurrency\x18\x0c \x01(\t\x12\x1b\n\x13\x63ompliance_severity\x18\r \x01(\t\x12\x17\n\x0fsync_compliance\x18\x0e \x01(\t\x12(\n wait_for_success_timeout_seconds\x18\x0f \x01(\x05\x12#\n\x1b\x61pply_only_at_cron_interval\x18\x10 \x01(\x08\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd8\x04\n\x03SSM\x12\x35\n\x0b\x61ssociation\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.ssm.Association\x12/\n\x08\x64ocument\x18\x02 \x03(\x0b\x32\x1d.oak9.tython.aws.ssm.Document\x12\x42\n\x12maintenance_window\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.ssm.MaintenanceWindow\x12O\n\x19maintenance_window_target\x18\x04 \x03(\x0b\x32,.oak9.tython.aws.ssm.MaintenanceWindowTarget\x12K\n\x17maintenance_window_task\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.ssm.MaintenanceWindowTask\x12\x31\n\tparameter\x18\x06 \x03(\x0b\x32\x1e.oak9.tython.aws.ssm.Parameter\x12:\n\x0epatch_baseline\x18\x07 \x03(\x0b\x32\".oak9.tython.aws.ssm.PatchBaseline\x12\x41\n\x12resource_data_sync\x18\x08 \x03(\x0b\x32%.oak9.tython.aws.ssm.ResourceDataSync\x12U\n\x1c\x61ssociation_parameter_values\x18\t \x03(\x0b\x32/.oak9.tython.aws.ssm.AssociationParameterValues\"\xb9\x02\n\x08\x44ocument\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\x07\x63ontent\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.ssm.Document.ContentEntry\x12\x15\n\rdocument_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x35\n\x04tags\x18\x05 \x03(\x0b\x32\'.oak9.tython.aws.ssm.Document.TagsEntry\x1a.\n\x0c\x43ontentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x03\n\x11MaintenanceWindow\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nstart_date\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\"\n\x1a\x61llow_unassociated_targets\x18\x04 \x01(\x08\x12\x0e\n\x06\x63utoff\x18\x05 \x01(\x05\x12\x10\n\x08schedule\x18\x06 \x01(\t\x12\x10\n\x08\x64uration\x18\x07 \x01(\x05\x12\x17\n\x0fschedule_offset\x18\x08 \x01(\x05\x12\x10\n\x08\x65nd_date\x18\t \x01(\t\x12>\n\x04tags\x18\n \x03(\x0b\x32\x30.oak9.tython.aws.ssm.MaintenanceWindow.TagsEntry\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x19\n\x11schedule_timezone\x18\x0c \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\x1eMaintenanceWindowTargetTargets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x80\x02\n\x17MaintenanceWindowTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11owner_information\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\twindow_id\x18\x04 \x01(\t\x12\x15\n\rresource_type\x18\x05 \x01(\t\x12\x44\n\x07targets\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.ssm.MaintenanceWindowTargetTargets\x12\x0c\n\x04name\x18\x07 \x01(\t\"s\n\x1bMaintenanceWindowTaskTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xb4\x01\n\'MaintenanceWindowTaskNotificationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10notification_arn\x18\x02 \x01(\t\x12\x19\n\x11notification_type\x18\x03 \x01(\t\x12\x1b\n\x13notification_events\x18\x04 \x03(\t\"\xac\x04\n:MaintenanceWindowTaskMaintenanceWindowRunCommandParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0ftimeout_seconds\x18\x02 \x01(\x05\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x1c\n\x14output_s3_key_prefix\x18\x04 \x01(\t\x12s\n\nparameters\x18\x05 \x03(\x0b\x32_.oak9.tython.aws.ssm.MaintenanceWindowTaskMaintenanceWindowRunCommandParameters.ParametersEntry\x12\x1a\n\x12\x64ocument_hash_type\x18\x06 \x01(\t\x12\x18\n\x10service_role_arn\x18\x07 \x01(\t\x12Y\n\x13notification_config\x18\x08 \x01(\x0b\x32<.oak9.tython.aws.ssm.MaintenanceWindowTaskNotificationConfig\x12\x1d\n\x15output_s3_bucket_name\x18\t \x01(\t\x12\x15\n\rdocument_hash\x18\n \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x02\n:MaintenanceWindowTaskMaintenanceWindowAutomationParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12s\n\nparameters\x18\x02 \x03(\x0b\x32_.oak9.tython.aws.ssm.MaintenanceWindowTaskMaintenanceWindowAutomationParameters.ParametersEntry\x12\x18\n\x10\x64ocument_version\x18\x03 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n=MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05input\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xad\x01\n6MaintenanceWindowTaskMaintenanceWindowLambdaParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63lient_context\x18\x02 \x01(\t\x12\x11\n\tqualifier\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\t\"\xf7\x04\n-MaintenanceWindowTaskTaskInvocationParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x82\x01\n)maintenance_window_run_command_parameters\x18\x02 \x01(\x0b\x32O.oak9.tython.aws.ssm.MaintenanceWindowTaskMaintenanceWindowRunCommandParameters\x12\x81\x01\n(maintenance_window_automation_parameters\x18\x03 \x01(\x0b\x32O.oak9.tython.aws.ssm.MaintenanceWindowTaskMaintenanceWindowAutomationParameters\x12\x88\x01\n,maintenance_window_step_functions_parameters\x18\x04 \x01(\x0b\x32R.oak9.tython.aws.ssm.MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters\x12y\n$maintenance_window_lambda_parameters\x18\x05 \x01(\x0b\x32K.oak9.tython.aws.ssm.MaintenanceWindowTaskMaintenanceWindowLambdaParameters\"\x91\x01\n MaintenanceWindowTaskLoggingInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x11\n\ts3_prefix\x18\x04 \x01(\t\"\x8c\x05\n\x15MaintenanceWindowTask\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nmax_errors\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10service_role_arn\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x17\n\x0fmax_concurrency\x18\x06 \x01(\t\x12\x41\n\x07targets\x18\x07 \x03(\x0b\x32\x30.oak9.tython.aws.ssm.MaintenanceWindowTaskTarget\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x10\n\x08task_arn\x18\t \x01(\t\x12\x66\n\x1atask_invocation_parameters\x18\n \x01(\x0b\x32\x42.oak9.tython.aws.ssm.MaintenanceWindowTaskTaskInvocationParameters\x12\x11\n\twindow_id\x18\x0b \x01(\t\x12W\n\x0ftask_parameters\x18\x0c \x03(\x0b\x32>.oak9.tython.aws.ssm.MaintenanceWindowTask.TaskParametersEntry\x12\x11\n\ttask_type\x18\r \x01(\t\x12K\n\x0clogging_info\x18\x0e \x01(\x0b\x32\x35.oak9.tython.aws.ssm.MaintenanceWindowTaskLoggingInfo\x1a\x35\n\x13TaskParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb5\x02\n\tParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08policies\x18\x04 \x01(\t\x12\x17\n\x0f\x61llowed_pattern\x18\x05 \x01(\t\x12\x0c\n\x04tier\x18\x06 \x01(\t\x12\r\n\x05value\x18\x07 \x01(\t\x12\x11\n\tdata_type\x18\x08 \x01(\t\x12\x36\n\x04tags\x18\t \x03(\x0b\x32(.oak9.tython.aws.ssm.Parameter.TagsEntry\x12\x0c\n\x04name\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x1cPatchBaselinePatchStringDate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"p\n\x18PatchBaselinePatchFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x9e\x01\n\x1dPatchBaselinePatchFilterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\rpatch_filters\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.ssm.PatchBaselinePatchFilter\"\xbe\x02\n\x11PatchBaselineRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x12\x61pprove_until_date\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.ssm.PatchBaselinePatchStringDate\x12\x1b\n\x13\x65nable_non_security\x18\x03 \x01(\x08\x12N\n\x12patch_filter_group\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.ssm.PatchBaselinePatchFilterGroup\x12\x1a\n\x12\x61pprove_after_days\x18\x05 \x01(\x05\x12\x18\n\x10\x63ompliance_level\x18\x06 \x01(\t\"\x8e\x01\n\x16PatchBaselineRuleGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\x0bpatch_rules\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.ssm.PatchBaselineRule\"\x8a\x01\n\x18PatchBaselinePatchSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08products\x18\x02 \x03(\t\x12\x15\n\rconfiguration\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x83\x05\n\rPatchBaseline\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10operating_system\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x43\n\x0e\x61pproval_rules\x18\x04 \x01(\x0b\x32+.oak9.tython.aws.ssm.PatchBaselineRuleGroup\x12>\n\x07sources\x18\x05 \x03(\x0b\x32-.oak9.tython.aws.ssm.PatchBaselinePatchSource\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x18\n\x10rejected_patches\x18\x07 \x03(\t\x12\x18\n\x10\x61pproved_patches\x18\x08 \x03(\t\x12\x1f\n\x17rejected_patches_action\x18\t \x01(\t\x12\x14\n\x0cpatch_groups\x18\n \x03(\t\x12)\n!approved_patches_compliance_level\x18\x0b \x01(\t\x12,\n$approved_patches_enable_non_security\x18\x0c \x01(\x08\x12J\n\x0eglobal_filters\x18\r \x01(\x0b\x32\x32.oak9.tython.aws.ssm.PatchBaselinePatchFilterGroup\x12:\n\x04tags\x18\x0e \x03(\x0b\x32,.oak9.tython.aws.ssm.PatchBaseline.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x01\n\x1dResourceDataSyncS3Destination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bkms_key_arn\x18\x02 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x03 \x01(\t\x12\x15\n\rbucket_region\x18\x04 \x01(\t\x12\x13\n\x0bsync_format\x18\x05 \x01(\t\x12\x15\n\rbucket_prefix\x18\x06 \x01(\t\"\xa1\x01\n&ResourceDataSyncAwsOrganizationsSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18organization_source_type\x18\x02 \x01(\t\x12\x1c\n\x14organizational_units\x18\x03 \x03(\t\"\x81\x02\n\x1aResourceDataSyncSyncSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_type\x18\x02 \x01(\t\x12]\n\x18\x61ws_organizations_source\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.ssm.ResourceDataSyncAwsOrganizationsSource\x12\x1e\n\x16include_future_regions\x18\x04 \x01(\x08\x12\x16\n\x0esource_regions\x18\x05 \x03(\t\"\xf0\x02\n\x10ResourceDataSync\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x0es3_destination\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.ssm.ResourceDataSyncS3Destination\x12\x13\n\x0bkms_key_arn\x18\x03 \x01(\t\x12\x44\n\x0bsync_source\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.ssm.ResourceDataSyncSyncSource\x12\x13\n\x0b\x62ucket_name\x18\x05 \x01(\t\x12\x15\n\rbucket_region\x18\x06 \x01(\t\x12\x13\n\x0bsync_format\x18\x07 \x01(\t\x12\x11\n\tsync_name\x18\x08 \x01(\t\x12\x11\n\tsync_type\x18\t \x01(\t\x12\x15\n\rbucket_prefix\x18\n \x01(\t\"o\n\x1a\x41ssociationParameterValues\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10parameter_values\x18\x02 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ssm_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ASSOCIATION_PARAMETERSENTRY._options = None
  _ASSOCIATION_PARAMETERSENTRY._serialized_options = b'8\001'
  _DOCUMENT_CONTENTENTRY._options = None
  _DOCUMENT_CONTENTENTRY._serialized_options = b'8\001'
  _DOCUMENT_TAGSENTRY._options = None
  _DOCUMENT_TAGSENTRY._serialized_options = b'8\001'
  _MAINTENANCEWINDOW_TAGSENTRY._options = None
  _MAINTENANCEWINDOW_TAGSENTRY._serialized_options = b'8\001'
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWRUNCOMMANDPARAMETERS_PARAMETERSENTRY._options = None
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWRUNCOMMANDPARAMETERS_PARAMETERSENTRY._serialized_options = b'8\001'
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWAUTOMATIONPARAMETERS_PARAMETERSENTRY._options = None
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWAUTOMATIONPARAMETERS_PARAMETERSENTRY._serialized_options = b'8\001'
  _MAINTENANCEWINDOWTASK_TASKPARAMETERSENTRY._options = None
  _MAINTENANCEWINDOWTASK_TASKPARAMETERSENTRY._serialized_options = b'8\001'
  _PARAMETER_TAGSENTRY._options = None
  _PARAMETER_TAGSENTRY._serialized_options = b'8\001'
  _PATCHBASELINE_TAGSENTRY._options = None
  _PATCHBASELINE_TAGSENTRY._serialized_options = b'8\001'
  _ASSOCIATIONTARGET._serialized_start=63
  _ASSOCIATIONTARGET._serialized_end=168
  _ASSOCIATIONS3OUTPUTLOCATION._serialized_start=171
  _ASSOCIATIONS3OUTPUTLOCATION._serialized_end=344
  _ASSOCIATIONINSTANCEASSOCIATIONOUTPUTLOCATION._serialized_start=347
  _ASSOCIATIONINSTANCEASSOCIATIONOUTPUTLOCATION._serialized_end=521
  _ASSOCIATION._serialized_start=524
  _ASSOCIATION._serialized_end=1200
  _ASSOCIATION_PARAMETERSENTRY._serialized_start=1151
  _ASSOCIATION_PARAMETERSENTRY._serialized_end=1200
  _SSM._serialized_start=1203
  _SSM._serialized_end=1803
  _DOCUMENT._serialized_start=1806
  _DOCUMENT._serialized_end=2119
  _DOCUMENT_CONTENTENTRY._serialized_start=2028
  _DOCUMENT_CONTENTENTRY._serialized_end=2074
  _DOCUMENT_TAGSENTRY._serialized_start=2076
  _DOCUMENT_TAGSENTRY._serialized_end=2119
  _MAINTENANCEWINDOW._serialized_start=2122
  _MAINTENANCEWINDOW._serialized_end=2520
  _MAINTENANCEWINDOW_TAGSENTRY._serialized_start=2076
  _MAINTENANCEWINDOW_TAGSENTRY._serialized_end=2119
  _MAINTENANCEWINDOWTARGETTARGETS._serialized_start=2522
  _MAINTENANCEWINDOWTARGETTARGETS._serialized_end=2640
  _MAINTENANCEWINDOWTARGET._serialized_start=2643
  _MAINTENANCEWINDOWTARGET._serialized_end=2899
  _MAINTENANCEWINDOWTASKTARGET._serialized_start=2901
  _MAINTENANCEWINDOWTASKTARGET._serialized_end=3016
  _MAINTENANCEWINDOWTASKNOTIFICATIONCONFIG._serialized_start=3019
  _MAINTENANCEWINDOWTASKNOTIFICATIONCONFIG._serialized_end=3199
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWRUNCOMMANDPARAMETERS._serialized_start=3202
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWRUNCOMMANDPARAMETERS._serialized_end=3758
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWRUNCOMMANDPARAMETERS_PARAMETERSENTRY._serialized_start=1151
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWRUNCOMMANDPARAMETERS_PARAMETERSENTRY._serialized_end=1200
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWAUTOMATIONPARAMETERS._serialized_start=3761
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWAUTOMATIONPARAMETERS._serialized_end=4072
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWAUTOMATIONPARAMETERS_PARAMETERSENTRY._serialized_start=1151
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWAUTOMATIONPARAMETERS_PARAMETERSENTRY._serialized_end=1200
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWSTEPFUNCTIONSPARAMETERS._serialized_start=4075
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWSTEPFUNCTIONSPARAMETERS._serialized_end=4224
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWLAMBDAPARAMETERS._serialized_start=4227
  _MAINTENANCEWINDOWTASKMAINTENANCEWINDOWLAMBDAPARAMETERS._serialized_end=4400
  _MAINTENANCEWINDOWTASKTASKINVOCATIONPARAMETERS._serialized_start=4403
  _MAINTENANCEWINDOWTASKTASKINVOCATIONPARAMETERS._serialized_end=5034
  _MAINTENANCEWINDOWTASKLOGGINGINFO._serialized_start=5037
  _MAINTENANCEWINDOWTASKLOGGINGINFO._serialized_end=5182
  _MAINTENANCEWINDOWTASK._serialized_start=5185
  _MAINTENANCEWINDOWTASK._serialized_end=5837
  _MAINTENANCEWINDOWTASK_TASKPARAMETERSENTRY._serialized_start=5784
  _MAINTENANCEWINDOWTASK_TASKPARAMETERSENTRY._serialized_end=5837
  _PARAMETER._serialized_start=5840
  _PARAMETER._serialized_end=6149
  _PARAMETER_TAGSENTRY._serialized_start=2076
  _PARAMETER_TAGSENTRY._serialized_end=2119
  _PATCHBASELINEPATCHSTRINGDATE._serialized_start=6151
  _PATCHBASELINEPATCHSTRINGDATE._serialized_end=6238
  _PATCHBASELINEPATCHFILTER._serialized_start=6240
  _PATCHBASELINEPATCHFILTER._serialized_end=6352
  _PATCHBASELINEPATCHFILTERGROUP._serialized_start=6355
  _PATCHBASELINEPATCHFILTERGROUP._serialized_end=6513
  _PATCHBASELINERULE._serialized_start=6516
  _PATCHBASELINERULE._serialized_end=6834
  _PATCHBASELINERULEGROUP._serialized_start=6837
  _PATCHBASELINERULEGROUP._serialized_end=6979
  _PATCHBASELINEPATCHSOURCE._serialized_start=6982
  _PATCHBASELINEPATCHSOURCE._serialized_end=7120
  _PATCHBASELINE._serialized_start=7123
  _PATCHBASELINE._serialized_end=7766
  _PATCHBASELINE_TAGSENTRY._serialized_start=2076
  _PATCHBASELINE_TAGSENTRY._serialized_end=2119
  _RESOURCEDATASYNCS3DESTINATION._serialized_start=7769
  _RESOURCEDATASYNCS3DESTINATION._serialized_end=7966
  _RESOURCEDATASYNCAWSORGANIZATIONSSOURCE._serialized_start=7969
  _RESOURCEDATASYNCAWSORGANIZATIONSSOURCE._serialized_end=8130
  _RESOURCEDATASYNCSYNCSOURCE._serialized_start=8133
  _RESOURCEDATASYNCSYNCSOURCE._serialized_end=8390
  _RESOURCEDATASYNC._serialized_start=8393
  _RESOURCEDATASYNC._serialized_end=8761
  _ASSOCIATIONPARAMETERVALUES._serialized_start=8763
  _ASSOCIATIONPARAMETERVALUES._serialized_end=8874
# @@protoc_insertion_point(module_scope)
