# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_rds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_rds.proto\x12\x13oak9.tython.aws.rds\x1a\x13shared/shared.proto\"y\n\x16\x44\x42\x43lusterDBClusterRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xb3\x06\n\x03RDS\x12O\n\x1a\x64\x62_cluster_db_cluster_role\x18\x01 \x03(\x0b\x32+.oak9.tython.aws.rds.DBClusterDBClusterRole\x12\\\n db_cluster_scaling_configuration\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.rds.DBClusterScalingConfiguration\x12S\n\x1c\x64\x62_instance_db_instance_role\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.rds.DBInstanceDBInstanceRole\x12V\n\x1d\x64\x62_instance_processor_feature\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.rds.DBInstanceProcessorFeature\x12\x44\n\x14\x64\x62_proxy_auth_format\x18\x05 \x03(\x0b\x32&.oak9.tython.aws.rds.DBProxyAuthFormat\x12\x42\n\x13\x64\x62_proxy_tag_format\x18\x06 \x03(\x0b\x32%.oak9.tython.aws.rds.DBProxyTagFormat\x12\x95\x01\n?db_proxy_target_group_connection_pool_configuration_info_format\x18\x07 \x03(\x0b\x32L.oak9.tython.aws.rds.DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12N\n\x19\x64\x62_security_group_ingress\x18\x08 \x03(\x0b\x32+.oak9.tython.aws.rds.DBSecurityGroupIngress\x12^\n!option_group_option_configuration\x18\t \x03(\x0b\x32\x33.oak9.tython.aws.rds.OptionGroupOptionConfiguration\"\xba\x01\n\x1d\x44\x42\x43lusterScalingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nauto_pause\x18\x02 \x01(\x08\x12\x14\n\x0cmax_capacity\x18\x03 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x04 \x01(\x05\x12 \n\x18seconds_until_auto_pause\x18\x05 \x01(\x05\"{\n\x18\x44\x42InstanceDBInstanceRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"r\n\x1a\x44\x42InstanceProcessorFeature\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xaf\x01\n\x11\x44\x42ProxyAuthFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61uth_scheme\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08iam_auth\x18\x04 \x01(\t\x12\x12\n\nsecret_arn\x18\x05 \x01(\t\x12\x11\n\tuser_name\x18\x06 \x01(\t\"g\n\x10\x44\x42ProxyTagFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x91\x02\n7DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17max_connections_percent\x18\x02 \x01(\x05\x12$\n\x1cmax_idle_connections_percent\x18\x03 \x01(\x05\x12!\n\x19\x63onnection_borrow_timeout\x18\x04 \x01(\x05\x12\x1f\n\x17session_pinning_filters\x18\x05 \x03(\t\x12\x12\n\ninit_query\x18\x06 \x01(\t\"\xca\x01\n\x16\x44\x42SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x1e\n\x16\x65_c2_security_group_id\x18\x03 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x04 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x05 \x01(\t\"p\n\x18OptionGroupOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xab\x02\n\x1eOptionGroupOptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1d\x64\x62_security_group_memberships\x18\x02 \x03(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12\x46\n\x0foption_settings\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.rds.OptionGroupOptionSetting\x12\x16\n\x0eoption_version\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12&\n\x1evpc_security_group_memberships\x18\x07 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_rds_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DBCLUSTERDBCLUSTERROLE._serialized_start=63
  _DBCLUSTERDBCLUSTERROLE._serialized_end=184
  _RDS._serialized_start=187
  _RDS._serialized_end=1006
  _DBCLUSTERSCALINGCONFIGURATION._serialized_start=1009
  _DBCLUSTERSCALINGCONFIGURATION._serialized_end=1195
  _DBINSTANCEDBINSTANCEROLE._serialized_start=1197
  _DBINSTANCEDBINSTANCEROLE._serialized_end=1320
  _DBINSTANCEPROCESSORFEATURE._serialized_start=1322
  _DBINSTANCEPROCESSORFEATURE._serialized_end=1436
  _DBPROXYAUTHFORMAT._serialized_start=1439
  _DBPROXYAUTHFORMAT._serialized_end=1614
  _DBPROXYTAGFORMAT._serialized_start=1616
  _DBPROXYTAGFORMAT._serialized_end=1719
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_start=1722
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_end=1995
  _DBSECURITYGROUPINGRESS._serialized_start=1998
  _DBSECURITYGROUPINGRESS._serialized_end=2200
  _OPTIONGROUPOPTIONSETTING._serialized_start=2202
  _OPTIONGROUPOPTIONSETTING._serialized_end=2314
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_start=2317
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_end=2616
# @@protoc_insertion_point(module_scope)
