# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_address.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgcp/gcp_compute_address.proto\x12\x1foak9.tython.gcp.compute_address\x1a\x13shared/shared.proto\"9\n\x17\x43omputeAddressXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xad\x03\n\x0e\x43omputeAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x02 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07network\x18\x07 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x08 \x01(\t\x12\x15\n\rprefix_length\x18\t \x01(\x01\x12\x0f\n\x07project\x18\n \x01(\t\x12\x0f\n\x07purpose\x18\x0b \x01(\t\x12\x0e\n\x06region\x18\x0c \x01(\t\x12\x11\n\tself_link\x18\r \x01(\t\x12\x12\n\nsubnetwork\x18\x0e \x01(\t\x12\r\n\x05users\x18\x0f \x03(\t\x12J\n\x08timeouts\x18\x10 \x01(\x0b\x32\x38.oak9.tython.gcp.compute_address.ComputeAddressXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_address_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEADDRESSXTIMEOUTS._serialized_start=87
  _COMPUTEADDRESSXTIMEOUTS._serialized_end=144
  _COMPUTEADDRESS._serialized_start=147
  _COMPUTEADDRESS._serialized_end=576
# @@protoc_insertion_point(module_scope)
