"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApigeeEndpointAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ApigeeEndpointAttachmentXTimeouts = ApigeeEndpointAttachmentXTimeouts

@typing_extensions.final
class ApigeeEndpointAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_ATTACHMENT_ID_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    SERVICE_ATTACHMENT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    endpoint_attachment_id: builtins.str
    host: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    org_id: builtins.str
    service_attachment: builtins.str
    @property
    def timeouts(self) -> global___ApigeeEndpointAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        endpoint_attachment_id: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        service_attachment: builtins.str = ...,
        timeouts: global___ApigeeEndpointAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_attachment_id", b"endpoint_attachment_id", "host", b"host", "id", b"id", "location", b"location", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "service_attachment", b"service_attachment", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeEndpointAttachment = ApigeeEndpointAttachment

@typing_extensions.final
class ApigeeEnvgroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ApigeeEnvgroupXTimeouts = ApigeeEnvgroupXTimeouts

@typing_extensions.final
class ApigeeEnvgroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTNAMES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    name: builtins.str
    org_id: builtins.str
    @property
    def timeouts(self) -> global___ApigeeEnvgroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        timeouts: global___ApigeeEnvgroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostnames", b"hostnames", "id", b"id", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeEnvgroup = ApigeeEnvgroup

@typing_extensions.final
class ApigeeEnvgroupAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ApigeeEnvgroupAttachmentXTimeouts = ApigeeEnvgroupAttachmentXTimeouts

@typing_extensions.final
class ApigeeEnvgroupAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVGROUP_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    envgroup_id: builtins.str
    environment: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def timeouts(self) -> global___ApigeeEnvgroupAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        envgroup_id: builtins.str = ...,
        environment: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        timeouts: global___ApigeeEnvgroupAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["envgroup_id", b"envgroup_id", "environment", b"environment", "id", b"id", "name", b"name", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeEnvgroupAttachment = ApigeeEnvgroupAttachment

@typing_extensions.final
class ApigeeEnvironmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ApigeeEnvironmentXTimeouts = ApigeeEnvironmentXTimeouts

@typing_extensions.final
class ApigeeEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_PROXY_TYPE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_proxy_type: builtins.str
    deployment_type: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    org_id: builtins.str
    @property
    def timeouts(self) -> global___ApigeeEnvironmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_proxy_type: builtins.str = ...,
        deployment_type: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        timeouts: global___ApigeeEnvironmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_proxy_type", b"api_proxy_type", "deployment_type", b"deployment_type", "description", b"description", "display_name", b"display_name", "id", b"id", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeEnvironment = ApigeeEnvironment

@typing_extensions.final
class ApigeeEnvironmentIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ApigeeEnvironmentIamBindingXCondition = ApigeeEnvironmentIamBindingXCondition

@typing_extensions.final
class ApigeeEnvironmentIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    env_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    org_id: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ApigeeEnvironmentIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        env_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        org_id: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ApigeeEnvironmentIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "env_id", b"env_id", "etag", b"etag", "id", b"id", "members", b"members", "org_id", b"org_id", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ApigeeEnvironmentIamBinding = ApigeeEnvironmentIamBinding

@typing_extensions.final
class ApigeeEnvironmentIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ApigeeEnvironmentIamMemberXCondition = ApigeeEnvironmentIamMemberXCondition

@typing_extensions.final
class ApigeeEnvironmentIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    env_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    org_id: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ApigeeEnvironmentIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        env_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        org_id: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ApigeeEnvironmentIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "env_id", b"env_id", "etag", b"etag", "id", b"id", "member", b"member", "org_id", b"org_id", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ApigeeEnvironmentIamMember = ApigeeEnvironmentIamMember

@typing_extensions.final
class ApigeeEnvironmentIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    env_id: builtins.str
    etag: builtins.str
    id: builtins.str
    org_id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        env_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        org_id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env_id", b"env_id", "etag", b"etag", "id", b"id", "org_id", b"org_id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___ApigeeEnvironmentIamPolicy = ApigeeEnvironmentIamPolicy

@typing_extensions.final
class ApigeeInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ApigeeInstanceXTimeouts = ApigeeInstanceXTimeouts

@typing_extensions.final
class ApigeeInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUMER_ACCEPT_LIST_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_NAME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_RANGE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    PEERING_CIDR_RANGE_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    SERVICE_ATTACHMENT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def consumer_accept_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    disk_encryption_key_name: builtins.str
    display_name: builtins.str
    host: builtins.str
    id: builtins.str
    ip_range: builtins.str
    location: builtins.str
    name: builtins.str
    org_id: builtins.str
    peering_cidr_range: builtins.str
    port: builtins.str
    service_attachment: builtins.str
    @property
    def timeouts(self) -> global___ApigeeInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        consumer_accept_list: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        disk_encryption_key_name: builtins.str = ...,
        display_name: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        ip_range: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        peering_cidr_range: builtins.str = ...,
        port: builtins.str = ...,
        service_attachment: builtins.str = ...,
        timeouts: global___ApigeeInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["consumer_accept_list", b"consumer_accept_list", "description", b"description", "disk_encryption_key_name", b"disk_encryption_key_name", "display_name", b"display_name", "host", b"host", "id", b"id", "ip_range", b"ip_range", "location", b"location", "name", b"name", "org_id", b"org_id", "peering_cidr_range", b"peering_cidr_range", "port", b"port", "resource_info", b"resource_info", "service_attachment", b"service_attachment", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeInstance = ApigeeInstance

@typing_extensions.final
class ApigeeInstanceAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ApigeeInstanceAttachmentXTimeouts = ApigeeInstanceAttachmentXTimeouts

@typing_extensions.final
class ApigeeInstanceAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    environment: builtins.str
    id: builtins.str
    instance_id: builtins.str
    name: builtins.str
    @property
    def timeouts(self) -> global___ApigeeInstanceAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        environment: builtins.str = ...,
        id: builtins.str = ...,
        instance_id: builtins.str = ...,
        name: builtins.str = ...,
        timeouts: global___ApigeeInstanceAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment", "id", b"id", "instance_id", b"instance_id", "name", b"name", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeInstanceAttachment = ApigeeInstanceAttachment

@typing_extensions.final
class ApigeeOrganizationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ApigeeOrganizationXTimeouts = ApigeeOrganizationXTimeouts

@typing_extensions.final
class ApigeeOrganization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANALYTICS_REGION_FIELD_NUMBER: builtins.int
    AUTHORIZED_NETWORK_FIELD_NUMBER: builtins.int
    BILLING_TYPE_FIELD_NUMBER: builtins.int
    CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    RUNTIME_DATABASE_ENCRYPTION_KEY_NAME_FIELD_NUMBER: builtins.int
    RUNTIME_TYPE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_TYPE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    analytics_region: builtins.str
    authorized_network: builtins.str
    billing_type: builtins.str
    ca_certificate: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    project_id: builtins.str
    runtime_database_encryption_key_name: builtins.str
    runtime_type: builtins.str
    subscription_type: builtins.str
    @property
    def timeouts(self) -> global___ApigeeOrganizationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        analytics_region: builtins.str = ...,
        authorized_network: builtins.str = ...,
        billing_type: builtins.str = ...,
        ca_certificate: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project_id: builtins.str = ...,
        runtime_database_encryption_key_name: builtins.str = ...,
        runtime_type: builtins.str = ...,
        subscription_type: builtins.str = ...,
        timeouts: global___ApigeeOrganizationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytics_region", b"analytics_region", "authorized_network", b"authorized_network", "billing_type", b"billing_type", "ca_certificate", b"ca_certificate", "description", b"description", "display_name", b"display_name", "id", b"id", "name", b"name", "project_id", b"project_id", "resource_info", b"resource_info", "runtime_database_encryption_key_name", b"runtime_database_encryption_key_name", "runtime_type", b"runtime_type", "subscription_type", b"subscription_type", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeOrganization = ApigeeOrganization
