# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_gke.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_gke.proto\x12\x13oak9.tython.gcp.gke\x1a\x13shared/shared.proto\",\n\x1aGkeHubMembershipXAuthority\x12\x0e\n\x06issuer\x18\x01 \x01(\t\"=\n$GkeHubMembershipXEndpointXGkeCluster\x12\x15\n\rresource_link\x18\x01 \x01(\t\"k\n\x19GkeHubMembershipXEndpoint\x12N\n\x0bgke_cluster\x18\x01 \x01(\x0b\x32\x39.oak9.tython.gcp.gke.GkeHubMembershipXEndpointXGkeCluster\"K\n\x19GkeHubMembershipXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc7\x03\n\x10GkeHubMembership\x12\n\n\x02id\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.oak9.tython.gcp.gke.GkeHubMembership.LabelsEntry\x12\x15\n\rmembership_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x42\n\tauthority\x18\x06 \x01(\x0b\x32/.oak9.tython.gcp.gke.GkeHubMembershipXAuthority\x12@\n\x08\x65ndpoint\x18\x07 \x01(\x0b\x32..oak9.tython.gcp.gke.GkeHubMembershipXEndpoint\x12@\n\x08timeouts\x18\x08 \x01(\x0b\x32..oak9.tython.gcp.gke.GkeHubMembershipXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_gke_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GKEHUBMEMBERSHIP_LABELSENTRY._options = None
  _GKEHUBMEMBERSHIP_LABELSENTRY._serialized_options = b'8\001'
  _GKEHUBMEMBERSHIPXAUTHORITY._serialized_start=63
  _GKEHUBMEMBERSHIPXAUTHORITY._serialized_end=107
  _GKEHUBMEMBERSHIPXENDPOINTXGKECLUSTER._serialized_start=109
  _GKEHUBMEMBERSHIPXENDPOINTXGKECLUSTER._serialized_end=170
  _GKEHUBMEMBERSHIPXENDPOINT._serialized_start=172
  _GKEHUBMEMBERSHIPXENDPOINT._serialized_end=279
  _GKEHUBMEMBERSHIPXTIMEOUTS._serialized_start=281
  _GKEHUBMEMBERSHIPXTIMEOUTS._serialized_end=356
  _GKEHUBMEMBERSHIP._serialized_start=359
  _GKEHUBMEMBERSHIP._serialized_end=814
  _GKEHUBMEMBERSHIP_LABELSENTRY._serialized_start=769
  _GKEHUBMEMBERSHIP_LABELSENTRY._serialized_end=814
# @@protoc_insertion_point(module_scope)
