"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudfunctionsFunctionXEventTriggerXFailurePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETRY_FIELD_NUMBER: builtins.int
    retry: builtins.bool
    def __init__(
        self,
        *,
        retry: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["retry", b"retry"]) -> None: ...

global___CloudfunctionsFunctionXEventTriggerXFailurePolicy = CloudfunctionsFunctionXEventTriggerXFailurePolicy

@typing_extensions.final
class CloudfunctionsFunctionXEventTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    FAILURE_POLICY_FIELD_NUMBER: builtins.int
    event_type: builtins.str
    resource: builtins.str
    @property
    def failure_policy(self) -> global___CloudfunctionsFunctionXEventTriggerXFailurePolicy: ...
    def __init__(
        self,
        *,
        event_type: builtins.str = ...,
        resource: builtins.str = ...,
        failure_policy: global___CloudfunctionsFunctionXEventTriggerXFailurePolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure_policy", b"failure_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_type", b"event_type", "failure_policy", b"failure_policy", "resource", b"resource"]) -> None: ...

global___CloudfunctionsFunctionXEventTrigger = CloudfunctionsFunctionXEventTrigger

@typing_extensions.final
class CloudfunctionsFunctionXSecretEnvironmentVariables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    key: builtins.str
    project_id: builtins.str
    secret: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        project_id: builtins.str = ...,
        secret: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "project_id", b"project_id", "secret", b"secret", "version", b"version"]) -> None: ...

global___CloudfunctionsFunctionXSecretEnvironmentVariables = CloudfunctionsFunctionXSecretEnvironmentVariables

@typing_extensions.final
class CloudfunctionsFunctionXSecretVolumesXVersions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    path: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "version", b"version"]) -> None: ...

global___CloudfunctionsFunctionXSecretVolumesXVersions = CloudfunctionsFunctionXSecretVolumesXVersions

@typing_extensions.final
class CloudfunctionsFunctionXSecretVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOUNT_PATH_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    mount_path: builtins.str
    project_id: builtins.str
    secret: builtins.str
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudfunctionsFunctionXSecretVolumesXVersions]: ...
    def __init__(
        self,
        *,
        mount_path: builtins.str = ...,
        project_id: builtins.str = ...,
        secret: builtins.str = ...,
        versions: collections.abc.Iterable[global___CloudfunctionsFunctionXSecretVolumesXVersions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount_path", b"mount_path", "project_id", b"project_id", "secret", b"secret", "versions", b"versions"]) -> None: ...

global___CloudfunctionsFunctionXSecretVolumes = CloudfunctionsFunctionXSecretVolumes

@typing_extensions.final
class CloudfunctionsFunctionXSourceRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYED_URL_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    deployed_url: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        deployed_url: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployed_url", b"deployed_url", "url", b"url"]) -> None: ...

global___CloudfunctionsFunctionXSourceRepository = CloudfunctionsFunctionXSourceRepository

@typing_extensions.final
class CloudfunctionsFunctionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read", "update", b"update"]) -> None: ...

global___CloudfunctionsFunctionXTimeouts = CloudfunctionsFunctionXTimeouts

@typing_extensions.final
class CloudfunctionsFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class BuildEnvironmentVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class EnvironmentVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AVAILABLE_MEMORY_MB_FIELD_NUMBER: builtins.int
    BUILD_ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOCKER_REGISTRY_FIELD_NUMBER: builtins.int
    DOCKER_REPOSITORY_FIELD_NUMBER: builtins.int
    ENTRY_POINT_FIELD_NUMBER: builtins.int
    ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    HTTPS_TRIGGER_SECURITY_LEVEL_FIELD_NUMBER: builtins.int
    HTTPS_TRIGGER_URL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INGRESS_SETTINGS_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MAX_INSTANCES_FIELD_NUMBER: builtins.int
    MIN_INSTANCES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    SOURCE_ARCHIVE_BUCKET_FIELD_NUMBER: builtins.int
    SOURCE_ARCHIVE_OBJECT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    TRIGGER_HTTP_FIELD_NUMBER: builtins.int
    VPC_CONNECTOR_FIELD_NUMBER: builtins.int
    VPC_CONNECTOR_EGRESS_SETTINGS_FIELD_NUMBER: builtins.int
    EVENT_TRIGGER_FIELD_NUMBER: builtins.int
    SECRET_ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    SECRET_VOLUMES_FIELD_NUMBER: builtins.int
    SOURCE_REPOSITORY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_memory_mb: builtins.float
    @property
    def build_environment_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    description: builtins.str
    docker_registry: builtins.str
    docker_repository: builtins.str
    entry_point: builtins.str
    @property
    def environment_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    https_trigger_security_level: builtins.str
    https_trigger_url: builtins.str
    id: builtins.str
    ingress_settings: builtins.str
    kms_key_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    max_instances: builtins.float
    min_instances: builtins.float
    name: builtins.str
    project: builtins.str
    region: builtins.str
    runtime: builtins.str
    service_account_email: builtins.str
    source_archive_bucket: builtins.str
    source_archive_object: builtins.str
    timeout: builtins.float
    trigger_http: builtins.bool
    vpc_connector: builtins.str
    vpc_connector_egress_settings: builtins.str
    @property
    def event_trigger(self) -> global___CloudfunctionsFunctionXEventTrigger: ...
    @property
    def secret_environment_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudfunctionsFunctionXSecretEnvironmentVariables]: ...
    @property
    def secret_volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudfunctionsFunctionXSecretVolumes]: ...
    @property
    def source_repository(self) -> global___CloudfunctionsFunctionXSourceRepository: ...
    @property
    def timeouts(self) -> global___CloudfunctionsFunctionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_memory_mb: builtins.float = ...,
        build_environment_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        docker_registry: builtins.str = ...,
        docker_repository: builtins.str = ...,
        entry_point: builtins.str = ...,
        environment_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        https_trigger_security_level: builtins.str = ...,
        https_trigger_url: builtins.str = ...,
        id: builtins.str = ...,
        ingress_settings: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        max_instances: builtins.float = ...,
        min_instances: builtins.float = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        runtime: builtins.str = ...,
        service_account_email: builtins.str = ...,
        source_archive_bucket: builtins.str = ...,
        source_archive_object: builtins.str = ...,
        timeout: builtins.float = ...,
        trigger_http: builtins.bool = ...,
        vpc_connector: builtins.str = ...,
        vpc_connector_egress_settings: builtins.str = ...,
        event_trigger: global___CloudfunctionsFunctionXEventTrigger | None = ...,
        secret_environment_variables: collections.abc.Iterable[global___CloudfunctionsFunctionXSecretEnvironmentVariables] | None = ...,
        secret_volumes: collections.abc.Iterable[global___CloudfunctionsFunctionXSecretVolumes] | None = ...,
        source_repository: global___CloudfunctionsFunctionXSourceRepository | None = ...,
        timeouts: global___CloudfunctionsFunctionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event_trigger", b"event_trigger", "resource_info", b"resource_info", "source_repository", b"source_repository", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_memory_mb", b"available_memory_mb", "build_environment_variables", b"build_environment_variables", "description", b"description", "docker_registry", b"docker_registry", "docker_repository", b"docker_repository", "entry_point", b"entry_point", "environment_variables", b"environment_variables", "event_trigger", b"event_trigger", "https_trigger_security_level", b"https_trigger_security_level", "https_trigger_url", b"https_trigger_url", "id", b"id", "ingress_settings", b"ingress_settings", "kms_key_name", b"kms_key_name", "labels", b"labels", "max_instances", b"max_instances", "min_instances", b"min_instances", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "runtime", b"runtime", "secret_environment_variables", b"secret_environment_variables", "secret_volumes", b"secret_volumes", "service_account_email", b"service_account_email", "source_archive_bucket", b"source_archive_bucket", "source_archive_object", b"source_archive_object", "source_repository", b"source_repository", "timeout", b"timeout", "timeouts", b"timeouts", "trigger_http", b"trigger_http", "vpc_connector", b"vpc_connector", "vpc_connector_egress_settings", b"vpc_connector_egress_settings"]) -> None: ...

global___CloudfunctionsFunction = CloudfunctionsFunction

@typing_extensions.final
class CloudfunctionsFunctionIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudfunctionsFunctionIamBindingXCondition = CloudfunctionsFunctionIamBindingXCondition

@typing_extensions.final
class CloudfunctionsFunctionIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cloud_function: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudfunctionsFunctionIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cloud_function: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudfunctionsFunctionIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_function", b"cloud_function", "condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudfunctionsFunctionIamBinding = CloudfunctionsFunctionIamBinding

@typing_extensions.final
class CloudfunctionsFunctionIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudfunctionsFunctionIamMemberXCondition = CloudfunctionsFunctionIamMemberXCondition

@typing_extensions.final
class CloudfunctionsFunctionIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cloud_function: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudfunctionsFunctionIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cloud_function: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudfunctionsFunctionIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_function", b"cloud_function", "condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudfunctionsFunctionIamMember = CloudfunctionsFunctionIamMember

@typing_extensions.final
class CloudfunctionsFunctionIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cloud_function: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cloud_function: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_function", b"cloud_function", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___CloudfunctionsFunctionIamPolicy = CloudfunctionsFunctionIamPolicy
