# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_project.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgcp/gcp_compute_project.proto\x12\x1foak9.tython.gcp.compute_project\x1a\x13shared/shared.proto\";\n)ComputeProjectDefaultNetworkTierXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\"\xec\x01\n ComputeProjectDefaultNetworkTier\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\\\n\x08timeouts\x18\x04 \x01(\x0b\x32J.oak9.tython.gcp.compute_project.ComputeProjectDefaultNetworkTierXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"A\n\x1f\x43omputeProjectMetadataXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xcc\x02\n\x16\x43omputeProjectMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12W\n\x08metadata\x18\x02 \x03(\x0b\x32\x45.oak9.tython.gcp.compute_project.ComputeProjectMetadata.MetadataEntry\x12\x0f\n\x07project\x18\x03 \x01(\t\x12R\n\x08timeouts\x18\x04 \x01(\x0b\x32@.oak9.tython.gcp.compute_project.ComputeProjectMetadataXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n#ComputeProjectMetadataItemXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe6\x01\n\x1a\x43omputeProjectMetadataItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12V\n\x08timeouts\x18\x05 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_project.ComputeProjectMetadataItemXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_project_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEPROJECTMETADATA_METADATAENTRY._options = None
  _COMPUTEPROJECTMETADATA_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEPROJECTDEFAULTNETWORKTIERXTIMEOUTS._serialized_start=87
  _COMPUTEPROJECTDEFAULTNETWORKTIERXTIMEOUTS._serialized_end=146
  _COMPUTEPROJECTDEFAULTNETWORKTIER._serialized_start=149
  _COMPUTEPROJECTDEFAULTNETWORKTIER._serialized_end=385
  _COMPUTEPROJECTMETADATAXTIMEOUTS._serialized_start=387
  _COMPUTEPROJECTMETADATAXTIMEOUTS._serialized_end=452
  _COMPUTEPROJECTMETADATA._serialized_start=455
  _COMPUTEPROJECTMETADATA._serialized_end=787
  _COMPUTEPROJECTMETADATA_METADATAENTRY._serialized_start=740
  _COMPUTEPROJECTMETADATA_METADATAENTRY._serialized_end=787
  _COMPUTEPROJECTMETADATAITEMXTIMEOUTS._serialized_start=789
  _COMPUTEPROJECTMETADATAITEMXTIMEOUTS._serialized_end=874
  _COMPUTEPROJECTMETADATAITEM._serialized_start=877
  _COMPUTEPROJECTMETADATAITEM._serialized_end=1107
# @@protoc_insertion_point(module_scope)
