"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Fleet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Fleet = Fleet

@typing_extensions.final
class RoboMaker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLEET_FIELD_NUMBER: builtins.int
    ROBOT_FIELD_NUMBER: builtins.int
    ROBOT_APPLICATION_FIELD_NUMBER: builtins.int
    ROBOT_APPLICATION_VERSION_FIELD_NUMBER: builtins.int
    SIMULATION_APPLICATION_FIELD_NUMBER: builtins.int
    SIMULATION_APPLICATION_VERSION_FIELD_NUMBER: builtins.int
    @property
    def fleet(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Fleet]: ...
    @property
    def robot(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Robot]: ...
    @property
    def robot_application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RobotApplication]: ...
    @property
    def robot_application_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RobotApplicationVersion]: ...
    @property
    def simulation_application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimulationApplication]: ...
    @property
    def simulation_application_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimulationApplicationVersion]: ...
    def __init__(
        self,
        *,
        fleet: collections.abc.Iterable[global___Fleet] | None = ...,
        robot: collections.abc.Iterable[global___Robot] | None = ...,
        robot_application: collections.abc.Iterable[global___RobotApplication] | None = ...,
        robot_application_version: collections.abc.Iterable[global___RobotApplicationVersion] | None = ...,
        simulation_application: collections.abc.Iterable[global___SimulationApplication] | None = ...,
        simulation_application_version: collections.abc.Iterable[global___SimulationApplicationVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fleet", b"fleet", "robot", b"robot", "robot_application", b"robot_application", "robot_application_version", b"robot_application_version", "simulation_application", b"simulation_application", "simulation_application_version", b"simulation_application_version"]) -> None: ...

global___RoboMaker = RoboMaker

@typing_extensions.final
class Robot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FLEET_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    GREENGRASS_GROUP_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    fleet: builtins.str
    architecture: builtins.str
    greengrass_group_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        fleet: builtins.str = ...,
        architecture: builtins.str = ...,
        greengrass_group_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["architecture", b"architecture", "fleet", b"fleet", "greengrass_group_id", b"greengrass_group_id", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Robot = Robot

@typing_extensions.final
class RobotApplicationRobotSoftwareSuite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___RobotApplicationRobotSoftwareSuite = RobotApplicationRobotSoftwareSuite

@typing_extensions.final
class RobotApplicationSourceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    architecture: builtins.str
    s3_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        architecture: builtins.str = ...,
        s3_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["architecture", b"architecture", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_key", b"s3_key"]) -> None: ...

global___RobotApplicationSourceConfig = RobotApplicationSourceConfig

@typing_extensions.final
class RobotApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_ID_FIELD_NUMBER: builtins.int
    ROBOT_SOFTWARE_SUITE_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    current_revision_id: builtins.str
    @property
    def robot_software_suite(self) -> global___RobotApplicationRobotSoftwareSuite: ...
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RobotApplicationSourceConfig]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        current_revision_id: builtins.str = ...,
        robot_software_suite: global___RobotApplicationRobotSoftwareSuite | None = ...,
        sources: collections.abc.Iterable[global___RobotApplicationSourceConfig] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "robot_software_suite", b"robot_software_suite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_revision_id", b"current_revision_id", "name", b"name", "resource_info", b"resource_info", "robot_software_suite", b"robot_software_suite", "sources", b"sources", "tags", b"tags"]) -> None: ...

global___RobotApplication = RobotApplication

@typing_extensions.final
class RobotApplicationVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_ID_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    current_revision_id: builtins.str
    application: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        current_revision_id: builtins.str = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "current_revision_id", b"current_revision_id", "resource_info", b"resource_info"]) -> None: ...

global___RobotApplicationVersion = RobotApplicationVersion

@typing_extensions.final
class SimulationApplicationRenderingEngine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___SimulationApplicationRenderingEngine = SimulationApplicationRenderingEngine

@typing_extensions.final
class SimulationApplicationSimulationSoftwareSuite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___SimulationApplicationSimulationSoftwareSuite = SimulationApplicationSimulationSoftwareSuite

@typing_extensions.final
class SimulationApplicationRobotSoftwareSuite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___SimulationApplicationRobotSoftwareSuite = SimulationApplicationRobotSoftwareSuite

@typing_extensions.final
class SimulationApplicationSourceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    ARCHITECTURE_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    architecture: builtins.str
    s3_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        architecture: builtins.str = ...,
        s3_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["architecture", b"architecture", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_key", b"s3_key"]) -> None: ...

global___SimulationApplicationSourceConfig = SimulationApplicationSourceConfig

@typing_extensions.final
class SimulationApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RENDERING_ENGINE_FIELD_NUMBER: builtins.int
    SIMULATION_SOFTWARE_SUITE_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_ID_FIELD_NUMBER: builtins.int
    ROBOT_SOFTWARE_SUITE_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def rendering_engine(self) -> global___SimulationApplicationRenderingEngine: ...
    @property
    def simulation_software_suite(self) -> global___SimulationApplicationSimulationSoftwareSuite: ...
    current_revision_id: builtins.str
    @property
    def robot_software_suite(self) -> global___SimulationApplicationRobotSoftwareSuite: ...
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimulationApplicationSourceConfig]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rendering_engine: global___SimulationApplicationRenderingEngine | None = ...,
        simulation_software_suite: global___SimulationApplicationSimulationSoftwareSuite | None = ...,
        current_revision_id: builtins.str = ...,
        robot_software_suite: global___SimulationApplicationRobotSoftwareSuite | None = ...,
        sources: collections.abc.Iterable[global___SimulationApplicationSourceConfig] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rendering_engine", b"rendering_engine", "resource_info", b"resource_info", "robot_software_suite", b"robot_software_suite", "simulation_software_suite", b"simulation_software_suite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_revision_id", b"current_revision_id", "name", b"name", "rendering_engine", b"rendering_engine", "resource_info", b"resource_info", "robot_software_suite", b"robot_software_suite", "simulation_software_suite", b"simulation_software_suite", "sources", b"sources", "tags", b"tags"]) -> None: ...

global___SimulationApplication = SimulationApplication

@typing_extensions.final
class SimulationApplicationVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_ID_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    current_revision_id: builtins.str
    application: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        current_revision_id: builtins.str = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "current_revision_id", b"current_revision_id", "resource_info", b"resource_info"]) -> None: ...

global___SimulationApplicationVersion = SimulationApplicationVersion
