# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ram.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_ram.proto\x12\x13oak9.tython.aws.ram\x1a\x13shared/shared.proto\"\x8d\x02\n\rResourceShare\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nprincipals\x18\x02 \x03(\t\x12!\n\x19\x61llow_external_principals\x18\x03 \x01(\x08\x12\x15\n\rresource_arns\x18\x04 \x03(\t\x12:\n\x04tags\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.ram.ResourceShare.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x03RAM\x12:\n\x0eresource_share\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.ram.ResourceShareb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ram_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCESHARE_TAGSENTRY._options = None
  _RESOURCESHARE_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCESHARE._serialized_start=64
  _RESOURCESHARE._serialized_end=333
  _RESOURCESHARE_TAGSENTRY._serialized_start=290
  _RESOURCESHARE_TAGSENTRY._serialized_end=333
  _RAM._serialized_start=335
  _RAM._serialized_end=400
# @@protoc_insertion_point(module_scope)
