"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AWSElasticBlockStoreVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    PARTITION_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    VOLUME_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    partition: builtins.int
    read_only: builtins.bool
    volume_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        partition: builtins.int = ...,
        read_only: builtins.bool = ...,
        volume_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "partition", b"partition", "read_only", b"read_only", "resource_info", b"resource_info", "volume_id", b"volume_id"]) -> None: ...

global___AWSElasticBlockStoreVolumeSource = AWSElasticBlockStoreVolumeSource

@typing_extensions.final
class Affinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_AFFINITY_FIELD_NUMBER: builtins.int
    POD_AFFINITY_FIELD_NUMBER: builtins.int
    POD_ANTI_AFFINITY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_affinity(self) -> global___NodeAffinity: ...
    @property
    def pod_affinity(self) -> global___PodAffinity: ...
    @property
    def pod_anti_affinity(self) -> global___PodAntiAffinity: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        node_affinity: global___NodeAffinity | None = ...,
        pod_affinity: global___PodAffinity | None = ...,
        pod_anti_affinity: global___PodAntiAffinity | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["node_affinity", b"node_affinity", "pod_affinity", b"pod_affinity", "pod_anti_affinity", b"pod_anti_affinity", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["node_affinity", b"node_affinity", "pod_affinity", b"pod_affinity", "pod_anti_affinity", b"pod_anti_affinity", "resource_info", b"resource_info"]) -> None: ...

global___Affinity = Affinity

@typing_extensions.final
class AttachedVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    device_path: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        device_path: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_path", b"device_path", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___AttachedVolume = AttachedVolume

@typing_extensions.final
class AzureDiskVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHING_MODE_FIELD_NUMBER: builtins.int
    DISK_NAME_FIELD_NUMBER: builtins.int
    DISK_U_R_I_FIELD_NUMBER: builtins.int
    FS_TYPE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    caching_mode: builtins.str
    disk_name: builtins.str
    disk_u_r_i: builtins.str
    fs_type: builtins.str
    kind: builtins.str
    read_only: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        caching_mode: builtins.str = ...,
        disk_name: builtins.str = ...,
        disk_u_r_i: builtins.str = ...,
        fs_type: builtins.str = ...,
        kind: builtins.str = ...,
        read_only: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caching_mode", b"caching_mode", "disk_name", b"disk_name", "disk_u_r_i", b"disk_u_r_i", "fs_type", b"fs_type", "kind", b"kind", "read_only", b"read_only", "resource_info", b"resource_info"]) -> None: ...

global___AzureDiskVolumeSource = AzureDiskVolumeSource

@typing_extensions.final
class AzureFilePersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_NAME_FIELD_NUMBER: builtins.int
    SECRET_NAMESPACE_FIELD_NUMBER: builtins.int
    SHARE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    read_only: builtins.bool
    secret_name: builtins.str
    secret_namespace: builtins.str
    share_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        read_only: builtins.bool = ...,
        secret_name: builtins.str = ...,
        secret_namespace: builtins.str = ...,
        share_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["read_only", b"read_only", "resource_info", b"resource_info", "secret_name", b"secret_name", "secret_namespace", b"secret_namespace", "share_name", b"share_name"]) -> None: ...

global___AzureFilePersistentVolumeSource = AzureFilePersistentVolumeSource

@typing_extensions.final
class AzureFileVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_NAME_FIELD_NUMBER: builtins.int
    SHARE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    read_only: builtins.bool
    secret_name: builtins.str
    share_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        read_only: builtins.bool = ...,
        secret_name: builtins.str = ...,
        share_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["read_only", b"read_only", "resource_info", b"resource_info", "secret_name", b"secret_name", "share_name", b"share_name"]) -> None: ...

global___AzureFileVolumeSource = AzureFileVolumeSource

@typing_extensions.final
class Binding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def target(self) -> global___ObjectReference: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        target: global___ObjectReference | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "target", b"target"]) -> None: ...

global___Binding = Binding

@typing_extensions.final
class CSIPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class VolumeAttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTROLLER_EXPAND_SECRET_REF_FIELD_NUMBER: builtins.int
    CONTROLLER_PUBLISH_SECRET_REF_FIELD_NUMBER: builtins.int
    DRIVER_FIELD_NUMBER: builtins.int
    FS_TYPE_FIELD_NUMBER: builtins.int
    NODE_EXPAND_SECRET_REF_FIELD_NUMBER: builtins.int
    NODE_PUBLISH_SECRET_REF_FIELD_NUMBER: builtins.int
    NODE_STAGE_SECRET_REF_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    VOLUME_ATTRIBUTES_FIELD_NUMBER: builtins.int
    VOLUME_HANDLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def controller_expand_secret_ref(self) -> global___SecretReference: ...
    @property
    def controller_publish_secret_ref(self) -> global___SecretReference: ...
    driver: builtins.str
    fs_type: builtins.str
    @property
    def node_expand_secret_ref(self) -> global___SecretReference: ...
    @property
    def node_publish_secret_ref(self) -> global___SecretReference: ...
    @property
    def node_stage_secret_ref(self) -> global___SecretReference: ...
    read_only: builtins.bool
    @property
    def volume_attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    volume_handle: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        controller_expand_secret_ref: global___SecretReference | None = ...,
        controller_publish_secret_ref: global___SecretReference | None = ...,
        driver: builtins.str = ...,
        fs_type: builtins.str = ...,
        node_expand_secret_ref: global___SecretReference | None = ...,
        node_publish_secret_ref: global___SecretReference | None = ...,
        node_stage_secret_ref: global___SecretReference | None = ...,
        read_only: builtins.bool = ...,
        volume_attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        volume_handle: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["controller_expand_secret_ref", b"controller_expand_secret_ref", "controller_publish_secret_ref", b"controller_publish_secret_ref", "node_expand_secret_ref", b"node_expand_secret_ref", "node_publish_secret_ref", b"node_publish_secret_ref", "node_stage_secret_ref", b"node_stage_secret_ref", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["controller_expand_secret_ref", b"controller_expand_secret_ref", "controller_publish_secret_ref", b"controller_publish_secret_ref", "driver", b"driver", "fs_type", b"fs_type", "node_expand_secret_ref", b"node_expand_secret_ref", "node_publish_secret_ref", b"node_publish_secret_ref", "node_stage_secret_ref", b"node_stage_secret_ref", "read_only", b"read_only", "resource_info", b"resource_info", "volume_attributes", b"volume_attributes", "volume_handle", b"volume_handle"]) -> None: ...

global___CSIPersistentVolumeSource = CSIPersistentVolumeSource

@typing_extensions.final
class CSIVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class VolumeAttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_FIELD_NUMBER: builtins.int
    FS_TYPE_FIELD_NUMBER: builtins.int
    NODE_PUBLISH_SECRET_REF_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    VOLUME_ATTRIBUTES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    driver: builtins.str
    fs_type: builtins.str
    @property
    def node_publish_secret_ref(self) -> global___LocalObjectReference: ...
    read_only: builtins.bool
    @property
    def volume_attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        driver: builtins.str = ...,
        fs_type: builtins.str = ...,
        node_publish_secret_ref: global___LocalObjectReference | None = ...,
        read_only: builtins.bool = ...,
        volume_attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["node_publish_secret_ref", b"node_publish_secret_ref", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver", b"driver", "fs_type", b"fs_type", "node_publish_secret_ref", b"node_publish_secret_ref", "read_only", b"read_only", "resource_info", b"resource_info", "volume_attributes", b"volume_attributes"]) -> None: ...

global___CSIVolumeSource = CSIVolumeSource

@typing_extensions.final
class Capabilities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADD_FIELD_NUMBER: builtins.int
    DROP_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def add(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def drop(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        add: collections.abc.Iterable[builtins.str] | None = ...,
        drop: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["add", b"add", "drop", b"drop", "resource_info", b"resource_info"]) -> None: ...

global___Capabilities = Capabilities

@typing_extensions.final
class CephFSPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITORS_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_FILE_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def monitors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    path: builtins.str
    read_only: builtins.bool
    secret_file: builtins.str
    @property
    def secret_ref(self) -> global___SecretReference: ...
    user: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        monitors: collections.abc.Iterable[builtins.str] | None = ...,
        path: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_file: builtins.str = ...,
        secret_ref: global___SecretReference | None = ...,
        user: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitors", b"monitors", "path", b"path", "read_only", b"read_only", "resource_info", b"resource_info", "secret_file", b"secret_file", "secret_ref", b"secret_ref", "user", b"user"]) -> None: ...

global___CephFSPersistentVolumeSource = CephFSPersistentVolumeSource

@typing_extensions.final
class CephFSVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITORS_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_FILE_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def monitors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    path: builtins.str
    read_only: builtins.bool
    secret_file: builtins.str
    @property
    def secret_ref(self) -> global___LocalObjectReference: ...
    user: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        monitors: collections.abc.Iterable[builtins.str] | None = ...,
        path: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_file: builtins.str = ...,
        secret_ref: global___LocalObjectReference | None = ...,
        user: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitors", b"monitors", "path", b"path", "read_only", b"read_only", "resource_info", b"resource_info", "secret_file", b"secret_file", "secret_ref", b"secret_ref", "user", b"user"]) -> None: ...

global___CephFSVolumeSource = CephFSVolumeSource

@typing_extensions.final
class CinderPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    VOLUME_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___SecretReference: ...
    volume_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___SecretReference | None = ...,
        volume_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "volume_id", b"volume_id"]) -> None: ...

global___CinderPersistentVolumeSource = CinderPersistentVolumeSource

@typing_extensions.final
class CinderVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    VOLUME_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___LocalObjectReference: ...
    volume_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___LocalObjectReference | None = ...,
        volume_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "volume_id", b"volume_id"]) -> None: ...

global___CinderVolumeSource = CinderVolumeSource

@typing_extensions.final
class ClaimSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_CLAIM_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_CLAIM_TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    resource_claim_name: builtins.str
    resource_claim_template_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_claim_name: builtins.str = ...,
        resource_claim_template_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_claim_name", b"resource_claim_name", "resource_claim_template_name", b"resource_claim_template_name", "resource_info", b"resource_info"]) -> None: ...

global___ClaimSource = ClaimSource

@typing_extensions.final
class ClientIPConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    timeout_seconds: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        timeout_seconds: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___ClientIPConfig = ClientIPConfig

@typing_extensions.final
class ComponentCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    error: builtins.str
    message: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        error: builtins.str = ...,
        message: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "message", b"message", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___ComponentCondition = ComponentCondition

@typing_extensions.final
class ComponentStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComponentCondition]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        conditions: collections.abc.Iterable[global___ComponentCondition] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "conditions", b"conditions", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ComponentStatus = ComponentStatus

@typing_extensions.final
class ComponentStatusList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComponentStatus]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ComponentStatus] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ComponentStatusList = ComponentStatusList

@typing_extensions.final
class ConfigMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class BinaryDataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class DataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    API_VERSION_FIELD_NUMBER: builtins.int
    BINARY_DATA_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    IMMUTABLE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def binary_data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    immutable: builtins.bool
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        binary_data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        immutable: builtins.bool = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "binary_data", b"binary_data", "data", b"data", "immutable", b"immutable", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ConfigMap = ConfigMap

@typing_extensions.final
class ConfigMapEnvSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OPTIONAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    optional: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        optional: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "optional", b"optional", "resource_info", b"resource_info"]) -> None: ...

global___ConfigMapEnvSource = ConfigMapEnvSource

@typing_extensions.final
class ConfigMapKeySelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    key: builtins.str
    name: builtins.str
    optional: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        name: builtins.str = ...,
        optional: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "name", b"name", "optional", b"optional", "resource_info", b"resource_info"]) -> None: ...

global___ConfigMapKeySelector = ConfigMapKeySelector

@typing_extensions.final
class ConfigMapList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigMap]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ConfigMap] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ConfigMapList = ConfigMapList

@typing_extensions.final
class ConfigMapNodeConfigSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KUBELET_CONFIG_KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    kubelet_config_key: builtins.str
    name: builtins.str
    namespace: builtins.str
    resource_version: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        kubelet_config_key: builtins.str = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_version: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kubelet_config_key", b"kubelet_config_key", "name", b"name", "namespace", b"namespace", "resource_info", b"resource_info", "resource_version", b"resource_version", "uid", b"uid"]) -> None: ...

global___ConfigMapNodeConfigSource = ConfigMapNodeConfigSource

@typing_extensions.final
class ConfigMapProjection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeyToPath]: ...
    name: builtins.str
    optional: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___KeyToPath] | None = ...,
        name: builtins.str = ...,
        optional: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "name", b"name", "optional", b"optional", "resource_info", b"resource_info"]) -> None: ...

global___ConfigMapProjection = ConfigMapProjection

@typing_extensions.final
class ConfigMapVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_MODE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_mode: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeyToPath]: ...
    name: builtins.str
    optional: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_mode: builtins.int = ...,
        items: collections.abc.Iterable[global___KeyToPath] | None = ...,
        name: builtins.str = ...,
        optional: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_mode", b"default_mode", "items", b"items", "name", b"name", "optional", b"optional", "resource_info", b"resource_info"]) -> None: ...

global___ConfigMapVolumeSource = ConfigMapVolumeSource

@typing_extensions.final
class Container(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    ENV_FROM_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_PULL_POLICY_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    LIVENESS_PROBE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    READINESS_PROBE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    SECURITY_CONTEXT_FIELD_NUMBER: builtins.int
    STARTUP_PROBE_FIELD_NUMBER: builtins.int
    STDIN_FIELD_NUMBER: builtins.int
    STDIN_ONCE_FIELD_NUMBER: builtins.int
    TERMINATION_MESSAGE_PATH_FIELD_NUMBER: builtins.int
    TERMINATION_MESSAGE_POLICY_FIELD_NUMBER: builtins.int
    TTY_FIELD_NUMBER: builtins.int
    VOLUME_DEVICES_FIELD_NUMBER: builtins.int
    VOLUME_MOUNTS_FIELD_NUMBER: builtins.int
    WORKING_DIR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvVar]: ...
    @property
    def env_from(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvFromSource]: ...
    image: builtins.str
    image_pull_policy: builtins.str
    @property
    def lifecycle(self) -> global___Lifecycle: ...
    @property
    def liveness_probe(self) -> global___Probe: ...
    name: builtins.str
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerPort]: ...
    @property
    def readiness_probe(self) -> global___Probe: ...
    @property
    def resources(self) -> global___ResourceRequirements: ...
    @property
    def security_context(self) -> global___SecurityContext: ...
    @property
    def startup_probe(self) -> global___Probe: ...
    stdin: builtins.bool
    stdin_once: builtins.bool
    termination_message_path: builtins.str
    termination_message_policy: builtins.str
    tty: builtins.bool
    @property
    def volume_devices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VolumeDevice]: ...
    @property
    def volume_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VolumeMount]: ...
    working_dir: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        env: collections.abc.Iterable[global___EnvVar] | None = ...,
        env_from: collections.abc.Iterable[global___EnvFromSource] | None = ...,
        image: builtins.str = ...,
        image_pull_policy: builtins.str = ...,
        lifecycle: global___Lifecycle | None = ...,
        liveness_probe: global___Probe | None = ...,
        name: builtins.str = ...,
        ports: collections.abc.Iterable[global___ContainerPort] | None = ...,
        readiness_probe: global___Probe | None = ...,
        resources: global___ResourceRequirements | None = ...,
        security_context: global___SecurityContext | None = ...,
        startup_probe: global___Probe | None = ...,
        stdin: builtins.bool = ...,
        stdin_once: builtins.bool = ...,
        termination_message_path: builtins.str = ...,
        termination_message_policy: builtins.str = ...,
        tty: builtins.bool = ...,
        volume_devices: collections.abc.Iterable[global___VolumeDevice] | None = ...,
        volume_mounts: collections.abc.Iterable[global___VolumeMount] | None = ...,
        working_dir: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lifecycle", b"lifecycle", "liveness_probe", b"liveness_probe", "readiness_probe", b"readiness_probe", "resource_info", b"resource_info", "resources", b"resources", "security_context", b"security_context", "startup_probe", b"startup_probe"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "command", b"command", "env", b"env", "env_from", b"env_from", "image", b"image", "image_pull_policy", b"image_pull_policy", "lifecycle", b"lifecycle", "liveness_probe", b"liveness_probe", "name", b"name", "ports", b"ports", "readiness_probe", b"readiness_probe", "resource_info", b"resource_info", "resources", b"resources", "security_context", b"security_context", "startup_probe", b"startup_probe", "stdin", b"stdin", "stdin_once", b"stdin_once", "termination_message_path", b"termination_message_path", "termination_message_policy", b"termination_message_policy", "tty", b"tty", "volume_devices", b"volume_devices", "volume_mounts", b"volume_mounts", "working_dir", b"working_dir"]) -> None: ...

global___Container = Container

@typing_extensions.final
class ContainerImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMES_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    size_bytes: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        names: collections.abc.Iterable[builtins.str] | None = ...,
        size_bytes: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["names", b"names", "resource_info", b"resource_info", "size_bytes", b"size_bytes"]) -> None: ...

global___ContainerImage = ContainerImage

@typing_extensions.final
class ContainerPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_PORT_FIELD_NUMBER: builtins.int
    HOST_IP_FIELD_NUMBER: builtins.int
    HOST_PORT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    container_port: builtins.int
    host_ip: builtins.str
    host_port: builtins.int
    name: builtins.str
    protocol: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        container_port: builtins.int = ...,
        host_ip: builtins.str = ...,
        host_port: builtins.int = ...,
        name: builtins.str = ...,
        protocol: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_port", b"container_port", "host_ip", b"host_ip", "host_port", b"host_port", "name", b"name", "protocol", b"protocol", "resource_info", b"resource_info"]) -> None: ...

global___ContainerPort = ContainerPort

@typing_extensions.final
class ContainerState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNING_FIELD_NUMBER: builtins.int
    TERMINATED_FIELD_NUMBER: builtins.int
    WAITING_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def running(self) -> global___ContainerStateRunning: ...
    @property
    def terminated(self) -> global___ContainerStateTerminated: ...
    @property
    def waiting(self) -> global___ContainerStateWaiting: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        running: global___ContainerStateRunning | None = ...,
        terminated: global___ContainerStateTerminated | None = ...,
        waiting: global___ContainerStateWaiting | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "running", b"running", "terminated", b"terminated", "waiting", b"waiting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "running", b"running", "terminated", b"terminated", "waiting", b"waiting"]) -> None: ...

global___ContainerState = ContainerState

@typing_extensions.final
class ContainerStateRunning(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STARTED_AT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def started_at(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        started_at: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "started_at", b"started_at"]) -> None: ...

global___ContainerStateRunning = ContainerStateRunning

@typing_extensions.final
class ContainerStateTerminated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    EXIT_CODE_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    SIGNAL_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    exit_code: builtins.int
    @property
    def finished_at(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    signal: builtins.int
    @property
    def started_at(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        exit_code: builtins.int = ...,
        finished_at: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        signal: builtins.int = ...,
        started_at: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["finished_at", b"finished_at", "resource_info", b"resource_info", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_id", b"container_id", "exit_code", b"exit_code", "finished_at", b"finished_at", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "signal", b"signal", "started_at", b"started_at"]) -> None: ...

global___ContainerStateTerminated = ContainerStateTerminated

@typing_extensions.final
class ContainerStateWaiting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    message: builtins.str
    reason: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "reason", b"reason", "resource_info", b"resource_info"]) -> None: ...

global___ContainerStateWaiting = ContainerStateWaiting

@typing_extensions.final
class ContainerStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    LAST_STATE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    READY_FIELD_NUMBER: builtins.int
    RESTART_COUNT_FIELD_NUMBER: builtins.int
    STARTED_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    image: builtins.str
    image_id: builtins.str
    @property
    def last_state(self) -> global___ContainerState: ...
    name: builtins.str
    ready: builtins.bool
    restart_count: builtins.int
    started: builtins.bool
    @property
    def state(self) -> global___ContainerState: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        image: builtins.str = ...,
        image_id: builtins.str = ...,
        last_state: global___ContainerState | None = ...,
        name: builtins.str = ...,
        ready: builtins.bool = ...,
        restart_count: builtins.int = ...,
        started: builtins.bool = ...,
        state: global___ContainerState | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_state", b"last_state", "resource_info", b"resource_info", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_id", b"container_id", "image", b"image", "image_id", b"image_id", "last_state", b"last_state", "name", b"name", "ready", b"ready", "resource_info", b"resource_info", "restart_count", b"restart_count", "started", b"started", "state", b"state"]) -> None: ...

global___ContainerStatus = ContainerStatus

@typing_extensions.final
class DaemonEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    port: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___DaemonEndpoint = DaemonEndpoint

@typing_extensions.final
class DownwardAPIProjection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DownwardAPIVolumeFile]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___DownwardAPIVolumeFile] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "resource_info", b"resource_info"]) -> None: ...

global___DownwardAPIProjection = DownwardAPIProjection

@typing_extensions.final
class DownwardAPIVolumeFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_REF_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_REF_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def field_ref(self) -> global___ObjectFieldSelector: ...
    mode: builtins.int
    path: builtins.str
    @property
    def resource_field_ref(self) -> global___ResourceFieldSelector: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        field_ref: global___ObjectFieldSelector | None = ...,
        mode: builtins.int = ...,
        path: builtins.str = ...,
        resource_field_ref: global___ResourceFieldSelector | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field_ref", b"field_ref", "resource_field_ref", b"resource_field_ref", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_ref", b"field_ref", "mode", b"mode", "path", b"path", "resource_field_ref", b"resource_field_ref", "resource_info", b"resource_info"]) -> None: ...

global___DownwardAPIVolumeFile = DownwardAPIVolumeFile

@typing_extensions.final
class DownwardAPIVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_MODE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_mode: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DownwardAPIVolumeFile]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_mode: builtins.int = ...,
        items: collections.abc.Iterable[global___DownwardAPIVolumeFile] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_mode", b"default_mode", "items", b"items", "resource_info", b"resource_info"]) -> None: ...

global___DownwardAPIVolumeSource = DownwardAPIVolumeSource

@typing_extensions.final
class EmptyDirVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIUM_FIELD_NUMBER: builtins.int
    SIZE_LIMIT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    medium: builtins.str
    @property
    def size_limit(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2.Quantity: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        medium: builtins.str = ...,
        size_limit: kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2.Quantity | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "size_limit", b"size_limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["medium", b"medium", "resource_info", b"resource_info", "size_limit", b"size_limit"]) -> None: ...

global___EmptyDirVolumeSource = EmptyDirVolumeSource

@typing_extensions.final
class EndpointAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTNAME_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    TARGET_REF_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    hostname: builtins.str
    ip: builtins.str
    node_name: builtins.str
    @property
    def target_ref(self) -> global___ObjectReference: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hostname: builtins.str = ...,
        ip: builtins.str = ...,
        node_name: builtins.str = ...,
        target_ref: global___ObjectReference | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_ref", b"target_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostname", b"hostname", "ip", b"ip", "node_name", b"node_name", "resource_info", b"resource_info", "target_ref", b"target_ref"]) -> None: ...

global___EndpointAddress = EndpointAddress

@typing_extensions.final
class EndpointPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PROTOCOL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_protocol: builtins.str
    name: builtins.str
    port: builtins.int
    protocol: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_protocol: builtins.str = ...,
        name: builtins.str = ...,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_protocol", b"app_protocol", "name", b"name", "port", b"port", "protocol", b"protocol", "resource_info", b"resource_info"]) -> None: ...

global___EndpointPort = EndpointPort

@typing_extensions.final
class EndpointSubset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESSES_FIELD_NUMBER: builtins.int
    NOT_READY_ADDRESSES_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointAddress]: ...
    @property
    def not_ready_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointAddress]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointPort]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        addresses: collections.abc.Iterable[global___EndpointAddress] | None = ...,
        not_ready_addresses: collections.abc.Iterable[global___EndpointAddress] | None = ...,
        ports: collections.abc.Iterable[global___EndpointPort] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addresses", b"addresses", "not_ready_addresses", b"not_ready_addresses", "ports", b"ports", "resource_info", b"resource_info"]) -> None: ...

global___EndpointSubset = EndpointSubset

@typing_extensions.final
class Endpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SUBSETS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def subsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointSubset]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        subsets: collections.abc.Iterable[global___EndpointSubset] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "subsets", b"subsets"]) -> None: ...

global___Endpoints = Endpoints

@typing_extensions.final
class EndpointsList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Endpoints]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Endpoints] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___EndpointsList = EndpointsList

@typing_extensions.final
class EnvFromSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_MAP_REF_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def config_map_ref(self) -> global___ConfigMapEnvSource: ...
    prefix: builtins.str
    @property
    def secret_ref(self) -> global___SecretEnvSource: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        config_map_ref: global___ConfigMapEnvSource | None = ...,
        prefix: builtins.str = ...,
        secret_ref: global___SecretEnvSource | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_map_ref", b"config_map_ref", "resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_map_ref", b"config_map_ref", "prefix", b"prefix", "resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> None: ...

global___EnvFromSource = EnvFromSource

@typing_extensions.final
class EnvVar(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_FROM_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    @property
    def value_from(self) -> global___EnvVarSource: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
        value_from: global___EnvVarSource | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value_from", b"value_from"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value", "value_from", b"value_from"]) -> None: ...

global___EnvVar = EnvVar

@typing_extensions.final
class EnvVarSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_MAP_KEY_REF_FIELD_NUMBER: builtins.int
    FIELD_REF_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_REF_FIELD_NUMBER: builtins.int
    SECRET_KEY_REF_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def config_map_key_ref(self) -> global___ConfigMapKeySelector: ...
    @property
    def field_ref(self) -> global___ObjectFieldSelector: ...
    @property
    def resource_field_ref(self) -> global___ResourceFieldSelector: ...
    @property
    def secret_key_ref(self) -> global___SecretKeySelector: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        config_map_key_ref: global___ConfigMapKeySelector | None = ...,
        field_ref: global___ObjectFieldSelector | None = ...,
        resource_field_ref: global___ResourceFieldSelector | None = ...,
        secret_key_ref: global___SecretKeySelector | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_map_key_ref", b"config_map_key_ref", "field_ref", b"field_ref", "resource_field_ref", b"resource_field_ref", "resource_info", b"resource_info", "secret_key_ref", b"secret_key_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_map_key_ref", b"config_map_key_ref", "field_ref", b"field_ref", "resource_field_ref", b"resource_field_ref", "resource_info", b"resource_info", "secret_key_ref", b"secret_key_ref"]) -> None: ...

global___EnvVarSource = EnvVarSource

@typing_extensions.final
class EphemeralContainer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    ENV_FROM_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_PULL_POLICY_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    LIVENESS_PROBE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    READINESS_PROBE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    SECURITY_CONTEXT_FIELD_NUMBER: builtins.int
    STARTUP_PROBE_FIELD_NUMBER: builtins.int
    STDIN_FIELD_NUMBER: builtins.int
    STDIN_ONCE_FIELD_NUMBER: builtins.int
    TARGET_CONTAINER_NAME_FIELD_NUMBER: builtins.int
    TERMINATION_MESSAGE_PATH_FIELD_NUMBER: builtins.int
    TERMINATION_MESSAGE_POLICY_FIELD_NUMBER: builtins.int
    TTY_FIELD_NUMBER: builtins.int
    VOLUME_DEVICES_FIELD_NUMBER: builtins.int
    VOLUME_MOUNTS_FIELD_NUMBER: builtins.int
    WORKING_DIR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvVar]: ...
    @property
    def env_from(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvFromSource]: ...
    image: builtins.str
    image_pull_policy: builtins.str
    @property
    def lifecycle(self) -> global___Lifecycle: ...
    @property
    def liveness_probe(self) -> global___Probe: ...
    name: builtins.str
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerPort]: ...
    @property
    def readiness_probe(self) -> global___Probe: ...
    @property
    def resources(self) -> global___ResourceRequirements: ...
    @property
    def security_context(self) -> global___SecurityContext: ...
    @property
    def startup_probe(self) -> global___Probe: ...
    stdin: builtins.bool
    stdin_once: builtins.bool
    target_container_name: builtins.str
    termination_message_path: builtins.str
    termination_message_policy: builtins.str
    tty: builtins.bool
    @property
    def volume_devices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VolumeDevice]: ...
    @property
    def volume_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VolumeMount]: ...
    working_dir: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        env: collections.abc.Iterable[global___EnvVar] | None = ...,
        env_from: collections.abc.Iterable[global___EnvFromSource] | None = ...,
        image: builtins.str = ...,
        image_pull_policy: builtins.str = ...,
        lifecycle: global___Lifecycle | None = ...,
        liveness_probe: global___Probe | None = ...,
        name: builtins.str = ...,
        ports: collections.abc.Iterable[global___ContainerPort] | None = ...,
        readiness_probe: global___Probe | None = ...,
        resources: global___ResourceRequirements | None = ...,
        security_context: global___SecurityContext | None = ...,
        startup_probe: global___Probe | None = ...,
        stdin: builtins.bool = ...,
        stdin_once: builtins.bool = ...,
        target_container_name: builtins.str = ...,
        termination_message_path: builtins.str = ...,
        termination_message_policy: builtins.str = ...,
        tty: builtins.bool = ...,
        volume_devices: collections.abc.Iterable[global___VolumeDevice] | None = ...,
        volume_mounts: collections.abc.Iterable[global___VolumeMount] | None = ...,
        working_dir: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lifecycle", b"lifecycle", "liveness_probe", b"liveness_probe", "readiness_probe", b"readiness_probe", "resource_info", b"resource_info", "resources", b"resources", "security_context", b"security_context", "startup_probe", b"startup_probe"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "command", b"command", "env", b"env", "env_from", b"env_from", "image", b"image", "image_pull_policy", b"image_pull_policy", "lifecycle", b"lifecycle", "liveness_probe", b"liveness_probe", "name", b"name", "ports", b"ports", "readiness_probe", b"readiness_probe", "resource_info", b"resource_info", "resources", b"resources", "security_context", b"security_context", "startup_probe", b"startup_probe", "stdin", b"stdin", "stdin_once", b"stdin_once", "target_container_name", b"target_container_name", "termination_message_path", b"termination_message_path", "termination_message_policy", b"termination_message_policy", "tty", b"tty", "volume_devices", b"volume_devices", "volume_mounts", b"volume_mounts", "working_dir", b"working_dir"]) -> None: ...

global___EphemeralContainer = EphemeralContainer

@typing_extensions.final
class EphemeralVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOLUME_CLAIM_TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def volume_claim_template(self) -> global___PersistentVolumeClaimTemplate: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        volume_claim_template: global___PersistentVolumeClaimTemplate | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_claim_template", b"volume_claim_template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_claim_template", b"volume_claim_template"]) -> None: ...

global___EphemeralVolumeSource = EphemeralVolumeSource

@typing_extensions.final
class Event(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    API_VERSION_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    EVENT_TIME_FIELD_NUMBER: builtins.int
    FIRST_TIMESTAMP_FIELD_NUMBER: builtins.int
    INVOLVED_OBJECT_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LAST_TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    RELATED_FIELD_NUMBER: builtins.int
    REPORTING_COMPONENT_FIELD_NUMBER: builtins.int
    REPORTING_INSTANCE_FIELD_NUMBER: builtins.int
    SERIES_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    action: builtins.str
    api_version: builtins.str
    count: builtins.int
    @property
    def event_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime: ...
    @property
    def first_timestamp(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def involved_object(self) -> global___ObjectReference: ...
    kind: builtins.str
    @property
    def last_timestamp(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    reason: builtins.str
    @property
    def related(self) -> global___ObjectReference: ...
    reporting_component: builtins.str
    reporting_instance: builtins.str
    @property
    def series(self) -> global___EventSeries: ...
    @property
    def source(self) -> global___EventSource: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        api_version: builtins.str = ...,
        count: builtins.int = ...,
        event_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime | None = ...,
        first_timestamp: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        involved_object: global___ObjectReference | None = ...,
        kind: builtins.str = ...,
        last_timestamp: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        reason: builtins.str = ...,
        related: global___ObjectReference | None = ...,
        reporting_component: builtins.str = ...,
        reporting_instance: builtins.str = ...,
        series: global___EventSeries | None = ...,
        source: global___EventSource | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event_time", b"event_time", "first_timestamp", b"first_timestamp", "involved_object", b"involved_object", "last_timestamp", b"last_timestamp", "metadata", b"metadata", "related", b"related", "resource_info", b"resource_info", "series", b"series", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "api_version", b"api_version", "count", b"count", "event_time", b"event_time", "first_timestamp", b"first_timestamp", "involved_object", b"involved_object", "kind", b"kind", "last_timestamp", b"last_timestamp", "message", b"message", "metadata", b"metadata", "reason", b"reason", "related", b"related", "reporting_component", b"reporting_component", "reporting_instance", b"reporting_instance", "resource_info", b"resource_info", "series", b"series", "source", b"source", "type", b"type"]) -> None: ...

global___Event = Event

@typing_extensions.final
class EventList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Event] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___EventList = EventList

@typing_extensions.final
class EventSeries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    LAST_OBSERVED_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    count: builtins.int
    @property
    def last_observed_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        last_observed_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_observed_time", b"last_observed_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "last_observed_time", b"last_observed_time", "resource_info", b"resource_info"]) -> None: ...

global___EventSeries = EventSeries

@typing_extensions.final
class EventSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    component: builtins.str
    host: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        component: builtins.str = ...,
        host: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component", b"component", "host", b"host", "resource_info", b"resource_info"]) -> None: ...

global___EventSource = EventSource

@typing_extensions.final
class ExecAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "resource_info", b"resource_info"]) -> None: ...

global___ExecAction = ExecAction

@typing_extensions.final
class FCVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    LUN_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    TARGET_W_W_NS_FIELD_NUMBER: builtins.int
    WWIDS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    lun: builtins.int
    read_only: builtins.bool
    @property
    def target_w_w_ns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def wwids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        lun: builtins.int = ...,
        read_only: builtins.bool = ...,
        target_w_w_ns: collections.abc.Iterable[builtins.str] | None = ...,
        wwids: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "lun", b"lun", "read_only", b"read_only", "resource_info", b"resource_info", "target_w_w_ns", b"target_w_w_ns", "wwids", b"wwids"]) -> None: ...

global___FCVolumeSource = FCVolumeSource

@typing_extensions.final
class FlexPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class OptionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_FIELD_NUMBER: builtins.int
    FS_TYPE_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    driver: builtins.str
    fs_type: builtins.str
    @property
    def options(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___SecretReference: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        driver: builtins.str = ...,
        fs_type: builtins.str = ...,
        options: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___SecretReference | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver", b"driver", "fs_type", b"fs_type", "options", b"options", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> None: ...

global___FlexPersistentVolumeSource = FlexPersistentVolumeSource

@typing_extensions.final
class FlexVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class OptionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_FIELD_NUMBER: builtins.int
    FS_TYPE_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    driver: builtins.str
    fs_type: builtins.str
    @property
    def options(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___LocalObjectReference: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        driver: builtins.str = ...,
        fs_type: builtins.str = ...,
        options: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___LocalObjectReference | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver", b"driver", "fs_type", b"fs_type", "options", b"options", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> None: ...

global___FlexVolumeSource = FlexVolumeSource

@typing_extensions.final
class FlockerVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_NAME_FIELD_NUMBER: builtins.int
    DATASET_U_U_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dataset_name: builtins.str
    dataset_u_u_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dataset_name: builtins.str = ...,
        dataset_u_u_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset_name", b"dataset_name", "dataset_u_u_id", b"dataset_u_u_id", "resource_info", b"resource_info"]) -> None: ...

global___FlockerVolumeSource = FlockerVolumeSource

@typing_extensions.final
class GCEPersistentDiskVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    PARTITION_FIELD_NUMBER: builtins.int
    PD_NAME_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    partition: builtins.int
    pd_name: builtins.str
    read_only: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        partition: builtins.int = ...,
        pd_name: builtins.str = ...,
        read_only: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "partition", b"partition", "pd_name", b"pd_name", "read_only", b"read_only", "resource_info", b"resource_info"]) -> None: ...

global___GCEPersistentDiskVolumeSource = GCEPersistentDiskVolumeSource

@typing_extensions.final
class GRPCAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    port: builtins.int
    service: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        service: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "resource_info", b"resource_info", "service", b"service"]) -> None: ...

global___GRPCAction = GRPCAction

@typing_extensions.final
class GitRepoVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIRECTORY_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    directory: builtins.str
    repository: builtins.str
    revision: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        directory: builtins.str = ...,
        repository: builtins.str = ...,
        revision: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["directory", b"directory", "repository", b"repository", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___GitRepoVolumeSource = GitRepoVolumeSource

@typing_extensions.final
class GlusterfsPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINTS_FIELD_NUMBER: builtins.int
    ENDPOINTS_NAMESPACE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    endpoints: builtins.str
    endpoints_namespace: builtins.str
    path: builtins.str
    read_only: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        endpoints: builtins.str = ...,
        endpoints_namespace: builtins.str = ...,
        path: builtins.str = ...,
        read_only: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoints", b"endpoints", "endpoints_namespace", b"endpoints_namespace", "path", b"path", "read_only", b"read_only", "resource_info", b"resource_info"]) -> None: ...

global___GlusterfsPersistentVolumeSource = GlusterfsPersistentVolumeSource

@typing_extensions.final
class GlusterfsVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINTS_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    endpoints: builtins.str
    path: builtins.str
    read_only: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        endpoints: builtins.str = ...,
        path: builtins.str = ...,
        read_only: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoints", b"endpoints", "path", b"path", "read_only", b"read_only", "resource_info", b"resource_info"]) -> None: ...

global___GlusterfsVolumeSource = GlusterfsVolumeSource

@typing_extensions.final
class HTTPGetAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    HTTP_HEADERS_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    host: builtins.str
    @property
    def http_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HTTPHeader]: ...
    path: builtins.str
    @property
    def port(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    scheme: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        http_headers: collections.abc.Iterable[global___HTTPHeader] | None = ...,
        path: builtins.str = ...,
        port: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        scheme: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["port", b"port", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "http_headers", b"http_headers", "path", b"path", "port", b"port", "resource_info", b"resource_info", "scheme", b"scheme"]) -> None: ...

global___HTTPGetAction = HTTPGetAction

@typing_extensions.final
class HTTPHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___HTTPHeader = HTTPHeader

@typing_extensions.final
class HostAlias(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTNAMES_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ip: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        ip: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostnames", b"hostnames", "ip", b"ip", "resource_info", b"resource_info"]) -> None: ...

global___HostAlias = HostAlias

@typing_extensions.final
class HostPathVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    path: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___HostPathVolumeSource = HostPathVolumeSource

@typing_extensions.final
class ISCSIPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAP_AUTH_DISCOVERY_FIELD_NUMBER: builtins.int
    CHAP_AUTH_SESSION_FIELD_NUMBER: builtins.int
    FS_TYPE_FIELD_NUMBER: builtins.int
    INITIATOR_NAME_FIELD_NUMBER: builtins.int
    IQN_FIELD_NUMBER: builtins.int
    ISCSI_INTERFACE_FIELD_NUMBER: builtins.int
    LUN_FIELD_NUMBER: builtins.int
    PORTALS_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    TARGET_PORTAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    chap_auth_discovery: builtins.bool
    chap_auth_session: builtins.bool
    fs_type: builtins.str
    initiator_name: builtins.str
    iqn: builtins.str
    iscsi_interface: builtins.str
    lun: builtins.int
    @property
    def portals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___SecretReference: ...
    target_portal: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        chap_auth_discovery: builtins.bool = ...,
        chap_auth_session: builtins.bool = ...,
        fs_type: builtins.str = ...,
        initiator_name: builtins.str = ...,
        iqn: builtins.str = ...,
        iscsi_interface: builtins.str = ...,
        lun: builtins.int = ...,
        portals: collections.abc.Iterable[builtins.str] | None = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___SecretReference | None = ...,
        target_portal: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chap_auth_discovery", b"chap_auth_discovery", "chap_auth_session", b"chap_auth_session", "fs_type", b"fs_type", "initiator_name", b"initiator_name", "iqn", b"iqn", "iscsi_interface", b"iscsi_interface", "lun", b"lun", "portals", b"portals", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "target_portal", b"target_portal"]) -> None: ...

global___ISCSIPersistentVolumeSource = ISCSIPersistentVolumeSource

@typing_extensions.final
class ISCSIVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAP_AUTH_DISCOVERY_FIELD_NUMBER: builtins.int
    CHAP_AUTH_SESSION_FIELD_NUMBER: builtins.int
    FS_TYPE_FIELD_NUMBER: builtins.int
    INITIATOR_NAME_FIELD_NUMBER: builtins.int
    IQN_FIELD_NUMBER: builtins.int
    ISCSI_INTERFACE_FIELD_NUMBER: builtins.int
    LUN_FIELD_NUMBER: builtins.int
    PORTALS_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    TARGET_PORTAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    chap_auth_discovery: builtins.bool
    chap_auth_session: builtins.bool
    fs_type: builtins.str
    initiator_name: builtins.str
    iqn: builtins.str
    iscsi_interface: builtins.str
    lun: builtins.int
    @property
    def portals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___LocalObjectReference: ...
    target_portal: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        chap_auth_discovery: builtins.bool = ...,
        chap_auth_session: builtins.bool = ...,
        fs_type: builtins.str = ...,
        initiator_name: builtins.str = ...,
        iqn: builtins.str = ...,
        iscsi_interface: builtins.str = ...,
        lun: builtins.int = ...,
        portals: collections.abc.Iterable[builtins.str] | None = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___LocalObjectReference | None = ...,
        target_portal: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chap_auth_discovery", b"chap_auth_discovery", "chap_auth_session", b"chap_auth_session", "fs_type", b"fs_type", "initiator_name", b"initiator_name", "iqn", b"iqn", "iscsi_interface", b"iscsi_interface", "lun", b"lun", "portals", b"portals", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "target_portal", b"target_portal"]) -> None: ...

global___ISCSIVolumeSource = ISCSIVolumeSource

@typing_extensions.final
class KeyToPath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    key: builtins.str
    mode: builtins.int
    path: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        mode: builtins.int = ...,
        path: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "mode", b"mode", "path", b"path", "resource_info", b"resource_info"]) -> None: ...

global___KeyToPath = KeyToPath

@typing_extensions.final
class Lifecycle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POST_START_FIELD_NUMBER: builtins.int
    PRE_STOP_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def post_start(self) -> global___LifecycleHandler: ...
    @property
    def pre_stop(self) -> global___LifecycleHandler: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        post_start: global___LifecycleHandler | None = ...,
        pre_stop: global___LifecycleHandler | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["post_start", b"post_start", "pre_stop", b"pre_stop", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["post_start", b"post_start", "pre_stop", b"pre_stop", "resource_info", b"resource_info"]) -> None: ...

global___Lifecycle = Lifecycle

@typing_extensions.final
class LifecycleHandler(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXEC_FIELD_NUMBER: builtins.int
    HTTP_GET_FIELD_NUMBER: builtins.int
    TCP_SOCKET_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def exec(self) -> global___ExecAction: ...
    @property
    def http_get(self) -> global___HTTPGetAction: ...
    @property
    def tcp_socket(self) -> global___TCPSocketAction: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        exec: global___ExecAction | None = ...,
        http_get: global___HTTPGetAction | None = ...,
        tcp_socket: global___TCPSocketAction | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec", b"exec", "http_get", b"http_get", "resource_info", b"resource_info", "tcp_socket", b"tcp_socket"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exec", b"exec", "http_get", b"http_get", "resource_info", b"resource_info", "tcp_socket", b"tcp_socket"]) -> None: ...

global___LifecycleHandler = LifecycleHandler

@typing_extensions.final
class LimitRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___LimitRangeSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___LimitRangeSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___LimitRange = LimitRange

@typing_extensions.final
class LimitRangeItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DefaultEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class DefaultRequestEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MaxEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MaxLimitRequestRatioEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MinEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFAULT_FIELD_NUMBER: builtins.int
    DEFAULT_REQUEST_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    MAX_LIMIT_REQUEST_RATIO_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def default(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def default_request(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def max(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def max_limit_request_ratio(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def min(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_request: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        max: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        max_limit_request_ratio: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        min: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default", b"default", "default_request", b"default_request", "max", b"max", "max_limit_request_ratio", b"max_limit_request_ratio", "min", b"min", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___LimitRangeItem = LimitRangeItem

@typing_extensions.final
class LimitRangeList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LimitRange]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___LimitRange] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___LimitRangeList = LimitRangeList

@typing_extensions.final
class LimitRangeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIMITS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def limits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LimitRangeItem]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        limits: collections.abc.Iterable[global___LimitRangeItem] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["limits", b"limits", "resource_info", b"resource_info"]) -> None: ...

global___LimitRangeSpec = LimitRangeSpec

@typing_extensions.final
class LoadBalancerIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTNAME_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    hostname: builtins.str
    ip: builtins.str
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortStatus]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hostname: builtins.str = ...,
        ip: builtins.str = ...,
        ports: collections.abc.Iterable[global___PortStatus] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostname", b"hostname", "ip", b"ip", "ports", b"ports", "resource_info", b"resource_info"]) -> None: ...

global___LoadBalancerIngress = LoadBalancerIngress

@typing_extensions.final
class LoadBalancerStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INGRESS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoadBalancerIngress]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ingress: collections.abc.Iterable[global___LoadBalancerIngress] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ingress", b"ingress", "resource_info", b"resource_info"]) -> None: ...

global___LoadBalancerStatus = LoadBalancerStatus

@typing_extensions.final
class LocalObjectReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___LocalObjectReference = LocalObjectReference

@typing_extensions.final
class LocalVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    path: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        path: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "path", b"path", "resource_info", b"resource_info"]) -> None: ...

global___LocalVolumeSource = LocalVolumeSource

@typing_extensions.final
class NFSVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SERVER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    path: builtins.str
    read_only: builtins.bool
    server: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        read_only: builtins.bool = ...,
        server: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "read_only", b"read_only", "resource_info", b"resource_info", "server", b"server"]) -> None: ...

global___NFSVolumeSource = NFSVolumeSource

@typing_extensions.final
class Namespace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___NamespaceSpec: ...
    @property
    def status(self) -> global___NamespaceStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___NamespaceSpec | None = ...,
        status: global___NamespaceStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Namespace = Namespace

@typing_extensions.final
class NamespaceCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___NamespaceCondition = NamespaceCondition

@typing_extensions.final
class NamespaceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Namespace]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Namespace] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___NamespaceList = NamespaceList

@typing_extensions.final
class NamespaceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FINALIZERS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def finalizers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        finalizers: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["finalizers", b"finalizers", "resource_info", b"resource_info"]) -> None: ...

global___NamespaceSpec = NamespaceSpec

@typing_extensions.final
class NamespaceStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITIONS_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespaceCondition]: ...
    phase: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conditions: collections.abc.Iterable[global___NamespaceCondition] | None = ...,
        phase: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "phase", b"phase", "resource_info", b"resource_info"]) -> None: ...

global___NamespaceStatus = NamespaceStatus

@typing_extensions.final
class Node(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___NodeSpec: ...
    @property
    def status(self) -> global___NodeStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___NodeSpec | None = ...,
        status: global___NodeStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Node = Node

@typing_extensions.final
class NodeAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    address: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___NodeAddress = NodeAddress

@typing_extensions.final
class NodeAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERRED_DURING_SCHEDULING_IGNORED_DURING_EXECUTION_FIELD_NUMBER: builtins.int
    REQUIRED_DURING_SCHEDULING_IGNORED_DURING_EXECUTION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def preferred_during_scheduling_ignored_during_execution(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PreferredSchedulingTerm]: ...
    @property
    def required_during_scheduling_ignored_during_execution(self) -> global___NodeSelector: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        preferred_during_scheduling_ignored_during_execution: collections.abc.Iterable[global___PreferredSchedulingTerm] | None = ...,
        required_during_scheduling_ignored_during_execution: global___NodeSelector | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["required_during_scheduling_ignored_during_execution", b"required_during_scheduling_ignored_during_execution", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["preferred_during_scheduling_ignored_during_execution", b"preferred_during_scheduling_ignored_during_execution", "required_during_scheduling_ignored_during_execution", b"required_during_scheduling_ignored_during_execution", "resource_info", b"resource_info"]) -> None: ...

global___NodeAffinity = NodeAffinity

@typing_extensions.final
class NodeCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_HEARTBEAT_TIME_FIELD_NUMBER: builtins.int
    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_heartbeat_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_heartbeat_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_heartbeat_time", b"last_heartbeat_time", "last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_heartbeat_time", b"last_heartbeat_time", "last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___NodeCondition = NodeCondition

@typing_extensions.final
class NodeConfigSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_MAP_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def config_map(self) -> global___ConfigMapNodeConfigSource: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        config_map: global___ConfigMapNodeConfigSource | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_map", b"config_map", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_map", b"config_map", "resource_info", b"resource_info"]) -> None: ...

global___NodeConfigSource = NodeConfigSource

@typing_extensions.final
class NodeConfigStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_FIELD_NUMBER: builtins.int
    ASSIGNED_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    LAST_KNOWN_GOOD_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def active(self) -> global___NodeConfigSource: ...
    @property
    def assigned(self) -> global___NodeConfigSource: ...
    error: builtins.str
    @property
    def last_known_good(self) -> global___NodeConfigSource: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        active: global___NodeConfigSource | None = ...,
        assigned: global___NodeConfigSource | None = ...,
        error: builtins.str = ...,
        last_known_good: global___NodeConfigSource | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["active", b"active", "assigned", b"assigned", "last_known_good", b"last_known_good", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "assigned", b"assigned", "error", b"error", "last_known_good", b"last_known_good", "resource_info", b"resource_info"]) -> None: ...

global___NodeConfigStatus = NodeConfigStatus

@typing_extensions.final
class NodeDaemonEndpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KUBELET_ENDPOINT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def kubelet_endpoint(self) -> global___DaemonEndpoint: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        kubelet_endpoint: global___DaemonEndpoint | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kubelet_endpoint", b"kubelet_endpoint", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kubelet_endpoint", b"kubelet_endpoint", "resource_info", b"resource_info"]) -> None: ...

global___NodeDaemonEndpoints = NodeDaemonEndpoints

@typing_extensions.final
class NodeList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Node]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Node] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___NodeList = NodeList

@typing_extensions.final
class NodeSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_SELECTOR_TERMS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_selector_terms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NodeSelectorTerm]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        node_selector_terms: collections.abc.Iterable[global___NodeSelectorTerm] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["node_selector_terms", b"node_selector_terms", "resource_info", b"resource_info"]) -> None: ...

global___NodeSelector = NodeSelector

@typing_extensions.final
class NodeSelectorRequirement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    key: builtins.str
    operator: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        operator: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "operator", b"operator", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___NodeSelectorRequirement = NodeSelectorRequirement

@typing_extensions.final
class NodeSelectorTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_EXPRESSIONS_FIELD_NUMBER: builtins.int
    MATCH_FIELDS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def match_expressions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NodeSelectorRequirement]: ...
    @property
    def match_fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NodeSelectorRequirement]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        match_expressions: collections.abc.Iterable[global___NodeSelectorRequirement] | None = ...,
        match_fields: collections.abc.Iterable[global___NodeSelectorRequirement] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_expressions", b"match_expressions", "match_fields", b"match_fields", "resource_info", b"resource_info"]) -> None: ...

global___NodeSelectorTerm = NodeSelectorTerm

@typing_extensions.final
class NodeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_SOURCE_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    POD_CIDR_FIELD_NUMBER: builtins.int
    POD_CIDRS_FIELD_NUMBER: builtins.int
    PROVIDER_ID_FIELD_NUMBER: builtins.int
    TAINTS_FIELD_NUMBER: builtins.int
    UNSCHEDULABLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def config_source(self) -> global___NodeConfigSource: ...
    external_id: builtins.str
    pod_cidr: builtins.str
    @property
    def pod_cidrs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    provider_id: builtins.str
    @property
    def taints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Taint]: ...
    unschedulable: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        config_source: global___NodeConfigSource | None = ...,
        external_id: builtins.str = ...,
        pod_cidr: builtins.str = ...,
        pod_cidrs: collections.abc.Iterable[builtins.str] | None = ...,
        provider_id: builtins.str = ...,
        taints: collections.abc.Iterable[global___Taint] | None = ...,
        unschedulable: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_source", b"config_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_source", b"config_source", "external_id", b"external_id", "pod_cidr", b"pod_cidr", "pod_cidrs", b"pod_cidrs", "provider_id", b"provider_id", "resource_info", b"resource_info", "taints", b"taints", "unschedulable", b"unschedulable"]) -> None: ...

global___NodeSpec = NodeSpec

@typing_extensions.final
class NodeStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AllocatableEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class CapacityEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDRESSES_FIELD_NUMBER: builtins.int
    ALLOCATABLE_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    DAEMON_ENDPOINTS_FIELD_NUMBER: builtins.int
    IMAGES_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    VOLUMES_ATTACHED_FIELD_NUMBER: builtins.int
    VOLUMES_IN_USE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NodeAddress]: ...
    @property
    def allocatable(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def capacity(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NodeCondition]: ...
    @property
    def config(self) -> global___NodeConfigStatus: ...
    @property
    def daemon_endpoints(self) -> global___NodeDaemonEndpoints: ...
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerImage]: ...
    @property
    def node_info(self) -> global___NodeSystemInfo: ...
    phase: builtins.str
    @property
    def volumes_attached(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AttachedVolume]: ...
    @property
    def volumes_in_use(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        addresses: collections.abc.Iterable[global___NodeAddress] | None = ...,
        allocatable: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        capacity: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        conditions: collections.abc.Iterable[global___NodeCondition] | None = ...,
        config: global___NodeConfigStatus | None = ...,
        daemon_endpoints: global___NodeDaemonEndpoints | None = ...,
        images: collections.abc.Iterable[global___ContainerImage] | None = ...,
        node_info: global___NodeSystemInfo | None = ...,
        phase: builtins.str = ...,
        volumes_attached: collections.abc.Iterable[global___AttachedVolume] | None = ...,
        volumes_in_use: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "daemon_endpoints", b"daemon_endpoints", "node_info", b"node_info", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addresses", b"addresses", "allocatable", b"allocatable", "capacity", b"capacity", "conditions", b"conditions", "config", b"config", "daemon_endpoints", b"daemon_endpoints", "images", b"images", "node_info", b"node_info", "phase", b"phase", "resource_info", b"resource_info", "volumes_attached", b"volumes_attached", "volumes_in_use", b"volumes_in_use"]) -> None: ...

global___NodeStatus = NodeStatus

@typing_extensions.final
class NodeSystemInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARCHITECTURE_FIELD_NUMBER: builtins.int
    BOOT_ID_FIELD_NUMBER: builtins.int
    CONTAINER_RUNTIME_VERSION_FIELD_NUMBER: builtins.int
    KERNEL_VERSION_FIELD_NUMBER: builtins.int
    KUBE_PROXY_VERSION_FIELD_NUMBER: builtins.int
    KUBELET_VERSION_FIELD_NUMBER: builtins.int
    MACHINE_ID_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_FIELD_NUMBER: builtins.int
    OS_IMAGE_FIELD_NUMBER: builtins.int
    SYSTEM_U_U_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    architecture: builtins.str
    boot_id: builtins.str
    container_runtime_version: builtins.str
    kernel_version: builtins.str
    kube_proxy_version: builtins.str
    kubelet_version: builtins.str
    machine_id: builtins.str
    operating_system: builtins.str
    os_image: builtins.str
    system_u_u_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        architecture: builtins.str = ...,
        boot_id: builtins.str = ...,
        container_runtime_version: builtins.str = ...,
        kernel_version: builtins.str = ...,
        kube_proxy_version: builtins.str = ...,
        kubelet_version: builtins.str = ...,
        machine_id: builtins.str = ...,
        operating_system: builtins.str = ...,
        os_image: builtins.str = ...,
        system_u_u_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["architecture", b"architecture", "boot_id", b"boot_id", "container_runtime_version", b"container_runtime_version", "kernel_version", b"kernel_version", "kube_proxy_version", b"kube_proxy_version", "kubelet_version", b"kubelet_version", "machine_id", b"machine_id", "operating_system", b"operating_system", "os_image", b"os_image", "resource_info", b"resource_info", "system_u_u_id", b"system_u_u_id"]) -> None: ...

global___NodeSystemInfo = NodeSystemInfo

@typing_extensions.final
class ObjectFieldSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    FIELD_PATH_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    field_path: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        field_path: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "field_path", b"field_path", "resource_info", b"resource_info"]) -> None: ...

global___ObjectFieldSelector = ObjectFieldSelector

@typing_extensions.final
class ObjectReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    FIELD_PATH_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    field_path: builtins.str
    kind: builtins.str
    name: builtins.str
    namespace: builtins.str
    resource_version: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        field_path: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_version: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "field_path", b"field_path", "kind", b"kind", "name", b"name", "namespace", b"namespace", "resource_info", b"resource_info", "resource_version", b"resource_version", "uid", b"uid"]) -> None: ...

global___ObjectReference = ObjectReference

@typing_extensions.final
class PersistentVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___PersistentVolumeSpec: ...
    @property
    def status(self) -> global___PersistentVolumeStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___PersistentVolumeSpec | None = ...,
        status: global___PersistentVolumeStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___PersistentVolume = PersistentVolume

@typing_extensions.final
class PersistentVolumeClaim(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___PersistentVolumeClaimSpec: ...
    @property
    def status(self) -> global___PersistentVolumeClaimStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___PersistentVolumeClaimSpec | None = ...,
        status: global___PersistentVolumeClaimStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___PersistentVolumeClaim = PersistentVolumeClaim

@typing_extensions.final
class PersistentVolumeClaimCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_PROBE_TIME_FIELD_NUMBER: builtins.int
    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_probe_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_probe_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_probe_time", b"last_probe_time", "last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_probe_time", b"last_probe_time", "last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___PersistentVolumeClaimCondition = PersistentVolumeClaimCondition

@typing_extensions.final
class PersistentVolumeClaimList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PersistentVolumeClaim]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___PersistentVolumeClaim] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___PersistentVolumeClaimList = PersistentVolumeClaimList

@typing_extensions.final
class PersistentVolumeClaimSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_MODES_FIELD_NUMBER: builtins.int
    DATA_SOURCE_FIELD_NUMBER: builtins.int
    DATA_SOURCE_REF_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_NAME_FIELD_NUMBER: builtins.int
    VOLUME_MODE_FIELD_NUMBER: builtins.int
    VOLUME_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def access_modes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def data_source(self) -> global___TypedLocalObjectReference: ...
    @property
    def data_source_ref(self) -> global___TypedObjectReference: ...
    @property
    def resources(self) -> global___ResourceRequirements: ...
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    storage_class_name: builtins.str
    volume_mode: builtins.str
    volume_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        access_modes: collections.abc.Iterable[builtins.str] | None = ...,
        data_source: global___TypedLocalObjectReference | None = ...,
        data_source_ref: global___TypedObjectReference | None = ...,
        resources: global___ResourceRequirements | None = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        storage_class_name: builtins.str = ...,
        volume_mode: builtins.str = ...,
        volume_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source", "data_source_ref", b"data_source_ref", "resource_info", b"resource_info", "resources", b"resources", "selector", b"selector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_modes", b"access_modes", "data_source", b"data_source", "data_source_ref", b"data_source_ref", "resource_info", b"resource_info", "resources", b"resources", "selector", b"selector", "storage_class_name", b"storage_class_name", "volume_mode", b"volume_mode", "volume_name", b"volume_name"]) -> None: ...

global___PersistentVolumeClaimSpec = PersistentVolumeClaimSpec

@typing_extensions.final
class PersistentVolumeClaimStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AllocatedResourcesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class CapacityEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACCESS_MODES_FIELD_NUMBER: builtins.int
    ALLOCATED_RESOURCES_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    RESIZE_STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def access_modes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allocated_resources(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def capacity(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PersistentVolumeClaimCondition]: ...
    phase: builtins.str
    resize_status: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        access_modes: collections.abc.Iterable[builtins.str] | None = ...,
        allocated_resources: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        capacity: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        conditions: collections.abc.Iterable[global___PersistentVolumeClaimCondition] | None = ...,
        phase: builtins.str = ...,
        resize_status: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_modes", b"access_modes", "allocated_resources", b"allocated_resources", "capacity", b"capacity", "conditions", b"conditions", "phase", b"phase", "resize_status", b"resize_status", "resource_info", b"resource_info"]) -> None: ...

global___PersistentVolumeClaimStatus = PersistentVolumeClaimStatus

@typing_extensions.final
class PersistentVolumeClaimTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___PersistentVolumeClaimSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___PersistentVolumeClaimSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___PersistentVolumeClaimTemplate = PersistentVolumeClaimTemplate

@typing_extensions.final
class PersistentVolumeClaimVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLAIM_NAME_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    claim_name: builtins.str
    read_only: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        claim_name: builtins.str = ...,
        read_only: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["claim_name", b"claim_name", "read_only", b"read_only", "resource_info", b"resource_info"]) -> None: ...

global___PersistentVolumeClaimVolumeSource = PersistentVolumeClaimVolumeSource

@typing_extensions.final
class PersistentVolumeList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PersistentVolume]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___PersistentVolume] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___PersistentVolumeList = PersistentVolumeList

@typing_extensions.final
class PersistentVolumeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CapacityEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACCESS_MODES_FIELD_NUMBER: builtins.int
    AWS_ELASTIC_BLOCK_STORE_FIELD_NUMBER: builtins.int
    AZURE_DISK_FIELD_NUMBER: builtins.int
    AZURE_FILE_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    CEPHFS_FIELD_NUMBER: builtins.int
    CINDER_FIELD_NUMBER: builtins.int
    CLAIM_REF_FIELD_NUMBER: builtins.int
    CSI_FIELD_NUMBER: builtins.int
    FC_FIELD_NUMBER: builtins.int
    FLEX_VOLUME_FIELD_NUMBER: builtins.int
    FLOCKER_FIELD_NUMBER: builtins.int
    GCE_PERSISTENT_DISK_FIELD_NUMBER: builtins.int
    GLUSTERFS_FIELD_NUMBER: builtins.int
    HOST_PATH_FIELD_NUMBER: builtins.int
    ISCSI_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    MOUNT_OPTIONS_FIELD_NUMBER: builtins.int
    NFS_FIELD_NUMBER: builtins.int
    NODE_AFFINITY_FIELD_NUMBER: builtins.int
    PERSISTENT_VOLUME_RECLAIM_POLICY_FIELD_NUMBER: builtins.int
    PHOTON_PERSISTENT_DISK_FIELD_NUMBER: builtins.int
    PORTWORX_VOLUME_FIELD_NUMBER: builtins.int
    QUOBYTE_FIELD_NUMBER: builtins.int
    RBD_FIELD_NUMBER: builtins.int
    SCALE_IO_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_NAME_FIELD_NUMBER: builtins.int
    STORAGEOS_FIELD_NUMBER: builtins.int
    VOLUME_MODE_FIELD_NUMBER: builtins.int
    VSPHERE_VOLUME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def access_modes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def aws_elastic_block_store(self) -> global___AWSElasticBlockStoreVolumeSource: ...
    @property
    def azure_disk(self) -> global___AzureDiskVolumeSource: ...
    @property
    def azure_file(self) -> global___AzureFilePersistentVolumeSource: ...
    @property
    def capacity(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def cephfs(self) -> global___CephFSPersistentVolumeSource: ...
    @property
    def cinder(self) -> global___CinderPersistentVolumeSource: ...
    @property
    def claim_ref(self) -> global___ObjectReference: ...
    @property
    def csi(self) -> global___CSIPersistentVolumeSource: ...
    @property
    def fc(self) -> global___FCVolumeSource: ...
    @property
    def flex_volume(self) -> global___FlexPersistentVolumeSource: ...
    @property
    def flocker(self) -> global___FlockerVolumeSource: ...
    @property
    def gce_persistent_disk(self) -> global___GCEPersistentDiskVolumeSource: ...
    @property
    def glusterfs(self) -> global___GlusterfsPersistentVolumeSource: ...
    @property
    def host_path(self) -> global___HostPathVolumeSource: ...
    @property
    def iscsi(self) -> global___ISCSIPersistentVolumeSource: ...
    @property
    def local(self) -> global___LocalVolumeSource: ...
    @property
    def mount_options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def nfs(self) -> global___NFSVolumeSource: ...
    @property
    def node_affinity(self) -> global___VolumeNodeAffinity: ...
    persistent_volume_reclaim_policy: builtins.str
    @property
    def photon_persistent_disk(self) -> global___PhotonPersistentDiskVolumeSource: ...
    @property
    def portworx_volume(self) -> global___PortworxVolumeSource: ...
    @property
    def quobyte(self) -> global___QuobyteVolumeSource: ...
    @property
    def rbd(self) -> global___RBDPersistentVolumeSource: ...
    @property
    def scale_io(self) -> global___ScaleIOPersistentVolumeSource: ...
    storage_class_name: builtins.str
    @property
    def storageos(self) -> global___StorageOSPersistentVolumeSource: ...
    volume_mode: builtins.str
    @property
    def vsphere_volume(self) -> global___VsphereVirtualDiskVolumeSource: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        access_modes: collections.abc.Iterable[builtins.str] | None = ...,
        aws_elastic_block_store: global___AWSElasticBlockStoreVolumeSource | None = ...,
        azure_disk: global___AzureDiskVolumeSource | None = ...,
        azure_file: global___AzureFilePersistentVolumeSource | None = ...,
        capacity: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        cephfs: global___CephFSPersistentVolumeSource | None = ...,
        cinder: global___CinderPersistentVolumeSource | None = ...,
        claim_ref: global___ObjectReference | None = ...,
        csi: global___CSIPersistentVolumeSource | None = ...,
        fc: global___FCVolumeSource | None = ...,
        flex_volume: global___FlexPersistentVolumeSource | None = ...,
        flocker: global___FlockerVolumeSource | None = ...,
        gce_persistent_disk: global___GCEPersistentDiskVolumeSource | None = ...,
        glusterfs: global___GlusterfsPersistentVolumeSource | None = ...,
        host_path: global___HostPathVolumeSource | None = ...,
        iscsi: global___ISCSIPersistentVolumeSource | None = ...,
        local: global___LocalVolumeSource | None = ...,
        mount_options: collections.abc.Iterable[builtins.str] | None = ...,
        nfs: global___NFSVolumeSource | None = ...,
        node_affinity: global___VolumeNodeAffinity | None = ...,
        persistent_volume_reclaim_policy: builtins.str = ...,
        photon_persistent_disk: global___PhotonPersistentDiskVolumeSource | None = ...,
        portworx_volume: global___PortworxVolumeSource | None = ...,
        quobyte: global___QuobyteVolumeSource | None = ...,
        rbd: global___RBDPersistentVolumeSource | None = ...,
        scale_io: global___ScaleIOPersistentVolumeSource | None = ...,
        storage_class_name: builtins.str = ...,
        storageos: global___StorageOSPersistentVolumeSource | None = ...,
        volume_mode: builtins.str = ...,
        vsphere_volume: global___VsphereVirtualDiskVolumeSource | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_elastic_block_store", b"aws_elastic_block_store", "azure_disk", b"azure_disk", "azure_file", b"azure_file", "cephfs", b"cephfs", "cinder", b"cinder", "claim_ref", b"claim_ref", "csi", b"csi", "fc", b"fc", "flex_volume", b"flex_volume", "flocker", b"flocker", "gce_persistent_disk", b"gce_persistent_disk", "glusterfs", b"glusterfs", "host_path", b"host_path", "iscsi", b"iscsi", "local", b"local", "nfs", b"nfs", "node_affinity", b"node_affinity", "photon_persistent_disk", b"photon_persistent_disk", "portworx_volume", b"portworx_volume", "quobyte", b"quobyte", "rbd", b"rbd", "resource_info", b"resource_info", "scale_io", b"scale_io", "storageos", b"storageos", "vsphere_volume", b"vsphere_volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_modes", b"access_modes", "aws_elastic_block_store", b"aws_elastic_block_store", "azure_disk", b"azure_disk", "azure_file", b"azure_file", "capacity", b"capacity", "cephfs", b"cephfs", "cinder", b"cinder", "claim_ref", b"claim_ref", "csi", b"csi", "fc", b"fc", "flex_volume", b"flex_volume", "flocker", b"flocker", "gce_persistent_disk", b"gce_persistent_disk", "glusterfs", b"glusterfs", "host_path", b"host_path", "iscsi", b"iscsi", "local", b"local", "mount_options", b"mount_options", "nfs", b"nfs", "node_affinity", b"node_affinity", "persistent_volume_reclaim_policy", b"persistent_volume_reclaim_policy", "photon_persistent_disk", b"photon_persistent_disk", "portworx_volume", b"portworx_volume", "quobyte", b"quobyte", "rbd", b"rbd", "resource_info", b"resource_info", "scale_io", b"scale_io", "storage_class_name", b"storage_class_name", "storageos", b"storageos", "volume_mode", b"volume_mode", "vsphere_volume", b"vsphere_volume"]) -> None: ...

global___PersistentVolumeSpec = PersistentVolumeSpec

@typing_extensions.final
class PersistentVolumeStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    message: builtins.str
    phase: builtins.str
    reason: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        phase: builtins.str = ...,
        reason: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "phase", b"phase", "reason", b"reason", "resource_info", b"resource_info"]) -> None: ...

global___PersistentVolumeStatus = PersistentVolumeStatus

@typing_extensions.final
class PhotonPersistentDiskVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    PD_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    pd_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        pd_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "pd_id", b"pd_id", "resource_info", b"resource_info"]) -> None: ...

global___PhotonPersistentDiskVolumeSource = PhotonPersistentDiskVolumeSource

@typing_extensions.final
class Pod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___PodSpec: ...
    @property
    def status(self) -> global___PodStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___PodSpec | None = ...,
        status: global___PodStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Pod = Pod

@typing_extensions.final
class PodAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERRED_DURING_SCHEDULING_IGNORED_DURING_EXECUTION_FIELD_NUMBER: builtins.int
    REQUIRED_DURING_SCHEDULING_IGNORED_DURING_EXECUTION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def preferred_during_scheduling_ignored_during_execution(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WeightedPodAffinityTerm]: ...
    @property
    def required_during_scheduling_ignored_during_execution(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodAffinityTerm]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        preferred_during_scheduling_ignored_during_execution: collections.abc.Iterable[global___WeightedPodAffinityTerm] | None = ...,
        required_during_scheduling_ignored_during_execution: collections.abc.Iterable[global___PodAffinityTerm] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["preferred_during_scheduling_ignored_during_execution", b"preferred_during_scheduling_ignored_during_execution", "required_during_scheduling_ignored_during_execution", b"required_during_scheduling_ignored_during_execution", "resource_info", b"resource_info"]) -> None: ...

global___PodAffinity = PodAffinity

@typing_extensions.final
class PodAffinityTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_SELECTOR_FIELD_NUMBER: builtins.int
    NAMESPACE_SELECTOR_FIELD_NUMBER: builtins.int
    NAMESPACES_FIELD_NUMBER: builtins.int
    TOPOLOGY_KEY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def label_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def namespace_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def namespaces(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    topology_key: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        label_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        namespace_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        namespaces: collections.abc.Iterable[builtins.str] | None = ...,
        topology_key: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label_selector", b"label_selector", "namespace_selector", b"namespace_selector", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["label_selector", b"label_selector", "namespace_selector", b"namespace_selector", "namespaces", b"namespaces", "resource_info", b"resource_info", "topology_key", b"topology_key"]) -> None: ...

global___PodAffinityTerm = PodAffinityTerm

@typing_extensions.final
class PodAntiAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERRED_DURING_SCHEDULING_IGNORED_DURING_EXECUTION_FIELD_NUMBER: builtins.int
    REQUIRED_DURING_SCHEDULING_IGNORED_DURING_EXECUTION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def preferred_during_scheduling_ignored_during_execution(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WeightedPodAffinityTerm]: ...
    @property
    def required_during_scheduling_ignored_during_execution(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodAffinityTerm]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        preferred_during_scheduling_ignored_during_execution: collections.abc.Iterable[global___WeightedPodAffinityTerm] | None = ...,
        required_during_scheduling_ignored_during_execution: collections.abc.Iterable[global___PodAffinityTerm] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["preferred_during_scheduling_ignored_during_execution", b"preferred_during_scheduling_ignored_during_execution", "required_during_scheduling_ignored_during_execution", b"required_during_scheduling_ignored_during_execution", "resource_info", b"resource_info"]) -> None: ...

global___PodAntiAffinity = PodAntiAffinity

@typing_extensions.final
class PodCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_PROBE_TIME_FIELD_NUMBER: builtins.int
    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_probe_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_probe_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_probe_time", b"last_probe_time", "last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_probe_time", b"last_probe_time", "last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___PodCondition = PodCondition

@typing_extensions.final
class PodDNSConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESERVERS_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    SEARCHES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def nameservers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodDNSConfigOption]: ...
    @property
    def searches(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        nameservers: collections.abc.Iterable[builtins.str] | None = ...,
        options: collections.abc.Iterable[global___PodDNSConfigOption] | None = ...,
        searches: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["nameservers", b"nameservers", "options", b"options", "resource_info", b"resource_info", "searches", b"searches"]) -> None: ...

global___PodDNSConfig = PodDNSConfig

@typing_extensions.final
class PodDNSConfigOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___PodDNSConfigOption = PodDNSConfigOption

@typing_extensions.final
class PodIP(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ip: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ip: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip", b"ip", "resource_info", b"resource_info"]) -> None: ...

global___PodIP = PodIP

@typing_extensions.final
class PodList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pod]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Pod] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___PodList = PodList

@typing_extensions.final
class PodOS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PodOS = PodOS

@typing_extensions.final
class PodReadinessGate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITION_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    condition_type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        condition_type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition_type", b"condition_type", "resource_info", b"resource_info"]) -> None: ...

global___PodReadinessGate = PodReadinessGate

@typing_extensions.final
class PodResourceClaim(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def source(self) -> global___ClaimSource: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        source: global___ClaimSource | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "source", b"source"]) -> None: ...

global___PodResourceClaim = PodResourceClaim

@typing_extensions.final
class PodSchedulingGate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PodSchedulingGate = PodSchedulingGate

@typing_extensions.final
class PodSecurityContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_GROUP_FIELD_NUMBER: builtins.int
    FS_GROUP_CHANGE_POLICY_FIELD_NUMBER: builtins.int
    RUN_AS_GROUP_FIELD_NUMBER: builtins.int
    RUN_AS_NON_ROOT_FIELD_NUMBER: builtins.int
    RUN_AS_USER_FIELD_NUMBER: builtins.int
    SE_LINUX_OPTIONS_FIELD_NUMBER: builtins.int
    SECCOMP_PROFILE_FIELD_NUMBER: builtins.int
    SUPPLEMENTAL_GROUPS_FIELD_NUMBER: builtins.int
    SYSCTLS_FIELD_NUMBER: builtins.int
    WINDOWS_OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_group: builtins.int
    fs_group_change_policy: builtins.str
    run_as_group: builtins.int
    run_as_non_root: builtins.bool
    run_as_user: builtins.int
    @property
    def se_linux_options(self) -> global___SELinuxOptions: ...
    @property
    def seccomp_profile(self) -> global___SeccompProfile: ...
    @property
    def supplemental_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def sysctls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Sysctl]: ...
    @property
    def windows_options(self) -> global___WindowsSecurityContextOptions: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_group: builtins.int = ...,
        fs_group_change_policy: builtins.str = ...,
        run_as_group: builtins.int = ...,
        run_as_non_root: builtins.bool = ...,
        run_as_user: builtins.int = ...,
        se_linux_options: global___SELinuxOptions | None = ...,
        seccomp_profile: global___SeccompProfile | None = ...,
        supplemental_groups: collections.abc.Iterable[builtins.int] | None = ...,
        sysctls: collections.abc.Iterable[global___Sysctl] | None = ...,
        windows_options: global___WindowsSecurityContextOptions | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "se_linux_options", b"se_linux_options", "seccomp_profile", b"seccomp_profile", "windows_options", b"windows_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_group", b"fs_group", "fs_group_change_policy", b"fs_group_change_policy", "resource_info", b"resource_info", "run_as_group", b"run_as_group", "run_as_non_root", b"run_as_non_root", "run_as_user", b"run_as_user", "se_linux_options", b"se_linux_options", "seccomp_profile", b"seccomp_profile", "supplemental_groups", b"supplemental_groups", "sysctls", b"sysctls", "windows_options", b"windows_options"]) -> None: ...

global___PodSecurityContext = PodSecurityContext

@typing_extensions.final
class PodSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class NodeSelectorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class OverheadEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACTIVE_DEADLINE_SECONDS_FIELD_NUMBER: builtins.int
    AFFINITY_FIELD_NUMBER: builtins.int
    AUTOMOUNT_SERVICE_ACCOUNT_TOKEN_FIELD_NUMBER: builtins.int
    CONTAINERS_FIELD_NUMBER: builtins.int
    DNS_CONFIG_FIELD_NUMBER: builtins.int
    DNS_POLICY_FIELD_NUMBER: builtins.int
    ENABLE_SERVICE_LINKS_FIELD_NUMBER: builtins.int
    EPHEMERAL_CONTAINERS_FIELD_NUMBER: builtins.int
    HOST_ALIASES_FIELD_NUMBER: builtins.int
    HOST_IP_C_FIELD_NUMBER: builtins.int
    HOST_NETWORK_FIELD_NUMBER: builtins.int
    HOST_P_ID_FIELD_NUMBER: builtins.int
    HOST_USERS_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    IMAGE_PULL_SECRETS_FIELD_NUMBER: builtins.int
    INIT_CONTAINERS_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    NODE_SELECTOR_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    OVERHEAD_FIELD_NUMBER: builtins.int
    PREEMPTION_POLICY_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PRIORITY_CLASS_NAME_FIELD_NUMBER: builtins.int
    READINESS_GATES_FIELD_NUMBER: builtins.int
    RESOURCE_CLAIMS_FIELD_NUMBER: builtins.int
    RESTART_POLICY_FIELD_NUMBER: builtins.int
    RUNTIME_CLASS_NAME_FIELD_NUMBER: builtins.int
    SCHEDULER_NAME_FIELD_NUMBER: builtins.int
    SCHEDULING_GATES_FIELD_NUMBER: builtins.int
    SECURITY_CONTEXT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    SET_HOSTNAME_AS_FQDN_FIELD_NUMBER: builtins.int
    SHARE_PROCESS_NAMESPACE_FIELD_NUMBER: builtins.int
    SUBDOMAIN_FIELD_NUMBER: builtins.int
    TERMINATION_GRACE_PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    TOLERATIONS_FIELD_NUMBER: builtins.int
    TOPOLOGY_SPREAD_CONSTRAINTS_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    active_deadline_seconds: builtins.int
    @property
    def affinity(self) -> global___Affinity: ...
    automount_service_account_token: builtins.bool
    @property
    def containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Container]: ...
    @property
    def dns_config(self) -> global___PodDNSConfig: ...
    dns_policy: builtins.str
    enable_service_links: builtins.bool
    @property
    def ephemeral_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EphemeralContainer]: ...
    @property
    def host_aliases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostAlias]: ...
    host_ip_c: builtins.bool
    host_network: builtins.bool
    host_p_id: builtins.bool
    host_users: builtins.bool
    hostname: builtins.str
    @property
    def image_pull_secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LocalObjectReference]: ...
    @property
    def init_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Container]: ...
    node_name: builtins.str
    @property
    def node_selector(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def os(self) -> global___PodOS: ...
    @property
    def overhead(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    preemption_policy: builtins.str
    priority: builtins.int
    priority_class_name: builtins.str
    @property
    def readiness_gates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodReadinessGate]: ...
    @property
    def resource_claims(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodResourceClaim]: ...
    restart_policy: builtins.str
    runtime_class_name: builtins.str
    scheduler_name: builtins.str
    @property
    def scheduling_gates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodSchedulingGate]: ...
    @property
    def security_context(self) -> global___PodSecurityContext: ...
    service_account: builtins.str
    service_account_name: builtins.str
    set_hostname_as_fqdn: builtins.bool
    share_process_namespace: builtins.bool
    subdomain: builtins.str
    termination_grace_period_seconds: builtins.int
    @property
    def tolerations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Toleration]: ...
    @property
    def topology_spread_constraints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopologySpreadConstraint]: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Volume]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        active_deadline_seconds: builtins.int = ...,
        affinity: global___Affinity | None = ...,
        automount_service_account_token: builtins.bool = ...,
        containers: collections.abc.Iterable[global___Container] | None = ...,
        dns_config: global___PodDNSConfig | None = ...,
        dns_policy: builtins.str = ...,
        enable_service_links: builtins.bool = ...,
        ephemeral_containers: collections.abc.Iterable[global___EphemeralContainer] | None = ...,
        host_aliases: collections.abc.Iterable[global___HostAlias] | None = ...,
        host_ip_c: builtins.bool = ...,
        host_network: builtins.bool = ...,
        host_p_id: builtins.bool = ...,
        host_users: builtins.bool = ...,
        hostname: builtins.str = ...,
        image_pull_secrets: collections.abc.Iterable[global___LocalObjectReference] | None = ...,
        init_containers: collections.abc.Iterable[global___Container] | None = ...,
        node_name: builtins.str = ...,
        node_selector: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        os: global___PodOS | None = ...,
        overhead: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        preemption_policy: builtins.str = ...,
        priority: builtins.int = ...,
        priority_class_name: builtins.str = ...,
        readiness_gates: collections.abc.Iterable[global___PodReadinessGate] | None = ...,
        resource_claims: collections.abc.Iterable[global___PodResourceClaim] | None = ...,
        restart_policy: builtins.str = ...,
        runtime_class_name: builtins.str = ...,
        scheduler_name: builtins.str = ...,
        scheduling_gates: collections.abc.Iterable[global___PodSchedulingGate] | None = ...,
        security_context: global___PodSecurityContext | None = ...,
        service_account: builtins.str = ...,
        service_account_name: builtins.str = ...,
        set_hostname_as_fqdn: builtins.bool = ...,
        share_process_namespace: builtins.bool = ...,
        subdomain: builtins.str = ...,
        termination_grace_period_seconds: builtins.int = ...,
        tolerations: collections.abc.Iterable[global___Toleration] | None = ...,
        topology_spread_constraints: collections.abc.Iterable[global___TopologySpreadConstraint] | None = ...,
        volumes: collections.abc.Iterable[global___Volume] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["affinity", b"affinity", "dns_config", b"dns_config", "os", b"os", "resource_info", b"resource_info", "security_context", b"security_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active_deadline_seconds", b"active_deadline_seconds", "affinity", b"affinity", "automount_service_account_token", b"automount_service_account_token", "containers", b"containers", "dns_config", b"dns_config", "dns_policy", b"dns_policy", "enable_service_links", b"enable_service_links", "ephemeral_containers", b"ephemeral_containers", "host_aliases", b"host_aliases", "host_ip_c", b"host_ip_c", "host_network", b"host_network", "host_p_id", b"host_p_id", "host_users", b"host_users", "hostname", b"hostname", "image_pull_secrets", b"image_pull_secrets", "init_containers", b"init_containers", "node_name", b"node_name", "node_selector", b"node_selector", "os", b"os", "overhead", b"overhead", "preemption_policy", b"preemption_policy", "priority", b"priority", "priority_class_name", b"priority_class_name", "readiness_gates", b"readiness_gates", "resource_claims", b"resource_claims", "resource_info", b"resource_info", "restart_policy", b"restart_policy", "runtime_class_name", b"runtime_class_name", "scheduler_name", b"scheduler_name", "scheduling_gates", b"scheduling_gates", "security_context", b"security_context", "service_account", b"service_account", "service_account_name", b"service_account_name", "set_hostname_as_fqdn", b"set_hostname_as_fqdn", "share_process_namespace", b"share_process_namespace", "subdomain", b"subdomain", "termination_grace_period_seconds", b"termination_grace_period_seconds", "tolerations", b"tolerations", "topology_spread_constraints", b"topology_spread_constraints", "volumes", b"volumes"]) -> None: ...

global___PodSpec = PodSpec

@typing_extensions.final
class PodStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITIONS_FIELD_NUMBER: builtins.int
    CONTAINER_STATUSES_FIELD_NUMBER: builtins.int
    EPHEMERAL_CONTAINER_STATUSES_FIELD_NUMBER: builtins.int
    HOST_IP_FIELD_NUMBER: builtins.int
    INIT_CONTAINER_STATUSES_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    NOMINATED_NODE_NAME_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    POD_IP_FIELD_NUMBER: builtins.int
    POD_IPS_FIELD_NUMBER: builtins.int
    QOS_CLASS_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodCondition]: ...
    @property
    def container_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerStatus]: ...
    @property
    def ephemeral_container_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerStatus]: ...
    host_ip: builtins.str
    @property
    def init_container_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerStatus]: ...
    message: builtins.str
    nominated_node_name: builtins.str
    phase: builtins.str
    pod_ip: builtins.str
    @property
    def pod_ips(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodIP]: ...
    qos_class: builtins.str
    reason: builtins.str
    @property
    def start_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conditions: collections.abc.Iterable[global___PodCondition] | None = ...,
        container_statuses: collections.abc.Iterable[global___ContainerStatus] | None = ...,
        ephemeral_container_statuses: collections.abc.Iterable[global___ContainerStatus] | None = ...,
        host_ip: builtins.str = ...,
        init_container_statuses: collections.abc.Iterable[global___ContainerStatus] | None = ...,
        message: builtins.str = ...,
        nominated_node_name: builtins.str = ...,
        phase: builtins.str = ...,
        pod_ip: builtins.str = ...,
        pod_ips: collections.abc.Iterable[global___PodIP] | None = ...,
        qos_class: builtins.str = ...,
        reason: builtins.str = ...,
        start_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "container_statuses", b"container_statuses", "ephemeral_container_statuses", b"ephemeral_container_statuses", "host_ip", b"host_ip", "init_container_statuses", b"init_container_statuses", "message", b"message", "nominated_node_name", b"nominated_node_name", "phase", b"phase", "pod_ip", b"pod_ip", "pod_ips", b"pod_ips", "qos_class", b"qos_class", "reason", b"reason", "resource_info", b"resource_info", "start_time", b"start_time"]) -> None: ...

global___PodStatus = PodStatus

@typing_extensions.final
class PodTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def template(self) -> global___PodTemplateSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        template: global___PodTemplateSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "template", b"template"]) -> None: ...

global___PodTemplate = PodTemplate

@typing_extensions.final
class PodTemplateList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodTemplate]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___PodTemplate] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___PodTemplateList = PodTemplateList

@typing_extensions.final
class PodTemplateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___PodSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___PodSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___PodTemplateSpec = PodTemplateSpec

@typing_extensions.final
class PortStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    error: builtins.str
    port: builtins.int
    protocol: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        error: builtins.str = ...,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "port", b"port", "protocol", b"protocol", "resource_info", b"resource_info"]) -> None: ...

global___PortStatus = PortStatus

@typing_extensions.final
class PortworxVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    VOLUME_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    read_only: builtins.bool
    volume_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        read_only: builtins.bool = ...,
        volume_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "read_only", b"read_only", "resource_info", b"resource_info", "volume_id", b"volume_id"]) -> None: ...

global___PortworxVolumeSource = PortworxVolumeSource

@typing_extensions.final
class PreferredSchedulingTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERENCE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def preference(self) -> global___NodeSelectorTerm: ...
    weight: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        preference: global___NodeSelectorTerm | None = ...,
        weight: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preference", b"preference", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["preference", b"preference", "resource_info", b"resource_info", "weight", b"weight"]) -> None: ...

global___PreferredSchedulingTerm = PreferredSchedulingTerm

@typing_extensions.final
class Probe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXEC_FIELD_NUMBER: builtins.int
    FAILURE_THRESHOLD_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    HTTP_GET_FIELD_NUMBER: builtins.int
    INITIAL_DELAY_SECONDS_FIELD_NUMBER: builtins.int
    PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    SUCCESS_THRESHOLD_FIELD_NUMBER: builtins.int
    TCP_SOCKET_FIELD_NUMBER: builtins.int
    TERMINATION_GRACE_PERIOD_SECONDS_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def exec(self) -> global___ExecAction: ...
    failure_threshold: builtins.int
    @property
    def grpc(self) -> global___GRPCAction: ...
    @property
    def http_get(self) -> global___HTTPGetAction: ...
    initial_delay_seconds: builtins.int
    period_seconds: builtins.int
    success_threshold: builtins.int
    @property
    def tcp_socket(self) -> global___TCPSocketAction: ...
    termination_grace_period_seconds: builtins.int
    timeout_seconds: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        exec: global___ExecAction | None = ...,
        failure_threshold: builtins.int = ...,
        grpc: global___GRPCAction | None = ...,
        http_get: global___HTTPGetAction | None = ...,
        initial_delay_seconds: builtins.int = ...,
        period_seconds: builtins.int = ...,
        success_threshold: builtins.int = ...,
        tcp_socket: global___TCPSocketAction | None = ...,
        termination_grace_period_seconds: builtins.int = ...,
        timeout_seconds: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec", b"exec", "grpc", b"grpc", "http_get", b"http_get", "resource_info", b"resource_info", "tcp_socket", b"tcp_socket"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exec", b"exec", "failure_threshold", b"failure_threshold", "grpc", b"grpc", "http_get", b"http_get", "initial_delay_seconds", b"initial_delay_seconds", "period_seconds", b"period_seconds", "resource_info", b"resource_info", "success_threshold", b"success_threshold", "tcp_socket", b"tcp_socket", "termination_grace_period_seconds", b"termination_grace_period_seconds", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___Probe = Probe

@typing_extensions.final
class ProjectedVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_MODE_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_mode: builtins.int
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VolumeProjection]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_mode: builtins.int = ...,
        sources: collections.abc.Iterable[global___VolumeProjection] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_mode", b"default_mode", "resource_info", b"resource_info", "sources", b"sources"]) -> None: ...

global___ProjectedVolumeSource = ProjectedVolumeSource

@typing_extensions.final
class QuobyteVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    REGISTRY_FIELD_NUMBER: builtins.int
    TENANT_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    group: builtins.str
    read_only: builtins.bool
    registry: builtins.str
    tenant: builtins.str
    user: builtins.str
    volume: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        group: builtins.str = ...,
        read_only: builtins.bool = ...,
        registry: builtins.str = ...,
        tenant: builtins.str = ...,
        user: builtins.str = ...,
        volume: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group", b"group", "read_only", b"read_only", "registry", b"registry", "resource_info", b"resource_info", "tenant", b"tenant", "user", b"user", "volume", b"volume"]) -> None: ...

global___QuobyteVolumeSource = QuobyteVolumeSource

@typing_extensions.final
class RBDPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    KEYRING_FIELD_NUMBER: builtins.int
    MONITORS_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    image: builtins.str
    keyring: builtins.str
    @property
    def monitors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    pool: builtins.str
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___SecretReference: ...
    user: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        image: builtins.str = ...,
        keyring: builtins.str = ...,
        monitors: collections.abc.Iterable[builtins.str] | None = ...,
        pool: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___SecretReference | None = ...,
        user: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "image", b"image", "keyring", b"keyring", "monitors", b"monitors", "pool", b"pool", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "user", b"user"]) -> None: ...

global___RBDPersistentVolumeSource = RBDPersistentVolumeSource

@typing_extensions.final
class RBDVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    KEYRING_FIELD_NUMBER: builtins.int
    MONITORS_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    image: builtins.str
    keyring: builtins.str
    @property
    def monitors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    pool: builtins.str
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___LocalObjectReference: ...
    user: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        image: builtins.str = ...,
        keyring: builtins.str = ...,
        monitors: collections.abc.Iterable[builtins.str] | None = ...,
        pool: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___LocalObjectReference | None = ...,
        user: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "image", b"image", "keyring", b"keyring", "monitors", b"monitors", "pool", b"pool", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "user", b"user"]) -> None: ...

global___RBDVolumeSource = RBDVolumeSource

@typing_extensions.final
class ReplicationController(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ReplicationControllerSpec: ...
    @property
    def status(self) -> global___ReplicationControllerStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ReplicationControllerSpec | None = ...,
        status: global___ReplicationControllerStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___ReplicationController = ReplicationController

@typing_extensions.final
class ReplicationControllerCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___ReplicationControllerCondition = ReplicationControllerCondition

@typing_extensions.final
class ReplicationControllerList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicationController]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ReplicationController] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ReplicationControllerList = ReplicationControllerList

@typing_extensions.final
class ReplicationControllerSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SelectorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    replicas: builtins.int
    @property
    def selector(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def template(self) -> global___PodTemplateSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        replicas: builtins.int = ...,
        selector: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        template: global___PodTemplateSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "replicas", b"replicas", "resource_info", b"resource_info", "selector", b"selector", "template", b"template"]) -> None: ...

global___ReplicationControllerSpec = ReplicationControllerSpec

@typing_extensions.final
class ReplicationControllerStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    FULLY_LABELED_REPLICAS_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    READY_REPLICAS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_replicas: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicationControllerCondition]: ...
    fully_labeled_replicas: builtins.int
    observed_generation: builtins.int
    ready_replicas: builtins.int
    replicas: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_replicas: builtins.int = ...,
        conditions: collections.abc.Iterable[global___ReplicationControllerCondition] | None = ...,
        fully_labeled_replicas: builtins.int = ...,
        observed_generation: builtins.int = ...,
        ready_replicas: builtins.int = ...,
        replicas: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_replicas", b"available_replicas", "conditions", b"conditions", "fully_labeled_replicas", b"fully_labeled_replicas", "observed_generation", b"observed_generation", "ready_replicas", b"ready_replicas", "replicas", b"replicas", "resource_info", b"resource_info"]) -> None: ...

global___ReplicationControllerStatus = ReplicationControllerStatus

@typing_extensions.final
class ResourceClaim(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ResourceClaim = ResourceClaim

@typing_extensions.final
class ResourceFieldSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_NAME_FIELD_NUMBER: builtins.int
    DIVISOR_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    container_name: builtins.str
    @property
    def divisor(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2.Quantity: ...
    resource: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        container_name: builtins.str = ...,
        divisor: kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2.Quantity | None = ...,
        resource: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["divisor", b"divisor", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_name", b"container_name", "divisor", b"divisor", "resource", b"resource", "resource_info", b"resource_info"]) -> None: ...

global___ResourceFieldSelector = ResourceFieldSelector

@typing_extensions.final
class ResourceQuota(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ResourceQuotaSpec: ...
    @property
    def status(self) -> global___ResourceQuotaStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ResourceQuotaSpec | None = ...,
        status: global___ResourceQuotaStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___ResourceQuota = ResourceQuota

@typing_extensions.final
class ResourceQuotaList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceQuota]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ResourceQuota] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ResourceQuotaList = ResourceQuotaList

@typing_extensions.final
class ResourceQuotaSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HardEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    HARD_FIELD_NUMBER: builtins.int
    SCOPE_SELECTOR_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def hard(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def scope_selector(self) -> global___ScopeSelector: ...
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hard: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        scope_selector: global___ScopeSelector | None = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scope_selector", b"scope_selector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hard", b"hard", "resource_info", b"resource_info", "scope_selector", b"scope_selector", "scopes", b"scopes"]) -> None: ...

global___ResourceQuotaSpec = ResourceQuotaSpec

@typing_extensions.final
class ResourceQuotaStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HardEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class UsedEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    HARD_FIELD_NUMBER: builtins.int
    USED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def hard(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def used(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hard: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        used: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hard", b"hard", "resource_info", b"resource_info", "used", b"used"]) -> None: ...

global___ResourceQuotaStatus = ResourceQuotaStatus

@typing_extensions.final
class ResourceRequirements(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LimitsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RequestsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLAIMS_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    REQUESTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def claims(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceClaim]: ...
    @property
    def limits(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def requests(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        claims: collections.abc.Iterable[global___ResourceClaim] | None = ...,
        limits: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        requests: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["claims", b"claims", "limits", b"limits", "requests", b"requests", "resource_info", b"resource_info"]) -> None: ...

global___ResourceRequirements = ResourceRequirements

@typing_extensions.final
class SELinuxOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEVEL_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    level: builtins.str
    role: builtins.str
    type: builtins.str
    user: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        level: builtins.str = ...,
        role: builtins.str = ...,
        type: builtins.str = ...,
        user: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["level", b"level", "resource_info", b"resource_info", "role", b"role", "type", b"type", "user", b"user"]) -> None: ...

global___SELinuxOptions = SELinuxOptions

@typing_extensions.final
class ScaleIOPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    GATEWAY_FIELD_NUMBER: builtins.int
    PROTECTION_DOMAIN_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    SSL_ENABLED_FIELD_NUMBER: builtins.int
    STORAGE_MODE_FIELD_NUMBER: builtins.int
    STORAGE_POOL_FIELD_NUMBER: builtins.int
    SYSTEM_FIELD_NUMBER: builtins.int
    VOLUME_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    gateway: builtins.str
    protection_domain: builtins.str
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___SecretReference: ...
    ssl_enabled: builtins.bool
    storage_mode: builtins.str
    storage_pool: builtins.str
    system: builtins.str
    volume_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        gateway: builtins.str = ...,
        protection_domain: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___SecretReference | None = ...,
        ssl_enabled: builtins.bool = ...,
        storage_mode: builtins.str = ...,
        storage_pool: builtins.str = ...,
        system: builtins.str = ...,
        volume_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "gateway", b"gateway", "protection_domain", b"protection_domain", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "ssl_enabled", b"ssl_enabled", "storage_mode", b"storage_mode", "storage_pool", b"storage_pool", "system", b"system", "volume_name", b"volume_name"]) -> None: ...

global___ScaleIOPersistentVolumeSource = ScaleIOPersistentVolumeSource

@typing_extensions.final
class ScaleIOVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    GATEWAY_FIELD_NUMBER: builtins.int
    PROTECTION_DOMAIN_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    SSL_ENABLED_FIELD_NUMBER: builtins.int
    STORAGE_MODE_FIELD_NUMBER: builtins.int
    STORAGE_POOL_FIELD_NUMBER: builtins.int
    SYSTEM_FIELD_NUMBER: builtins.int
    VOLUME_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    gateway: builtins.str
    protection_domain: builtins.str
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___LocalObjectReference: ...
    ssl_enabled: builtins.bool
    storage_mode: builtins.str
    storage_pool: builtins.str
    system: builtins.str
    volume_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        gateway: builtins.str = ...,
        protection_domain: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___LocalObjectReference | None = ...,
        ssl_enabled: builtins.bool = ...,
        storage_mode: builtins.str = ...,
        storage_pool: builtins.str = ...,
        system: builtins.str = ...,
        volume_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "gateway", b"gateway", "protection_domain", b"protection_domain", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "ssl_enabled", b"ssl_enabled", "storage_mode", b"storage_mode", "storage_pool", b"storage_pool", "system", b"system", "volume_name", b"volume_name"]) -> None: ...

global___ScaleIOVolumeSource = ScaleIOVolumeSource

@typing_extensions.final
class ScopeSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_EXPRESSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def match_expressions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScopedResourceSelectorRequirement]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        match_expressions: collections.abc.Iterable[global___ScopedResourceSelectorRequirement] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_expressions", b"match_expressions", "resource_info", b"resource_info"]) -> None: ...

global___ScopeSelector = ScopeSelector

@typing_extensions.final
class ScopedResourceSelectorRequirement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_FIELD_NUMBER: builtins.int
    SCOPE_NAME_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    operator: builtins.str
    scope_name: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        operator: builtins.str = ...,
        scope_name: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operator", b"operator", "resource_info", b"resource_info", "scope_name", b"scope_name", "values", b"values"]) -> None: ...

global___ScopedResourceSelectorRequirement = ScopedResourceSelectorRequirement

@typing_extensions.final
class SeccompProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCALHOST_PROFILE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    localhost_profile: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        localhost_profile: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["localhost_profile", b"localhost_profile", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___SeccompProfile = SeccompProfile

@typing_extensions.final
class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StringDataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    API_VERSION_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    IMMUTABLE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    STRING_DATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    immutable: builtins.bool
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def string_data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        immutable: builtins.bool = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        string_data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "data", b"data", "immutable", b"immutable", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "string_data", b"string_data", "type", b"type"]) -> None: ...

global___Secret = Secret

@typing_extensions.final
class SecretEnvSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OPTIONAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    optional: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        optional: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "optional", b"optional", "resource_info", b"resource_info"]) -> None: ...

global___SecretEnvSource = SecretEnvSource

@typing_extensions.final
class SecretKeySelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    key: builtins.str
    name: builtins.str
    optional: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        name: builtins.str = ...,
        optional: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "name", b"name", "optional", b"optional", "resource_info", b"resource_info"]) -> None: ...

global___SecretKeySelector = SecretKeySelector

@typing_extensions.final
class SecretList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Secret]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Secret] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___SecretList = SecretList

@typing_extensions.final
class SecretProjection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONAL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeyToPath]: ...
    name: builtins.str
    optional: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___KeyToPath] | None = ...,
        name: builtins.str = ...,
        optional: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "name", b"name", "optional", b"optional", "resource_info", b"resource_info"]) -> None: ...

global___SecretProjection = SecretProjection

@typing_extensions.final
class SecretReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___SecretReference = SecretReference

@typing_extensions.final
class SecretVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_MODE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    OPTIONAL_FIELD_NUMBER: builtins.int
    SECRET_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_mode: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeyToPath]: ...
    optional: builtins.bool
    secret_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_mode: builtins.int = ...,
        items: collections.abc.Iterable[global___KeyToPath] | None = ...,
        optional: builtins.bool = ...,
        secret_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_mode", b"default_mode", "items", b"items", "optional", b"optional", "resource_info", b"resource_info", "secret_name", b"secret_name"]) -> None: ...

global___SecretVolumeSource = SecretVolumeSource

@typing_extensions.final
class SecurityContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PRIVILEGE_ESCALATION_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    PRIVILEGED_FIELD_NUMBER: builtins.int
    PROC_MOUNT_FIELD_NUMBER: builtins.int
    READ_ONLY_ROOT_FILESYSTEM_FIELD_NUMBER: builtins.int
    RUN_AS_GROUP_FIELD_NUMBER: builtins.int
    RUN_AS_NON_ROOT_FIELD_NUMBER: builtins.int
    RUN_AS_USER_FIELD_NUMBER: builtins.int
    SE_LINUX_OPTIONS_FIELD_NUMBER: builtins.int
    SECCOMP_PROFILE_FIELD_NUMBER: builtins.int
    WINDOWS_OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allow_privilege_escalation: builtins.bool
    @property
    def capabilities(self) -> global___Capabilities: ...
    privileged: builtins.bool
    proc_mount: builtins.str
    read_only_root_filesystem: builtins.bool
    run_as_group: builtins.int
    run_as_non_root: builtins.bool
    run_as_user: builtins.int
    @property
    def se_linux_options(self) -> global___SELinuxOptions: ...
    @property
    def seccomp_profile(self) -> global___SeccompProfile: ...
    @property
    def windows_options(self) -> global___WindowsSecurityContextOptions: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allow_privilege_escalation: builtins.bool = ...,
        capabilities: global___Capabilities | None = ...,
        privileged: builtins.bool = ...,
        proc_mount: builtins.str = ...,
        read_only_root_filesystem: builtins.bool = ...,
        run_as_group: builtins.int = ...,
        run_as_non_root: builtins.bool = ...,
        run_as_user: builtins.int = ...,
        se_linux_options: global___SELinuxOptions | None = ...,
        seccomp_profile: global___SeccompProfile | None = ...,
        windows_options: global___WindowsSecurityContextOptions | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capabilities", b"capabilities", "resource_info", b"resource_info", "se_linux_options", b"se_linux_options", "seccomp_profile", b"seccomp_profile", "windows_options", b"windows_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_privilege_escalation", b"allow_privilege_escalation", "capabilities", b"capabilities", "privileged", b"privileged", "proc_mount", b"proc_mount", "read_only_root_filesystem", b"read_only_root_filesystem", "resource_info", b"resource_info", "run_as_group", b"run_as_group", "run_as_non_root", b"run_as_non_root", "run_as_user", b"run_as_user", "se_linux_options", b"se_linux_options", "seccomp_profile", b"seccomp_profile", "windows_options", b"windows_options"]) -> None: ...

global___SecurityContext = SecurityContext

@typing_extensions.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ServiceSpec: ...
    @property
    def status(self) -> global___ServiceStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ServiceSpec | None = ...,
        status: global___ServiceStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Service = Service

@typing_extensions.final
class ServiceAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    AUTOMOUNT_SERVICE_ACCOUNT_TOKEN_FIELD_NUMBER: builtins.int
    IMAGE_PULL_SECRETS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    automount_service_account_token: builtins.bool
    @property
    def image_pull_secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LocalObjectReference]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ObjectReference]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        automount_service_account_token: builtins.bool = ...,
        image_pull_secrets: collections.abc.Iterable[global___LocalObjectReference] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        secrets: collections.abc.Iterable[global___ObjectReference] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "automount_service_account_token", b"automount_service_account_token", "image_pull_secrets", b"image_pull_secrets", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "secrets", b"secrets"]) -> None: ...

global___ServiceAccount = ServiceAccount

@typing_extensions.final
class ServiceAccountList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceAccount]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ServiceAccount] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ServiceAccountList = ServiceAccountList

@typing_extensions.final
class ServiceAccountTokenProjection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    EXPIRATION_SECONDS_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    audience: builtins.str
    expiration_seconds: builtins.int
    path: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        expiration_seconds: builtins.int = ...,
        path: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "expiration_seconds", b"expiration_seconds", "path", b"path", "resource_info", b"resource_info"]) -> None: ...

global___ServiceAccountTokenProjection = ServiceAccountTokenProjection

@typing_extensions.final
class ServiceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Service] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ServiceList = ServiceList

@typing_extensions.final
class ServicePort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PROTOCOL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NODE_PORT_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    TARGET_PORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_protocol: builtins.str
    name: builtins.str
    node_port: builtins.int
    port: builtins.int
    protocol: builtins.str
    @property
    def target_port(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_protocol: builtins.str = ...,
        name: builtins.str = ...,
        node_port: builtins.int = ...,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        target_port: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_port", b"target_port"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_protocol", b"app_protocol", "name", b"name", "node_port", b"node_port", "port", b"port", "protocol", b"protocol", "resource_info", b"resource_info", "target_port", b"target_port"]) -> None: ...

global___ServicePort = ServicePort

@typing_extensions.final
class ServiceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SelectorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ALLOCATE_LOAD_BALANCER_NODE_PORTS_FIELD_NUMBER: builtins.int
    CLUSTER_IP_FIELD_NUMBER: builtins.int
    CLUSTER_IPS_FIELD_NUMBER: builtins.int
    EXTERNAL_IPS_FIELD_NUMBER: builtins.int
    EXTERNAL_NAME_FIELD_NUMBER: builtins.int
    EXTERNAL_TRAFFIC_POLICY_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_NODE_PORT_FIELD_NUMBER: builtins.int
    INTERNAL_TRAFFIC_POLICY_FIELD_NUMBER: builtins.int
    IP_FAMILIES_FIELD_NUMBER: builtins.int
    IP_FAMILY_POLICY_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_CLASS_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_IP_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_SOURCE_RANGES_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    PUBLISH_NOT_READY_ADDRESSES_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_CONFIG_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allocate_load_balancer_node_ports: builtins.bool
    cluster_ip: builtins.str
    @property
    def cluster_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def external_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    external_name: builtins.str
    external_traffic_policy: builtins.str
    health_check_node_port: builtins.int
    internal_traffic_policy: builtins.str
    @property
    def ip_families(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ip_family_policy: builtins.str
    load_balancer_class: builtins.str
    load_balancer_ip: builtins.str
    @property
    def load_balancer_source_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServicePort]: ...
    publish_not_ready_addresses: builtins.bool
    @property
    def selector(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    session_affinity: builtins.str
    @property
    def session_affinity_config(self) -> global___SessionAffinityConfig: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allocate_load_balancer_node_ports: builtins.bool = ...,
        cluster_ip: builtins.str = ...,
        cluster_ips: collections.abc.Iterable[builtins.str] | None = ...,
        external_ips: collections.abc.Iterable[builtins.str] | None = ...,
        external_name: builtins.str = ...,
        external_traffic_policy: builtins.str = ...,
        health_check_node_port: builtins.int = ...,
        internal_traffic_policy: builtins.str = ...,
        ip_families: collections.abc.Iterable[builtins.str] | None = ...,
        ip_family_policy: builtins.str = ...,
        load_balancer_class: builtins.str = ...,
        load_balancer_ip: builtins.str = ...,
        load_balancer_source_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        ports: collections.abc.Iterable[global___ServicePort] | None = ...,
        publish_not_ready_addresses: builtins.bool = ...,
        selector: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        session_affinity: builtins.str = ...,
        session_affinity_config: global___SessionAffinityConfig | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "session_affinity_config", b"session_affinity_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocate_load_balancer_node_ports", b"allocate_load_balancer_node_ports", "cluster_ip", b"cluster_ip", "cluster_ips", b"cluster_ips", "external_ips", b"external_ips", "external_name", b"external_name", "external_traffic_policy", b"external_traffic_policy", "health_check_node_port", b"health_check_node_port", "internal_traffic_policy", b"internal_traffic_policy", "ip_families", b"ip_families", "ip_family_policy", b"ip_family_policy", "load_balancer_class", b"load_balancer_class", "load_balancer_ip", b"load_balancer_ip", "load_balancer_source_ranges", b"load_balancer_source_ranges", "ports", b"ports", "publish_not_ready_addresses", b"publish_not_ready_addresses", "resource_info", b"resource_info", "selector", b"selector", "session_affinity", b"session_affinity", "session_affinity_config", b"session_affinity_config", "type", b"type"]) -> None: ...

global___ServiceSpec = ServiceSpec

@typing_extensions.final
class ServiceStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITIONS_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Condition]: ...
    @property
    def load_balancer(self) -> global___LoadBalancerStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conditions: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Condition] | None = ...,
        load_balancer: global___LoadBalancerStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["load_balancer", b"load_balancer", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "load_balancer", b"load_balancer", "resource_info", b"resource_info"]) -> None: ...

global___ServiceStatus = ServiceStatus

@typing_extensions.final
class SessionAffinityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_IP_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def client_ip(self) -> global___ClientIPConfig: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_ip: global___ClientIPConfig | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_ip", b"client_ip", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_ip", b"client_ip", "resource_info", b"resource_info"]) -> None: ...

global___SessionAffinityConfig = SessionAffinityConfig

@typing_extensions.final
class StorageOSPersistentVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    VOLUME_NAME_FIELD_NUMBER: builtins.int
    VOLUME_NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___ObjectReference: ...
    volume_name: builtins.str
    volume_namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___ObjectReference | None = ...,
        volume_name: builtins.str = ...,
        volume_namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "volume_name", b"volume_name", "volume_namespace", b"volume_namespace"]) -> None: ...

global___StorageOSPersistentVolumeSource = StorageOSPersistentVolumeSource

@typing_extensions.final
class StorageOSVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    VOLUME_NAME_FIELD_NUMBER: builtins.int
    VOLUME_NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    read_only: builtins.bool
    @property
    def secret_ref(self) -> global___LocalObjectReference: ...
    volume_name: builtins.str
    volume_namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        read_only: builtins.bool = ...,
        secret_ref: global___LocalObjectReference | None = ...,
        volume_name: builtins.str = ...,
        volume_namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "read_only", b"read_only", "resource_info", b"resource_info", "secret_ref", b"secret_ref", "volume_name", b"volume_name", "volume_namespace", b"volume_namespace"]) -> None: ...

global___StorageOSVolumeSource = StorageOSVolumeSource

@typing_extensions.final
class Sysctl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___Sysctl = Sysctl

@typing_extensions.final
class TCPSocketAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    host: builtins.str
    @property
    def port(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["port", b"port", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___TCPSocketAction = TCPSocketAction

@typing_extensions.final
class Taint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECT_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    TIME_ADDED_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    effect: builtins.str
    key: builtins.str
    @property
    def time_added(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    value: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        effect: builtins.str = ...,
        key: builtins.str = ...,
        time_added: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        value: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "time_added", b"time_added"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["effect", b"effect", "key", b"key", "resource_info", b"resource_info", "time_added", b"time_added", "value", b"value"]) -> None: ...

global___Taint = Taint

@typing_extensions.final
class Toleration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECT_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    TOLERATION_SECONDS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    effect: builtins.str
    key: builtins.str
    operator: builtins.str
    toleration_seconds: builtins.int
    value: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        effect: builtins.str = ...,
        key: builtins.str = ...,
        operator: builtins.str = ...,
        toleration_seconds: builtins.int = ...,
        value: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["effect", b"effect", "key", b"key", "operator", b"operator", "resource_info", b"resource_info", "toleration_seconds", b"toleration_seconds", "value", b"value"]) -> None: ...

global___Toleration = Toleration

@typing_extensions.final
class TopologySelectorLabelRequirement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___TopologySelectorLabelRequirement = TopologySelectorLabelRequirement

@typing_extensions.final
class TopologySelectorTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_LABEL_EXPRESSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def match_label_expressions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopologySelectorLabelRequirement]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        match_label_expressions: collections.abc.Iterable[global___TopologySelectorLabelRequirement] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_label_expressions", b"match_label_expressions", "resource_info", b"resource_info"]) -> None: ...

global___TopologySelectorTerm = TopologySelectorTerm

@typing_extensions.final
class TopologySpreadConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_SELECTOR_FIELD_NUMBER: builtins.int
    MATCH_LABEL_KEYS_FIELD_NUMBER: builtins.int
    MAX_SKEW_FIELD_NUMBER: builtins.int
    MIN_DOMAINS_FIELD_NUMBER: builtins.int
    NODE_AFFINITY_POLICY_FIELD_NUMBER: builtins.int
    NODE_TAINTS_POLICY_FIELD_NUMBER: builtins.int
    TOPOLOGY_KEY_FIELD_NUMBER: builtins.int
    WHEN_UNSATISFIABLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def label_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def match_label_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_skew: builtins.int
    min_domains: builtins.int
    node_affinity_policy: builtins.str
    node_taints_policy: builtins.str
    topology_key: builtins.str
    when_unsatisfiable: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        label_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        match_label_keys: collections.abc.Iterable[builtins.str] | None = ...,
        max_skew: builtins.int = ...,
        min_domains: builtins.int = ...,
        node_affinity_policy: builtins.str = ...,
        node_taints_policy: builtins.str = ...,
        topology_key: builtins.str = ...,
        when_unsatisfiable: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label_selector", b"label_selector", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["label_selector", b"label_selector", "match_label_keys", b"match_label_keys", "max_skew", b"max_skew", "min_domains", b"min_domains", "node_affinity_policy", b"node_affinity_policy", "node_taints_policy", b"node_taints_policy", "resource_info", b"resource_info", "topology_key", b"topology_key", "when_unsatisfiable", b"when_unsatisfiable"]) -> None: ...

global___TopologySpreadConstraint = TopologySpreadConstraint

@typing_extensions.final
class TypedLocalObjectReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_group: builtins.str
    kind: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_group", b"api_group", "kind", b"kind", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___TypedLocalObjectReference = TypedLocalObjectReference

@typing_extensions.final
class TypedObjectReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_group: builtins.str
    kind: builtins.str
    name: builtins.str
    namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_group", b"api_group", "kind", b"kind", "name", b"name", "namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___TypedObjectReference = TypedObjectReference

@typing_extensions.final
class Volume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_ELASTIC_BLOCK_STORE_FIELD_NUMBER: builtins.int
    AZURE_DISK_FIELD_NUMBER: builtins.int
    AZURE_FILE_FIELD_NUMBER: builtins.int
    CEPHFS_FIELD_NUMBER: builtins.int
    CINDER_FIELD_NUMBER: builtins.int
    CONFIG_MAP_FIELD_NUMBER: builtins.int
    CSI_FIELD_NUMBER: builtins.int
    DOWNWARD_A_P_I_FIELD_NUMBER: builtins.int
    EMPTY_DIR_FIELD_NUMBER: builtins.int
    EPHEMERAL_FIELD_NUMBER: builtins.int
    FC_FIELD_NUMBER: builtins.int
    FLEX_VOLUME_FIELD_NUMBER: builtins.int
    FLOCKER_FIELD_NUMBER: builtins.int
    GCE_PERSISTENT_DISK_FIELD_NUMBER: builtins.int
    GIT_REPO_FIELD_NUMBER: builtins.int
    GLUSTERFS_FIELD_NUMBER: builtins.int
    HOST_PATH_FIELD_NUMBER: builtins.int
    ISCSI_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NFS_FIELD_NUMBER: builtins.int
    PERSISTENT_VOLUME_CLAIM_FIELD_NUMBER: builtins.int
    PHOTON_PERSISTENT_DISK_FIELD_NUMBER: builtins.int
    PORTWORX_VOLUME_FIELD_NUMBER: builtins.int
    PROJECTED_FIELD_NUMBER: builtins.int
    QUOBYTE_FIELD_NUMBER: builtins.int
    RBD_FIELD_NUMBER: builtins.int
    SCALE_IO_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    STORAGEOS_FIELD_NUMBER: builtins.int
    VSPHERE_VOLUME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def aws_elastic_block_store(self) -> global___AWSElasticBlockStoreVolumeSource: ...
    @property
    def azure_disk(self) -> global___AzureDiskVolumeSource: ...
    @property
    def azure_file(self) -> global___AzureFileVolumeSource: ...
    @property
    def cephfs(self) -> global___CephFSVolumeSource: ...
    @property
    def cinder(self) -> global___CinderVolumeSource: ...
    @property
    def config_map(self) -> global___ConfigMapVolumeSource: ...
    @property
    def csi(self) -> global___CSIVolumeSource: ...
    @property
    def downward_a_p_i(self) -> global___DownwardAPIVolumeSource: ...
    @property
    def empty_dir(self) -> global___EmptyDirVolumeSource: ...
    @property
    def ephemeral(self) -> global___EphemeralVolumeSource: ...
    @property
    def fc(self) -> global___FCVolumeSource: ...
    @property
    def flex_volume(self) -> global___FlexVolumeSource: ...
    @property
    def flocker(self) -> global___FlockerVolumeSource: ...
    @property
    def gce_persistent_disk(self) -> global___GCEPersistentDiskVolumeSource: ...
    @property
    def git_repo(self) -> global___GitRepoVolumeSource: ...
    @property
    def glusterfs(self) -> global___GlusterfsVolumeSource: ...
    @property
    def host_path(self) -> global___HostPathVolumeSource: ...
    @property
    def iscsi(self) -> global___ISCSIVolumeSource: ...
    name: builtins.str
    @property
    def nfs(self) -> global___NFSVolumeSource: ...
    @property
    def persistent_volume_claim(self) -> global___PersistentVolumeClaimVolumeSource: ...
    @property
    def photon_persistent_disk(self) -> global___PhotonPersistentDiskVolumeSource: ...
    @property
    def portworx_volume(self) -> global___PortworxVolumeSource: ...
    @property
    def projected(self) -> global___ProjectedVolumeSource: ...
    @property
    def quobyte(self) -> global___QuobyteVolumeSource: ...
    @property
    def rbd(self) -> global___RBDVolumeSource: ...
    @property
    def scale_io(self) -> global___ScaleIOVolumeSource: ...
    @property
    def secret(self) -> global___SecretVolumeSource: ...
    @property
    def storageos(self) -> global___StorageOSVolumeSource: ...
    @property
    def vsphere_volume(self) -> global___VsphereVirtualDiskVolumeSource: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        aws_elastic_block_store: global___AWSElasticBlockStoreVolumeSource | None = ...,
        azure_disk: global___AzureDiskVolumeSource | None = ...,
        azure_file: global___AzureFileVolumeSource | None = ...,
        cephfs: global___CephFSVolumeSource | None = ...,
        cinder: global___CinderVolumeSource | None = ...,
        config_map: global___ConfigMapVolumeSource | None = ...,
        csi: global___CSIVolumeSource | None = ...,
        downward_a_p_i: global___DownwardAPIVolumeSource | None = ...,
        empty_dir: global___EmptyDirVolumeSource | None = ...,
        ephemeral: global___EphemeralVolumeSource | None = ...,
        fc: global___FCVolumeSource | None = ...,
        flex_volume: global___FlexVolumeSource | None = ...,
        flocker: global___FlockerVolumeSource | None = ...,
        gce_persistent_disk: global___GCEPersistentDiskVolumeSource | None = ...,
        git_repo: global___GitRepoVolumeSource | None = ...,
        glusterfs: global___GlusterfsVolumeSource | None = ...,
        host_path: global___HostPathVolumeSource | None = ...,
        iscsi: global___ISCSIVolumeSource | None = ...,
        name: builtins.str = ...,
        nfs: global___NFSVolumeSource | None = ...,
        persistent_volume_claim: global___PersistentVolumeClaimVolumeSource | None = ...,
        photon_persistent_disk: global___PhotonPersistentDiskVolumeSource | None = ...,
        portworx_volume: global___PortworxVolumeSource | None = ...,
        projected: global___ProjectedVolumeSource | None = ...,
        quobyte: global___QuobyteVolumeSource | None = ...,
        rbd: global___RBDVolumeSource | None = ...,
        scale_io: global___ScaleIOVolumeSource | None = ...,
        secret: global___SecretVolumeSource | None = ...,
        storageos: global___StorageOSVolumeSource | None = ...,
        vsphere_volume: global___VsphereVirtualDiskVolumeSource | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_elastic_block_store", b"aws_elastic_block_store", "azure_disk", b"azure_disk", "azure_file", b"azure_file", "cephfs", b"cephfs", "cinder", b"cinder", "config_map", b"config_map", "csi", b"csi", "downward_a_p_i", b"downward_a_p_i", "empty_dir", b"empty_dir", "ephemeral", b"ephemeral", "fc", b"fc", "flex_volume", b"flex_volume", "flocker", b"flocker", "gce_persistent_disk", b"gce_persistent_disk", "git_repo", b"git_repo", "glusterfs", b"glusterfs", "host_path", b"host_path", "iscsi", b"iscsi", "nfs", b"nfs", "persistent_volume_claim", b"persistent_volume_claim", "photon_persistent_disk", b"photon_persistent_disk", "portworx_volume", b"portworx_volume", "projected", b"projected", "quobyte", b"quobyte", "rbd", b"rbd", "resource_info", b"resource_info", "scale_io", b"scale_io", "secret", b"secret", "storageos", b"storageos", "vsphere_volume", b"vsphere_volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_elastic_block_store", b"aws_elastic_block_store", "azure_disk", b"azure_disk", "azure_file", b"azure_file", "cephfs", b"cephfs", "cinder", b"cinder", "config_map", b"config_map", "csi", b"csi", "downward_a_p_i", b"downward_a_p_i", "empty_dir", b"empty_dir", "ephemeral", b"ephemeral", "fc", b"fc", "flex_volume", b"flex_volume", "flocker", b"flocker", "gce_persistent_disk", b"gce_persistent_disk", "git_repo", b"git_repo", "glusterfs", b"glusterfs", "host_path", b"host_path", "iscsi", b"iscsi", "name", b"name", "nfs", b"nfs", "persistent_volume_claim", b"persistent_volume_claim", "photon_persistent_disk", b"photon_persistent_disk", "portworx_volume", b"portworx_volume", "projected", b"projected", "quobyte", b"quobyte", "rbd", b"rbd", "resource_info", b"resource_info", "scale_io", b"scale_io", "secret", b"secret", "storageos", b"storageos", "vsphere_volume", b"vsphere_volume"]) -> None: ...

global___Volume = Volume

@typing_extensions.final
class VolumeDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    device_path: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        device_path: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_path", b"device_path", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___VolumeDevice = VolumeDevice

@typing_extensions.final
class VolumeMount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOUNT_PATH_FIELD_NUMBER: builtins.int
    MOUNT_PROPAGATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SUB_PATH_FIELD_NUMBER: builtins.int
    SUB_PATH_EXPR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    mount_path: builtins.str
    mount_propagation: builtins.str
    name: builtins.str
    read_only: builtins.bool
    sub_path: builtins.str
    sub_path_expr: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        mount_path: builtins.str = ...,
        mount_propagation: builtins.str = ...,
        name: builtins.str = ...,
        read_only: builtins.bool = ...,
        sub_path: builtins.str = ...,
        sub_path_expr: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount_path", b"mount_path", "mount_propagation", b"mount_propagation", "name", b"name", "read_only", b"read_only", "resource_info", b"resource_info", "sub_path", b"sub_path", "sub_path_expr", b"sub_path_expr"]) -> None: ...

global___VolumeMount = VolumeMount

@typing_extensions.final
class VolumeNodeAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUIRED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def required(self) -> global___NodeSelector: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        required: global___NodeSelector | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["required", b"required", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["required", b"required", "resource_info", b"resource_info"]) -> None: ...

global___VolumeNodeAffinity = VolumeNodeAffinity

@typing_extensions.final
class VolumeProjection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_MAP_FIELD_NUMBER: builtins.int
    DOWNWARD_A_P_I_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_TOKEN_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def config_map(self) -> global___ConfigMapProjection: ...
    @property
    def downward_a_p_i(self) -> global___DownwardAPIProjection: ...
    @property
    def secret(self) -> global___SecretProjection: ...
    @property
    def service_account_token(self) -> global___ServiceAccountTokenProjection: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        config_map: global___ConfigMapProjection | None = ...,
        downward_a_p_i: global___DownwardAPIProjection | None = ...,
        secret: global___SecretProjection | None = ...,
        service_account_token: global___ServiceAccountTokenProjection | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_map", b"config_map", "downward_a_p_i", b"downward_a_p_i", "resource_info", b"resource_info", "secret", b"secret", "service_account_token", b"service_account_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_map", b"config_map", "downward_a_p_i", b"downward_a_p_i", "resource_info", b"resource_info", "secret", b"secret", "service_account_token", b"service_account_token"]) -> None: ...

global___VolumeProjection = VolumeProjection

@typing_extensions.final
class VsphereVirtualDiskVolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_POLICY_ID_FIELD_NUMBER: builtins.int
    STORAGE_POLICY_NAME_FIELD_NUMBER: builtins.int
    VOLUME_PATH_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fs_type: builtins.str
    storage_policy_id: builtins.str
    storage_policy_name: builtins.str
    volume_path: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fs_type: builtins.str = ...,
        storage_policy_id: builtins.str = ...,
        storage_policy_name: builtins.str = ...,
        volume_path: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_type", b"fs_type", "resource_info", b"resource_info", "storage_policy_id", b"storage_policy_id", "storage_policy_name", b"storage_policy_name", "volume_path", b"volume_path"]) -> None: ...

global___VsphereVirtualDiskVolumeSource = VsphereVirtualDiskVolumeSource

@typing_extensions.final
class WeightedPodAffinityTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POD_AFFINITY_TERM_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def pod_affinity_term(self) -> global___PodAffinityTerm: ...
    weight: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        pod_affinity_term: global___PodAffinityTerm | None = ...,
        weight: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pod_affinity_term", b"pod_affinity_term", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pod_affinity_term", b"pod_affinity_term", "resource_info", b"resource_info", "weight", b"weight"]) -> None: ...

global___WeightedPodAffinityTerm = WeightedPodAffinityTerm

@typing_extensions.final
class WindowsSecurityContextOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GMSA_CREDENTIAL_SPEC_FIELD_NUMBER: builtins.int
    GMSA_CREDENTIAL_SPEC_NAME_FIELD_NUMBER: builtins.int
    HOST_PROCESS_FIELD_NUMBER: builtins.int
    RUN_AS_USER_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    gmsa_credential_spec: builtins.str
    gmsa_credential_spec_name: builtins.str
    host_process: builtins.bool
    run_as_user_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        gmsa_credential_spec: builtins.str = ...,
        gmsa_credential_spec_name: builtins.str = ...,
        host_process: builtins.bool = ...,
        run_as_user_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gmsa_credential_spec", b"gmsa_credential_spec", "gmsa_credential_spec_name", b"gmsa_credential_spec_name", "host_process", b"host_process", "resource_info", b"resource_info", "run_as_user_name", b"run_as_user_name"]) -> None: ...

global___WindowsSecurityContextOptions = WindowsSecurityContextOptions
